@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/fs/ds/ds-fs-factory.h $
- * $Id: ds-fs-factory.h 34716 2008-10-02 16:58:59Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef DS_FILESYSTEM_FACTORY_H
@@ -39,9 +39,6 @@ public:
 	virtual AbstractFSNode *makeCurrentDirectoryFileNode() const;
 	virtual AbstractFSNode *makeFileNodePath(const Common::String &path) const;
 
-protected:
-	DSFilesystemFactory() {};
-
 private:
 	friend class Common::Singleton<SingletonBaseType>;
 };
