@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/keymapper/remap-dialog.h $
- * $Id: remap-dialog.h 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef REMAP_DIALOG_H
@@ -33,8 +33,10 @@
 #include "gui/dialog.h"
 
 namespace GUI {
-	class PopupWidget;
-	class ScrollBarWidget;
+class ButtonWidget;
+class PopUpWidget;
+class ScrollBarWidget;
+class StaticTextWidget;
 }
 
 namespace Common {
