@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/midi/seq.cpp $
- * $Id: seq.cpp 51056 2010-07-20 08:56:53Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 /*
@@ -28,16 +28,22 @@
  *    both the QuickTime support and (vkeybd http://www.alsa-project.org/~iwai/alsa.html)
  */
 
+// Disable symbol overrides so that we can use system headers.
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 #include "common/scummsys.h"
 
 #if defined(USE_SEQ_MIDI)
 
+#include "common/error.h"
+#include "common/textconsole.h"
 #include "common/util.h"
-#include "sound/musicplugin.h"
-#include "sound/mpu401.h"
+#include "audio/musicplugin.h"
+#include "audio/mpu401.h"
 
 #include <fcntl.h>
 #include <unistd.h>
+#include <errno.h>
 
 ////////////////////////////////////////
 //
@@ -51,6 +57,7 @@ class MidiDriver_SEQ : public MidiDriver_MPU401 {
 public:
 	MidiDriver_SEQ();
 	int open();
+	bool isOpen() const { return _isOpen; }
 	void close();
 	void send(uint32 b);
 	void sysEx(const byte *msg, uint16 length);
@@ -82,7 +89,7 @@ int MidiDriver_SEQ::open() {
 		device_name = dev_seq;
 	}
 
-	device = (::open((device_name), O_RDWR, 0));
+	device = ::open((device_name), O_RDWR, 0);
 
 	if ((device_name == NULL) || (device < 0)) {
 		if (device_name == NULL)
@@ -144,10 +151,11 @@ void MidiDriver_SEQ::send(uint32 b) {
 		warning("MidiDriver_SEQ::send: unknown : %08x", (int)b);
 		break;
 	}
-	(void)write(device, buf, position);
+	if (write(device, buf, position) == -1)
+		warning("MidiDriver_SEQ::send: write failed (%s)", strerror(errno));
 }
 
-void MidiDriver_SEQ::sysEx (const byte *msg, uint16 length) {
+void MidiDriver_SEQ::sysEx(const byte *msg, uint16 length) {
 	unsigned char buf [266*4];
 	int position = 0;
 	const byte *chr = msg;
@@ -169,7 +177,8 @@ void MidiDriver_SEQ::sysEx (const byte *msg, uint16 length) {
 	buf[position++] = _device_num;
 	buf[position++] = 0;
 
-	(void)write(device, buf, position);
+	if (write(device, buf, position) == -1)
+		warning("MidiDriver_SEQ::send: write failed (%s)", strerror(errno));
 }
 
 
