@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/dc/audio.cpp $
- * $Id: audio.cpp 32836 2008-06-29 11:51:47Z marcus_c $
+ * $URL$
+ * $Id$
  *
  */
 
 #include <common/scummsys.h>
 #include "engines/engine.h"
-#include "sound/mixer_intern.h"
+#include "audio/mixer_intern.h"
 #include "dc.h"
 
 EXTERN_C void *memcpy4s(void *s1, const void *s2, unsigned int n);
