@@ -18,18 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/dc/dc.h $
- * $Id: dc.h 51478 2010-07-29 19:11:49Z marcus_c $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "backends/base-backend.h"
 #include <graphics/surface.h>
 #include <graphics/colormasks.h>
+#include <graphics/palette.h>
 #include <ronin/soundcommon.h>
 #include "backends/timer/default/default-timer.h"
+#include "backends/audiocd/default/default-audiocd.h"
 #include "backends/fs/fs-factory.h"
-#include "sound/mixer_intern.h"
+#include "audio/mixer_intern.h"
+#ifdef DYNAMIC_MODULES
+#include "backends/plugins/dynamic-plugin.h"
+#endif
 
 #define NUM_BUFFERS 4
 #define SOUND_BUFFER_SHIFT 3
@@ -50,7 +55,29 @@ class DCHardware {
   DCHardware() { dc_init_hardware(); }
 };
 
-class OSystem_Dreamcast : private DCHardware, public BaseBackend, public FilesystemFactory {
+class DCCDManager : public DefaultAudioCDManager {
+  // Initialise the specified CD drive for audio playback.
+  bool openCD(int drive);
+
+  // Poll cdrom status
+  // Returns true if cd audio is playing
+  bool pollCD();
+
+  // Play cdrom audio track
+  void playCD(int track, int num_loops, int start_frame, int duration);
+
+  // Stop cdrom audio track
+  void stopCD();
+
+  // Update cdrom audio status
+  void updateCD();
+};
+
+class OSystem_Dreamcast : private DCHardware, public BaseBackend, public PaletteManager, public FilesystemFactory
+#ifdef DYNAMIC_MODULES
+  , public FilePluginProvider
+#endif
+ {
 
  public:
   OSystem_Dreamcast();
@@ -79,9 +106,14 @@ class OSystem_Dreamcast : private DCHardware, public BaseBackend, public Filesys
   int getGraphicsMode() const;
 
   // Set colors of the palette
+  PaletteManager *getPaletteManager() { return this; }
+protected:
+	// PaletteManager API
   void setPalette(const byte *colors, uint start, uint num);
   void grabPalette(byte *colors, uint start, uint num);
 
+public:
+
   // Determine the pixel format currently in use for screen rendering.
   Graphics::PixelFormat getScreenFormat() const;
 
@@ -135,21 +167,7 @@ class OSystem_Dreamcast : private DCHardware, public BaseBackend, public Filesys
   // Returns true if an event was retrieved.
   bool pollEvent(Common::Event &event);
 
-  // Initialise the specified CD drive for audio playback.
-  bool openCD(int drive);
-
-  // Poll cdrom status
-  // Returns true if cd audio is playing
-  bool pollCD();
-
-  // Play cdrom audio track
-  void playCD(int track, int num_loops, int start_frame, int duration);
-
-  // Stop cdrom audio track
-  void stopCD();
-
-  // Update cdrom audio status
-  void updateCD();
+  AudioCDManager *getAudioCDManager() { return _cdManager; }
 
   // Quit
   void quit();
@@ -194,6 +212,7 @@ class OSystem_Dreamcast : private DCHardware, public BaseBackend, public Filesys
   Audio::MixerImpl *_mixer;
   DefaultTimerManager *_timer;
   SoftKeyboard _softkbd;
+  DCCDManager *_cdManager;
 
   int _ms_cur_x, _ms_cur_y, _ms_cur_w, _ms_cur_h, _ms_old_x, _ms_old_y;
   int _ms_hotspot_x, _ms_hotspot_y, _ms_visible, _devpoll, _last_screen_refresh;
@@ -236,6 +255,17 @@ class OSystem_Dreamcast : private DCHardware, public BaseBackend, public Filesys
 
   Common::SeekableReadStream *createConfigReadStream();
   Common::WriteStream *createConfigWriteStream();
+
+  void logMessage(LogMessageType::Type type, const char *message);
+  Common::String getSystemLanguage() const;
+
+#ifdef DYNAMIC_MODULES
+  class DCPlugin;
+
+ protected:
+  Plugin* createPlugin(const Common::FSNode &node) const;
+  bool isPluginFilename(const Common::FSNode &node) const;
+#endif
 };
 
 
