@@ -18,21 +18,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/ds/arm9/source/dsoptions.cpp $
- * $Id: dsoptions.cpp 51473 2010-07-29 16:24:08Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "dsoptions.h"
 #include "dsmain.h"
 #include "gui/dialog.h"
-#include "gui/GuiManager.h"
-#include "gui/ListWidget.h"
-#include "gui/TabWidget.h"
+#include "gui/gui-manager.h"
+#include "gui/widgets/list.h"
+#include "gui/widgets/tab.h"
 #include "osystem_ds.h"
 #include "engines/scumm/scumm.h"
 #include "touchkeyboard.h"
-#include "gui/PopUpWidget.h"
+#include "gui/widgets/popup.h"
 
 #include "common/translation.h"
 
