@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/gp2x/gp2x-hw.cpp $
- * $Id: gp2x-hw.cpp 52645 2010-09-08 21:43:46Z djwillis $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,6 +30,9 @@
  *
  */
 
+// Disable symbol overrides so that we can use system headers.
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 #include "gp2x-common.h"
 
 #include "gp2x-hw.h"
@@ -48,6 +51,10 @@
 #include <sys/time.h>
 #include <unistd.h>
 
+extern "C" {
+static unsigned long gp2x_dev[8]={0,0,0,0,0,0,0,0};//, gp2x_ticks_per_second;
+}
+
 namespace GP2X_HW {
 
 enum {
