@@ -18,16 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/iphone/osys_events.cpp $
- * $Id: osys_events.cpp 49792 2010-06-15 11:00:57Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
+// Disable symbol overrides so that we can use system headers.
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 #include "gui/message.h"
 #include "common/translation.h"
 
 #include "osys_main.h"
 
+static const int kQueuedInputEventDelay = 50;
 
 bool OSystem_IPHONE::pollEvent(Common::Event &event) {
 	//printf("pollEvent()\n");
@@ -39,14 +43,7 @@ bool OSystem_IPHONE::pollEvent(Common::Event &event) {
 		_timerCallbackNext = curTime + _timerCallbackTimer;
 	}
 
-	if (_needEventRestPeriod) {
-		// Workaround: Some engines can't handle mouse-down and mouse-up events
-		// appearing right after each other, without a call returning no input in between.
-		_needEventRestPeriod = false;
-		return false;
-	}
-
-	if (_queuedInputEvent.type != (Common::EventType)0) {
+	if (_queuedInputEvent.type != (Common::EventType)0 && curTime >= _queuedEventTime) {
 		event = _queuedInputEvent;
 		_queuedInputEvent.type = (Common::EventType)0;
 		return true;
@@ -60,16 +57,31 @@ bool OSystem_IPHONE::pollEvent(Common::Event &event) {
 		int y = 0;
 		switch (_screenOrientation) {
 			case kScreenOrientationPortrait:
-				x = (int)(xUnit * _screenWidth);
-				y = (int)(yUnit * _screenHeight);
+				if (_overlayVisible) {
+					x = (int)(xUnit * _overlayWidth);
+					y = (int)(yUnit * _overlayHeight);
+				} else {
+					x = (int)(xUnit * _screenWidth);
+					y = (int)(yUnit * _screenHeight);
+				}
 				break;
 			case kScreenOrientationLandscape:
-				x = (int)(yUnit * _screenWidth);
-				y = (int)((1.0 - xUnit) * _screenHeight);
+				if (_overlayVisible) {
+					x = (int)(yUnit * _overlayWidth);
+					y = (int)((1.0 - xUnit) * _overlayHeight);
+				} else {
+					x = (int)(yUnit * _screenWidth);
+					y = (int)((1.0 - xUnit) * _screenHeight);
+				}
 				break;
 			case kScreenOrientationFlippedLandscape:
-				x = (int)((1.0 - yUnit) * _screenWidth);
-				y = (int)(xUnit * _screenHeight);
+				if (_overlayVisible) {
+					x = (int)((1.0 - yUnit) * _overlayWidth);
+					y = (int)(xUnit * _overlayHeight);
+				} else {
+					x = (int)((1.0 - yUnit) * _screenWidth);
+					y = (int)(xUnit * _screenHeight);
+				}
 				break;
 		}
 
@@ -176,7 +188,7 @@ bool OSystem_IPHONE::handleEvent_mouseUp(Common::Event &event, int x, int y) {
 			_queuedInputEvent.mouse.x = _mouseX;
 			_queuedInputEvent.mouse.y = _mouseY;
 			_lastMouseTap = getMillis();
-			_needEventRestPeriod = true;
+			_queuedEventTime = _lastMouseTap + kQueuedInputEventDelay;
 		} else
 			return false;
 	}
@@ -217,7 +229,7 @@ bool OSystem_IPHONE::handleEvent_secondMouseUp(Common::Event &event, int x, int
 			event.kbd.flags = _queuedInputEvent.kbd.flags = 0;
 			event.kbd.keycode = _queuedInputEvent.kbd.keycode = Common::KEYCODE_ESCAPE;
 			event.kbd.ascii = _queuedInputEvent.kbd.ascii = Common::ASCII_ESCAPE;
-			_needEventRestPeriod = true;
+			_queuedEventTime = curTime + kQueuedInputEventDelay;
 			_lastSecondaryTap = 0;
 		} else if (!_mouseClickAndDragEnabled) {
 			//printf("Rightclick!\n");
@@ -228,7 +240,7 @@ bool OSystem_IPHONE::handleEvent_secondMouseUp(Common::Event &event, int x, int
 			_queuedInputEvent.mouse.x = _mouseX;
 			_queuedInputEvent.mouse.y = _mouseY;
 			_lastSecondaryTap = curTime;
-			_needEventRestPeriod = true;
+			_queuedEventTime = curTime + kQueuedInputEventDelay;
 		} else {
 			//printf("Right nothing!\n");
 			return false;
@@ -262,15 +274,18 @@ bool OSystem_IPHONE::handleEvent_mouseDragged(Common::Event &event, int x, int y
 		mouseNewPosX = (int)(_mouseX - deltaX / 0.5f);
 		mouseNewPosY = (int)(_mouseY - deltaY / 0.5f);
 
+		int widthCap = _overlayVisible ? _overlayWidth : _screenWidth;
+		int heightCap = _overlayVisible ? _overlayHeight : _screenHeight;
+
 		if (mouseNewPosX < 0)
 			mouseNewPosX = 0;
-		else if (mouseNewPosX > _screenWidth)
-			mouseNewPosX = _screenWidth;
+		else if (mouseNewPosX > widthCap)
+			mouseNewPosX = widthCap;
 
 		if (mouseNewPosY < 0)
 			mouseNewPosY = 0;
-		else if (mouseNewPosY > _screenHeight)
-			mouseNewPosY = _screenHeight;
+		else if (mouseNewPosY > heightCap)
+			mouseNewPosY = heightCap;
 
 	} else {
 		mouseNewPosX = x;
@@ -313,7 +328,7 @@ bool OSystem_IPHONE::handleEvent_mouseSecondDragged(Common::Event &event, int x,
 			event.kbd.flags = _queuedInputEvent.kbd.flags = 0;
 			event.kbd.keycode = _queuedInputEvent.kbd.keycode = Common::KEYCODE_F5;
 			event.kbd.ascii = _queuedInputEvent.kbd.ascii = Common::ASCII_F5;
-			_needEventRestPeriod = true;
+			_queuedEventTime = getMillis() + kQueuedInputEventDelay;
 			return true;
 		}
 
@@ -442,7 +457,7 @@ void  OSystem_IPHONE::handleEvent_keyPressed(Common::Event &event, int keyPresse
 	event.kbd.flags = _queuedInputEvent.kbd.flags = 0;
 	event.kbd.keycode = _queuedInputEvent.kbd.keycode = (Common::KeyCode)keyPressed;
 	event.kbd.ascii = _queuedInputEvent.kbd.ascii = ascii;
-	_needEventRestPeriod = true;
+	_queuedEventTime = getMillis() + kQueuedInputEventDelay;
 }
 
 bool OSystem_IPHONE::handleEvent_swipe(Common::Event &event, int direction) {
@@ -509,7 +524,7 @@ bool OSystem_IPHONE::handleEvent_swipe(Common::Event &event, int direction) {
 	event.type = Common::EVENT_KEYDOWN;
 	_queuedInputEvent.type = Common::EVENT_KEYUP;
 	event.kbd.flags = _queuedInputEvent.kbd.flags = 0;
-	_needEventRestPeriod = true;
+	_queuedEventTime = getMillis() + kQueuedInputEventDelay;
 
 	return true;
 }
