@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/n64/osys_n64_base.cpp $
- * $Id: osys_n64_base.cpp 52644 2010-09-08 21:18:22Z hkz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -112,6 +112,10 @@ OSystem_N64::OSystem_N64() {
 
 	// Clear palette array
 	_screenPalette = (uint16*)memalign(8, 256 * sizeof(uint16));
+#ifndef N64_EXTREME_MEMORY_SAVING
+	_screenExactPalette = (uint8*)memalign(8, 256 * 3);
+	memset(_screenExactPalette, 0, 256 * 3);
+#endif
 	memset(_screenPalette, 0, 256 * sizeof(uint16));
 	memset(_cursorPalette, 0, 256 * sizeof(uint16));
 
@@ -346,9 +350,13 @@ int16 OSystem_N64::getWidth() {
 }
 
 void OSystem_N64::setPalette(const byte *colors, uint start, uint num) {
+#ifndef N64_EXTREME_MEMORY_SAVING
+	memcpy(_screenExactPalette + start * 3, colors, num * 3);
+#endif
+
 	for (uint i = 0; i < num; ++i) {
 		_screenPalette[start + i] = colRGB888toBGR555(colors[2], colors[1], colors[0]);
-		colors += 4;
+		colors += 3;
 	}
 
 	// If cursor uses the game palette, we need to rebuild the hicolor buffer
@@ -395,6 +403,7 @@ void OSystem_N64::rebuildOffscreenMouseBuffer(void) {
 }
 
 void OSystem_N64::grabPalette(byte *colors, uint start, uint num) {
+#ifdef N64_EXTREME_MEMORY_SAVING  // This way loses precisions
 	uint32 i;
 	uint16 color;
 
@@ -405,8 +414,10 @@ void OSystem_N64::grabPalette(byte *colors, uint start, uint num) {
 		*colors++ = ((color & 0x1F) << 3);
 		*colors++ = (((color >> 5) & 0x1F) << 3);
 		*colors++ = (((color >> 10) & 0x1F) << 3);
-		*colors++ = 0;
 	}
+#else
+	memcpy(colors, _screenExactPalette + start * 3, num * 3);
+#endif
 
 	return;
 }
@@ -414,7 +425,7 @@ void OSystem_N64::grabPalette(byte *colors, uint start, uint num) {
 void OSystem_N64::setCursorPalette(const byte *colors, uint start, uint num) {
 	for (uint i = 0; i < num; ++i) {
 		_cursorPalette[start + i] = colRGB888toBGR555(colors[2], colors[1], colors[0]);
-		colors += 4;
+		colors += 3;
 	}
 
 	_cursorPaletteDisabled = false;
@@ -859,7 +870,7 @@ void OSystem_N64::getTimeAndDate(TimeDate &t) const {
 	// No RTC inside the N64, read mips timer to simulate
 	// passing of time, not a perfect solution, but can't think
 	// of anything better.
-	
+
 	uint32 now = getMilliTick();
 
 	t.tm_sec  = (now / 1000) % 60;
