@@ -2,26 +2,27 @@
 ##################################################################################################################
 
 	@WorkingEngines = qw(
-		scumm agos sky queen gob groovie saga drascula 
+		scumm agos sky queen gob groovie saga drascula
 		kyra lure agi touche parallaction cine
-		cruise made m4 tinsel tucker sword1 sword2 draci sci teenagent mohawk hugo
+		cruise made m4 tinsel tucker sword1 sword2 draci sci teenagent mohawk hugo toon lastexpress tsage
 	);
-	
+
 	@WorkingEngines_1st = qw(
-		scumm queen groovie saga drascula 
+		scumm queen groovie saga drascula
 		touche parallaction cine
-?		cruise made m4 tucker 
+?		cruise made m4 tucker lastexpress
 	);
-	
+
 	@WorkingEngines_2nd = qw(
-		agos sky gob 
-		kyra lure agi tinsel
-		sword1 sword2 draci sci teenagent hugo
+		agos sky gob kyra lure 
+		agi tinsel sword1 sword2 
+		draci sci teenagent hugo toon
+		tsage
 	);
 
 	@TestingEngines = qw(
-		 
-	);	
+
+	);
 
 	@EnablableEngines = (@WorkingEngines, @TestingEngines);
 
@@ -36,16 +37,16 @@
 	#disabled subengines lol saga2 personal nightmare
 
 	%UseableFeatures = (
-		'zlib'		=> 'zlib.lib', 
-		'mad'		=> 'libmad.lib', 
+		'zlib'		=> 'zlib.lib',
+		'mad'		=> 'libmad.lib',
 		'tremor'	=> 'libtremor.lib',
 		'flac'		=> 'libflac.lib'
 	);
-	
+
 	# these are normally enabled for each variation
 	#$DefaultFeatures = qw(zlib,mad);
-	$DefaultFeatures = qw(zlib,mad,tremor,flac);		
-													
+	$DefaultFeatures = qw(zlib,mad,tremor,flac);
+
 ##################################################################################################################
 	##
 	## General system information, based on $COMPUTERNAME, so this way
@@ -62,13 +63,13 @@
 		$SkipExistingPackages = 0;
 		$ReallyQuiet = 0;
 		$DevBase = "C:\\S";
-		
+
 		# specify an optional FTP server to upload to after each Build+Package (can leave empty)
 		#$FTP_Host = "host.com";
 		$FTP_User = "something";
 		$FTP_Pass = "password";
 		$FTP_Dir  = "cvsbuilds";
-	
+
 		# What Platform SDKs are installed on this machine?
 		# possible SDKs: ("UIQ2", UIQ3", "S60v1", "S60v2", "S60v3", "S80", "S90")
 		# Note1: the \epoc32 directory needs to be in these rootdirs
@@ -93,10 +94,10 @@
 			$SDK_LibraryDirs{'ALL'}{'zlib.lib'}		= "$DevBase\\zlib-1.2.2\\epoc";
 			#$SDK_LibraryDirs{'ALL'}{'libmad.lib'}	= "$DevBase\\libmad-0.15.1b\\group";
 			$SDK_LibraryDirs{'ALL'}{'libtremor.lib'}= "$DevBase\\tremor\\epoc";
-			
+
 			## SDL 1.2.12 / AnotherGuest / Symbian version
 			my $SdlBase = "$DevBase\\SDL-1.2.12-ag\\Symbian";
-			#$SDK_LibraryDirs{'S60v1'}{'esdl.lib'}	= "$SdlBase\\S60"; // unsupported? 
+			#$SDK_LibraryDirs{'S60v1'}{'esdl.lib'}	= "$SdlBase\\S60"; // unsupported?
 			#$SDK_LibraryDirs{'S60v2'}{'esdl.lib'}	= "$SdlBase\\S60v2";
 			$SDK_LibraryDirs{'S60v3'}{'esdl.lib'}	= "$SdlBase\\S60v3";
 			#$SDK_LibraryDirs{'S80'}{'esdl.lib'}	= "$SdlBase\\S80";
@@ -107,7 +108,7 @@
 			## HardlySupported(TM) :P
 			#$SDK_LibraryDirs{'ALL'}{'libmpeg2.lib'} = "$DevBase\\mpeg2dec-0.4.0\\epoc";
 		}
-		
+
 		# now you can add $VariationSets only built on this PC below this line :)
 
 		#$VariationSets{'ALL'}{'scumm'} = "$DefaultFeatures scumm scumm_7_8 he";
@@ -296,14 +297,14 @@
 	#   scummvm-051101-SymbianS90_queen.sis
 
 	# NOTE: empty $VariationSets{''} string instead of 'ALL' = easy way to disable pkg!
-	
+
 	if (1) # all regular combo's
 	{
 		# the first one includes all SDKs & release-ready engines
-	
+
 			$VariationSets{'ALL'}{'all'} = "$DefaultFeatures @WorkingEngines @EnablableSubEngines";
-			$VariationSets{'ALL'}{'1St'} = "$DefaultFeatures @WorkingEngines_1st @EnablableSubEngines";
-			$VariationSets{'ALL'}{'2nd'} = "$DefaultFeatures @WorkingEngines_2nd @EnablableSubEngines";
+#			$VariationSets{'ALL'}{'1St'} = "$DefaultFeatures @WorkingEngines_1st @EnablableSubEngines";
+#			$VariationSets{'ALL'}{'2nd'} = "$DefaultFeatures @WorkingEngines_2nd @EnablableSubEngines";
 		# now one for each ready-for-release engine
 		if (0)
 		{
@@ -324,16 +325,16 @@
 			}
 		}
 		# below here you could specify weird & experimental combinations, non-ready engines
-	
+
 			# Separate version for the broken sword engines (1&2)
 			#$VariationSets{'ALL'}{'brokensword'} = "$DefaultFeatures sword1 sword2";
-		
+
 			# Separate version for Scumm games (COMI) since memory usage might be high
-			#$VariationSets{'ALL'}{'scumm'} = "$DefaultFeatures scumm scumm_7_8 he";			
-	
+			#$VariationSets{'ALL'}{'scumm'} = "$DefaultFeatures scumm scumm_7_8 he";
+
 			# for mega-fast-testing only plz! Warning: contains to engines!
 			#$VariationSets{'ALL'}{'fast_empty'} = "";
-	
+
 	} # end quick-n-fast if (1|0)
 
 
