@@ -21,8 +21,7 @@
 
 #include <malloc.h>
 
-#include <gfx/gfx.h>
-#include <gfx/gfx_con.h>
+#include <gxflux/gfx_con.h>
 
 #include "common/config-manager.h"
 #include "graphics/conversion.h"
@@ -209,7 +208,7 @@ Graphics::PixelFormat OSystem_Wii::getScreenFormat() const {
 	return _pfGame;
 }
 
-Common::List<Graphics::PixelFormat> OSystem_Wii::getSupportedFormats() {
+Common::List<Graphics::PixelFormat> OSystem_Wii::getSupportedFormats() const {
 	Common::List<Graphics::PixelFormat> res;
 	res.push_back(_pfRGB565);
 	res.push_back(Graphics::PixelFormat::createFormatCLUT8());
@@ -321,31 +320,29 @@ int16 OSystem_Wii::getHeight() {
 
 void OSystem_Wii::setPalette(const byte *colors, uint start, uint num) {
 #ifdef USE_RGB_COLOR
-	// work around nonsense calls
-	if (_pfGame.bytesPerPixel > 1)
-		return;
+	assert(_pfGame.bytesPerPixel == 1);
 #endif
 
 	const byte *s = colors;
 	u16 *d = _texGame.palette;
 
-	for (uint i = 0; i < num; ++i) {
+	for (uint i = 0; i < num; ++i, s +=3)
 		d[start + i] = Graphics::RGBToColor<Graphics::ColorMasks<565> >(s[0], s[1], s[2]);
-		s += 4;
-	}
 
 	gfx_tex_flush_palette(&_texGame);
 
+	s = colors;
+	d = _cursorPalette;
+
+	for (uint i = 0; i < num; ++i, s += 3) {
+		d[start + i] = Graphics::ARGBToColor<Graphics::ColorMasks<3444> >(0xff, s[0], s[1], s[2]);
+	}
+
 	if (_cursorPaletteDisabled) {
 		assert(_texMouse.palette);
 
-		s = colors;
-		d = _texMouse.palette;
-
-		for (uint i = 0; i < num; ++i) {
-			d[start + i] = Graphics::ARGBToColor<Graphics::ColorMasks<3444> >(0xff, s[0], s[1], s[2]);
-			s += 4;
-		}
+		memcpy((u8 *)_texMouse.palette + start * 2,
+			(u8 *)_cursorPalette + start * 2, num * 2);
 
 		_cursorPaletteDirty = true;
 	}
@@ -353,22 +350,18 @@ void OSystem_Wii::setPalette(const byte *colors, uint start, uint num) {
 
 void OSystem_Wii::grabPalette(byte *colors, uint start, uint num) {
 #ifdef USE_RGB_COLOR
-	// work around nonsense calls from graphics/scaler/thumbnail_intern.cpp
-	if (_pfGame.bytesPerPixel > 1)
-		return;
+	assert(_pfGame.bytesPerPixel == 1);
 #endif
 
 	u16 *s = _texGame.palette;
 	byte *d = colors;
 
 	u8 r, g, b;
-	for (uint i = 0; i < num; ++i) {
+	for (uint i = 0; i < num; ++i, d += 3) {
 		Graphics::colorToRGB<Graphics::ColorMasks<565> >(s[start + i], r, g, b);
 		d[0] = r;
 		d[1] = g;
 		d[2] = b;
-		d[3] = 0xff;
-		d += 4;
 	}
 }
 
@@ -393,10 +386,8 @@ void OSystem_Wii::setCursorPalette(const byte *colors, uint start, uint num) {
 	const byte *s = colors;
 	u16 *d = _texMouse.palette;
 
-	for (uint i = 0; i < num; ++i) {
+	for (uint i = 0; i < num; ++i, s += 3)
 		d[start + i] = Graphics::ARGBToColor<Graphics::ColorMasks<3444> >(0xff, s[0], s[1], s[2]);
-		s += 4;
-	}
 
 	_cursorPaletteDirty = true;
 }
@@ -446,6 +437,22 @@ void OSystem_Wii::copyRectToScreen(const byte *buf, int pitch, int x, int y,
 	_gameDirty = true;
 }
 
+bool OSystem_Wii::needsScreenUpdate() {
+	if (getMillis() - _lastScreenUpdate < 1000 / MAX_FPS)
+		return false;
+
+	if (_gameRunning && _gameDirty)
+		return true;
+
+	if (_overlayVisible && _overlayDirty)
+		return true;
+
+	if (_mouseVisible && _texMouse.palette && _cursorPaletteDirty)
+		return true;
+
+	return false;
+}
+
 void OSystem_Wii::updateScreen() {
 	static f32 ar;
 	static gfx_screen_coords_t cc;
