@@ -18,33 +18,33 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/wince/CEDevice.h $
- * $Id: CEDevice.h 28966 2007-09-19 08:40:12Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
-#ifndef CEDEVICE
-#define CEDEVICE
+#ifndef CEDEVICE_H
+#define CEDEVICE_H
 
 #include "common/scummsys.h"
 #include "common/system.h"
 #include "common/str.h"
 
 class CEDevice {
-	public:
-		static void init();
-		static void end();
-		static void wakeUp();
-		static bool hasPocketPCResolution();
-		static bool hasSquareQVGAResolution();
-		static bool hasDesktopResolution();
-		static bool hasWideResolution();
-		static bool hasSmartphoneResolution();
-		static bool isSmartphone();
+public:
+	static void init();
+	static void end();
+	static void wakeUp();
+	static bool hasPocketPCResolution();
+	static bool hasSquareQVGAResolution();
+	static bool hasDesktopResolution();
+	static bool hasWideResolution();
+	static bool hasSmartphoneResolution();
+	static bool isSmartphone();
 
-	private:
-		static DWORD reg_access(TCHAR *key, TCHAR *val, DWORD data);
-		static void backlight_xchg();
+private:
+	static DWORD reg_access(const TCHAR *key, const TCHAR *val, DWORD data);
+	static void backlight_xchg();
 };
 
 #endif
