@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/wince/CELauncherDialog.h $
- * $Id: CELauncherDialog.h 34716 2008-10-02 16:58:59Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#ifndef CELAUNCHERDIALOG
-#define CELAUNCHERDIALOG
+#ifndef CELAUNCHERDIALOG_H
+#define CELAUNCHERDIALOG_H
 
 #include "base/plugins.h"
 #include "common/fs.h"
