@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/wince/CEgui/Panel.h $
- * $Id: Panel.h 28966 2007-09-19 08:40:12Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
-#ifndef CEGUI_PANEL
-#define CEGUI_PANEL
+#ifndef CEGUI_PANEL_H
+#define CEGUI_PANEL_H
 
 #include "common/scummsys.h"
 #include "common/system.h"
@@ -40,23 +40,24 @@ using Common::HashMap;
 
 namespace CEGUI {
 
-	class Panel : public Toolbar {
-	public:
-		Panel(int interleave_first, int interleave);
-		virtual bool draw(SDL_Surface *surface);
-		virtual ~Panel();
-		bool add(const String &name, const PanelItem *item);
-		void clear();
-		virtual void forceRedraw();
-		virtual bool action(int x, int y, bool pushed);
-	private:
+class Panel : public Toolbar {
+public:
+	Panel(int interleave_first, int interleave);
+	virtual bool draw(SDL_Surface *surface);
+	virtual ~Panel();
+	bool add(const String &name, const PanelItem *item);
+	void clear();
+	virtual void forceRedraw();
+	virtual bool action(int x, int y, bool pushed);
+private:
 
-		typedef HashMap<String, PanelItem*, Common::IgnoreCase_Hash , Common::IgnoreCase_EqualTo> ItemMap;
+	typedef HashMap<String, PanelItem *, Common::IgnoreCase_Hash , Common::IgnoreCase_EqualTo> ItemMap;
 
-		ItemMap _itemsMap;
-		int _interleave;
-		int _currentItem;
-	};
-}
+	ItemMap _itemsMap;
+	int _interleave;
+	int _currentItem;
+};
+
+} // End of namespace CEGUI
 
 #endif
