@@ -18,31 +18,33 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/wince/CEgui/SDL_ImageResource.h $
- * $Id: SDL_ImageResource.h 28966 2007-09-19 08:40:12Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
-#ifndef CEGUI_SDL_IMAGERESOURCE
-#define CEGUI_SDL_IMAGERESOURCE
+#ifndef CEGUI_SDL_IMAGERESOURCE_H
+#define CEGUI_SDL_IMAGERESOURCE_H
 
 #include "common/scummsys.h"
 #include "common/system.h"
 
-#include "SDL.h"
+struct SDL_Surface;
 
 namespace CEGUI {
-	class SDL_ImageResource {
-	public:
-		SDL_ImageResource();
-		SDL_Surface* load(WORD resourceID);
-		SDL_Surface* get();
-		int height();
-		int width();
-		virtual ~SDL_ImageResource();
-	private:
-		SDL_Surface *_surface;
-	};
-}
+
+class SDL_ImageResource {
+public:
+	SDL_ImageResource();
+	SDL_Surface *load(WORD resourceID);
+	SDL_Surface *get();
+	int height();
+	int width();
+	virtual ~SDL_ImageResource();
+private:
+	SDL_Surface *_surface;
+};
+
+} // End of namespace CEGUI
 
 #endif
