@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/wince/CEgui/Toolbar.cpp $
- * $Id: Toolbar.cpp 28966 2007-09-19 08:40:12Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,12 +27,12 @@
 
 namespace CEGUI {
 
-	// Not to be drawn on game screen !
-	Toolbar::Toolbar() : GUIElement(0, 0, 320, 40)
-	{
-	}
-
-
-	Toolbar::~Toolbar() {
-	}
+// Not to be drawn on game screen !
+Toolbar::Toolbar() : GUIElement(0, 0, 320, 40) {
 }
+
+
+Toolbar::~Toolbar() {
+}
+
+} // End of namespace CEGUI
