@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/plugins/dynamic-plugin.h $
- * $Id: dynamic-plugin.h 32627 2008-06-09 03:59:16Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #define BACKENDS_PLUGINS_DYNAMICPLUGIN_H
 
 #include "base/plugins.h"
+#include "common/textconsole.h"
 
 
 class DynamicPlugin : public Plugin {
@@ -37,7 +38,12 @@ protected:
 
 	virtual VoidFunc findSymbol(const char *symbol) = 0;
 
+	const Common::String _filename;
+
 public:
+	DynamicPlugin(const Common::String &filename) :
+		_filename(filename) {}
+
 	virtual bool loadPlugin() {
 		// Validate the plugin API version
 		IntFunc verFunc = (IntFunc)findSymbol("PLUGIN_getVersion");
@@ -97,6 +103,10 @@ public:
 	virtual void unloadPlugin() {
 		delete _pluginObject;
 	}
+
+	virtual const char *getFileName() const {
+		return _filename.c_str();
+	}
 };
 
 #endif
