@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/plugins/win32/win32-provider.cpp $
- * $Id: win32-provider.cpp 50346 2010-06-26 21:55:52Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/scummsys.h"
+
 #if defined(DYNAMIC_MODULES) && defined(_WIN32)
 
 #include "backends/plugins/win32/win32-provider.h"
@@ -49,7 +51,6 @@ private:
 
 protected:
 	void *_dlHandle;
-	Common::String _filename;
 
 	virtual VoidFunc findSymbol(const char *symbol) {
 		#ifndef _WIN32_WCE
@@ -65,7 +66,7 @@ protected:
 
 public:
 	Win32Plugin(const Common::String &filename)
-		: _dlHandle(0), _filename(filename) {}
+		: DynamicPlugin(filename), _dlHandle(0) {}
 
 	bool loadPlugin() {
 		assert(!_dlHandle);
