@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/timer/default/default-timer.cpp $
- * $Id: default-timer.cpp 43627 2009-08-22 00:41:22Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 #include "common/scummsys.h"
@@ -34,7 +34,7 @@ struct TimerSlot {
 	uint32 interval;	// in microseconds
 
 	uint32 nextFireTime;	// in milliseconds
-	uint32 nextFireTimeMicro;	// mircoseconds part of nextFire
+	uint32 nextFireTimeMicro;	// microseconds part of nextFire
 
 	TimerSlot *next;
 };
