@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/vkeybd/polygon.cpp $
- * $Id: polygon.cpp 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/scummsys.h"
+
 #ifdef ENABLE_VKEYBD
 
 #include "backends/vkeybd/polygon.h"
