@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/vkeybd/virtual-keyboard.cpp $
- * $Id: virtual-keyboard.cpp 50483 2010-06-29 06:38:00Z spalek $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/scummsys.h"
+
 #ifdef ENABLE_VKEYBD
 
 #include "backends/vkeybd/virtual-keyboard.h"
@@ -31,6 +33,7 @@
 #include "backends/vkeybd/virtual-keyboard-parser.h"
 #include "backends/vkeybd/keycode-descriptions.h"
 #include "common/config-manager.h"
+#include "common/textconsole.h"
 #include "common/unzip.h"
 
 #define KEY_START_CHAR ('[')
@@ -69,7 +72,7 @@ void VirtualKeyboard::reset() {
 	deleteEvents();
 	_modes.clear();
 	_initialMode = _currentMode = 0;
-	_hAlignment = kAlignCentre;
+	_hAlignment = kAlignCenter;
 	_vAlignment = kAlignBottom;
 	_keyQueue.clear();
 	_loaded = false;
