@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/vkeybd/virtual-keyboard.h $
- * $Id: virtual-keyboard.h 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -134,7 +134,7 @@ protected:
 
 	enum HorizontalAlignment {
 		kAlignLeft,
-		kAlignCentre,
+		kAlignCenter,
 		kAlignRight
 	};
 
