@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/algorithm.h $
- * $Id: algorithm.h 51524 2010-07-30 23:42:50Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 #ifndef COMMON_ALGORITHM_H
@@ -242,13 +242,20 @@ void sort(T first, T last) {
  */
 template<class T>
 T gcd(T a, T b) {
-	if (a <= 0) a = -a;
-	if (b <= 0) b = -b;
+	// Note: We check for <= instead of < to avoid spurious compiler
+	// warnings if T is an unsigned type, i.e. warnings like "comparison
+	// of unsigned expression < 0 is always false".
+	if (a <= 0)
+		a = -a;
+	if (b <= 0)
+		b = -b;
+
 	while (a > 0) {
 		T tmp = a;
 		a = b % a;
 		b = tmp;
 	}
+
 	return b;
 }
 
