@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/array.h $
- * $Id: array.h 45247 2009-10-19 17:46:50Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef COMMON_ARRAY_H
@@ -150,6 +150,12 @@ public:
 		insert_aux(_storage + idx, &element, &element + 1);
 	}
 
+	void insert_at(int idx, const Array<T> &array) {
+		assert(idx >= 0 && (uint)idx <= _size);
+		insert_aux(_storage + idx, array.begin(), array.end());
+	}
+
+
 	T remove_at(int idx) {
 		assert(idx >= 0 && (uint)idx < _size);
 		T tmp = _storage[idx];
@@ -176,7 +182,11 @@ public:
 
 		delete[] _storage;
 		_size = array._size;
+#ifdef __DS__
+		_capacity = _size;
+#else
 		_capacity = _size + 32;
+#endif
 		_storage = new T[_capacity];
 		assert(_storage);
 		copy(array._storage, array._storage + _size, _storage);
