@@ -18,21 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/config-file.h $
- * $Id: config-file.h 38338 2009-02-16 01:04:19Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef COMMON_CONFIG_FILE_H
 #define COMMON_CONFIG_FILE_H
 
-#include "common/config-manager.h"
+#include "common/hash-str.h"
 #include "common/list.h"
 #include "common/str.h"
-#include "common/stream.h"
 
 namespace Common {
 
+class SeekableReadStream;
+class WriteStream;
+
 /**
  * This class allows reading/writing INI style config files.
  * It is used by the ConfigManager for storage, but can also
