@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/file.cpp $
- * $Id: file.cpp 49705 2010-06-15 10:19:06Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,8 +27,7 @@
 #include "common/debug.h"
 #include "common/file.h"
 #include "common/fs.h"
-#include "common/util.h"
-#include "common/system.h"
+#include "common/textconsole.h"
 
 namespace Common {
 
