@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/keyboard.h $
- * $Id: keyboard.h 48120 2010-02-23 22:50:28Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,15 @@
 
 #include "common/scummsys.h"
 
+#if defined(__amigaos4__)
+// KEYCODE_LESS and KEYCODE_GREATER are already defined in AmigaOS, inside
+// include/include_h/intuition/intuition.h (bug #3121350)
+#if defined(KEYCODE_LESS) && defined(KEYCODE_GREATER)
+#undef KEYCODE_LESS
+#undef KEYCODE_GREATER
+#endif
+#endif
+
 namespace Common {
 
 enum KeyCode {
@@ -281,7 +290,7 @@ struct KeyState {
 	 * you can write
 	 *    if (keystate.flags & KBD_CTRL) { ... }
 	 */
-	bool hasFlags(byte f) {
+	bool hasFlags(byte f) const {
 		return f == (flags & ~(KBD_NUM|KBD_CAPS|KBD_SCRL));
 	}
 
