@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/memorypool.h $
- * $Id: memorypool.h 48313 2010-03-20 13:18:47Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -66,7 +66,7 @@ public:
 	 * Constructor for a memory pool with the given chunk size.
 	 * @param chunkSize		the chunk size of this memory pool
 	 */
-	MemoryPool(size_t chunkSize);
+	explicit MemoryPool(size_t chunkSize);
 	~MemoryPool();
 
 	/**
