@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/mutex.h $
- * $Id: mutex.h 36135 2009-01-30 03:35:47Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -49,8 +49,8 @@ class StackLock {
 	void lock();
 	void unlock();
 public:
-	StackLock(MutexRef mutex, const char *mutexName = NULL);
-	StackLock(const Mutex &mutex, const char *mutexName = NULL);
+	explicit StackLock(MutexRef mutex, const char *mutexName = NULL);
+	explicit StackLock(const Mutex &mutex, const char *mutexName = NULL);
 	~StackLock();
 };
 
