@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/str.cpp $
- * $Id: str.cpp 52618 2010-09-07 11:40:44Z wjpalenstijn $
+ * $URL$
+ * $Id$
  */
 
 #include "common/str.h"
@@ -430,7 +430,7 @@ uint String::hash() const {
 }
 
 // static
-String String::printf(const char *fmt, ...) {
+String String::format(const char *fmt, ...) {
 	String output;
 	assert(output.isStorageIntern());
 
@@ -439,12 +439,20 @@ String String::printf(const char *fmt, ...) {
 	int len = vsnprintf(output._str, _builtinCapacity, fmt, va);
 	va_end(va);
 
-	if (len == -1) {
-		// MSVC doesn't return the size the full string would take up.
-		// Try increasing the size of the string until it fits.
+	if (len == -1 || len == _builtinCapacity - 1) {
+		// MSVC and IRIX don't return the size the full string would take up.
+		// MSVC returns -1, IRIX returns the number of characters actually written,
+		// which is at the most the size of the buffer minus one, as the string is
+		// truncated to fit.
 
 		// We assume MSVC failed to output the correct, null-terminated string
 		// if the return value is either -1 or size.
+		// For IRIX, because we lack a better mechanism, we assume failure
+		// if the return value equals size - 1.
+		// The downside to this is that whenever we try to format a string where the
+		// size is 1 below the built-in capacity, the size is needlessly increased.
+
+		// Try increasing the size of the string until it fits.
 		int size = _builtinCapacity;
 		do {
 			size *= 2;
@@ -455,7 +463,7 @@ String String::printf(const char *fmt, ...) {
 			va_start(va, fmt);
 			len = vsnprintf(output._str, size, fmt, va);
 			va_end(va);
-		} while (len == -1 || len >= size);
+		} while (len == -1 || len >= size - 1);
 		output._size = len;
 	} else if (len < (int)_builtinCapacity) {
 		// vsnprintf succeeded
