@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/str.h $
- * $Id: str.h 50712 2010-07-05 21:29:52Z wjpalenstijn $
+ * $URL$
+ * $Id$
  */
 
 #ifndef COMMON_STRING_H
@@ -218,7 +218,7 @@ public:
 	/**
 	 * Printf-like function. Returns a formatted String.
 	 */
-	static Common::String printf(const char *fmt, ...) GCC_PRINTF(1,2);
+	static Common::String format(const char *fmt, ...) GCC_PRINTF(1,2);
 
 public:
 	typedef char *        iterator;
@@ -288,7 +288,7 @@ extern char *trim(char *t);
 Common::String lastPathComponent(const Common::String &path, const char sep);
 
 /**
- * Normalize a gien path to a canonical form. In particular:
+ * Normalize a given path to a canonical form. In particular:
  * - trailing separators are removed:  /foo/bar/ -> /foo/bar
  * - double separators (= empty components) are removed:   /foo//bar -> /foo/bar
  * - dot components are removed:  /foo/./bar -> /foo/bar
