@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/system.h $
- * $Id: system.h 49843 2010-06-15 12:33:20Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,31 +28,32 @@
 
 #include "common/scummsys.h"
 #include "common/noncopyable.h"
-#include "common/rect.h"
 #include "common/list.h" // For OSystem::getSupportedFormats()
-
 #include "graphics/pixelformat.h"
 
 namespace Audio {
-	class Mixer;
+class Mixer;
 }
 
 namespace Graphics {
-	struct Surface;
+struct Surface;
 }
 
 namespace Common {
-	struct Event;
-	class EventManager;
-	class SaveFileManager;
-	class SearchSet;
-	class TimerManager;
-	class SeekableReadStream;
-	class WriteStream;
-	class HardwareKeySet;
+class EventManager;
+struct Rect;
+class SaveFileManager;
+class SearchSet;
+class String;
+class TimerManager;
+class SeekableReadStream;
+class WriteStream;
+class HardwareKeySet;
 }
 
+class AudioCDManager;
 class FilesystemFactory;
+class PaletteManager;
 
 /**
  * A structure describing time and date. This is a clone of struct tm
@@ -72,6 +73,16 @@ struct TimeDate {
 	int tm_year;    ///< year - 1900
 };
 
+namespace LogMessageType {
+
+enum Type {
+	kError,
+	kWarning,
+	kDebug
+};
+
+} // End of namespace LogMessageType
+
 /**
  * Interface for ScummVM backends. If you want to port ScummVM to a system
  * which is not currently covered by any of our backends, this is the place
@@ -350,10 +361,17 @@ public:
 
 	/**
 	 * Determine which graphics mode is currently active.
-	 * @return the active graphics mode
+	 * @return the ID of the active graphics mode
 	 */
 	virtual int getGraphicsMode() const = 0;
 
+	/**
+	 * Sets the graphics scale factor to x1. Games with large screen sizes
+	 * reset the scale to x1 so the screen will not be too big when starting
+	 * the game.
+	 */
+	virtual void resetGraphicsScale() = 0;
+
 #ifdef USE_RGB_COLOR
 	/**
 	 * Determine the pixel format currently in use for screen rendering.
@@ -499,49 +517,10 @@ public:
 	virtual int16 getWidth() = 0;
 
 	/**
-	 * Replace the specified range of the palette with new colors.
-	 * The palette entries from 'start' till (start+num-1) will be replaced - so
-	 * a full palette update is accomplished via start=0, num=256.
-	 *
-	 * The palette data is specified in interleaved RGBA format. That is, the
-	 * first byte of the memory block 'colors' points at is the red component
-	 * of the first new color; the second byte the green component of the first
-	 * new color; the third byte the blue component, the last byte to the alpha
-	 * (transparency) value. Then the second color starts, and so on. So memory
-	 * looks like this: R1-G1-B1-A1-R2-G2-B2-A2-R3-...
-	 *
-	 * @param colors	the new palette data, in interleaved RGBA format
-	 * @param start		the first palette entry to be updated
-	 * @param num		the number of palette entries to be updated
-	 *
-	 * @note It is an error if start+num exceeds 256, behaviour is undefined
-	 *       in that case (the backend may ignore it silently or assert).
-	 * @note It is an error if this function gets called when the pixel format
-	 *       in use (the return value of getScreenFormat) has more than one
-	 *       byte per pixel.
-	 * @note The alpha value is not actually used, and future revisions of this
-	 *       API are probably going to remove it.
-	 *
-	 * @see getScreenFormat
+	 * Return the palette manager singleton. For more information, refer
+	 * to the PaletteManager documentation.
 	 */
-	virtual void setPalette(const byte *colors, uint start, uint num) = 0;
-
-	/**
-	 * Grabs a specified part of the currently active palette.
-	 * The format is the same as for setPalette.
-	 *
-	 * @see setPalette
-	 * @param colors	the palette data, in interleaved RGBA format
-	 * @param start		the first platte entry to be read
-	 * @param num		the number of palette entries to be read
-	 *
-	 * @note It is an error if this function gets called when the pixel format
-	 *       in use (the return value of getScreenFormat) has more than one
-	 *       byte per pixel.
-	 *
-	 * @see getScreenFormat
-	 */
-	virtual void grabPalette(byte *colors, uint start, uint num) = 0;
+	virtual PaletteManager *getPaletteManager() = 0;
 
 	/**
 	 * Blit a bitmap to the virtual screen.
@@ -926,46 +905,14 @@ public:
 
 
 
-	/**
-	 * @name Audio CD
-	 * The methods in this group deal with Audio CD playback.
-	 * The default implementation simply does nothing.
-	 * This is the lower level implementation as provided by the
-	 * backends. The engines should use the Audio::AudioCDManager
-	 * class instead of using it directly.
-	 */
+	/** @name Audio CD */
 	//@{
 
 	/**
-	 * Initialise the specified CD drive for audio playback.
-	 * @return true if the CD drive was inited succesfully
+	 * Return the audio cd manager. For more information, refer to the
+	 * AudioCDManager documentation.
 	 */
-	virtual bool openCD(int drive);
-
-	/**
-	 * Poll CD status.
-	 * @return true if CD audio is playing
-	 */
-	virtual bool pollCD();
-
-	/**
-	 * Start audio CD playback.
-	 * @param track			the track to play.
-	 * @param num_loops		how often playback should be repeated (-1 = infinitely often).
-	 * @param start_frame	the frame at which playback should start (75 frames = 1 second).
-	 * @param duration		the number of frames to play.
-	 */
-	virtual void playCD(int track, int num_loops, int start_frame, int duration) {}
-
-	/**
-	 * Stop audio CD playback.
-	 */
-	virtual void stopCD() {}
-
-	/**
-	 * Update cdrom audio status.
-	 */
-	virtual void updateCD() {}
+	virtual AudioCDManager *getAudioCDManager() = 0;
 
 	//@}
 
@@ -976,6 +923,13 @@ public:
 	/** Quit (exit) the application. */
 	virtual void quit() = 0;
 
+	/**
+	 * Signals that a fatal error inside the client code has happened.
+	 *
+	 * This should quit the application.
+	 */
+	virtual void fatalError();
+
 	/**
 	 * Set a window caption or any other comparable status display to the
 	 * given value. The caption must be a pure ISO LATIN 1 string. Passing a
@@ -994,8 +948,9 @@ public:
 	 *
 	 * Currently, only pure ASCII messages can be expected to show correctly.
 	 *
-	 * @note There is a default implementation which uses a TimedMessageDialog
-	 *       to display the message. Hence implementing this is optional.
+	 * @note There is a default implementation in BaseBackend which uses a
+	 *       TimedMessageDialog to display the message. Hence implementing
+	 *       this is optional.
 	 *
 	 * @param msg	the message to display on screen
 	 */
@@ -1043,6 +998,38 @@ public:
 	 */
 	virtual Common::WriteStream *createConfigWriteStream() = 0;
 
+	/**
+	 * Logs a given message.
+	 *
+	 * It is up to the backend where to log the different messages.
+	 * The backend should aim at using a non-buffered output for it
+	 * so that no log data is lost in case of a crash.
+	 *
+	 * The default implementation outputs them on stdout/stderr.
+	 *
+	 * @param type    the type of the message
+	 * @param message the message itself
+	 */
+	virtual void logMessage(LogMessageType::Type type, const char *message);
+
+	/**
+	 * Returns the locale of the system.
+	 *
+	 * This returns the currently set up locale of the system, on which
+	 * ScummVM is run.
+	 *
+	 * The format of the locale is language_country. These should match
+	 * the POSIX locale values.
+	 *
+	 * For information about POSIX locales read here:
+	 * http://en.wikipedia.org/wiki/Locale#POSIX-type_platforms
+	 *
+	 * The default implementation returns "en_US".
+	 *
+	 * @return locale of the system
+	 */
+	virtual Common::String getSystemLanguage() const;
+
 	//@}
 };
 
