@@ -18,18 +18,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/unarj.h $
- * $Id: unarj.h 48040 2010-02-13 11:56:30Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
+/**
+ * @file
+ * ARJ decompressor used in engines:
+ * - drascula
+ */
+
 #ifndef COMMON_UNARJ_H
 #define COMMON_UNARJ_H
 
+#include "common/str.h"
+
 namespace Common {
 
 class Archive;
-class String;
 
 /**
  * This factory method creates an Archive instance corresponding to the content
