@@ -18,19 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/unzip.h $
- * $Id: unzip.h 50482 2010-06-29 06:33:31Z spalek $
+ * $URL$
+ * $Id$
  */
 
 #ifndef COMMON_UNZIP_H
 #define COMMON_UNZIP_H
 
+#include "common/str.h"
+
 namespace Common {
 
 class Archive;
 class FSNode;
 class SeekableReadStream;
-class String;
 
 /**
  * This factory method creates an Archive instance corresponding to the content
