@@ -725,8 +725,8 @@ const Feature s_features[] = {
 	{     "mad",         "USE_MAD", "libmad",           true, "libmad (MP3) support" },
 	{  "vorbis",      "USE_VORBIS", "libvorbisfile_static libvorbis_static libogg_static", true, "Ogg Vorbis support" },
 	{    "flac",        "USE_FLAC", "libFLAC_static",   true, "FLAC support" },
-	{     "png",         "USE_PNG", "libpng",           true, "libpng support" },
-	{  "theora",   "USE_THEORADEC", "libtheora_static", true, "Theora decoding support" },
+	{     "png",         "USE_PNG", "libpng",           false, "libpng support" },
+	{  "theora",   "USE_THEORADEC", "libtheora_static", false, "Theora decoding support" },
 	{   "mpeg2",       "USE_MPEG2", "libmpeg2",         false, "mpeg2 codec for cutscenes" },
 
 	// Feature flags
@@ -735,7 +735,7 @@ const Feature s_features[] = {
 	{       "16bit",   "USE_RGB_COLOR",         "", true, "16bit color support" },
 	{     "mt32emu",     "USE_MT32EMU",         "", true, "integrated MT-32 emulator" },
 	{        "nasm",        "USE_NASM",         "", true, "IA-32 assembly support" }, // This feature is special in the regard, that it needs additional handling.
-	{      "opengl",      "USE_OPENGL", "opengl32", true, "OpenGL support" },
+	{      "opengl",      "USE_OPENGL", "opengl32", false, "OpenGL support" },
 	{      "indeo3",      "USE_INDEO3",         "", true, "Indeo3 codec support"},
 	{ "translation", "USE_TRANSLATION",         "", true, "Translation support" },
 	{      "vkeybd",   "ENABLE_VKEYBD",         "", false, "Virtual keyboard support"},
