@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/loader_v3.cpp $
- * $Id: loader_v3.cpp 50606 2010-07-02 22:55:56Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "common/config-manager.h"
 #include "common/fs.h"
+#include "common/textconsole.h"
 
 namespace Agi {
 
@@ -121,7 +122,7 @@ int AgiLoader_v3::init() {
 	}
 
 	if (!fp.open(path)) {
-		printf("Failed to open \"%s\"\n", path.c_str());
+		warning("Failed to open '%s'", path.c_str());
 		return errBadFileOpen;
 	}
 	// build offset table for v3 directory format
