@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/lzw.cpp $
- * $Id: lzw.cpp 46942 2010-01-03 20:15:44Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -36,6 +36,8 @@
 #include "agi/agi.h"
 #include "agi/lzw.h"
 
+#include "common/textconsole.h"
+
 namespace Agi {
 
 
@@ -107,7 +109,7 @@ uint8 *LZWDecoder::decodeString(uint8 *buffer, uint32 code) {
 		*buffer++ = appendCharacter[code];
 		code = prefixCode[code];
 		if (i++ >= 4000) {
-			error("lzw: error in code expansion.");
+			error("lzw: error in code expansion");
 		}
 	}
 	*buffer = code;
