@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/picture.cpp $
- * $Id: picture.cpp 49743 2010-06-15 10:31:39Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "agi/agi.h"
 #include "agi/graphics.h"
 
+#include "common/textconsole.h"
+
 namespace Agi {
 
 PictureMgr::PictureMgr(AgiBase *agi, GfxMgr *gfx) {
@@ -562,7 +564,7 @@ void PictureMgr::drawPicture() {
 	_patCode = 0;
 	_patNum = 0;
 	_priOn = _scrOn = false;
-	_scrColor = 0xf;
+	_scrColor = (_pictureVersion == AGIPIC_C64) ? 0x0 : 0xf;
 	_priColor = 0x4;
 
 	drawing = 1;
@@ -601,7 +603,7 @@ void PictureMgr::drawPicture() {
 			_patCode = nextByte();
 			plotBrush();
 			break;
-		case 0xf0:	// set colour on screen (AGI pic v2)
+		case 0xf0:	// set color on screen (AGI pic v2)
 			if (_pictureVersion == AGIPIC_V15)
 				break;
 
@@ -615,7 +617,7 @@ void PictureMgr::drawPicture() {
 				_scrColor &= 0xF;	// for v3 drawing diff
 				_scrOn = true;
 				_priOn = false;
-			} else if (_pictureVersion == AGIPIC_V15) {	// set colour on screen
+			} else if (_pictureVersion == AGIPIC_V15) {	// set color on screen
 				_scrColor = nextByte();
 				_scrColor &= 0xF;
 				_scrOn = true;
@@ -623,7 +625,7 @@ void PictureMgr::drawPicture() {
 				_scrOn = false;
 			}
 			break;
-		case 0xf2:	// set colour on priority (AGI pic v2)
+		case 0xf2:	// set color on priority (AGI pic v2)
 			if (_pictureVersion == AGIPIC_V15)
 				break;
 
