@@ -18,16 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/preagi.cpp $
- * $Id: preagi.cpp 50128 2010-06-21 21:36:36Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/config-manager.h"
 #include "common/debug-channels.h"
 #include "common/random.h"
+#include "common/textconsole.h"
 
-#include "sound/mididrv.h"
+#include "audio/mididrv.h"
 
 #include "agi/preagi.h"
 #include "agi/graphics.h"
@@ -42,8 +43,7 @@ namespace Agi {
 PreAgiEngine::PreAgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBase(syst, gameDesc) {
 
 	// Setup mixer
-	_mixer->setVolumeForSoundType(Audio::Mixer::kSFXSoundType, ConfMan.getInt("sfx_volume"));
-	_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, ConfMan.getInt("music_volume"));
+	syncSoundSettings();
 
 	_rnd = new Common::RandomSource();
 
@@ -122,9 +122,6 @@ void PreAgiEngine::initialize() {
 	_mixer->playStream(Audio::Mixer::kSFXSoundType, &_speakerHandle,
 							_speakerStream, -1, Audio::Mixer::kMaxChannelVolume, 0, DisposeAfterUse::NO, true);
 
-
-	//_timer->installTimerProc(agiTimerFunctionLow, 10 * 1000, NULL);
-
 	debugC(2, kDebugLevelMain, "Detect game");
 
 	// clear all resources and events
