@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/preagi.h $
- * $Id: preagi.h 48279 2010-03-18 15:07:11Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,7 +29,7 @@
 #include "agi/agi.h"
 #include "agi/preagi_common.h"
 
-#include "sound/softsynth/pcspk.h"
+#include "audio/softsynth/pcspk.h"
 
 namespace Agi {
 
