@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/preagi_mickey.cpp $
- * $Id: preagi_mickey.cpp 46942 2010-01-03 20:15:44Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/events.h"
 #include "common/savefile.h"
+#include "common/textconsole.h"
 
 #include "graphics/cursorman.h"
 
@@ -302,6 +303,8 @@ void Mickey::getMouseMenuSelRow(MSA_MENU menu, int *sel0, int *sel1, int iRow, i
 		if (y != IDI_MSA_ROW_MENU_1) return;
 		sel = sel1;
 		break;
+	default:
+		return;
 	}
 
 	for (iWord = 0; iWord < menu.row[iRow].count; iWord++) {
@@ -1001,7 +1004,7 @@ bool Mickey::loadGame() {
 			if (_vm->getSelection(kSelAnyKey) == 0)
 				return false;
 		} else {
-			if (infile->readUint32BE() != MKID_BE('MICK')) {
+			if (infile->readUint32BE() != MKTAG('M','I','C','K')) {
 				warning("Mickey::loadGame wrong save game format");
 				return false;
 			}
@@ -1118,7 +1121,7 @@ void Mickey::saveGame() {
 			if (_vm->getSelection(kSelAnyKey) == 0)
 				return;
 		} else {
-			outfile->writeUint32BE(MKID_BE('MICK'));	// header
+			outfile->writeUint32BE(MKTAG('M','I','C','K'));	// header
 			outfile->writeByte(MSA_SAVEGAME_VERSION);
 
 			outfile->writeByte(_game.iRoom);
@@ -1234,7 +1237,7 @@ int Mickey::getPlanet() {
 	if (!_game.nButtons)
 		return -1;
 
-	for (int iPlanet = 0; iPlanet < IDI_MSA_MAX_DAT; iPlanet++) {
+	for (int iPlanet = 0; iPlanet < IDI_MSA_MAX_DAT - 1; iPlanet++) {
 		if (!strcmp(IDS_MSA_ADDR_PLANET[iPlanet], _game.szAddr)) {
 			return iPlanet;
 		}
@@ -1313,7 +1316,7 @@ void Mickey::flipSwitch() {
 			_game.iPlanetXtal[0] = IDI_MSA_PLANET_EARTH;
 			_game.iPlanetXtal[8] = IDI_MSA_PLANET_URANUS;
 
-			for (int i = 1; i < 9; i++) {
+			for (int i = 1; i < IDI_MSA_MAX_PLANET; i++) {
 				if (i < 8) {
 					do {
 						// Earth (planet 0) and Uranus (planet 8) are excluded
