@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/preagi_troll.cpp $
- * $Id: preagi_troll.cpp 48218 2010-03-10 06:39:23Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "agi/graphics.h"
 
 #include "common/events.h"
+#include "common/textconsole.h"
 
 #include "graphics/cursorman.h"
 
