@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/saveload.cpp $
- * $Id: saveload.cpp 52996 2010-10-03 18:32:39Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,9 +29,11 @@
 //
 
 #include "common/file.h"
-#include "graphics/thumbnail.h"
 #include "common/config-manager.h"
 #include "common/savefile.h"
+#include "common/textconsole.h"
+#include "graphics/thumbnail.h"
+#include "graphics/surface.h"
 
 #include "agi/agi.h"
 #include "agi/graphics.h"
@@ -52,7 +54,7 @@
 
 namespace Agi {
 
-static const uint32 AGIflag = MKID_BE('AGI:');
+static const uint32 AGIflag = MKTAG('A','G','I',':');
 
 int AgiEngine::saveGame(const char *fileName, const char *description) {
 	char gameIDstring[8] = "gameIDX";
@@ -333,7 +335,7 @@ int AgiEngine::loadGame(const char *fileName, bool checkId) {
 		debug(0, "Saved game MD5: \"%s\"", md5);
 
 		if (!getGameMD5()) {
-			warning("Since your game was only detected via the fallback detector, there is no possibility to assure the save is compatible with your game version.");
+			warning("Since your game was only detected via the fallback detector, there is no possibility to assure the save is compatible with your game version");
 
 			debug(0, "The game used for saving is \"%s\".", md5);
 		} else if (strcmp(md5, getGameMD5())) {
@@ -596,7 +598,7 @@ int AgiEngine::selectSlot() {
 	int hm = 1, vm = 3;	// box margins
 	int xmin, xmax, slotClicked;
 	char desc[NUM_VISIBLE_SLOTS][40];
-	int textCentre, buttonLength, buttonX[2], buttonY;
+	int textCenter, buttonLength, buttonX[2], buttonY;
 	const char *buttonText[] = { "  OK  ", "Cancel", NULL };
 
 	_noSaveLoadAllowed = true;
@@ -605,10 +607,10 @@ int AgiEngine::selectSlot() {
 		getSavegameDescription(_firstSlot + i, desc[i]);
 	}
 
-	textCentre = GFX_WIDTH / CHAR_LINES / 2;
+	textCenter = GFX_WIDTH / CHAR_LINES / 2;
 	buttonLength = 6;
-	buttonX[0] = (textCentre - 3 * buttonLength / 2) * CHAR_COLS;
-	buttonX[1] = (textCentre + buttonLength / 2) * CHAR_COLS;
+	buttonX[0] = (textCenter - 3 * buttonLength / 2) * CHAR_COLS;
+	buttonX[1] = (textCenter + buttonLength / 2) * CHAR_COLS;
 	buttonY = (vm + 17) * CHAR_LINES;
 
 	for (i = 0; i < 2; i++)
@@ -641,8 +643,8 @@ int AgiEngine::selectSlot() {
 			for (i = 0; i < NUM_VISIBLE_SLOTS; i++) {
 				sprintf(dstr, "[%2d. %-28.28s]", i + _firstSlot, desc[i]);
 				printText(dstr, 0, hm + 1, vm + 4 + i,
-						(40 - 2 * hm) - 1, i == active ? MSG_BOX_COLOUR : MSG_BOX_TEXT,
-						i == active ? MSG_BOX_TEXT : MSG_BOX_COLOUR);
+						(40 - 2 * hm) - 1, i == active ? MSG_BOX_COLOR : MSG_BOX_TEXT,
+						i == active ? MSG_BOX_TEXT : MSG_BOX_COLOR);
 			}
 
 			char upArrow[] = "^";
@@ -650,11 +652,11 @@ int AgiEngine::selectSlot() {
 			char scrollBar[] = " ";
 
 			for (i = 1; i < NUM_VISIBLE_SLOTS - 1; i++)
-				printText(scrollBar, 35, hm + 1, vm + 4 + i, 1, MSG_BOX_COLOUR, 7, true);
+				printText(scrollBar, 35, hm + 1, vm + 4 + i, 1, MSG_BOX_COLOR, 7, true);
 
 			printText(upArrow, 35, hm + 1, vm + 4, 1, 8, 7);
 			printText(downArrow, 35, hm + 1, vm + 4 + NUM_VISIBLE_SLOTS - 1, 1, 8, 7);
-			printText(scrollBar, 35, hm + 1, vm + 4 + sbPos, 1, MSG_BOX_COLOUR, MSG_BOX_TEXT);
+			printText(scrollBar, 35, hm + 1, vm + 4 + sbPos, 1, MSG_BOX_COLOR, MSG_BOX_TEXT);
 
 			oldActive = active;
 			oldFirstSlot = _firstSlot;
@@ -807,7 +809,7 @@ int AgiEngine::saveGameDialog() {
 	do {
 		drawWindow(hp, vp, GFX_WIDTH - hp, GFX_HEIGHT - vp);
 		printText("Select a slot in which you wish to\nsave the game:",
-				0, hm + 1, vm + 1, w, MSG_BOX_TEXT, MSG_BOX_COLOUR);
+				0, hm + 1, vm + 1, w, MSG_BOX_TEXT, MSG_BOX_COLOR);
 		slot = selectSlot();
 		if (slot + _firstSlot == 0)
 			messageBox("That slot is for Autosave only.");
@@ -818,7 +820,7 @@ int AgiEngine::saveGameDialog() {
 	drawWindow(hp, vp + 5 * CHAR_LINES, GFX_WIDTH - hp,
 			GFX_HEIGHT - vp - 9 * CHAR_LINES);
 	printText("Enter a description for this game:",
-			0, hm + 1, vm + 6, w, MSG_BOX_TEXT, MSG_BOX_COLOUR);
+			0, hm + 1, vm + 6, w, MSG_BOX_TEXT, MSG_BOX_COLOR);
 	_gfx->drawRectangle(3 * CHAR_COLS, 11 * CHAR_LINES - 1,
 			37 * CHAR_COLS, 12 * CHAR_LINES, MSG_BOX_TEXT);
 	_gfx->flushBlock(3 * CHAR_COLS, 11 * CHAR_LINES - 1,
@@ -843,7 +845,7 @@ int AgiEngine::saveGameDialog() {
 	for (numChars = 0; numChars < 28 && name[numChars]; numChars++)
 		handleGetstring(name[numChars]);
 
-	_gfx->printCharacter(numChars + 3, 11, _game.cursorChar, MSG_BOX_COLOUR, MSG_BOX_TEXT);
+	_gfx->printCharacter(numChars + 3, 11, _game.cursorChar, MSG_BOX_COLOR, MSG_BOX_TEXT);
 	do {
 		mainCycle();
 	} while (_game.inputMode == INPUT_GETSTRING);
@@ -901,7 +903,7 @@ int AgiEngine::loadGameDialog() {
 
 	drawWindow(hp, vp, GFX_WIDTH - hp, GFX_HEIGHT - vp);
 	printText("Select a game which you wish to\nrestore:",
-			0, hm + 1, vm + 1, w, MSG_BOX_TEXT, MSG_BOX_COLOUR);
+			0, hm + 1, vm + 1, w, MSG_BOX_TEXT, MSG_BOX_COLOR);
 
 	slot = selectSlot();
 
