@@ -18,15 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/sound_2gs.cpp $
- * $Id: sound_2gs.cpp 49758 2010-06-15 10:38:39Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/config-manager.h"
 #include "common/fs.h"
 #include "common/md5.h"
+#include "common/memstream.h"
 #include "common/str-array.h"
+#include "common/textconsole.h"
 
 #include "agi/agi.h"
 #include "agi/sound_2gs.h"
@@ -765,7 +767,7 @@ bool SoundGen2GS::loadInstruments() {
 	// load the instrument headers and their sample data.
 	// None of the tested SIERRASTANDARD-files have zeroes in them so
 	// there's no need to check for prematurely ending samples here.
-	setProgramChangeMapping(&exeInfo->instSet.progToInst);
+	setProgramChangeMapping(exeInfo->instSet->progToInst);
 	return loadWaveFile(*waveFsnode, *exeInfo) && loadInstrumentHeaders(*exeFsnode, *exeInfo);
 }
 
@@ -791,29 +793,29 @@ static const MidiProgramChangeMapping progToInstMappingV2 = {
 
 /** Older Apple IIGS AGI instrument set. Used only by Space Quest I (AGI v1.002). */
 static const InstrumentSetInfo instSetV1 = {
-	1192, 26, "7ee16bbc135171ffd6b9120cc7ff1af2", "edd3bf8905d9c238e02832b732fb2e18", progToInstMappingV1
+	1192, 26, "7ee16bbc135171ffd6b9120cc7ff1af2", "edd3bf8905d9c238e02832b732fb2e18", &progToInstMappingV1
 };
 
 /** Newer Apple IIGS AGI instrument set (AGI v1.003+). Used by all others than Space Quest I. */
 static const InstrumentSetInfo instSetV2 = {
-	1292, 28, "b7d428955bb90721996de1cbca25e768", "c05fb0b0e11deefab58bc68fbd2a3d07", progToInstMappingV2
+	1292, 28, "b7d428955bb90721996de1cbca25e768", "c05fb0b0e11deefab58bc68fbd2a3d07", &progToInstMappingV2
 };
 
 /** Information about different Apple IIGS AGI executables. */
 static const IIgsExeInfo IIgsExeInfos[] = {
-	{GID_SQ1,      "SQ",   0x1002, 138496, 0x80AD, instSetV1},
-	{GID_LSL1,     "LL",   0x1003, 141003, 0x844E, instSetV2},
-	{GID_AGIDEMO,  "DEMO", 0x1005, 141884, 0x8469, instSetV2},
-	{GID_KQ1,      "KQ",   0x1006, 141894, 0x8469, instSetV2},
-	{GID_PQ1,      "PQ",   0x1007, 141882, 0x8469, instSetV2},
-	{GID_MIXEDUP,  "MG",   0x1013, 142552, 0x84B7, instSetV2},
-	{GID_KQ2,      "KQ2",  0x1013, 143775, 0x84B7, instSetV2},
-	{GID_KQ3,      "KQ3",  0x1014, 144312, 0x84B7, instSetV2},
-	{GID_SQ2,      "SQ2",  0x1014, 107882, 0x6563, instSetV2},
-	{GID_MH1,      "MH",   0x2004, 147678, 0x8979, instSetV2},
-	{GID_KQ4,      "KQ4",  0x2006, 147652, 0x8979, instSetV2},
-	{GID_BC,       "BC",   0x3001, 148192, 0x8979, instSetV2},
-	{GID_GOLDRUSH, "GR",   0x3003, 148268, 0x8979, instSetV2}
+	{GID_SQ1,      "SQ",   0x1002, 138496, 0x80AD, &instSetV1},
+	{GID_LSL1,     "LL",   0x1003, 141003, 0x844E, &instSetV2},
+	{GID_AGIDEMO,  "DEMO", 0x1005, 141884, 0x8469, &instSetV2},
+	{GID_KQ1,      "KQ",   0x1006, 141894, 0x8469, &instSetV2},
+	{GID_PQ1,      "PQ",   0x1007, 141882, 0x8469, &instSetV2},
+	{GID_MIXEDUP,  "MG",   0x1013, 142552, 0x84B7, &instSetV2},
+	{GID_KQ2,      "KQ2",  0x1013, 143775, 0x84B7, &instSetV2},
+	{GID_KQ3,      "KQ3",  0x1014, 144312, 0x84B7, &instSetV2},
+	{GID_SQ2,      "SQ2",  0x1014, 107882, 0x6563, &instSetV2},
+	{GID_MH1,      "MH",   0x2004, 147678, 0x8979, &instSetV2},
+	{GID_KQ4,      "KQ4",  0x2006, 147652, 0x8979, &instSetV2},
+	{GID_BC,       "BC",   0x3001, 148192, 0x8979, &instSetV2},
+	{GID_GOLDRUSH, "GR",   0x3003, 148268, 0x8979, &instSetV2}
 };
 
 /**
@@ -839,27 +841,26 @@ bool SoundGen2GS::loadInstrumentHeaders(const Common::FSNode &exePath, const IIg
 	}
 
 	// Read the whole executable file into memory
-	Common::SharedPtr<Common::MemoryReadStream> data(file.readStream(file.size()));
+	Common::SharedPtr<Common::SeekableReadStream> data(file.readStream(file.size()));
 	file.close();
 
 	// Check that we got enough data to be able to parse the instruments
-	if (data && data->size() >= (int32)(exeInfo.instSetStart + exeInfo.instSet.byteCount)) {
+	if (data && data->size() >= (int32)(exeInfo.instSetStart + exeInfo.instSet->byteCount)) {
 		// Check instrument set's length (The info's saved in the executable)
 		data->seek(exeInfo.instSetStart - 4);
 		uint16 instSetByteCount = data->readUint16LE();
-		if (instSetByteCount != exeInfo.instSet.byteCount) {
+		if (instSetByteCount != exeInfo.instSet->byteCount) {
 			debugC(3, kDebugLevelSound, "Wrong instrument set size (Is %d, should be %d) in Apple IIGS executable (%s)",
-				instSetByteCount, exeInfo.instSet.byteCount, exePath.getPath().c_str());
+				instSetByteCount, exeInfo.instSet->byteCount, exePath.getPath().c_str());
 		}
 
 		// Check instrument set's md5sum
 		data->seek(exeInfo.instSetStart);
 
-		char md5str[32+1];
-		Common::md5_file_string(*data, md5str, exeInfo.instSet.byteCount);
-		if (scumm_stricmp(md5str, exeInfo.instSet.md5)) {
+		Common::String md5str = Common::computeStreamMD5AsString(*data, exeInfo.instSet->byteCount);
+		if (md5str != exeInfo.instSet->md5) {
 			warning("Unknown Apple IIGS instrument set (md5: %s) in %s, trying to use it nonetheless",
-				md5str, exePath.getPath().c_str());
+				md5str.c_str(), exePath.getPath().c_str());
 		}
 
 		// Read in the instrument set one instrument at a time
@@ -867,20 +868,20 @@ bool SoundGen2GS::loadInstrumentHeaders(const Common::FSNode &exePath, const IIg
 
 		// Load the instruments
 		_instruments.clear();
-		_instruments.reserve(exeInfo.instSet.instCount);
+		_instruments.reserve(exeInfo.instSet->instCount);
 
 		IIgsInstrumentHeader instrument;
-		for (uint i = 0; i < exeInfo.instSet.instCount; i++) {
+		for (uint i = 0; i < exeInfo.instSet->instCount; i++) {
 			if (!instrument.read(*data)) {
 				warning("Error loading Apple IIGS instrument (%d. of %d) from %s, not loading more instruments",
-					i + 1, exeInfo.instSet.instCount, exePath.getPath().c_str());
+					i + 1, exeInfo.instSet->instCount, exePath.getPath().c_str());
 				break;
 			}
 			_instruments.push_back(instrument); // Add the successfully loaded instrument to the instruments array
 		}
 
 		// Loading was successful only if all instruments were loaded successfully
-		loadedOk = (_instruments.size() == exeInfo.instSet.instCount);
+		loadedOk = (_instruments.size() == exeInfo.instSet->instCount);
 	} else // Couldn't read enough data from the executable file
 		warning("Error loading instruments from Apple IIGS executable (%s)", exePath.getPath().c_str());
 
@@ -892,18 +893,17 @@ bool SoundGen2GS::loadWaveFile(const Common::FSNode &wavePath, const IIgsExeInfo
 
 	// Open the wave file and read it into memory
 	file.open(wavePath);
-	Common::SharedPtr<Common::MemoryReadStream> uint8Wave(file.readStream(file.size()));
+	Common::SharedPtr<Common::SeekableReadStream> uint8Wave(file.readStream(file.size()));
 	file.close();
 
 	// Check that we got the whole wave file
 	if (uint8Wave && uint8Wave->size() == SIERRASTANDARD_SIZE) {
 		// Check wave file's md5sum
-		char md5str[32+1];
-		Common::md5_file_string(*uint8Wave, md5str, SIERRASTANDARD_SIZE);
-		if (scumm_stricmp(md5str, exeInfo.instSet.waveFileMd5)) {
+		Common::String md5str = Common::computeStreamMD5AsString(*uint8Wave, SIERRASTANDARD_SIZE);
+		if (md5str != exeInfo.instSet->waveFileMd5) {
 			warning("Unknown Apple IIGS wave file (md5: %s, game: %s).\n" \
 				"Please report the information on the previous line to the ScummVM team.\n" \
-				"Using the wave file as it is - music may sound weird", md5str, exeInfo.exePrefix);
+				"Using the wave file as it is - music may sound weird", md5str.c_str(), exeInfo.exePrefix);
 		}
 
 		uint8Wave->seek(0); // Seek wave to its start
