@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/text.cpp $
- * $Id: text.cpp 49881 2010-06-15 18:17:51Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -166,7 +166,7 @@ void AgiEngine::blitTextbox(const char *p, int y, int x, int len) {
 	drawWindow(xoff, yoff, xoff + w - 1, yoff + h - 1);
 
 	printText2(2, msg, 0, CHAR_COLS + xoff, CHAR_LINES + yoff,
-			len + 1, MSG_BOX_TEXT, MSG_BOX_COLOUR);
+			len + 1, MSG_BOX_TEXT, MSG_BOX_COLOR);
 
 	free(msg);
 
@@ -560,7 +560,7 @@ char *AgiEngine::agiSprintf(const char *s) {
 					// remove all leading 0
 					// don't remove the 3rd zero if 000
 					for (i = 0; z[i] == '0' && i < 14; i++)
-					    ;
+						;
 				} else {
 					i = 15 - i;
 				}
@@ -730,7 +730,7 @@ void AgiEngine::drawWindow(int x1, int y1, int x2, int y2) {
 
 	debugC(4, kDebugLevelText, "x1=%d, y1=%d, x2=%d, y2=%d", x1, y1, x2, y2);
 	_gfx->saveBlock(x1, y1, x2, y2, _game.window.buffer);
-	_gfx->drawBox(x1, y1, x2, y2, MSG_BOX_COLOUR, MSG_BOX_LINE, 2);
+	_gfx->drawBox(x1, y1, x2, y2, MSG_BOX_COLOR, MSG_BOX_LINE, 2);
 }
 
 } // End of namespace Agi
