@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/wagparser.cpp $
- * $Id: wagparser.cpp 50928 2010-07-16 03:34:25Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #include "common/util.h"
 #include "common/fs.h"
 #include "common/debug.h"
+#include "common/textconsole.h"
 
 #include "agi/wagparser.h"
 
