@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/agos.cpp $
- * $Id: agos.cpp 52905 2010-09-26 12:08:16Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/config-manager.h"
 #include "common/EventRecorder.h"
-#include "common/events.h"
 #include "common/file.h"
 #include "common/fs.h"
+#include "common/textconsole.h"
 #include "common/system.h"
 
 #include "engines/util.h"
@@ -35,15 +35,12 @@
 #include "agos/debugger.h"
 #include "agos/intern.h"
 #include "agos/agos.h"
-#include "agos/vga.h"
+
+#include "backends/audiocd/audiocd.h"
 
 #include "graphics/surface.h"
 
-#include "sound/mididrv.h"
-#include "sound/mods/protracker.h"
-#include "sound/audiocd.h"
-
-using Common::File;
+#include "audio/mididrv.h"
 
 namespace AGOS {
 
@@ -471,7 +468,6 @@ AGOSEngine::AGOSEngine(OSystem *syst)
 	_planarBuf = 0;
 
 	_midiEnabled = false;
-	_nativeMT32 = false;
 
 	_vgaTickCounter = 0;
 
@@ -556,30 +552,13 @@ Common::Error AGOSEngine::init() {
 		((getFeatures() & GF_TALKIE) && getPlatform() == Common::kPlatformAcorn) ||
 		(getPlatform() == Common::kPlatformPC)) {
 
-		// Setup midi driver
-		MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_ADLIB | MDT_MIDI | (getGameType() == GType_SIMON1 ? MDT_PREFER_MT32 : MDT_PREFER_GM));
-		_nativeMT32 = ((MidiDriver::getMusicType(dev) == MT_MT32) || ConfMan.getBool("native_mt32"));
-
-		_driver = MidiDriver::createMidi(dev);
-
-		if (_nativeMT32)
-			_driver->property(MidiDriver::PROP_CHANNEL_MASK, 0x03FE);
-
-		_midi.setNativeMT32(_nativeMT32);
-		_midi.mapMT32toGM(getGameType() != GType_SIMON2 && !_nativeMT32);
-
-		_midi.setDriver(_driver);
-
-		int ret = _midi.open();
+		int ret = _midi.open(getGameType());
 		if (ret)
-			warning("MIDI Player init failed: \"%s\"", _midi.getErrorName (ret));
+			warning("MIDI Player init failed: \"%s\"", MidiDriver::getErrorName(ret));
 
 		_midi.setVolume(ConfMan.getInt("music_volume"), ConfMan.getInt("sfx_volume"));
 
-
 		_midiEnabled = true;
-	} else {
-		_driver = NULL;
 	}
 
 	// Setup mixer
@@ -735,7 +714,7 @@ void AGOSEngine_Simon2::setupGame() {
 	_itemMemSize = 20000;
 	_tableMemSize = 100000;
 	// Check whether to use MT-32 MIDI tracks in Simon the Sorcerer 2
-	if (getGameType() == GType_SIMON2 && _nativeMT32)
+	if (getGameType() == GType_SIMON2 && _midi.hasNativeMT32())
 		_musicIndexBase = (1128 + 612) / 4;
 	else
 		_musicIndexBase = 1128 / 4;
@@ -896,14 +875,7 @@ void AGOSEngine::setupGame() {
 }
 
 AGOSEngine::~AGOSEngine() {
-	// In Simon 2, this gets deleted along with _sound further down
-	if (getGameType() != GType_SIMON2)
-		delete _gameFile;
-
-	_midi.close();
-	delete _driver;
-
-	AudioCD.stop();
+	_system->getAudioCDManager()->stop();
 
 	for (uint i = 0; i < _itemHeap.size(); i++) {
 		delete[] _itemHeap[i];
@@ -926,14 +898,24 @@ AGOSEngine::~AGOSEngine() {
 	free(_textMem);
 	free(_xtblList);
 
+	if (_backGroundBuf)
+		_backGroundBuf->free();
 	delete _backGroundBuf;
+	if (_backBuf)
+		_backBuf->free();
 	delete _backBuf;
 	free(_planarBuf);
+	if (_scaleBuf)
+		_scaleBuf->free();
 	delete _scaleBuf;
 	free(_zoneBuffers);
 
-	free(_window4BackScn);
-	free(_window6BackScn);
+	if (_window4BackScn)
+		_window4BackScn->free();
+	delete _window4BackScn;
+	if (_window6BackScn)
+		_window6BackScn->free();
+	delete _window6BackScn;
 
 	free(_firstTimeStruct);
 	free(_pendingDeleteTimeEvent);
@@ -950,6 +932,7 @@ AGOSEngine::~AGOSEngine() {
 
 	delete _debugger;
 	delete _sound;
+	delete _gameFile;
 }
 
 GUI::Debugger *AGOSEngine::getDebugger() {
@@ -1039,18 +1022,15 @@ uint32 AGOSEngine::getTime() const {
 }
 
 void AGOSEngine::syncSoundSettings() {
-	// Sync the engine with the config manager
-	int soundVolumeMusic = ConfMan.getInt("music_volume");
-	int soundVolumeSFX = ConfMan.getInt("sfx_volume");
-	int soundVolumeSpeech = ConfMan.getInt("speech_volume");
+	Engine::syncSoundSettings();
 
 	bool mute = false;
 	if (ConfMan.hasKey("mute"))
 		mute = ConfMan.getBool("mute");
 
-	_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, (mute ? 0 : (_musicPaused ? 0 : soundVolumeMusic)));
-	_mixer->setVolumeForSoundType(Audio::Mixer::kSFXSoundType, (mute ? 0 : soundVolumeSFX));
-	_mixer->setVolumeForSoundType(Audio::Mixer::kSpeechSoundType, (mute ? 0 : soundVolumeSpeech));
+	// Sync the engine with the config manager
+	int soundVolumeMusic = ConfMan.getInt("music_volume");
+	int soundVolumeSFX = ConfMan.getInt("sfx_volume");
 
 	if (_midiEnabled)
 		_midi.setVolume((mute ? 0 : soundVolumeMusic), (mute ? 0 : soundVolumeSFX));
