@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/agos.h $
- * $Id: agos.h 50643 2010-07-04 07:32:12Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,15 +29,13 @@
 #include "engines/engine.h"
 
 #include "common/array.h"
+#include "common/error.h"
 #include "common/keyboard.h"
 #include "common/random.h"
 #include "common/rect.h"
 #include "common/stack.h"
 #include "common/util.h"
 
-#ifdef ENABLE_AGOS2
-#include "agos/animation.h"
-#endif
 #include "agos/midi.h"
 #include "agos/sound.h"
 #include "agos/vga.h"
@@ -47,8 +45,13 @@
  *
  * Status of this engine: ???
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Elvira: Mistress of the Dark
+ * - Elvira 2: The Jaws of Cerberus
+ * - The Feeble Files
+ * - Simon the Sorcerer
+ * - Simon the Sorcerer 2
+ * - Simon the Sorcerer Puzzle Pack
  */
 namespace AGOS {
 
@@ -56,6 +59,10 @@ uint fileReadItemID(Common::SeekableReadStream *in);
 
 #define CHECK_BOUNDS(x, y) assert((uint)(x) < ARRAYSIZE(y))
 
+#ifdef ENABLE_AGOS2
+class MoviePlayer;
+#endif
+
 struct Child;
 struct SubObject;
 
@@ -180,7 +187,7 @@ class AGOSEngine : public Engine {
 	virtual Common::Error run() {
 		Common::Error err;
 		err = init();
-		if (err != Common::kNoError)
+		if (err.getCode() != Common::kNoError)
 			return err;
 		return go();
 	}
@@ -523,8 +530,8 @@ protected:
 	uint16 _PVCount1;
 	uint16 _GPVCount1;
 
-	uint8 _currentPalette[1024];
-	uint8 _displayPalette[1024];
+	uint8 _currentPalette[768];
+	uint8 _displayPalette[768];
 
 	byte *_planarBuf;
 	byte _videoBuf1[32000];
@@ -544,9 +551,7 @@ protected:
 	byte _lettersToPrintBuf[80];
 
 	MidiPlayer _midi;
-	MidiDriver *_driver;
 	bool _midiEnabled;
-	bool _nativeMT32;
 
 	int _vgaTickCounter;
 
@@ -1136,7 +1141,7 @@ protected:
 	int getScale(int16 y, int16 x);
 	void checkScrollX(int16 x, int16 xpos);
 	void checkScrollY(int16 y, int16 ypos);
-	void centreScroll();
+	void centerScroll();
 
 	virtual void clearVideoWindow(uint16 windowNum, uint16 color);
 	void clearVideoBackGround(uint16 windowNum, uint16 color);
@@ -1917,12 +1922,12 @@ public:
 	void off_mouseOff();
 	void off_loadVideo();
 	void off_playVideo();
-	void off_centreScroll();
+	void off_centerScroll();
 	void off_resetPVCount();
 	void off_setPathValues();
 	void off_stopClock();
 	void off_restartClock();
-	void off_setColour();
+	void off_setColor();
 	void off_b3Set();
 	void off_b3Clear();
 	void off_b3Zero();
@@ -2012,7 +2017,7 @@ protected:
 	void scrollOracleUp();
 	void scrollOracleDown();
 
-	void listSaveGames(int n);
+	void listSaveGamesFeeble();
 	void saveUserGame(int slot);
 	void windowBackSpace(WindowBlock *window);
 
@@ -2093,6 +2098,8 @@ protected:
 	void startOverlayAnims();
 	void startAnOverlayAnim();
 
+	void printInfoText(const char *itemText);
+
 	virtual char *genSaveName(int slot);
 };
 
