@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/animation.h $
- * $Id: animation.h 49079 2010-05-18 14:17:24Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,18 +28,16 @@
 #ifndef AGOS_ANIMATION_H
 #define AGOS_ANIMATION_H
 
-#include "graphics/video/dxa_decoder.h"
-#include "graphics/video/smk_decoder.h"
-#include "sound/mixer.h"
+#include "video/dxa_decoder.h"
+#include "video/smk_decoder.h"
+#include "audio/mixer.h"
 
 namespace AGOS {
 
 class AGOSEngine_Feeble;
 
 class MoviePlayer {
-	friend class MoviePlayerDXA;
-	friend class MoviePlayerSMK;
-
+protected:
 	AGOSEngine_Feeble *_vm;
 
 	Audio::Mixer *_mixer;
@@ -68,7 +66,7 @@ public:
 	virtual void nextFrame() = 0;
 	virtual void stopVideo() = 0;
 
-private:
+protected:
 	virtual void handleNextFrame();
 	virtual bool processFrame() = 0;
 	virtual void startSound() {}
@@ -77,7 +75,7 @@ protected:
 	uint32 _firstFrameOffset;
 };
 
-class MoviePlayerDXA : public MoviePlayer, ::Graphics::DXADecoder {
+class MoviePlayerDXA : public MoviePlayer, Video::DXADecoder {
 	static const char *_sequenceList[90];
 	uint8 _sequenceNum;
 public:
@@ -95,7 +93,7 @@ private:
 	void copyFrameToBuffer(byte *dst, uint x, uint y, uint pitch);
 };
 
-class MoviePlayerSMK : public MoviePlayer, ::Graphics::SmackerDecoder {
+class MoviePlayerSMK : public MoviePlayer, Video::SmackerDecoder {
 public:
 	MoviePlayerSMK(AGOSEngine_Feeble *vm, const char *name);
 
