@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/cursor.cpp $
- * $Id: cursor.cpp 50643 2010-07-04 07:32:12Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -781,8 +781,8 @@ void AGOSEngine_Simon1::initMouse() {
 }
 
 static const byte mouseCursorPalette[] = {
-	0x00, 0x00, 0x00, 0x00, // Black
-	0xFF, 0xFF, 0xFF, 0x00, // White
+	0x00, 0x00, 0x00, // Black
+	0xFF, 0xFF, 0xFF  // White
 };
 
 void AGOSEngine::initMouse() {
@@ -792,7 +792,7 @@ void AGOSEngine::initMouse() {
 
 	memset(_mouseData, 0xFF, _maxCursorWidth * _maxCursorHeight);
 
-	CursorMan.replaceCursorPalette(mouseCursorPalette, 0, ARRAYSIZE(mouseCursorPalette) / 4);
+	CursorMan.replaceCursorPalette(mouseCursorPalette, 0, ARRAYSIZE(mouseCursorPalette) / 3);
 }
 
 void AGOSEngine::drawMousePointer() {
