@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/debugger.cpp $
- * $Id: debugger.cpp 40555 2009-05-14 11:15:36Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -53,16 +53,6 @@ Debugger::Debugger(AGOSEngine *vm)
 }
 
 
-void Debugger::preEnter() {
-	//_vm->_midi.pause(1);
-}
-
-
-void Debugger::postEnter() {
-	//_vm->_midi.pause(0);
-}
-
-
 bool Debugger::Cmd_DebugLevel(int argc, const char **argv) {
 	if (argc == 1) {
 		if (_vm->_debugMode == false)
