@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/draw.cpp $
- * $Id: draw.cpp 50643 2010-07-04 07:32:12Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "common/system.h"
 
 #include "graphics/surface.h"
+#include "graphics/palette.h"
 
 #include "agos/agos.h"
 #include "agos/intern.h"
@@ -779,9 +780,9 @@ void AGOSEngine::setMoveRect(uint16 x, uint16 y, uint16 width, uint16 height) {
 void AGOSEngine::displayScreen() {
 	if (_fastFadeInFlag == 0 && _paletteFlag == 1) {
 		_paletteFlag = 0;
-		if (memcmp(_displayPalette, _currentPalette, 1024)) {
-			memcpy(_currentPalette, _displayPalette, 1024);
-			_system->setPalette(_displayPalette, 0, 256);
+		if (memcmp(_displayPalette, _currentPalette, sizeof(_currentPalette))) {
+			memcpy(_currentPalette, _displayPalette, sizeof(_displayPalette));
+			_system->getPaletteManager()->setPalette(_displayPalette, 0, 256);
 		}
 	}
 
@@ -860,8 +861,8 @@ void AGOSEngine::fastFadeIn() {
 		slowFadeIn();
 	} else {
 		_paletteFlag = false;
-		memcpy(_currentPalette, _displayPalette, 1024);
-		_system->setPalette(_displayPalette, 0, _fastFadeInFlag);
+		memcpy(_currentPalette, _displayPalette, sizeof(_displayPalette));
+		_system->getPaletteManager()->setPalette(_displayPalette, 0, _fastFadeInFlag);
 		_fastFadeInFlag = 0;
 	}
 }
@@ -879,17 +880,17 @@ void AGOSEngine::slowFadeIn() {
 		src = _displayPalette;
 		dst = _currentPalette;
 
-		for (p = _fastFadeInFlag; p !=0 ; p -= 3) {
+		for (p = _fastFadeInFlag; p != 0; p -= 3) {
 			if (src[0] >= c)
 				dst[0] += 4;
 			if (src[1] >= c)
 				dst[1] += 4;
 			if (src[2] >= c)
 				dst[2] += 4;
-			src += 4;
-			dst += 4;
+			src += 3;
+			dst += 3;
 		}
-		_system->setPalette(_currentPalette, 0, _fastFadeCount);
+		_system->getPaletteManager()->setPalette(_currentPalette, 0, _fastFadeCount);
 		delay(5);
 	}
 	_fastFadeInFlag = 0;
