@@ -18,25 +18,28 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/event.cpp $
- * $Id: event.cpp 50963 2010-07-17 18:38:42Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
 
 #include "agos/agos.h"
+#include "agos/animation.h"
 #include "agos/debugger.h"
 #include "agos/intern.h"
 
 #include "common/events.h"
 #include "common/system.h"
+#include "common/textconsole.h"
+
+#include "backends/audiocd/audiocd.h"
 
 #include "gui/about.h"
 
 #include "graphics/surface.h"
 
-#include "sound/audiocd.h"
 
 namespace AGOS {
 
@@ -429,7 +432,7 @@ void AGOSEngine::delay(uint amount) {
 	uint32 cur = start;
 	uint this_delay, vgaPeriod;
 
-	AudioCD.updateCD();
+	_system->getAudioCDManager()->updateCD();
 
 	_debugger->onFrame();
 
@@ -534,7 +537,7 @@ void AGOSEngine::delay(uint amount) {
 		if (_leftButton == 1)
 			_leftButtonCount++;
 
-		AudioCD.updateCD();
+		_system->getAudioCDManager()->updateCD();
 
 		_system->updateScreen();
 
