@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/feeble.cpp $
- * $Id: feeble.cpp 43294 2009-08-12 00:53:35Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,6 +31,7 @@
 
 #include "agos/intern.h"
 #include "agos/agos.h"
+#include "agos/animation.h"
 
 namespace AGOS {
 
