@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/gfx.cpp $
- * $Id: gfx.cpp 50643 2010-07-04 07:32:12Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 
 
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "graphics/surface.h"
 
@@ -778,7 +779,7 @@ void AGOSEngine::drawVertImage(VC10_state *state) {
 }
 
 void AGOSEngine::drawVertImageUncompressed(VC10_state *state) {
-	assert ((state->flags & kDFCompressed) == 0) ;
+	assert((state->flags & kDFCompressed) == 0);
 
 	const byte *src;
 	byte *dst;
@@ -804,7 +805,7 @@ void AGOSEngine::drawVertImageUncompressed(VC10_state *state) {
 }
 
 void AGOSEngine::drawVertImageCompressed(VC10_state *state) {
-	assert (state->flags & kDFCompressed) ;
+	assert(state->flags & kDFCompressed);
 	uint w, h;
 
 	state->x_skip *= 4;				/* reached */
@@ -1041,7 +1042,7 @@ void AGOSEngine::paletteFadeOut(byte *palPtr, uint num, uint size) {
 			p[2] -= size;
 		else
 			p[2] = 0;
-		p += 4;
+		p += 3;
 	} while (--num);
 }
 
