@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/icons.cpp $
- * $Id: icons.cpp 49843 2010-06-15 12:33:20Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
 
-#include "common/system.h"
-
 #include "common/file.h"
+#include "common/system.h"
+#include "common/textconsole.h"
 
 #include "graphics/surface.h"
 
@@ -484,7 +484,7 @@ void AGOSEngine::drawIconArray(uint num, Item *itemRef, int line, int classMask)
 	Item *item_ptr_org = itemRef;
 	WindowBlock *window;
 	uint width, height;
-	uint k, i, curWidth;
+	uint k, curWidth;
 	bool item_again, showArrows;
 	uint x_pos, y_pos;
 	const int iconSize = (getGameType() == GType_SIMON2) ? 20 : 1;
@@ -502,8 +502,6 @@ void AGOSEngine::drawIconArray(uint num, Item *itemRef, int line, int classMask)
 		height = window->height / 3;
 	}
 
-	i = 0;
-
 	if (window == NULL)
 		return;
 
