@@ -18,16 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/midiparser_s1d.cpp $
- * $Id: midiparser_s1d.cpp 42606 2009-07-19 09:09:56Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/debug.h"
 #include "common/util.h"
+#include "common/textconsole.h"
 
-#include "sound/mididrv.h"
-#include "sound/midiparser.h"
+#include "audio/mididrv.h"
+#include "audio/midiparser.h"
 
 namespace AGOS {
 
