@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/res.cpp $
- * $Id: res.cpp 43304 2009-08-12 02:24:03Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,8 @@
 
 
 #include "common/file.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
 #include "agos/agos.h"
@@ -35,8 +37,6 @@
 
 #include "common/zlib.h"
 
-using Common::File;
-
 namespace AGOS {
 
 #ifdef ENABLE_AGOS2
@@ -67,7 +67,7 @@ uint32 AGOSEngine::readUint32Wrapper(const void *src) {
 
 void AGOSEngine::decompressData(const char *srcName, byte *dst, uint32 offset, uint32 srcSize, uint32 dstSize) {
 #ifdef USE_ZLIB
-		File in;
+		Common::File in;
 		in.open(srcName);
 		if (in.isOpen() == false)
 			error("decompressData: Can't load %s", srcName);
@@ -548,7 +548,7 @@ uint fileReadItemID(Common::SeekableReadStream *in) {
 }
 
 void AGOSEngine::openGameFile() {
-	_gameFile = new File();
+	_gameFile = new Common::File();
 	_gameFile->open(getFileName(GAME_GMEFILE));
 
 	if (!_gameFile->isOpen())
@@ -717,7 +717,7 @@ static void transferLoop(uint8 *dataOut, int &outIndex, uint32 destVal, int max)
 	assert(outIndex > max - 1);
 	byte *pDest = dataOut + outIndex;
 
-	 for (int i = 0; (i <= max) && (outIndex > 0) ; ++i) {
+	 for (int i = 0; (i <= max) && (outIndex > 0); ++i) {
 		pDest = dataOut + --outIndex;
 		*pDest = pDest[destVal];
 	 }
@@ -783,7 +783,7 @@ void AGOSEngine::loadVGABeardFile(uint16 id) {
 	uint32 offs, size;
 
 	if (getFeatures() & GF_OLD_BUNDLE) {
-		File in;
+		Common::File in;
 		char filename[15];
 		if (id == 23)
 			id = 112;
@@ -824,7 +824,7 @@ void AGOSEngine::loadVGABeardFile(uint16 id) {
 }
 
 void AGOSEngine::loadVGAVideoFile(uint16 id, uint8 type, bool useError) {
-	File in;
+	Common::File in;
 	char filename[15];
 	byte *dst;
 	uint32 file, offs, srcSize, dstSize;
