@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/script.cpp $
- * $Id: script.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "agos/animation.h"
 #include "agos/agos.h"
