@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/script_dp.cpp $
- * $Id: script_dp.cpp 44286 2009-09-24 03:53:06Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -271,7 +271,7 @@ void AGOSEngine_DIMP::setupOpcodes() {
 		OPCODE(os1_unloadZone),
 		OPCODE(o_invalid),
 		OPCODE(os1_unfreezeZones),
-		OPCODE(off_centreScroll),
+		OPCODE(off_centerScroll),
 		/* 188 */
 		OPCODE(os2_isShortText),
 		OPCODE(os2_clearMarks),
@@ -281,7 +281,7 @@ void AGOSEngine_DIMP::setupOpcodes() {
 		OPCODE(opp_setPathValues),
 		OPCODE(off_stopClock),
 		OPCODE(off_restartClock),
-		OPCODE(off_setColour),
+		OPCODE(off_setColor),
 	};
 
 	_opcodesDIMP = opcodes;
