@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/script_s1.cpp $
- * $Id: script_s1.cpp 48645 2010-04-12 21:21:06Z salty-horse $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/system.h"
 
+#include "graphics/palette.h"
+
 #include "agos/agos.h"
 
 #ifdef _WIN32_WCE
@@ -578,13 +580,13 @@ void AGOSEngine_Simon1::os1_specialFade() {
 
 	for (i = 32; i != 0; --i) {
 		paletteFadeOut(_currentPalette, 32, 8);
-		paletteFadeOut(_currentPalette + 4 * 48, 144, 8);
-		paletteFadeOut(_currentPalette + 4 * 208, 48, 8);
-		_system->setPalette(_currentPalette, 0, 256);
+		paletteFadeOut(_currentPalette + 3 * 48, 144, 8);
+		paletteFadeOut(_currentPalette + 3 * 208, 48, 8);
+		_system->getPaletteManager()->setPalette(_currentPalette, 0, 256);
 		delay(5);
 	}
 
-	memcpy(_displayPalette, _currentPalette, 1024);
+	memcpy(_displayPalette, _currentPalette, sizeof(_currentPalette));
 }
 
 void AGOSEngine::scriptMouseOff() {
