@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/string_pn.cpp $
- * $Id: string_pn.cpp 44495 2009-09-30 16:16:53Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "agos/agos.h"
 #include "agos/intern.h"
 
+#include "common/textconsole.h"
+
 namespace AGOS {
 
 uint32 AGOSEngine_PN::ftext(uint32 base, int n) {
