@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/verb_pn.cpp $
- * $Id: verb_pn.cpp 43304 2009-08-12 02:24:03Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -185,7 +185,7 @@ void AGOSEngine_PN::hitBox5(HitArea *ha) {
 
 	_mousePrintFG++;
 	_mouseString = (const char *)"take \0";
-	_mouseString1 = getMessage(_objectName1, _dragStore->msg1);
+	_mouseString1 = _dragStore ? getMessage(_objectName1, _dragStore->msg1) : "";
 
 	if (_dragStore->flags & kOBFRoomBox)
 		_mouseString1 = (const char *)"all\r";
