@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/vga_ff.cpp $
- * $Id: vga_ff.cpp 48365 2010-03-23 00:42:42Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -201,7 +201,7 @@ void AGOSEngine::vc78_computeXY() {
 	if (getGameType() == GType_FF) {
 		setBitFlag(85, false);
 		if (getBitFlag(74)) {
-			centreScroll();
+			centerScroll();
 		}
 	}
 }
@@ -348,7 +348,7 @@ void AGOSEngine::checkScrollY(int16 y, int16 ypos) {
 	}
 }
 
-void AGOSEngine::centreScroll() {
+void AGOSEngine::centerScroll() {
 	int16 x, y, tmp;
 
 	if (_scrollXMax != 0) {
@@ -405,9 +405,9 @@ void AGOSEngine_PuzzlePack::vc63_fastFadeIn() {
 	if (getBitFlag(100)) {
 		startOverlayAnims();
 	} else if (getBitFlag(103)) {
-		printf("NameAndTime\n");
+		debug("vc63_fastFadeIn: NameAndTime");
 	} else if (getBitFlag(104)) {
-		printf("HiScoreTable\n");
+		debug("vc63_fastFadeIn: HiScoreTable");
 	}
 }
 
