@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/window.cpp $
- * $Id: window.cpp 44314 2009-09-24 17:52:53Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
 
 
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "graphics/surface.h"
 
@@ -151,13 +152,13 @@ void AGOSEngine::colorWindow(WindowBlock *window) {
 
 	if (getGameType() == GType_ELVIRA2 && window->y == 146) {
 		if (window->fillColor == 1) {
-			_displayPalette[33 * 4 + 0] = 48 * 4;
-			_displayPalette[33 * 4 + 1] = 40 * 4;
-			_displayPalette[33 * 4 + 2] = 32 * 4;
+			_displayPalette[33 * 3 + 0] = 48 * 4;
+			_displayPalette[33 * 3 + 1] = 40 * 4;
+			_displayPalette[33 * 3 + 2] = 32 * 4;
 		} else {
-			_displayPalette[33 * 4 + 0] = 56 * 4;
-			_displayPalette[33 * 4 + 1] = 56 * 4;
-			_displayPalette[33 * 4 + 2] = 40 * 4;
+			_displayPalette[33 * 3 + 0] = 56 * 4;
+			_displayPalette[33 * 3 + 1] = 56 * 4;
+			_displayPalette[33 * 3 + 2] = 40 * 4;
 		}
 
 		y--;
