@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/anim.cpp $
- * $Id: anim.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,7 +28,8 @@
  */
 
 #include "common/endian.h"
-#include "common/stream.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 #include "cine/cine.h"
 #include "cine/anim.h"
@@ -485,7 +486,7 @@ void convert4BBP(byte *dest, const byte *source, int16 width, int16 height) {
  * @param[out] animHeader Image header reference
  * @param readS Input stream open for reading
  */
-void loadAnimHeader(AnimHeaderStruct &animHeader, Common::MemoryReadStream readS) {
+void loadAnimHeader(AnimHeaderStruct &animHeader, Common::SeekableReadStream &readS) {
 	animHeader.field_0 = readS.readByte();
 	animHeader.field_1 = readS.readByte();
 	animHeader.field_2 = readS.readByte();
