@@ -18,26 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/cine.cpp $
- * $Id: cine.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/events.h"
 #include "common/EventRecorder.h"
-#include "common/file.h"
-#include "common/savefile.h"
 #include "common/config-manager.h"
 #include "common/debug-channels.h"
-#include "common/system.h"
 
 #include "engines/util.h"
 
 #include "graphics/cursorman.h"
 
-#include "sound/mididrv.h"
-#include "sound/mixer.h"
-
 #include "cine/cine.h"
 #include "cine/bg_list.h"
 #include "cine/main_loop.h"
@@ -53,17 +46,14 @@ Sound *g_sound = 0;
 CineEngine *g_cine = 0;
 
 CineEngine::CineEngine(OSystem *syst, const CINEGameDescription *gameDesc) : Engine(syst), _gameDescription(gameDesc) {
-	DebugMan.addDebugChannel(kCineDebugScript, "Script", "Script debug level");
-	DebugMan.addDebugChannel(kCineDebugPart,   "Part",   "Part debug level");
-	DebugMan.addDebugChannel(kCineDebugSound,  "Sound",  "Sound debug level");
-
 	// Setup mixer
-	_mixer->setVolumeForSoundType(Audio::Mixer::kSFXSoundType, ConfMan.getInt("sfx_volume"));
-	_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, ConfMan.getInt("music_volume"));
-	// Use music volume for plain sound types (At least the AdLib player uses a plain sound type
-	// so previously the music and sfx volume controls didn't affect it at all).
-	// FIXME: Make AdLib player differentiate between playing sound effects and music and remove this.
-	_mixer->setVolumeForSoundType(Audio::Mixer::kPlainSoundType, ConfMan.getInt("music_volume"));
+	syncSoundSettings();
+
+	DebugMan.addDebugChannel(kCineDebugScript,    "Script",    "Script debug level");
+	DebugMan.addDebugChannel(kCineDebugPart,      "Part",      "Part debug level");
+	DebugMan.addDebugChannel(kCineDebugSound,     "Sound",     "Sound debug level");
+	DebugMan.addDebugChannel(kCineDebugCollision, "Collision", "Collision debug level");
+	_console = new CineConsole(this);
 
 	g_cine = this;
 
@@ -74,7 +64,23 @@ CineEngine::~CineEngine() {
 	if (getGameType() == Cine::GType_OS) {
 		freeErrmessDat();
 	}
+
 	DebugMan.clearAllDebugChannels();
+	delete _console;
+}
+
+void CineEngine::syncSoundSettings() {
+	Engine::syncSoundSettings();
+
+	bool mute = false;
+	if (ConfMan.hasKey("mute"))
+		mute = ConfMan.getBool("mute");
+
+	// Use music volume for plain sound types (At least the AdLib player uses a plain sound type
+	// so previously the music and sfx volume controls didn't affect it at all).
+	// FIXME: Make AdLib player differentiate between playing sound effects and music and remove this.
+	_mixer->setVolumeForSoundType(Audio::Mixer::kPlainSoundType,
+									mute ? 0 : ConfMan.getInt("music_volume"));
 }
 
 Common::Error CineEngine::run() {
@@ -158,6 +164,7 @@ void CineEngine::initialize() {
 	renderer->initialize();
 
 	collisionPage = new byte[320 * 200];
+	memset(collisionPage, 0, 320 * 200);
 
 	// Clear part buffer as there's nothing loaded into it yet.
 	// Its size will change when loading data into it with the loadPart function.
