@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/gfx.cpp $
- * $Id: gfx.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,8 +30,9 @@
 #include "cine/pal.h"
 
 #include "common/endian.h"
-#include "common/system.h"
 #include "common/events.h"
+#include "common/system.h"
+#include "common/textconsole.h"
 
 #include "graphics/cursorman.h"
 
@@ -1429,10 +1430,13 @@ void OSRenderer::loadCt256(const byte *ct, const char *name) {
  * @param idx Background index
  */
 void OSRenderer::selectBg(unsigned int idx) {
-	assert(idx < 9 && _bgTable[idx].bg);
-	assert(_bgTable[idx].pal.isValid() && !(_bgTable[idx].pal.empty()));
+	assert(idx < 9);
 
+	if (_bgTable[idx].bg) {
+		assert(_bgTable[idx].pal.isValid() && !(_bgTable[idx].pal.empty()));
 	_currentBg = idx;
+	} else
+		warning("OSRenderer::selectBg(%d) - attempt to select null background", idx);
 	reloadPalette();
 }
 
