@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/main_loop.cpp $
- * $Id: main_loop.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -161,6 +161,12 @@ static void processEvent(Common::Event &event) {
 		case Common::KEYCODE_KP3:
 			moveUsingKeyboard(+1, -1); // Down & Right
 			break;
+		case Common::KEYCODE_d:
+			if (event.kbd.hasFlags(Common::KBD_CTRL)) {
+				g_cine->getDebugger()->attach();
+				g_cine->getDebugger()->onFrame();
+			}
+			// No Break to allow fallthrough to process 'd' without CTRL
 		default:
 			lastKeyStroke = event.kbd.keycode;
 			break;
