@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/msg.cpp $
- * $Id: msg.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/debug.h"
 #include "common/endian.h"
+#include "common/textconsole.h"
 
 #include "cine/msg.h"
 #include "cine/various.h"
