@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/object.cpp $
- * $Id: object.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/endian.h"
-#include "common/scummsys.h"
+#include "common/memstream.h"
 #include "common/util.h"
 
 #include "cine/cine.h"
@@ -43,6 +43,7 @@ void resetObjectTable() {
 }
 
 void loadObject(char *pObjectName) {
+	debug(5, "loadObject(\"%s\")", pObjectName);
 	uint16 numEntry;
 	uint16 entrySize;
 	uint16 i;
@@ -61,7 +62,7 @@ void loadObject(char *pObjectName) {
 	assert(numEntry <= NUM_MAX_OBJECT);
 
 	for (i = 0; i < numEntry; i++) {
-		if (g_cine->_objectTable[i].costume != -2) {	// flag is keep ?
+		if (g_cine->_objectTable[i].costume != -2 && g_cine->_objectTable[i].costume != -3) {	// flag is keep ?
 			Common::MemoryReadStream readS(ptr, entrySize);
 
 			g_cine->_objectTable[i].x = readS.readSint16BE();
