@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/part.cpp $
- * $Id: part.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/debug.h"
 #include "common/endian.h"
+#include "common/textconsole.h"
 
 #include "cine/cine.h"
 #include "cine/unpack.h"
@@ -164,7 +165,7 @@ void CineEngine::readVolCnf() {
 		// All file name blocks' sizes were divisible by either 11 or 13, but not with both.
 		fileNameLength = (fileNameLenMod11 ? 11 : 13);
 	} else {
-		warning("Couldn't deduce file name length from data in 'vol.cnf', using a backup deduction scheme.");
+		warning("Couldn't deduce file name length from data in 'vol.cnf', using a backup deduction scheme");
 		// Here we use the former file name length detection method
 		// if we couldn't deduce the file name length from the data.
 		fileNameLength = (compressed ? 11 : 13);
