@@ -18,22 +18,24 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/sound.cpp $
- * $Id: sound.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
 #include "common/file.h"
+#include "common/memstream.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "cine/cine.h"
 #include "cine/sound.h"
 
-#include "sound/audiostream.h"
-#include "sound/fmopl.h"
-#include "sound/decoders/raw.h"
-#include "sound/mods/soundfx.h"
+#include "audio/audiostream.h"
+#include "audio/fmopl.h"
+#include "audio/decoders/raw.h"
+#include "audio/mods/soundfx.h"
 
 namespace Cine {
 
@@ -575,9 +577,7 @@ PCSoundFxPlayer::PCSoundFxPlayer(PCSoundDriver *driver)
 
 PCSoundFxPlayer::~PCSoundFxPlayer() {
 	_driver->setUpdateCallback(NULL, NULL);
-	if (_playing) {
-		stop();
-	}
+	stop();
 }
 
 bool PCSoundFxPlayer::load(const char *song) {
@@ -589,9 +589,7 @@ bool PCSoundFxPlayer::load(const char *song) {
 	}
 	_fadeOutCounter = 0;
 
-	if (_playing) {
-		stop();
-	}
+	stop();
 
 	_sfxData = readBundleSoundFile(song);
 	if (!_sfxData) {
@@ -645,8 +643,8 @@ void PCSoundFxPlayer::stop() {
 			_driver->stopChannel(i);
 		}
 		_driver->stopAll();
-		unload();
 	}
+	unload();
 }
 
 void PCSoundFxPlayer::fadeOut() {
