@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/sound.h $
- * $Id: sound.h 29790 2007-12-09 13:41:59Z cyx $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,10 +27,10 @@
 #define CINE_SOUND_H_
 
 #include "common/util.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Audio {
-	class AudioStream;
+class AudioStream;
 }
 
 namespace Cine {
