@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/texte.cpp $
- * $Id: texte.cpp 48764 2010-04-21 21:22:43Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "cine/cine.h"
 #include "common/file.h"
+#include "common/textconsole.h"
+
+#include "cine/cine.h"
 #include "cine/various.h"
 
 namespace Cine {
@@ -605,6 +607,8 @@ void loadErrmessDat(const char *fname) {
 	in.open(fname);
 
 	if (in.isOpen()) {
+		// FIXME - This can leak in some situations in Operation Stealth
+		//         Engine Restart - multiple allocations with no free?
 		char **ptr = (char **)malloc(sizeof(char *) * 6 * 4 + 60 * 6 * 4);
 
 		for (int i = 0; i < 6 * 4; i++) {
