@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/various.cpp $
- * $Id: various.cpp 51937 2010-08-09 11:38:01Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/endian.h"
 #include "common/events.h"
+#include "common/textconsole.h"
 
 #include "graphics/cursorman.h"
 
@@ -1323,7 +1324,8 @@ void addSeqListElement(uint16 objIdx, int16 param1, int16 param2, int16 frame, i
 	Common::List<SeqListElement>::iterator it;
 	SeqListElement tmp;
 
-	for (it = g_cine->_seqList.begin(); it != g_cine->_seqList.end() && it->varE < param7; ++it) ;
+	for (it = g_cine->_seqList.begin(); it != g_cine->_seqList.end() && it->varE < param7; ++it)
+		;
 
 	tmp.objIdx = objIdx;
 	tmp.var4 = param1;
