@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/backgroundIncrust.cpp $
- * $Id: backgroundIncrust.cpp 44808 2009-10-09 08:15:30Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -198,17 +198,13 @@ void regenerateBackgroundIncrust(backgroundIncrustStruct *pHead) {
 	while (pl) {
 		backgroundIncrustStruct* pl2 = pl->next;
 
-		bool bLoad = false;
 		int frame = pl->frame;
 		//int screen = pl->backgroundIdx;
 
 		if ((filesDatabase[frame].subData.ptr == NULL) || (strcmp(pl->name, filesDatabase[frame].subData.name))) {
 			frame = NUM_FILE_ENTRIES - 1;
-			if (loadFile(pl->name, frame, pl->spriteId) >= 0) {
-				bLoad = true;
-			} else {
+			if (loadFile(pl->name, frame, pl->spriteId) < 0)
 				frame = -1;
-			}
 		}
 
 		if (frame >= 0) {
