@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/cruise_main.cpp $
- * $Id: cruise_main.cpp 54667 2010-11-30 08:27:15Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #include "common/endian.h"
 #include "common/events.h"
 #include "common/system.h"	// for g_system->getEventManager()
+#include "common/textconsole.h"
 
 #include "cruise/cruise.h"
 #include "cruise/cruise_main.h"
@@ -44,11 +45,11 @@ gfxEntryStruct* linkedMsgList = NULL;
 
 void MemoryList() {
 	if (!_vm->_memList.empty()) {
-		printf("Current list of un-freed memory blocks:\n");
+		debug("Current list of un-freed memory blocks:");
 		Common::List<byte *>::iterator i;
 		for (i = _vm->_memList.begin(); i != _vm->_memList.end(); ++i) {
 			byte *v = *i;
-			printf("%s - %d\n", (const char *)(v - 68), *((int32 *)(v - 72)));
+			debug("%s - %d", (const char *)(v - 68), *((int32 *)(v - 72)));
 		}
 	}
 }
@@ -1004,18 +1005,7 @@ bool findRelation(int objOvl, int objIdx, int x, int y) {
 					if (!obj2Ovl)  obj2Ovl = j;
 
 					char verbe_name[80];
-					char obj1_name[80];
-					char obj2_name[80];
-					char r_verbe_name[80];
-					char r_obj1_name[80];
-					char r_obj2_name[80];
-
 					verbe_name[0]	= 0;
-					obj1_name[0]	= 0;
-					obj2_name[0]	= 0;
-					r_verbe_name[0] = 0;
-					r_obj1_name[0]	= 0;
-					r_obj2_name[0]	= 0;
 
 					ovlDataStruct *ovl2 = NULL;
 					ovlDataStruct *ovl3 = NULL;
@@ -1889,7 +1879,7 @@ void CruiseEngine::mainLoop() {
 		// FIXME: I suspect that the original game does multiple script executions between game frames; the bug with
 		// Raoul appearing when looking at the book is being there are 3 script iterations separation between the
 		// scene being changed to the book, and the Raoul actor being frozen/disabled. This loop is a hack to ensure
-		// that when a background changes, a few extra script executions are done
+		// that does a few extra script executions for that scene
 		bool bgChanged;
 		int numIterations = 1;
 
@@ -1902,7 +1892,8 @@ void CruiseEngine::mainLoop() {
 			removeFinishedScripts(&relHead);
 			removeFinishedScripts(&procHead);
 
-			if (!bgChanged && backgroundChanged[masterScreen]) {
+			if (!bgChanged && backgroundChanged[masterScreen] &&
+					!strcmp(backgroundTable[0].name, "S06B.PI1")) {
 				bgChanged = true;
 				numIterations += 2;
 			}
