@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/ctp.cpp $
- * $Id: ctp.cpp 51936 2010-08-09 10:30:40Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -167,7 +167,7 @@ void makeCtStruct(Common::Array<CtStruct> &lst, int16 table[][40], int num, int
 	}
 
 	ct.num = num;
-	ct.colour = walkboxColor[num];
+	ct.color = walkboxColor[num];
 	ct.bounds.left = minX;
 	ct.bounds.right = maxX;
 	ct.bounds.top = minY;
