@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/dataLoader.cpp $
- * $Id: dataLoader.cpp 48218 2010-03-10 06:39:23Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "cruise/cruise_main.h"
 #include "common/endian.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 namespace Cruise {
 
@@ -55,7 +57,7 @@ void decodeGfxUnified(dataFileEntry *pCurrentFileEntry, int16 format) {
 		break;
 
 	default:
-		error("Unkown gfx format %d", format);
+		error("Unknown gfx format %d", format);
 	}
 
 	uint8 *buffer = (uint8 *)MemAlloc(spriteSize);
@@ -357,7 +359,7 @@ int loadFNTSub(uint8 *ptr, int destIdx) {
 	uint8 *ptr2 = ptr;
 	uint8 *destPtr;
 	int fileIndex;
-	uint32 fontSize;
+	//uint32 fontSize;
 
 	ptr2 += 4;
 	loadFileVar1 = READ_BE_UINT32(ptr2);
@@ -372,7 +374,7 @@ int loadFNTSub(uint8 *ptr, int destIdx) {
 
 	memcpy(destPtr, ptr2, loadFileVar1);
 
-	fontSize = READ_BE_UINT32(ptr2);
+	//fontSize = READ_BE_UINT32(ptr2);
 
 	if (destPtr != NULL) {
 		int32 i;
