@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/detection.cpp $
- * $Id: detection.cpp 49788 2010-06-15 10:59:23Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 
 #include "base/plugins.h"
 #include "common/savefile.h"
+#include "common/system.h"
 #include "engines/advancedDetector.h"
 
 #include "cruise/cruise.h"
@@ -74,7 +75,7 @@ static const CRUISEGameDescription gameDescriptions[] = {
 	{
 		{
 			"cruise",
-			"16 colours",
+			"16 colors",
 			AD_ENTRY1("D1", "cd29a4cd9162076e9a18495fe56a48f3"),
 			Common::EN_GRB,
 			Common::kPlatformPC,
