@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/linker.cpp $
- * $Id: linker.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -147,8 +147,6 @@ int updateScriptImport(int ovlIdx) {
 				const char *ptrImportName;
 				uint8 *ptrData;
 
-				int var_22 = 0;
-
 				if (param == 0) {
 					pScript = getOvlData3Entry(ovlIdx, i);
 				} else {
@@ -159,8 +157,6 @@ int updateScriptImport(int ovlIdx) {
 				ptrImportName = (const char*)(pScript->dataPtr + pScript->offsetToImportName);	// import name
 				ptrData = pScript->dataPtr;
 
-				var_22 = 0;
-
 				if (pScript->numRelocGlob > 0) {
 					int counter = pScript->numRelocGlob;
 
