@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/menu.cpp $
- * $Id: menu.cpp 52691 2010-09-12 21:21:21Z criezy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,6 +29,7 @@
 
 #include "engines/metaengine.h"
 #include "gui/saveload.h"
+#include "common/system.h"
 #include "common/translation.h"
 
 namespace Cruise {
@@ -218,7 +219,7 @@ static void handleSaveLoad(bool saveFlag) {
 		dialog = new GUI::SaveLoadChooser(_("Load game:"), _("Load"));
 
 	dialog->setSaveMode(saveFlag);
-	int slot = dialog->runModal(plugin, ConfMan.getActiveDomainName());
+	int slot = dialog->runModalWithPluginAndTarget(plugin, ConfMan.getActiveDomainName());
 
 	if (slot >= 0) {
 		if (!saveFlag)
