@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/overlay.cpp $
- * $Id: overlay.cpp 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/stream.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 #include "cruise/cruise.h"
 #include "cruise/cruise_main.h"
@@ -662,6 +663,7 @@ int loadOverlay(const char *scriptName) {
 #endif
 #ifdef DUMP_OBJECT
 	{
+		// TODO: Rewrite this to use Common::DumpFile
 		int i;
 		FILE *fHandle;
 		char nameBundle[100];
