@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/saveload.cpp $
- * $Id: saveload.cpp 51936 2010-08-09 10:30:40Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,6 +30,7 @@
 #include "common/serializer.h"
 #include "common/savefile.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "graphics/scaler.h"
 #include "graphics/thumbnail.h"
@@ -901,8 +902,7 @@ Common::Error loadSavegameData(int saveGameIdx) {
 			}
 
 			/*if (j < 2) {
-				printf("Unsupported mono file load!\n");
-				ASSERT(0);
+				error("Unsupported mono file load");
 				//loadFileMode1(filesDatabase[j].subData.name,filesDatabase[j].subData.var4);
 			} else */
 			if (strlen(filesDatabase[i].subData.name) > 0) {
