@@ -18,21 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/sound.cpp $
- * $Id: sound.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
+#include "common/system.h"
+#include "common/textconsole.h"
 
 #include "cruise/cruise.h"
 #include "cruise/cruise_main.h"
 #include "cruise/sound.h"
 #include "cruise/volume.h"
 
-#include "sound/audiostream.h"
-#include "sound/fmopl.h"
-#include "sound/mods/soundfx.h"
+#include "audio/audiostream.h"
+#include "audio/fmopl.h"
+#include "audio/mods/soundfx.h"
 
 namespace Cruise {
 
@@ -40,6 +42,7 @@ class PCSoundDriver {
 public:
 	typedef void (*UpdateCallback)(void *);
 
+	PCSoundDriver() { _upCb = NULL, _upRef = NULL, _musicVolume = 0, _sfxVolume = 0; }
 	virtual ~PCSoundDriver() {}
 
 	virtual void setupChannel(int channel, const byte *data, int instrument, int volume) = 0;
@@ -282,9 +285,21 @@ void PCSoundDriver::resetChannel(int channel) {
 }
 
 void PCSoundDriver::syncSounds() {
+	bool mute = false;
+	if (ConfMan.hasKey("mute"))
+		mute = ConfMan.getBool("mute");
+
+	bool music_mute = mute;
+	bool sfx_mute = mute;
+
+	if (!mute) {
+		music_mute = ConfMan.getBool("music_mute");
+		sfx_mute = ConfMan.getBool("sfx_mute");
+	}
+
 	// Get the new music and sfx volumes
-	_musicVolume = ConfMan.getBool("music_mute") ? 0 : MIN(255, ConfMan.getInt("music_volume"));
-	_sfxVolume = ConfMan.getBool("sfx_mute") ? 0 : MIN(255, ConfMan.getInt("sfx_volume"));
+	_musicVolume = music_mute ? 0 : MIN(255, ConfMan.getInt("music_volume"));
+	_sfxVolume = sfx_mute ? 0 : MIN(255, ConfMan.getInt("sfx_volume"));
 }
 
 AdLibSoundDriver::AdLibSoundDriver(Audio::Mixer *mixer)
