@@ -18,17 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cruise/sound.h $
- * $Id: sound.h 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef CRUISE_SOUND_H
 #define CRUISE_SOUND_H
 
-#include "sound/mididrv.h"
-#include "sound/midiparser.h"
-#include "sound/mixer.h"
+#include "audio/mididrv.h"
+#include "audio/midiparser.h"
+#include "audio/mixer.h"
 
 #include "common/config-manager.h"
 #include "common/serializer.h"
