@@ -18,22 +18,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/dialogs.h $
- * $Id: dialogs.h 49249 2010-05-26 19:54:50Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef GLOBAL_DIALOGS_H
 #define GLOBAL_DIALOGS_H
 
-#include "common/str.h"
 #include "gui/dialog.h"
 
 class Engine;
 
 namespace GUI {
-	class ButtonWidget;
-	class GraphicsWidget;
-	class SaveLoadChooser;
+class ButtonWidget;
+class CommandSender;
+class GraphicsWidget;
+class SaveLoadChooser;
 }
 
 class MainMenuDialog : public GUI::Dialog {
