@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/draci/animation.cpp $
- * $Id: animation.cpp 50618 2010-07-03 05:05:28Z spalek $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,6 +31,9 @@
 #include "draci/sound.h"
 #include "draci/surface.h"
 
+#include "common/memstream.h"
+#include "common/system.h"
+
 namespace Draci {
 
 Animation::Animation(DraciEngine *vm, int id, uint z, bool playing) : _vm(vm) {
@@ -357,7 +360,7 @@ void AnimationManager::insert(Animation *anim, bool allocateIndex) {
 }
 
 void AnimationManager::drawScene(Surface *surf) {
-	// Fill the screen with colour zero since some rooms may rely on the screen being black
+	// Fill the screen with color zero since some rooms may rely on the screen being black
 	_vm->_screen->getSurface()->fill(0);
 
 	sortAnimations();
@@ -496,8 +499,8 @@ const Animation *AnimationManager::getTopAnimation(int x, int y) const {
 
 	Animation *retval = NULL;
 
-	// Get transparent colour for the current screen
-	const int transparent = _vm->_screen->getSurface()->getTransparentColour();
+	// Get transparent color for the current screen
+	const int transparent = _vm->_screen->getSurface()->getTransparentColor();
 
 	for (it = _animations.reverse_begin(); it != _animations.end(); --it) {
 
