@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/draci/draci.h $
- * $Id: draci.h 48279 2010-03-18 15:07:11Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "engines/engine.h"
 #include "common/random.h"
+#include "draci/console.h"
 
 struct ADGameDescription;
 
@@ -37,10 +38,10 @@ class OSystem;
 /**
  * This is the namespace of the Draci engine.
  *
- * Status of this engine: ???
+ * Status of this engine: Complete
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Dragon History
  */
 namespace Draci {
 
@@ -75,6 +76,8 @@ public:
 	virtual Common::Error saveGameState(int slot, const char *desc);
 	virtual bool canSaveGameStateCurrently();
 
+	GUI::Debugger *getDebugger() { return _console; }
+
 	Screen *_screen;
 	Mouse *_mouse;
 	Game *_game;
@@ -82,7 +85,6 @@ public:
 	AnimationManager *_anims;
 	Sound *_sound;
 	MusicPlayer *_music;
-	MidiDriver *_midiDriver;
 
 	Font *_smallFont;
 	Font *_bigFont;
@@ -107,8 +109,9 @@ public:
 
 	Common::RandomSource _rnd;
 
-	int32 _engineStartTime;
 	int32 _pauseStartTime;
+private:
+	DraciConsole *_console;
 };
 
 enum {
