@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/draci/game.h $
- * $Id: game.h 50519 2010-06-30 08:27:09Z spalek $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,7 +31,7 @@
 #include "draci/walking.h"
 
 namespace Common {
-	class Serializer;
+class Serializer;
 }
 
 namespace Draci {
@@ -145,7 +145,7 @@ public:
 
 struct Person {
 	uint _x, _y;
-	byte _fontColour;
+	byte _fontColor;
 };
 
 struct Dialogue {
@@ -348,7 +348,7 @@ private:
 	void enterNewRoom();
 	void initWalkingOverlays();
 	void loadRoomObjects();
-	void redrawWalkingPath(Animation *anim, byte colour, const WalkingPath &path);
+	void redrawWalkingPath(Animation *anim, byte color, const WalkingPath &path);
 
 	DraciEngine *_vm;
 
