@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/draci/mouse.cpp $
- * $Id: mouse.cpp 47118 2010-01-07 15:07:36Z marcus_c $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -54,10 +54,10 @@ void Mouse::handleEvent(Common::Event event) {
 
 	case Common::EVENT_LBUTTONUP:
 		debugC(6, kDraciGeneralDebugLevel, "Left button up (x: %u y: %u)", _x, _y);
-                // Don't set _lButton to false, because some touchpads generate
-                // down and up at such a quick succession, that they will
-                // cancel each other in the same call of handleEvents().  Let
-                // the game clear this flag by calling lButtonSet() instead.
+		// Don't set _lButton to false, because some touchpads generate
+		// down and up at such a quick succession, that they will
+		// cancel each other in the same call of handleEvents().  Let
+		// the game clear this flag by calling lButtonSet() instead.
 		break;
 
 	case Common::EVENT_RBUTTONDOWN:
@@ -106,14 +106,14 @@ void Mouse::setCursorType(CursorType cur) {
 	f = _vm->_iconsArchive->getFile(cur);
 
 	Sprite sp(f->_data, f->_length, 0, 0, true);
-	CursorMan.replaceCursorPalette(_vm->_screen->getPalette(), 0, kNumColours);
+	CursorMan.replaceCursorPalette(_vm->_screen->getPalette(), 0, kNumColors);
 	CursorMan.replaceCursor(sp.getBuffer(), sp.getWidth(), sp.getHeight(),
 	        sp.getWidth() / 2, sp.getHeight() / 2, 255);
 }
 
 void Mouse::loadItemCursor(const GameItem *item, bool highlighted) {
 	const int itemID = item->_absNum;
-	const int archiveIndex = 2 * itemID + highlighted;
+	const int archiveIndex = 2 * itemID + (highlighted ? 1 : 0);
 	CursorType newCursor = static_cast<CursorType> (kItemCursor + archiveIndex);
 	if (newCursor == getCursorType()) {
 		return;
@@ -124,7 +124,7 @@ void Mouse::loadItemCursor(const GameItem *item, bool highlighted) {
 	f = _vm->_itemImagesArchive->getFile(archiveIndex);
 
 	Sprite sp(f->_data, f->_length, 0, 0, true);
-	CursorMan.replaceCursorPalette(_vm->_screen->getPalette(), 0, kNumColours);
+	CursorMan.replaceCursorPalette(_vm->_screen->getPalette(), 0, kNumColors);
 	CursorMan.replaceCursor(sp.getBuffer(), sp.getWidth(), sp.getHeight(),
 	        sp.getWidth() / 2, sp.getHeight() / 2, 255);
 }
