@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/draci/walking.h $
- * $Id: walking.h 46068 2009-11-22 09:13:05Z spalek $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -45,12 +45,12 @@ public:
 	bool getPixel(int x, int y) const;
 	bool isWalkable(const Common::Point &p) const;
 
-	Sprite *newOverlayFromMap(byte colour) const;
+	Sprite *newOverlayFromMap(byte color) const;
 	Common::Point findNearestWalkable(int x, int y) const;
 
 	bool findShortestPath(Common::Point p1, Common::Point p2, WalkingPath *path) const;
 	void obliquePath(const WalkingPath& path, WalkingPath *obliquedPath);
-	Sprite *newOverlayFromPath(const WalkingPath &path, byte colour) const;
+	Sprite *newOverlayFromPath(const WalkingPath &path, byte color) const;
 	Common::Point getDelta() const { return Common::Point(_deltaX, _deltaY); }
 
 	static int pointsBetween(const Common::Point &p1, const Common::Point &p2);
@@ -68,7 +68,7 @@ private:
 	// 4 possible directions to walk from a pixel.
 	static const int kDirections[][2];
 
-	void drawOverlayRectangle(const Common::Point &p, byte colour, byte *buf) const;
+	void drawOverlayRectangle(const Common::Point &p, byte color, byte *buf) const;
 	bool lineIsCovered(const Common::Point &p1, const Common::Point &p2) const;
 
 	// Returns true if the number of vertices on the path was decreased.
