@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/actors.cpp $
- * $Id: actors.cpp 50890 2010-07-14 17:02:14Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -450,7 +450,7 @@ void DrasculaEngine::placeVonBraun(int pointX) {
 	trackVonBraun = (pointX < vonBraunX) ? 0 : 1;
 	vonBraunHasMoved = 1;
 
-	for (;;) {
+	while (!shouldQuit()) {
 		updateEvents();
 		updateRoom();
 		updateScreen();
