@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/converse.cpp $
- * $Id: converse.cpp 52846 2010-09-21 17:58:09Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "drascula/drascula.h"
 
 namespace Drascula {
@@ -211,6 +213,7 @@ void DrasculaEngine::converse(int index) {
 		}
 
 		updateEvents();
+		flushKeyBuffer();
 
 		phrase1_bottom = 8 * print_abc_opc(phrase1, 2, game1);
 		phrase2_bottom = phrase1_bottom + 8 * print_abc_opc(phrase2, phrase1_bottom + 2, game2);
