@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/palette.cpp $
- * $Id: palette.cpp 49722 2010-06-15 10:24:38Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "graphics/palette.h"
+
 #include "drascula/drascula.h"
 
 namespace Drascula {
@@ -65,16 +67,13 @@ void DrasculaEngine::black() {
 }
 
 void DrasculaEngine::setPalette(byte *PalBuf) {
-	byte pal[256 * 4];
-	int i;
+	byte pal[256 * 3];
 
-	for (i = 0; i < 256; i++) {
-		pal[i * 4 + 0] = PalBuf[i * 3 + 0] * 4;
-		pal[i * 4 + 1] = PalBuf[i * 3 + 1] * 4;
-		pal[i * 4 + 2] = PalBuf[i * 3 + 2] * 4;
-		pal[i * 4 + 3] = 0;
+	for (int i = 0; i < 3 * 256; ++i) {
+		pal[i] = PalBuf[i] * 4;
 	}
-	_system->setPalette(pal, 0, 256);
+
+	_system->getPaletteManager()->setPalette(pal, 0, 256);
 	_system->updateScreen();
 }
 
