@@ -18,18 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/sound.cpp $
- * $Id: sound.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "sound/audiocd.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/voc.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/voc.h"
 
 #include "common/config-manager.h"
+#include "common/textconsole.h"
+
+#include "backends/audiocd/audiocd.h"
 
 #include "drascula/drascula.h"
 
@@ -54,7 +56,7 @@ void DrasculaEngine::volumeControls() {
 	setCursor(kCursorCrosshair);
 	showCursor();
 
-	for (;;) {
+	while (!shouldQuit()) {
 		int masterVolume = CLIP((_mixer->getVolumeForSoundType(Audio::Mixer::kPlainSoundType) / 16), 0, 15);
 		int voiceVolume = CLIP((_mixer->getVolumeForSoundType(Audio::Mixer::kSpeechSoundType) / 16), 0, 15);
 		int musicVolume = CLIP((_mixer->getVolumeForSoundType(Audio::Mixer::kMusicSoundType) / 16), 0, 15);
@@ -123,20 +125,20 @@ void DrasculaEngine::finishSound() {
 }
 
 void DrasculaEngine::playMusic(int p) {
-	AudioCD.stop();
-	AudioCD.play(p - 1, 1, 0, 0);
+	_system->getAudioCDManager()->stop();
+	_system->getAudioCDManager()->play(p - 1, 1, 0, 0);
 }
 
 void DrasculaEngine::stopMusic() {
-	AudioCD.stop();
+	_system->getAudioCDManager()->stop();
 }
 
 void DrasculaEngine::updateMusic() {
-	AudioCD.updateCD();
+	_system->getAudioCDManager()->updateCD();
 }
 
 int DrasculaEngine::musicStatus() {
-	return AudioCD.isPlaying();
+	return _system->getAudioCDManager()->isPlaying();
 }
 
 void DrasculaEngine::stopSound() {
@@ -145,7 +147,7 @@ void DrasculaEngine::stopSound() {
 
 void DrasculaEngine::MusicFadeout() {
 	int org_vol = _mixer->getVolumeForSoundType(Audio::Mixer::kMusicSoundType);
-	for (;;) {
+	while (!shouldQuit()) {
 		int vol = _mixer->getVolumeForSoundType(Audio::Mixer::kMusicSoundType);
 		vol -= 10;
 			if (vol < 0)
@@ -157,7 +159,7 @@ void DrasculaEngine::MusicFadeout() {
 		_system->updateScreen();
 		_system->delayMillis(50);
 	}
-	AudioCD.stop();
+	_system->getAudioCDManager()->stop();
 	_system->delayMillis(100);
 	_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, org_vol);
 }
