@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/game.h $
- * $Id: game.h 49786 2010-06-15 10:57:28Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,7 +28,8 @@
 
 #include "common/array.h"
 #include "common/hash-str.h"
-#include "engines/savestate.h"	// TODO: Push this #include out to .cpp files needing it
+#include "common/str.h"
+#include "common/util.h"
 
 /**
  * A simple structure used to map gameids (like "monkey", "sword1", ...) to
