@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/detection_tables.h $
- * $Id: detection_tables.h 53802 2010-10-25 07:29:12Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -2278,6 +2278,20 @@ static const GOBGameDescription gameDescriptions[] = {
 		kFeaturesAdLib,
 		"disk0.stk", 0, 0
 	},
+	{ // Supplied by alex86r in bug report #3297633
+		{
+			"fascination",
+			"VGA 3 disks edition",
+			AD_ENTRY1s("disk0.stk", "ab3dfdce43917bc806812959d692fc8f", 1061929),
+			IT_ITA,
+			kPlatformPC,
+			ADGF_NO_FLAGS,
+			GUIO_NOSUBTITLES | GUIO_NOSPEECH
+		},
+		kGameTypeFascination,
+		kFeaturesAdLib,
+		"disk0.stk", 0, 0
+	},
 	{
 		{
 			"fascination",
@@ -3240,7 +3254,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3254,7 +3268,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3268,7 +3282,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3282,7 +3296,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3296,7 +3310,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3310,7 +3324,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3324,7 +3338,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3338,7 +3352,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3352,7 +3366,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3366,7 +3380,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3380,7 +3394,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3394,7 +3408,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3408,7 +3422,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3422,7 +3436,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3436,7 +3450,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3450,7 +3464,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by Hkz on #scummvm
@@ -3464,7 +3478,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by Hkz on #scummvm
@@ -3478,7 +3492,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by Hkz on #scummvm
@@ -3492,7 +3506,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by DjDiabolik in bug report #1971294
@@ -3506,7 +3520,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by DjDiabolik in bug report #1971294
@@ -3520,7 +3534,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by DjDiabolik in bug report #1971294
@@ -3534,7 +3548,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by DjDiabolik in bug report #1971294
@@ -3548,7 +3562,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by DjDiabolik in bug report #1971294
@@ -3562,7 +3576,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ // Supplied by goodoldgeorg in bug report #2098838
@@ -3576,7 +3590,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3594,7 +3608,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 1
 	},
 	{
@@ -3608,7 +3622,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3622,7 +3636,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3636,7 +3650,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3650,7 +3664,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3664,7 +3678,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3678,7 +3692,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -3692,7 +3706,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		"lda1.stk", 0, 0
 	},
 	{
@@ -3706,7 +3720,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeDynasty,
-		kFeatures640,
+		kFeatures640x480,
 		"lda1.stk", 0, 0
 	},
 	{
@@ -3720,7 +3734,21 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeUrban,
-		kFeatures640,
+		kFeatures640x480 | kFeaturesTrueColor,
+		0, 0, 0
+	},
+	{ // Supplied by Collector9 in bug report #3228040
+		{
+			"urban",
+			"",
+			AD_ENTRY1s("intro.stk", "6ce3d878178932053267237ec4843ce1", 1252518),
+			EN_USA,
+			kPlatformPC,
+			ADGF_NO_FLAGS,
+			GUIO_NOSUBTITLES | GUIO_NOSPEECH
+		},
+		kGameTypeUrban,
+		kFeatures640x480 | kFeaturesTrueColor,
 		0, 0, 0
 	},
 	{ // Supplied by gamin in the forums
@@ -3734,7 +3762,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeUrban,
-		kFeatures640,
+		kFeatures640x480 | kFeaturesTrueColor,
 		0, 0, 0
 	},
 	{ // Supplied by jvprat on #scummvm
@@ -3748,7 +3776,35 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeUrban,
-		kFeatures640,
+		kFeatures640x480 | kFeaturesTrueColor,
+		0, 0, 0
+	},
+	{ // Supplied by Alex on the gobsmacked blog
+		{
+			"urban",
+			"",
+			AD_ENTRY1s("intro.stk", "9ea647085a16dd0fb9ecd84cd8778ec9", 1253436),
+			IT_ITA,
+			kPlatformPC,
+			ADGF_NO_FLAGS,
+			GUIO_NOSUBTITLES | GUIO_NOSPEECH
+		},
+		kGameTypeUrban,
+		kFeatures640x480 | kFeaturesTrueColor,
+		0, 0, 0
+	},
+	{ // Supplied by alex86r in bug report #3297602
+		{
+			"urban",
+			"",
+			AD_ENTRY1s("intro.stk", "4e4a3c017fe5475353bf94c455fe3efd", 1253448),
+			IT_ITA,
+			kPlatformPC,
+			ADGF_NO_FLAGS,
+			GUIO_NOSUBTITLES | GUIO_NOSPEECH
+		},
+		kGameTypeUrban,
+		kFeatures640x480 | kFeaturesTrueColor,
 		0, 0, 0
 	},
 	{ // Supplied by goodoldgeorg in bug report #2770340
@@ -3762,7 +3818,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeUrban,
-		kFeatures640,
+		kFeatures640x480 | kFeaturesTrueColor,
 		0, 0, 0
 	},
 	{
@@ -3781,7 +3837,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeUrban,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesTrueColor | kFeaturesSCNDemo,
 		0, 0, 2
 	},
 	{
@@ -3799,7 +3855,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -3817,7 +3873,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -3835,7 +3891,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{ // Supplied by scoriae in the forums
@@ -3853,7 +3909,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -3876,7 +3932,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 3
 	},
 	{
@@ -3894,7 +3950,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 4
 	},
 	{
@@ -3916,7 +3972,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 5
 	},
 	{
@@ -3937,7 +3993,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 6
 	},
 	{
@@ -3955,7 +4011,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -3973,7 +4029,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -3991,7 +4047,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{ // Supplied by scoriae in the forums
@@ -4009,7 +4065,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4027,7 +4083,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4045,7 +4101,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4063,7 +4119,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4081,7 +4137,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{ // Supplied by Hkz on #scummvm
@@ -4099,7 +4155,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4117,7 +4173,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{ //Supplied by goodoldgeorg in bug report #2820006
@@ -4135,7 +4191,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4153,7 +4209,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4171,7 +4227,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeBambou,
-		kFeatures640,
+		kFeatures640x480,
 		"intro.stk", "intro.tot", 0
 	},
 	{
@@ -4189,7 +4245,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4207,7 +4263,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4225,7 +4281,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		"intro2.stk", 0, 0
 	},
 	{
@@ -4253,7 +4309,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{ // Found in french ADI 2 Francais-Maths CE2. Exact version not specified.
@@ -4267,7 +4323,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4295,7 +4351,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4309,7 +4365,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4323,7 +4379,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4337,7 +4393,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4351,7 +4407,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4365,7 +4421,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", "ediintro.tot", 0
 	},
 	{
@@ -4385,7 +4441,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeAdi2,
-		kFeatures640 | kFeaturesSCNDemo,
+		kFeatures640x480 | kFeaturesSCNDemo,
 		0, 0, 1
 	},
 	{
@@ -4399,7 +4455,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4413,7 +4469,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4427,7 +4483,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4441,7 +4497,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4455,7 +4511,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4469,7 +4525,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4525,7 +4581,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4553,7 +4609,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4567,7 +4623,7 @@ static const GOBGameDescription gameDescriptions[] = {
 			GUIO_NONE
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{
@@ -4865,7 +4921,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeWoodruff,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //9
@@ -4921,7 +4977,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeUrban,
-		kFeaturesCD,
+		kFeatures640x480 | kFeaturesTrueColor,
 		0, 0, 0
 	},
 	{ //13
@@ -4935,7 +4991,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //14
@@ -4949,7 +5005,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //15
@@ -4963,7 +5019,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //16
@@ -4977,7 +5033,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //17
@@ -4991,7 +5047,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //18
@@ -5005,7 +5061,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypePlaytoons,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //19
@@ -5019,7 +5075,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeBambou,
-		kFeatures640,
+		kFeatures640x480,
 		0, 0, 0
 	},
 	{ //20
@@ -5061,7 +5117,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeAdi2,
-		kFeatures640,
+		kFeatures640x480,
 		"adi2.stk", 0, 0
 	},
 	{ //23
@@ -5075,7 +5131,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NOSUBTITLES | GUIO_NOSPEECH
 		},
 		kGameTypeAdi4,
-		kFeatures640,
+		kFeatures640x480,
 		"adif41.stk", 0, 0
 	},
 	{ //24
@@ -5089,7 +5145,7 @@ static const GOBGameDescription fallbackDescs[] = {
 			GUIO_NONE
 		},
 		kGameTypeUrban,
-		kFeaturesAdLib | kFeatures640 | kFeaturesSCNDemo,
+		kFeaturesAdLib | kFeatures640x480 | kFeaturesSCNDemo,
 		"", "", 8
 	}
 };
