@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/draw.cpp $
- * $Id: draw.cpp 52267 2010-08-21 18:16:04Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
+#include "common/str.h"
 
 #include "gob/gob.h"
 #include "gob/draw.h"
@@ -66,7 +67,7 @@ Draw::Draw(GobEngine *vm) : _vm(vm) {
 	for (int i = 0; i < kFontCount; i++)
 		_fonts[i] = 0;
 
-	_spritesArray.resize(SPRITES_COUNT);
+	_spritesArray.resize(kSpriteCount);
 
 	_invalidatedCount = 0;
 	for (int i = 0; i < 30; i++) {
@@ -244,6 +245,9 @@ void Draw::blitInvalidated() {
 	if (_noInvalidated && !_applyPal)
 		return;
 
+	if (_vm->isTrueColor())
+		_applyPal = false;
+
 	if (_noInvalidated) {
 		setPalette();
 		_applyPal = false;
@@ -263,10 +267,10 @@ void Draw::blitInvalidated() {
 
 	_vm->_video->_doRangeClamp = false;
 	for (int i = 0; i < _invalidatedCount; i++) {
-		_vm->_video->drawSprite(*_backSurface, *_frontSurface,
+		_frontSurface->blit(*_backSurface,
 		    _invalidatedLefts[i], _invalidatedTops[i],
 		    _invalidatedRights[i], _invalidatedBottoms[i],
-		    _invalidatedLefts[i], _invalidatedTops[i], 0);
+		    _invalidatedLefts[i], _invalidatedTops[i]);
 		_vm->_video->dirtyRectsAdd(_invalidatedLefts[i], _invalidatedTops[i],
 				_invalidatedRights[i], _invalidatedBottoms[i]);
 	}
@@ -294,13 +298,22 @@ void Draw::clearPalette() {
 	}
 }
 
+uint32 Draw::getColor(uint8 index) const {
+	if (!_vm->isTrueColor())
+		return index;
+
+	return _vm->getPixelFormat().RGBToColor(_vgaPalette[index].red   << 2,
+	                                        _vgaPalette[index].green << 2,
+	                                        _vgaPalette[index].blue  << 2);
+}
+
 void Draw::dirtiedRect(int16 surface,
 		int16 left, int16 top, int16 right, int16 bottom) {
 
 	dirtiedRect(_spritesArray[surface], left, top, right, bottom);
 }
 
-void Draw::dirtiedRect(SurfaceDescPtr surface,
+void Draw::dirtiedRect(SurfacePtr surface,
 		int16 left, int16 top, int16 right, int16 bottom) {
 
 	if (surface == _backSurface)
@@ -314,9 +327,19 @@ void Draw::dirtiedRect(SurfaceDescPtr surface,
 void Draw::initSpriteSurf(int16 index, int16 width, int16 height,
 		int16 flags) {
 
-	_spritesArray[index] =
-		_vm->_video->initSurfDesc(_vm->_global->_videoMode, width, height, flags);
-	_vm->_video->clearSurf(*_spritesArray[index]);
+	_spritesArray[index] = _vm->_video->initSurfDesc(width, height, flags);
+	_spritesArray[index]->clear();
+}
+
+void Draw::freeSprite(int16 index) {
+	assert(index < kSpriteCount);
+
+	_spritesArray[index].reset();
+
+	if (index == kFrontSurface)
+		_spritesArray[index] = _frontSurface;
+	if (index == kBackSurface)
+		_spritesArray[index] = _backSurface;
 }
 
 void Draw::adjustCoords(char adjust, int16 *coord1, int16 *coord2) {
@@ -328,7 +351,7 @@ void Draw::adjustCoords(char adjust, int16 *coord1, int16 *coord2) {
 			if (coord2)
 				*coord2 *= 2;
 			if (coord1)
-				*coord2 *= 2;
+				*coord1 *= 2;
 			break;
 
 		case 1:
@@ -347,10 +370,15 @@ void Draw::adjustCoords(char adjust, int16 *coord1, int16 *coord2) {
 	}
 }
 
-int Draw::stringLength(const char *str, int16 fontIndex) {
+int Draw::stringLength(const char *str, uint16 fontIndex) {
 	static const int8 japaneseExtraCharLen[12] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
-	if ((fontIndex < 0) || (fontIndex > 7) || !_fonts[fontIndex])
+	if (fontIndex >= kFontCount) {
+		warning("Draw::stringLength(): Font %d > Count %d", fontIndex, kFontCount);
+		return 0;
+	}
+
+	if (!_fonts[fontIndex])
 		return 0;
 
 	Font &font = *_fonts[fontIndex];
@@ -381,14 +409,14 @@ int Draw::stringLength(const char *str, int16 fontIndex) {
 }
 
 void Draw::drawString(const char *str, int16 x, int16 y, int16 color1, int16 color2,
-		int16 transp, SurfaceDesc &dest, const Font &font) {
+		int16 transp, Surface &dest, const Font &font) {
 
 	while (*str != '\0') {
 		const int16 charRight  = x + font.getCharWidth(*str);
 		const int16 charBottom = y + font.getCharHeight();
 
 		if ((charRight <= dest.getWidth()) && (charBottom <= dest.getHeight()))
-			_vm->_video->drawLetter(*str, x, y, font, transp, color1, color2, dest);
+			font.drawLetter(dest, *str, x, y, color1, color2, transp);
 
 		x += font.getCharWidth(*str);
 		str++;
@@ -418,6 +446,14 @@ void Draw::printTextCentered(int16 id, int16 left, int16 top, int16 right,
 	if (str[0] == '\0')
 		return;
 
+	if (fontIndex >= kFontCount) {
+		warning("Draw::printTextCentered(): Font %d > Count %d", fontIndex, kFontCount);
+		return;
+	}
+
+	if (!_fonts[fontIndex])
+		return;
+
 	_transparency = 1;
 	_destSpriteX = left;
 	_destSpriteY = top;
@@ -470,10 +506,8 @@ void Draw::oPlaytoons_sub_F_1B(uint16 id, int16 left, int16 top, int16 right, in
 			else
 				WRITE_VAR(24, (uint32) 0);
 			WRITE_VAR(25, (uint32) shortId);
-			if (_hotspotText) {
-				strncpy(_hotspotText, paramStr, 40);
-				_hotspotText[39] = 0;
-			}
+			if (_hotspotText)
+				Common::strlcpy(_hotspotText, paramStr, 40);
 		}
 		_vm->_inter->funcBlock(0);
 		_vm->_game->_script->pop();
@@ -481,6 +515,14 @@ void Draw::oPlaytoons_sub_F_1B(uint16 id, int16 left, int16 top, int16 right, in
 
 	strcpy(paramStr, tmpStr);
 
+	if (fontIndex >= kFontCount) {
+		warning("Draw::oPlaytoons_sub_F_1B(): Font %d > Count %d", fontIndex, kFontCount);
+		return;
+	}
+
+	if (!_fonts[fontIndex])
+		return;
+
 	if (*paramStr) {
 		_transparency = 1;
 		_fontIndex = fontIndex;
@@ -542,20 +584,18 @@ void Draw::forceBlit(bool backwards) {
 		return;
 	if (_frontSurface == _backSurface)
 		return;
+	/*
 	if (_spritesArray[kFrontSurface] != _frontSurface)
 		return;
 	if (_spritesArray[kBackSurface] != _backSurface)
 		return;
+	*/
 
 	if (!backwards) {
-		_vm->_video->drawSprite(*_backSurface, *_frontSurface, 0, 0,
-				_backSurface->getWidth() - 1, _backSurface->getHeight() - 1,
-				0, 0, 0);
+		_frontSurface->blit(*_backSurface);
 		_vm->_video->dirtyRectsAll();
 	} else
-		_vm->_video->drawSprite(*_frontSurface, *_backSurface, 0, 0,
-				_frontSurface->getWidth() - 1, _frontSurface->getHeight() - 1,
-				0, 0, 0);
+		_backSurface->blit(*_frontSurface);
 
 }
 
@@ -602,7 +642,7 @@ const int16 Draw::_wobbleTable[360] = {
 	-0x0A03, -0x08E8, -0x07CC, -0x06B0, -0x0593, -0x0476, -0x0359, -0x023B, -0x011D
 };
 
-void Draw::wobble(SurfaceDesc &surfDesc) {
+void Draw::wobble(Surface &surfDesc) {
 	int16 amplitude = 32;
 	uint16 curFrame = 0;
 	uint16 frameWobble = 0;
@@ -626,16 +666,14 @@ void Draw::wobble(SurfaceDesc &surfDesc) {
 			amplitude--;
 
 		for (uint16 y = 0; y < _vm->_height; y++)
-			_vm->_video->drawSprite(surfDesc, *_frontSurface,
-					0, y, _vm->_width - 1, y, offsets[y], y, 0);
+			_frontSurface->blit(surfDesc, 0, y, _vm->_width - 1, y, offsets[y], y);
 
 		_vm->_palAnim->fadeStep(0);
 		_vm->_video->dirtyRectsAll();
 		_vm->_video->waitRetrace();
 	}
 
-	_vm->_video->drawSprite(surfDesc, *_frontSurface,
-			0, 0, _vm->_width - 1, _vm->_height - 1, 0, 0, 0);
+	_frontSurface->blit(surfDesc);
 
 	_applyPal = false;
 	_invalidatedCount = 0;
@@ -646,17 +684,20 @@ void Draw::wobble(SurfaceDesc &surfDesc) {
 }
 
 Font *Draw::loadFont(const char *path) const {
-	if (!_vm->_dataIO->existData(path))
+	if (!_vm->_dataIO->hasFile(path))
 		return 0;
 
-	byte *data = _vm->_dataIO->getData(path);
+	int32 size;
+	byte *data = _vm->_dataIO->getFile(path, size);
 
 	return new Font(data);
 }
 
-bool Draw::loadFont(int fontIndex, const char *path) {
-	if ((fontIndex < 0) || (fontIndex >= kFontCount))
+bool Draw::loadFont(uint16 fontIndex, const char *path) {
+	if (fontIndex >= kFontCount) {
+		warning("Draw::loadFont(): Font %d > Count %d (\"%s\")", fontIndex, kFontCount, path);
 		return false;
+	}
 
 	delete _fonts[fontIndex];
 
