@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/draw.h $
- * $Id: draw.h 52267 2010-08-21 18:16:04Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,8 +30,6 @@
 
 namespace Gob {
 
-#define SPRITES_COUNT 100
-
 #define RENDERFLAG_NOINVALIDATE      0x0001
 #define RENDERFLAG_CAPTUREPUSH       0x0002
 #define RENDERFLAG_COLLISIONS        0x0004
@@ -45,12 +43,13 @@ namespace Gob {
 
 class Draw {
 public:
-	static const int kFontCount      =  8;
-	static const int kFrontSurface   = 20;
-	static const int kBackSurface    = 21;
-	static const int kAnimSurface    = 22;
-	static const int kCursorSurface  = 23;
-	static const int kCaptureSurface = 30;
+	static const int kSpriteCount    = 100;
+	static const int kFontCount      =  16;
+	static const int kFrontSurface   =  20;
+	static const int kBackSurface    =  21;
+	static const int kAnimSurface    =  22;
+	static const int kCursorSurface  =  23;
+	static const int kCaptureSurface =  30;
 
 	struct FontToSprite {
 		int8 sprite;
@@ -66,12 +65,12 @@ public:
 		int16 top;
 		int16 width;
 		int16 height;
-		SurfaceDescPtr savedSurface;
+		SurfacePtr savedSurface;
 	};
 
 	int16 _renderFlags;
 
-	int16 _fontIndex;
+	uint16 _fontIndex;
 	int16 _spriteLeft;
 	int16 _spriteTop;
 	int16 _spriteRight;
@@ -98,7 +97,7 @@ public:
 	FontToSprite _fontToSprite[4];
 	Font *_fonts[kFontCount];
 
-	Common::Array<SurfaceDescPtr> _spritesArray;
+	Common::Array<SurfacePtr> _spritesArray;
 
 	int16 _invalidatedCount;
 	int16 _invalidatedLefts[30];
@@ -112,8 +111,8 @@ public:
 	bool _paletteCleared;
 	bool _applyPal;
 
-	SurfaceDescPtr _backSurface;
-	SurfaceDescPtr _frontSurface;
+	SurfacePtr _backSurface;
+	SurfacePtr _frontSurface;
 
 	int16 _unusedPalette1[18];
 	int16 _unusedPalette2[16];
@@ -137,9 +136,9 @@ public:
 	int32 _cursorHotspotXVar;
 	int32 _cursorHotspotYVar;
 
-	SurfaceDescPtr _cursorSprites;
-	SurfaceDescPtr _cursorSpritesBack;
-	SurfaceDescPtr _scummvmCursor;
+	SurfacePtr _cursorSprites;
+	SurfacePtr _cursorSpritesBack;
+	SurfacePtr _scummvmCursor;
 
 	int16 _cursorAnim;
 	int8 _cursorAnimLow[40];
@@ -173,21 +172,20 @@ public:
 	void setPalette();
 	void clearPalette();
 
+	uint32 getColor(uint8 index) const;
+
 	void dirtiedRect(int16 surface, int16 left, int16 top, int16 right, int16 bottom);
-	void dirtiedRect(SurfaceDescPtr surface, int16 left, int16 top, int16 right, int16 bottom);
+	void dirtiedRect(SurfacePtr surface, int16 left, int16 top, int16 right, int16 bottom);
 
 	void initSpriteSurf(int16 index, int16 width, int16 height, int16 flags);
-	void freeSprite(int16 index) {
-		assert(index < SPRITES_COUNT);
-		_spritesArray[index].reset();
-	}
+	void freeSprite(int16 index);
 	void adjustCoords(char adjust, int16 *coord1, int16 *coord2);
 	void adjustCoords(char adjust, uint16 *coord1, uint16 *coord2) {
 		adjustCoords(adjust, (int16 *)coord1, (int16 *)coord2);
 	}
-	int stringLength(const char *str, int16 fontIndex);
+	int stringLength(const char *str, uint16 fontIndex);
 	void drawString(const char *str, int16 x, int16 y, int16 color1, int16 color2,
-			int16 transp, SurfaceDesc &dest, const Font &font);
+			int16 transp, Surface &dest, const Font &font);
 	void printTextCentered(int16 id, int16 left, int16 top, int16 right,
 			int16 bottom, const char *str, int16 fontIndex, int16 color);
 	void oPlaytoons_sub_F_1B( uint16 id, int16 left, int16 top, int16 right, int16 bottom, char *paramStr, int16 var3, int16 var4, int16 shortId);
@@ -196,10 +194,10 @@ public:
 	void forceBlit(bool backwards = false);
 
 	static const int16 _wobbleTable[360];
-	void wobble(SurfaceDesc &surfDesc);
+	void wobble(Surface &surfDesc);
 
 	Font *loadFont(const char *path) const;
-	bool loadFont(int fontIndex, const char *path);
+	bool loadFont(uint16 fontIndex, const char *path);
 
 	virtual void initScreen() = 0;
 	virtual void closeScreen() = 0;
@@ -267,7 +265,7 @@ public:
 	virtual ~Draw_Fascination() {}
 	virtual void spriteOperation(int16 operation);
 
-	void decompWin(int16 x, int16 y, SurfaceDescPtr destPtr);
+	void decompWin(int16 x, int16 y, SurfacePtr destPtr);
 	void drawWin(int16 fct);
 	void saveWin(int16 id);
 	void restoreWin(int16 id);
