@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/game.cpp $
- * $Id: game.cpp 52267 2010-08-21 18:16:04Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
+#include "common/str.h"
 
 #include "gob/gob.h"
 #include "gob/game.h"
-#include "gob/helper.h"
 #include "gob/global.h"
 #include "gob/dataio.h"
 #include "gob/variables.h"
@@ -44,24 +44,23 @@
 namespace Gob {
 
 Environments::Environments(GobEngine *vm) : _vm(vm) {
-	_environments = new Environment[kEnvironmentCount];
-
 	for (uint i = 0; i < kEnvironmentCount; i++) {
 		Environment &e = _environments[i];
+		Media       &m = _media[i];
 
 		e.cursorHotspotX = 0;
 		e.cursorHotspotY = 0;
 		e.variables      = 0;
 		e.script         = 0;
 		e.resources      = 0;
-		e.curTotFile[0]  = '\0';
+
+		for (int j = 0; j < 17; j++)
+			m.fonts[j] = 0;
 	}
 }
 
 Environments::~Environments() {
 	clear();
-
-	delete[] _environments;
 }
 
 void Environments::clear() {
@@ -90,6 +89,9 @@ void Environments::clear() {
 		if (!has(_environments[i].resources, i + 1))
 			delete _environments[i].resources;
 	}
+
+	for (uint i = 0; i < kEnvironmentCount; i++)
+		clearMedia(i);
 }
 
 void Environments::set(uint8 env) {
@@ -109,7 +111,7 @@ void Environments::set(uint8 env) {
 	e.script         = _vm->_game->_script;
 	e.resources      = _vm->_game->_resources;
 	e.variables      = _vm->_inter->_variables;
-	strncpy(e.curTotFile, _vm->_game->_curTotFile, 14);
+	e.totFile        = _vm->_game->_curTotFile;
 }
 
 void Environments::get(uint8 env) const {
@@ -123,14 +125,13 @@ void Environments::get(uint8 env) const {
 	_vm->_game->_script            = e.script;
 	_vm->_game->_resources         = e.resources;
 	_vm->_inter->_variables        = e.variables;
-	strncpy(_vm->_game->_curTotFile, e.curTotFile, 14);
+	_vm->_game->_curTotFile        = e.totFile;
 }
 
-const char *Environments::getTotFile(uint8 env) const {
-	if (env >= kEnvironmentCount)
-		return "";
+const Common::String &Environments::getTotFile(uint8 env) const {
+	assert(env < kEnvironmentCount);
 
-	return _environments[env].curTotFile;
+	return _environments[env].totFile;
 }
 
 bool Environments::has(Variables *variables, uint8 startEnv, int16 except) const {
@@ -169,13 +170,284 @@ bool Environments::has(Resources *resources, uint8 startEnv, int16 except) const
 	return false;
 }
 
+bool Environments::clearMedia(uint8 env) {
+	if (env >= kEnvironmentCount)
+		return false;
 
-Game::Game(GobEngine *vm) : _vm(vm) {
+	Media &m = _media[env];
+
+	for (int i = 0; i < 10; i++)
+		m.sprites[i].reset();
+
+	for (int i = 0; i < 10; i++)
+		m.sounds[i].free();
+
+	for (int i = 0; i < 17; i++) {
+		delete m.fonts[i];
+		m.fonts[i] = 0;
+	}
+
+	return true;
+}
+
+bool Environments::setMedia(uint8 env) {
+	if (env >= kEnvironmentCount)
+		return false;
+
+	clearMedia(env);
+
+	Media &m = _media[env];
+
+	for (int i = 0; i < 10; i++) {
+		m.sprites[i] = _vm->_draw->_spritesArray[i];
+		_vm->_draw->_spritesArray[i].reset();
+	}
+
+	for (int i = 0; i < 10; i++) {
+		SoundDesc *sound = _vm->_sound->sampleGetBySlot(i);
+		if (sound)
+			m.sounds[i].swap(*sound);
+	}
+
+	int n = MIN(Draw::kFontCount, 17);
+	for (int i = 0; i < n; i++) {
+		m.fonts[i] = _vm->_draw->_fonts[i];
+		_vm->_draw->_fonts[i] = 0;
+	}
+
+	return true;
+}
+
+bool Environments::getMedia(uint8 env) {
+	if (env >= kEnvironmentCount)
+		return false;
+
+	Media &m = _media[env];
+
+	for (int i = 0; i < 10; i++) {
+		_vm->_draw->_spritesArray[i] = m.sprites[i];
+		m.sprites[i].reset();
+	}
+
+	for (int i = 0; i < 10; i++) {
+		SoundDesc *sound = _vm->_sound->sampleGetBySlot(i);
+		if (sound)
+			m.sounds[i].swap(*sound);
+		m.sounds[i].free();
+	}
+
+	int n = MIN(Draw::kFontCount, 17);
+	for (int i = 0; i < n; i++) {
+		delete _vm->_draw->_fonts[i];
+		_vm->_draw->_fonts[i] = m.fonts[i];
+		m.fonts[i]= 0;
+	}
+
+	return true;
+}
+
+
+TotFunctions::TotFunctions(GobEngine *vm) : _vm(vm) {
+	for (uint8 i = 0; i < kTotCount; i++) {
+		_tots[i].script    = 0;
+		_tots[i].resources = 0;
+	}
+}
+
+TotFunctions::~TotFunctions() {
+	for (uint8 i = 0; i < kTotCount; i++)
+		freeTot(_tots[i]);
+}
+
+bool TotFunctions::loadTot(Tot &tot, const Common::String &file) {
+	tot.script    = new Script(_vm);
+	tot.resources = new Resources(_vm);
+
+	if (!tot.script->load(file) || !tot.resources->load(file)) {
+		freeTot(tot);
+		return false;
+	}
+
+	return true;
+}
+
+void TotFunctions::freeTot(Tot &tot) {
+	delete tot.script;
+	delete tot.resources;
+
+	tot.script    = 0;
+	tot.resources = 0;
+
+	tot.file.clear();
+	tot.functions.clear();
+}
+
+bool TotFunctions::loadIDE(Tot &tot) {
+	// Mapping file of function names -> function numbers/offsets
+	Common::String ideFile = Util::setExtension(tot.file, ".IDE");
+	Common::SeekableReadStream *ide = _vm->_dataIO->getFile(ideFile);
+	if (!ide)
+		// No mapping file => No named functions
+		return true;
+
+	char buffer[17];
+
+	uint32 count = ide->readUint16LE();
+	for (uint32 i = 0; i < count; i++) {
+		Function function;
+
+		function.type = ide->readByte();
+
+		ide->read(buffer, 17);
+		buffer[16] = '\0';
+
+		function.name = buffer;
+
+		ide->skip(2); // Unknown;
+		function.offset = ide->readUint16LE();
+		ide->skip(2); // Unknown;
+
+		if ((function.type != 0x47) && (function.type != 0x67))
+			continue;
+
+		tot.script->seek(function.offset);
+
+		if (tot.script->readByte() != 1) {
+			warning("TotFunctions::loadIDE(): IDE corrupt");
+			return false;
+		}
+
+		debugC(5, kDebugGameFlow, "Function 0x%02X: \"%s\"", function.type,
+				function.name.c_str());
+		tot.functions.push_back(function);
+	}
+
+	tot.script->seek(0);
+	return true;
+}
+
+int TotFunctions::find(const Common::String &totFile) const {
+	for (int i = 0; i < kTotCount; i++)
+		if (_tots[i].file.equalsIgnoreCase(totFile))
+			return i;
+
+	return -1;
+}
+
+int TotFunctions::findFree() const {
+	for (int i = 0; i < kTotCount; i++)
+		if (_tots[i].file.empty())
+			return i;
+
+	return -1;
+}
+
+bool TotFunctions::load(const Common::String &totFile) {
+	if (find(totFile) >= 0) {
+		warning("TotFunctions::load(): \"%s\" already loaded", totFile.c_str());
+		return false;
+	}
+
+	int index = findFree();
+	if (index < 0) {
+		warning("TotFunctions::load(): No free space for \"%s\"", totFile.c_str());
+		return false;
+	}
+
+	Tot &tot = _tots[index];
+	if (!loadTot(tot, totFile))
+		return false;
+
+	tot.file = totFile;
+
+	if (!loadIDE(tot)) {
+		freeTot(tot);
+		return false;
+	}
+
+	return true;
+}
+
+bool TotFunctions::unload(const Common::String &totFile) {
+	int index = find(totFile);
+	if (index < 0) {
+		warning("TotFunctions::unload(): \"%s\" not loaded", totFile.c_str());
+		return false;
+	}
+
+	Tot &tot = _tots[index];
+
+	if (_vm->_game->_script == tot.script)
+		_vm->_game->_script = 0;
+	if (_vm->_game->_resources == tot.resources)
+		_vm->_game->_resources = 0;
+
+	freeTot(tot);
+
+	return true;
+}
+
+bool TotFunctions::call(const Common::String &totFile,
+		const Common::String &function) const {
+
+	int index = find(totFile);
+	if (index < 0) {
+		warning("TotFunctions::call(): No such TOT \"%s\"", totFile.c_str());
+		return false;
+	}
+
+	const Tot &tot = _tots[index];
+
+	uint16 offset = 0;
+	Common::List<Function>::const_iterator it;
+	for (it = tot.functions.begin(); it != tot.functions.end(); ++it) {
+		if (it->name.equalsIgnoreCase(function)) {
+			offset = it->offset;
+			break;
+		}
+	}
+
+	if (offset == 0) {
+		warning("TotFunctions::call(): No such function \"%s\" in \"%s\"",
+				function.c_str(), totFile.c_str());
+		return false;
+	}
+
+	return call(tot, offset);
+}
+
+bool TotFunctions::call(const Common::String &totFile, uint16 offset) const {
+	int index = find(totFile);
+	if (index < 0) {
+		warning("TotFunctions::call(): No such TOT \"%s\"", totFile.c_str());
+		return false;
+	}
+
+	return call(_tots[index], offset);
+}
+
+bool TotFunctions::call(const Tot &tot, uint16 offset) const {
+	Script        *script     = _vm->_game->_script;
+	Resources     *resources  = _vm->_game->_resources;
+	Common::String curtotFile = _vm->_game->_curTotFile;
+
+	_vm->_game->_script     = tot.script;
+	_vm->_game->_resources  = tot.resources;
+	_vm->_game->_curTotFile = tot.file;
+
+	_vm->_game->playTot(offset);
+
+	_vm->_game->_script     = script;
+	_vm->_game->_resources  = resources;
+	_vm->_game->_curTotFile = curtotFile;
+
+	return true;
+}
+
+
+Game::Game(GobEngine *vm) : _vm(vm), _environments(_vm), _totFunctions(_vm) {
 	_captureCount = 0;
 
-	_curTotFile[0] = 0;
-	_totToLoad[0] = 0;
-
 	_startTimeKey = 0;
 	_mouseButtons = kMouseButtonsNone;
 
@@ -193,14 +465,12 @@ Game::Game(GobEngine *vm) : _vm(vm) {
 	_numEnvironments = 0;
 	_curEnvironment = 0;
 
-	_environments = new Environments(_vm);
-	_script       = new Script(_vm);
-	_resources    = new Resources(_vm);
-	_hotspots     = new Hotspots(_vm);
+	_script    = new Script(_vm);
+	_resources = new Resources(_vm);
+	_hotspots  = new Hotspots(_vm);
 }
 
 Game::~Game() {
-	delete _environments;
 	delete _script;
 	delete _resources;
 	delete _hotspots;
@@ -214,7 +484,7 @@ void Game::prepareStart() {
 	_vm->_video->setFullPalette(_vm->_global->_pPaletteDesc);
 
 	_vm->_draw->initScreen();
-	_vm->_video->fillRect(*_vm->_draw->_frontSurface, 0, 0,
+	_vm->_draw->_frontSurface->fillRect(0, 0,
 	_vm->_video->_surfWidth - 1, _vm->_video->_surfHeight - 1, 1);
 
 	_vm->_util->setMousePos(152, 92);
@@ -242,32 +512,28 @@ void Game::prepareStart() {
 	_startTimeKey = _vm->_util->getTimeKey();
 }
 
-void Game::playTot(int16 skipPlay) {
-	char savedTotName[20];
-	int16 *oldCaptureCounter;
-	int16 *oldBreakFrom;
-	int16 *oldNestLevel;
-	int16 _captureCounter;
-	int16 breakFrom;
-	int16 nestLevel;
-
-	oldNestLevel = _vm->_inter->_nestLevel;
-	oldBreakFrom = _vm->_inter->_breakFromLevel;
-	oldCaptureCounter = _vm->_scenery->_pCaptureCounter;
+void Game::playTot(int16 function) {
+	int16 *oldNestLevel      = _vm->_inter->_nestLevel;
+	int16 *oldBreakFrom      = _vm->_inter->_breakFromLevel;
+	int16 *oldCaptureCounter = _vm->_scenery->_pCaptureCounter;
 
 	_script->push();
 
-	_vm->_inter->_nestLevel = &nestLevel;
-	_vm->_inter->_breakFromLevel = &breakFrom;
-	_vm->_scenery->_pCaptureCounter = &_captureCounter;
-	strcpy(savedTotName, _curTotFile);
+	int16 captureCounter = 0;
+	int16 breakFrom;
+	int16 nestLevel;
+	_vm->_inter->_nestLevel         = &nestLevel;
+	_vm->_inter->_breakFromLevel    = &breakFrom;
+	_vm->_scenery->_pCaptureCounter = &captureCounter;
 
-	if (skipPlay <= 0) {
+	Common::String oldTotFile;
+
+	if (function <= 0) {
 		while (!_vm->shouldQuit()) {
 			if (_vm->_inter->_variables)
 				_vm->_draw->animateCursor(4);
 
-			if (skipPlay != -1) {
+			if (function != -1) {
 				_vm->_inter->initControlVars(1);
 
 				for (int i = 0; i < 4; i++) {
@@ -293,14 +559,14 @@ void Game::playTot(int16 skipPlay) {
 				_vm->_inter->initControlVars(0);
 
 			_vm->_draw->_cursorHotspotXVar = -1;
-			_totToLoad[0] = 0;
+			_totToLoad.clear();
 
-			if ((_curTotFile[0] == 0) && (!_script->isLoaded()))
+			if ((_curTotFile.empty()) && (!_script->isLoaded()))
 				break;
 
-			if (skipPlay == -2) {
+			if (function == -2) {
 				_vm->_vidPlayer->closeVideo();
-				skipPlay = 0;
+				function = 0;
 			}
 
 			if (!_script->load(_curTotFile)) {
@@ -319,14 +585,20 @@ void Game::playTot(int16 skipPlay) {
 
 			_vm->_inter->renewTimeInVars();
 
-			WRITE_VAR(13, _vm->_global->_useMouse);
-			WRITE_VAR(14, _vm->_global->_soundFlags);
-			WRITE_VAR(15, _vm->_global->_fakeVideoMode);
-			WRITE_VAR(16, _vm->_global->_language);
+			if (_vm->_inter->_variables) {
+				WRITE_VAR(13, _vm->_global->_useMouse);
+				WRITE_VAR(14, _vm->_global->_soundFlags);
+				WRITE_VAR(15, _vm->_global->_fakeVideoMode);
+				WRITE_VAR(16, _vm->_global->_language);
+
+				// WORKAROUND: Inca2 seems to depend on that variable to be cleared
+				if (_vm->getGameType() == kGameTypeInca2)
+					WRITE_VAR(59, 0);
+			}
 
 			_vm->_inter->callSub(2);
 
-			if (_totToLoad[0] != 0)
+			if (!_totToLoad.empty())
 				_vm->_inter->_terminate = 0;
 
 			_vm->_draw->blitInvalidated();
@@ -338,7 +610,7 @@ void Game::playTot(int16 skipPlay) {
 			for (int i = 0; i < *_vm->_scenery->_pCaptureCounter; i++)
 				capturePop(0);
 
-			if (skipPlay != -1) {
+			if (function != -1) {
 				_vm->_goblin->freeObjects();
 
 				_vm->_sound->blasterStop(0);
@@ -354,15 +626,20 @@ void Game::playTot(int16 skipPlay) {
 
 			_vm->_draw->closeAllWin();
 
-			if (_totToLoad[0] == 0)
+			if (_totToLoad.empty())
 				break;
 
-			strcpy(_curTotFile, _totToLoad);
+			_curTotFile = _totToLoad;
+
 		}
 	} else {
 		_vm->_inter->initControlVars(0);
 		_vm->_scenery->_pCaptureCounter = oldCaptureCounter;
-		_script->seek(_script->getFunctionOffset(skipPlay + 1));
+
+		if (function > 13)
+			_script->seek(function);
+		else
+			_script->seek(_script->getFunctionOffset(function + 1));
 
 		_vm->_inter->callSub(2);
 
@@ -370,10 +647,10 @@ void Game::playTot(int16 skipPlay) {
 			_vm->_inter->_terminate = 2;
 	}
 
-	strcpy(_curTotFile, savedTotName);
+	_curTotFile = oldTotFile;
 
-	_vm->_inter->_nestLevel = oldNestLevel;
-	_vm->_inter->_breakFromLevel = oldBreakFrom;
+	_vm->_inter->_nestLevel         = oldNestLevel;
+	_vm->_inter->_breakFromLevel    = oldBreakFrom;
 	_vm->_scenery->_pCaptureCounter = oldCaptureCounter;
 
 	_script->pop();
@@ -545,22 +822,29 @@ void Game::start() {
 
 	_vm->_draw->closeScreen();
 
-	for (int i = 0; i < SPRITES_COUNT; i++)
+	for (int i = 0; i < Draw::kSpriteCount; i++)
 		_vm->_draw->freeSprite(i);
 	_vm->_draw->_scummvmCursor.reset();
 }
 
-// flagbits: 0 = freeInterVariables, 1 = skipPlay
-void Game::totSub(int8 flags, const char *newTotFile) {
+// flagbits: 0 = freeInterVariables, 1 = function -1
+void Game::totSub(int8 flags, const Common::String &totFile) {
 	int8 curBackupPos;
 
-	if ((flags == 16) || (flags == 17))
-		warning("Urban Stub: Game::totSub(), flags == %d", flags);
+	if ((flags == 16) || (flags == 17)) {
+		// Prefetch tot data + delete prefetched data
+		return;
+	}
 
 	if (_numEnvironments >= Environments::kEnvironmentCount)
-		return;
+		error("Game::totSub(): Environments overflow");
 
-	_environments->set(_numEnvironments);
+	_environments.set(_numEnvironments);
+
+	if (flags == 18) {
+		warning("Backuping media to %d", _numEnvironments);
+		_environments.setMedia(_numEnvironments);
+	}
 
 	curBackupPos = _curEnvironment;
 	_numEnvironments++;
@@ -570,22 +854,22 @@ void Game::totSub(int8 flags, const char *newTotFile) {
 	_resources = new Resources(_vm);
 
 	if (flags & 0x80)
-		warning("Urban Stub: Game::totSub(), flags & 0x80");
+		warning("Addy Stub: Game::totSub(), flags & 0x80");
 
-	if (flags & 1)
+	if (flags & 5)
 		_vm->_inter->_variables = 0;
 
-	strncpy0(_curTotFile, newTotFile, 9);
-	strcat(_curTotFile, ".TOT");
+	_curTotFile = totFile + ".TOT";
 
 	if (_vm->_inter->_terminate != 0) {
 		clearUnusedEnvironment();
 		return;
 	}
 
-	_hotspots->push(0, true);
+	if (!(flags & 0x20))
+		_hotspots->push(0, true);
 
-	if (flags & 2)
+	if ((flags == 18) || (flags & 0x06))
 		playTot(-1);
 	else
 		playTot(0);
@@ -593,21 +877,29 @@ void Game::totSub(int8 flags, const char *newTotFile) {
 	if (_vm->_inter->_terminate != 2)
 		_vm->_inter->_terminate = 0;
 
-	_hotspots->clear();
-	_hotspots->pop();
-
-	if ((flags & 1) && _vm->_inter->_variables) {
-		_vm->_inter->delocateVars();
+	if (!(flags & 0x20)) {
+		_hotspots->clear();
+		_hotspots->pop();
 	}
 
+	if ((flags & 5) && _vm->_inter->_variables)
+		_vm->_inter->delocateVars();
+
 	clearUnusedEnvironment();
 
 	_numEnvironments--;
 	_curEnvironment = curBackupPos;
-	_environments->get(_numEnvironments);
+	_environments.get(_numEnvironments);
+
+	if (flags == 18) {
+		warning("Restoring media from %d", _numEnvironments);
+		_environments.getMedia(_numEnvironments);
+	}
+
+	_vm->_global->_inter_animDataSize = _script->getAnimDataSize();
 }
 
-void Game::switchTotSub(int16 index, int16 skipPlay) {
+void Game::switchTotSub(int16 index, int16 function) {
 	int16 backupedCount;
 	int16 curBackupPos;
 
@@ -620,14 +912,14 @@ void Game::switchTotSub(int16 index, int16 skipPlay) {
 
 	// WORKAROUND: Some versions don't make the MOVEMENT menu item unselectable
 	// in the dreamland screen, resulting in a crash when it's clicked.
-	if ((_vm->getGameType() == kGameTypeGob2) && (index == -1) && (skipPlay == 7) &&
-	    !scumm_stricmp(_environments->getTotFile(newPos), "gob06.tot"))
+	if ((_vm->getGameType() == kGameTypeGob2) && (index == -1) && (function == 7) &&
+	     _environments.getTotFile(newPos).equalsIgnoreCase("gob06.tot"))
 		return;
 
 	curBackupPos = _curEnvironment;
 	backupedCount = _numEnvironments;
 	if (_curEnvironment == _numEnvironments)
-		_environments->set(_numEnvironments++);
+		_environments.set(_numEnvironments++);
 
 	_curEnvironment -= index;
 	if (index >= 0)
@@ -635,7 +927,7 @@ void Game::switchTotSub(int16 index, int16 skipPlay) {
 
 	clearUnusedEnvironment();
 
-	_environments->get(_curEnvironment);
+	_environments.get(_curEnvironment);
 
 	if (_vm->_inter->_terminate != 0) {
 		clearUnusedEnvironment();
@@ -643,7 +935,7 @@ void Game::switchTotSub(int16 index, int16 skipPlay) {
 	}
 
 	_hotspots->push(0, true);
-	playTot(skipPlay);
+	playTot(function);
 
 	if (_vm->_inter->_terminate != 2)
 		_vm->_inter->_terminate = 0;
@@ -654,18 +946,56 @@ void Game::switchTotSub(int16 index, int16 skipPlay) {
 
 	_curEnvironment = curBackupPos;
 	_numEnvironments = backupedCount;
-	_environments->get(_curEnvironment);
+	_environments.get(_curEnvironment);
 }
 
 void Game::clearUnusedEnvironment() {
-	if (!_environments->has(_script)) {
+	if (!_environments.has(_script)) {
 		delete _script;
 		_script = 0;
 	}
-	if (!_environments->has(_resources)) {
+	if (!_environments.has(_resources)) {
 		delete _resources;
 		_resources = 0;
 	}
 }
 
+bool Game::loadFunctions(const Common::String &tot, uint16 flags) {
+	if ((flags & 0xFFFE) != 0) {
+		warning("Game::loadFunctions(): Unknown flags 0x%04X", flags);
+		return false;
+	}
+
+	bool unload = (flags & 0x1) != 0;
+
+	if (unload) {
+		debugC(4, kDebugGameFlow, "Unloading function for \"%s\"", tot.c_str());
+		return _totFunctions.unload(tot);
+	}
+
+	debugC(4, kDebugGameFlow, "Loading function for \"%s\"", tot.c_str());
+	return _totFunctions.load(tot);
+}
+
+bool Game::callFunction(const Common::String &tot, const Common::String &function,
+		int16 param) {
+
+	if (param != 0) {
+		warning("Game::callFunction(): param != 0 (%d)", param);
+		return false;
+	}
+
+	debugC(4, kDebugGameFlow, "Calling function \"%s\":\"%s\"",
+			tot.c_str(), function.c_str());
+
+	uint16 offset = atoi(function.c_str());
+	if (offset != 0)
+		return _totFunctions.call(tot, offset);
+
+	if (function.size() > 16)
+		return _totFunctions.call(tot, Common::String(function.c_str(), 16));
+
+	return _totFunctions.call(tot, function);
+}
+
 } // End of namespace Gob
