@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/global.cpp $
- * $Id: global.cpp 44472 2009-09-29 22:43:30Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -88,7 +88,7 @@ Global::Global(GobEngine *vm) : _vm(vm) {
 	_unusedPalette1[16] = (int16) 0xAAAA;
 	_unusedPalette1[17] = (int16) 0xFFFF;
 
-	for (int i = 0; i < 16 ;i++)
+	for (int i = 0; i < 16; i++)
 		_unusedPalette2[i] = i;
 
 	_vgaPalette[ 0].red = 0x00; _vgaPalette[ 0].green = 0x00; _vgaPalette[ 0].blue = 0x00;
@@ -116,7 +116,6 @@ Global::Global(GobEngine *vm) : _vm(vm) {
 	_debugFlag = 0;
 	_inVM = 0;
 
-	_inter_execPtr = 0;
 	_inter_animDataSize = 10;
 
 	_inter_mouseX = 0;
