@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/global.h $
- * $Id: global.h 47182 2010-01-08 22:09:43Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -127,12 +127,11 @@ public:
 	bool _setAllPalette;
 	bool _dontSetPalette;
 
-	SurfaceDescPtr _primarySurfDesc;
+	SurfacePtr _primarySurfDesc;
 
 	int16 _debugFlag;
 	int16 _inVM;
 
-	byte *_inter_execPtr;
 	int16 _inter_animDataSize;
 
 	int16 _inter_mouseX;
