@@ -18,22 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/gob.cpp $
- * $Id: gob.cpp 52135 2010-08-17 07:41:15Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/debug-channels.h"
-#include "common/endian.h"
-#include "common/events.h"
 #include "common/EventRecorder.h"
 
+#include "backends/audiocd/audiocd.h"
 #include "base/plugins.h"
 #include "common/config-manager.h"
-#include "common/md5.h"
-#include "sound/mididrv.h"
+#include "audio/mididrv.h"
 
-#include "gui/GuiManager.h"
+#include "gui/gui-manager.h"
 #include "gui/dialog.h"
 #include "gui/widget.h"
 
@@ -136,6 +134,8 @@ GobEngine::GobEngine(OSystem *syst) : Engine(syst) {
 
 	_copyProtection = ConfMan.getBool("copy_protection");
 
+	_console = new GobConsole(this);
+
 	DebugMan.addDebugChannel(kDebugFuncOp, "FuncOpcodes", "Script FuncOpcodes debug level");
 	DebugMan.addDebugChannel(kDebugDrawOp, "DrawOpcodes", "Script DrawOpcodes debug level");
 	DebugMan.addDebugChannel(kDebugGobOp, "GoblinOpcodes", "Script GoblinOpcodes debug level");
@@ -153,6 +153,8 @@ GobEngine::GobEngine(OSystem *syst) : Engine(syst) {
 }
 
 GobEngine::~GobEngine() {
+	delete _console;
+
 	deinitGameParts();
 }
 
@@ -209,10 +211,6 @@ bool GobEngine::isEGA() const {
 	return (_features & kFeaturesEGA) != 0;
 }
 
-bool GobEngine::is640() const {
-	return (_features & kFeatures640) != 0;
-}
-
 bool GobEngine::hasAdLib() const {
 	return (_features & kFeaturesAdLib) != 0;
 }
@@ -225,22 +223,68 @@ bool GobEngine::isBATDemo() const {
 	return (_features & kFeaturesBATDemo) != 0;
 }
 
+bool GobEngine::is640x480() const {
+	return (_features & kFeatures640x480) != 0;
+}
+
 bool GobEngine::is800x600() const {
 	return (_features & kFeatures800x600) != 0;
 }
 
+bool GobEngine::isTrueColor() const {
+	return (_features & kFeaturesTrueColor) != 0;
+}
+
 bool GobEngine::isDemo() const {
 	return (isSCNDemo() || isBATDemo());
 }
 
+bool GobEngine::isCurrentTot(const Common::String &tot) const {
+	return _game->_curTotFile.equalsIgnoreCase(tot);
+}
+
+const Graphics::PixelFormat &GobEngine::getPixelFormat() const {
+	return _pixelFormat;
+}
+
+void GobEngine::setTrueColor(bool trueColor) {
+	if (isTrueColor() == trueColor)
+		return;
+
+	_features = (_features & ~kFeaturesTrueColor) | (trueColor ? kFeaturesTrueColor : 0);
+
+	_video->setSize(is640x480());
+
+	_pixelFormat = g_system->getScreenFormat();
+
+	Common::Array<SurfacePtr>::iterator surf;
+	for (surf = _draw->_spritesArray.begin(); surf != _draw->_spritesArray.end(); ++surf)
+		if (*surf)
+			(*surf)->setBPP(_pixelFormat.bytesPerPixel);
+
+	if (_draw->_backSurface)
+		_draw->_backSurface->setBPP(_pixelFormat.bytesPerPixel);
+	if (_draw->_frontSurface)
+		_draw->_frontSurface->setBPP(_pixelFormat.bytesPerPixel);
+	if (_draw->_cursorSprites)
+		_draw->_cursorSprites->setBPP(_pixelFormat.bytesPerPixel);
+	if (_draw->_cursorSpritesBack)
+		_draw->_cursorSpritesBack->setBPP(_pixelFormat.bytesPerPixel);
+	if (_draw->_scummvmCursor)
+		_draw->_scummvmCursor->setBPP(_pixelFormat.bytesPerPixel);
+	SurfacePtr _scummvmCursor;
+}
+
 Common::Error GobEngine::run() {
 	if (!initGameParts()) {
 		GUIErrorMessage("GobEngine::init(): Unknown version of game engine");
 		return Common::kUnknownError;
 	}
 
-	_video->setSize(is640());
-	_video->init();
+	if (!initGraphics()) {
+		GUIErrorMessage("GobEngine::init(): Failed to set up graphics");
+		return Common::kUnknownError;
+	}
 
 	// On some systems it's not safe to run CD audio games from the CD.
 	if (isCD())
@@ -248,7 +292,7 @@ Common::Error GobEngine::run() {
 
 	int cd_num = ConfMan.getInt("cdrom");
 	if (cd_num >= 0)
-		_system->openCD(cd_num);
+		_system->getAudioCDManager()->openCD(cd_num);
 
 	_global->_debugFlag = 1;
 	_video->_doRangeClamp = true;
@@ -330,6 +374,7 @@ void GobEngine::pauseEngineIntern(bool pause) {
 			_inter->_soundEndTimeKey += duration;
 	}
 
+	_vidPlayer->pauseAll(pause);
 	_mixer->pauseAll(pause);
 }
 
@@ -356,7 +401,7 @@ bool GobEngine::initGameParts() {
 
 	_global    = new Global(this);
 	_util      = new Util(this);
-	_dataIO    = new DataIO(this);
+	_dataIO    = new DataIO();
 	_palAnim   = new PalAnim(this);
 	_vidPlayer = new VideoPlayer(this);
 	_sound     = new Sound(this);
@@ -413,7 +458,6 @@ bool GobEngine::initGameParts() {
 		break;
 
 	case kGameTypeGob3:
-	case kGameTypeInca2:
 		_init     = new Init_v3(this);
 		_video    = new Video_v2(this);
 		_inter    = new Inter_v3(this);
@@ -425,6 +469,18 @@ bool GobEngine::initGameParts() {
 		_saveLoad = new SaveLoad_v3(this, _targetName.c_str(), SaveLoad_v3::kScreenshotTypeGob3);
 		break;
 
+	case kGameTypeInca2:
+		_init     = new Init_v3(this);
+		_video    = new Video_v2(this);
+		_inter    = new Inter_Inca2(this);
+		_mult     = new Mult_v2(this);
+		_draw     = new Draw_v2(this);
+		_map      = new Map_v2(this);
+		_goblin   = new Goblin_v3(this);
+		_scenery  = new Scenery_v2(this);
+		_saveLoad = new SaveLoad_Inca2(this, _targetName.c_str());
+		break;
+
 	case kGameTypeLostInTime:
 		_init     = new Init_v3(this);
 		_video    = new Video_v2(this);
@@ -461,7 +517,6 @@ bool GobEngine::initGameParts() {
 		_saveLoad = new SaveLoad(this);
 		break;
 
-	case kGameTypeAdi4:
 	case kGameTypeUrban:
 		_init     = new Init_v6(this);
 		_video    = new Video_v6(this);
@@ -489,15 +544,16 @@ bool GobEngine::initGameParts() {
 
 	case kGameTypeAdibou2:
 	case kGameTypeAdi2:
-		_init     = new Init_v2(this);
+	case kGameTypeAdi4:
+		_init     = new Init_v7(this);
 		_video    = new Video_v6(this);
-		_inter    = new Inter_Playtoons(this);
+		_inter    = new Inter_v7(this);
 		_mult     = new Mult_v2(this);
 		_draw     = new Draw_v2(this);
 		_map      = new Map_v2(this);
 		_goblin   = new Goblin_v4(this);
 		_scenery  = new Scenery_v2(this);
-		_saveLoad = new SaveLoad_Playtoons(this, _targetName.c_str());
+		_saveLoad = new SaveLoad_v7(this, _targetName.c_str());
 		break;
 
 	case kGameTypeAdibou1:
@@ -516,23 +572,10 @@ bool GobEngine::initGameParts() {
 		return false;
 	}
 
-	_inter->setupOpcodes();
+	// Setup mixer
+	syncSoundSettings();
 
-	if (is640()) {
-		_video->_surfWidth = _width = 640;
-		_video->_surfHeight = _video->_splitHeight1 = _height = 480;
-		_global->_mouseMaxX = 640;
-		_global->_mouseMaxY = 480;
-		_mode = 0x18;
-		_global->_primarySurfDesc = SurfaceDescPtr(new SurfaceDesc(0x18, 640, 480));
-	} else {
-		_video->_surfWidth = _width = 320;
-		_video->_surfHeight = _video->_splitHeight1 = _height = 200;
-		_global->_mouseMaxX = 320;
-		_global->_mouseMaxY = 200;
-		_mode = 0x14;
-		_global->_primarySurfDesc = SurfaceDescPtr(new SurfaceDesc(0x14, 320, 200));
-	}
+	_inter->setupOpcodes();
 
 	return true;
 }
@@ -556,4 +599,34 @@ void GobEngine::deinitGameParts() {
 	delete _dataIO;    _dataIO = 0;
 }
 
+bool GobEngine::initGraphics() {
+	if        (is800x600()) {
+		warning("GobEngine::initGraphics(): 800x600 games currently unsupported");
+		return false;
+	} else if (is640x480()) {
+		_width  = 640;
+		_height = 480;
+		_mode   = 0x18;
+	} else {
+		_width  = 320;
+		_height = 200;
+		_mode   = 0x14;
+	}
+
+	_video->setSize(is640x480());
+
+	_pixelFormat = g_system->getScreenFormat();
+
+	_video->_surfWidth    = _width;
+	_video->_surfHeight   = _height;
+	_video->_splitHeight1 = _height;
+
+	_global->_mouseMaxX = _width;
+	_global->_mouseMaxY = _height;
+
+	_global->_primarySurfDesc = SurfacePtr(new Surface(_width, _height, _pixelFormat.bytesPerPixel));
+
+	return true;
+}
+
 } // End of namespace Gob
