@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/init_v1.cpp $
- * $Id: init_v1.cpp 42767 2009-07-25 16:08:31Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -54,8 +54,7 @@ void Init_v1::initVideo() {
 	_vm->_global->_pPaletteDesc->unused1 = _vm->_global->_unusedPalette1;
 	_vm->_global->_pPaletteDesc->unused2 = _vm->_global->_unusedPalette2;
 
-	if (_vm->_global->_videoMode != 0)
-		_vm->_video->initSurfDesc(_vm->_global->_videoMode, 320, 200, PRIMARY_SURFACE);
+	_vm->_video->initSurfDesc(320, 200, PRIMARY_SURFACE);
 }
 
 } // End of namespace Gob
