@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/init_v2.cpp $
- * $Id: init_v2.cpp 48171 2010-03-06 22:40:55Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -44,8 +44,7 @@ void Init_v2::initVideo() {
 		_vm->validateVideoMode(_vm->_global->_videoMode);
 
 	_vm->_draw->_frontSurface = _vm->_global->_primarySurfDesc;
-	_vm->_video->initSurfDesc(_vm->_global->_videoMode,
-			_vm->_video->_surfWidth, _vm->_video->_surfHeight, PRIMARY_SURFACE);
+	_vm->_video->initSurfDesc(_vm->_video->_surfWidth, _vm->_video->_surfHeight, PRIMARY_SURFACE);
 
 	_vm->_global->_mousePresent = 1;
 
@@ -65,9 +64,7 @@ void Init_v2::initVideo() {
 	_vm->_global->_pPaletteDesc->unused1 = _vm->_global->_unusedPalette1;
 	_vm->_global->_pPaletteDesc->unused2 = _vm->_global->_unusedPalette2;
 
-	if (_vm->_global->_videoMode != 0)
-		_vm->_video->initSurfDesc(_vm->_global->_videoMode, _vm->_video->_surfWidth,
-				_vm->_video->_surfHeight, PRIMARY_SURFACE);
+	_vm->_video->initSurfDesc(_vm->_video->_surfWidth, _vm->_video->_surfHeight, PRIMARY_SURFACE);
 }
 
 } // End of namespace Gob
