@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/init_v6.cpp $
- * $Id: init_v6.cpp 42767 2009-07-25 16:08:31Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "gob/gob.h"
 #include "gob/init.h"
 #include "gob/global.h"
+#include "gob/dataio.h"
 
 namespace Gob {
 
@@ -40,9 +41,22 @@ Init_v6::~Init_v6() {
 void Init_v6::initGame() {
 	_vm->_global->_noCd = false;
 
-	if (Common::File::exists("cd1.itk") && Common::File::exists("cd2.itk") &&
-	    Common::File::exists("cd3.itk") && Common::File::exists("cd4.itk")) {
-		_vm->_global->_noCd = true;
+	if (_vm->getGameType() == kGameTypeUrban) {
+		if (Common::File::exists("cd1.itk") && Common::File::exists("cd2.itk") &&
+				Common::File::exists("cd3.itk") && Common::File::exists("cd4.itk")) {
+
+			_vm->_global->_noCd = true;
+
+		// WORKAROUND: The CD number detection in Urban Runner is quite daft
+		// (it checks CD1.ITK - CD4.ITK and the first that's found determines
+		// the CD number), while its NO_CD modus wants everything in CD1.ITK.
+		// So we just open the other ITKs, too.
+			_vm->_dataIO->openArchive("CD1.ITK", false);
+			_vm->_dataIO->openArchive("CD2.ITK", false);
+			_vm->_dataIO->openArchive("CD3.ITK", false);
+			_vm->_dataIO->openArchive("CD4.ITK", false);
+		}
+
 	}
 
 	Init::initGame();
