@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_bargon.cpp $
- * $Id: inter_bargon.cpp 51882 2010-08-08 00:49:38Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -120,16 +120,16 @@ void Inter_Bargon::oBargon_intro2(OpGobParams &params) {
 	int16 mouseX;
 	int16 mouseY;
 	MouseButtons buttons;
-	SurfaceDescPtr surface;
+	SurfacePtr surface;
 	SoundDesc samples[4];
 	int16 comp[5] = { 0, 1, 2, 3, -1 };
 	static const char *sndFiles[] = {"1INTROII.snd", "2INTROII.snd", "1INTRO3.snd", "2INTRO3.snd"};
 
-	surface = _vm->_video->initSurfDesc(_vm->_global->_videoMode, 320, 200, 0);
+	surface = _vm->_video->initSurfDesc(320, 200);
 	_vm->_video->drawPackedSprite("2ille.ims", *surface);
-	_vm->_video->drawSprite(*surface, *_vm->_draw->_frontSurface, 0, 0, 319, 199, 0, 0, 0);
+	_vm->_draw->_frontSurface->blit(*surface, 0, 0, 319, 199, 0, 0);
 	_vm->_video->drawPackedSprite("2ille4.ims", *surface);
-	_vm->_video->drawSprite(*surface, *_vm->_draw->_frontSurface, 0, 0, 319, 199, 320, 0, 0);
+	_vm->_draw->_frontSurface->blit(*surface, 0, 0, 319, 199, 320, 0);
 	_vm->_util->setScrollOffset(320, 0);
 	_vm->_video->dirtyRectsAll();
 	_vm->_palAnim->fade(_vm->_global->_pPaletteDesc, -2, 0);
@@ -140,7 +140,7 @@ void Inter_Bargon::oBargon_intro2(OpGobParams &params) {
 		if ((_vm->_game->checkKeys(&mouseX, &mouseY, &buttons, 0) == kKeyEscape) ||
 				_vm->shouldQuit()) {
 			_vm->_palAnim->fade(0, -2, 0);
-			_vm->_video->clearSurf(*_vm->_draw->_frontSurface);
+			_vm->_draw->_frontSurface->clear();
 			memset((char *)_vm->_draw->_vgaPalette, 0, 768);
 			WRITE_VAR(4, buttons);
 			WRITE_VAR(0, kKeyEscape);
@@ -161,7 +161,7 @@ void Inter_Bargon::oBargon_intro2(OpGobParams &params) {
 	_vm->_sound->blasterPlayComposition(comp, 0, samples, 4);
 	_vm->_sound->blasterWaitEndPlay(true, false);
 	_vm->_palAnim->fade(0, 0, 0);
-	_vm->_video->clearSurf(*_vm->_draw->_frontSurface);
+	_vm->_draw->_frontSurface->clear();
 }
 
 void Inter_Bargon::oBargon_intro3(OpGobParams &params) {
@@ -175,10 +175,12 @@ void Inter_Bargon::oBargon_intro3(OpGobParams &params) {
 	static const char *sndFiles[] = {"1INTROIV.snd", "2INTROIV.snd"};
 	static const char *palFiles[] = {"2ou2.clt", "2ou3.clt", "2ou4.clt", "2ou5.clt"};
 
+	int32 size;
+
 	for (int i = 0; i < 2; i++)
 		_vm->_sound->sampleLoad(&samples[i], SOUND_SND, sndFiles[i]);
 	for (int i = 0; i < 4; i++)
-		palettes[i] = _vm->_dataIO->getData(palFiles[i]);
+		palettes[i] = _vm->_dataIO->getFile(palFiles[i], size);
 	palBak = _vm->_global->_pPaletteDesc->vgaPal;
 
 	_vm->_sound->blasterPlayComposition(comp, 0, samples, 2);
@@ -192,7 +194,7 @@ void Inter_Bargon::oBargon_intro3(OpGobParams &params) {
 				_vm->shouldQuit()) {
 			_vm->_sound->blasterStop(10);
 			_vm->_palAnim->fade(0, -2, 0);
-			_vm->_video->clearSurf(*_vm->_draw->_frontSurface);
+			_vm->_draw->_frontSurface->clear();
 			memset(_vm->_draw->_vgaPalette, 0, 768);
 			WRITE_VAR(4, buttons);
 			WRITE_VAR(0, kKeyEscape);
