@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_fascin.cpp $
- * $Id: inter_fascin.cpp 52672 2010-09-10 23:40:08Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -114,7 +114,7 @@ void Inter_Fascination::setupOpcodesGob() {
 	OPCODEGOB(1002, o2_stopProtracker);
 }
 
-bool Inter_Fascination::oFascin_repeatUntil(OpFuncParams &params) {
+void Inter_Fascination::oFascin_repeatUntil(OpFuncParams &params) {
 	int16 size;
 	bool flag;
 
@@ -130,15 +130,15 @@ bool Inter_Fascination::oFascin_repeatUntil(OpFuncParams &params) {
 
 		_vm->_game->_script->seek(blockPos + size + 1);
 
-		flag = _vm->_game->_script->evalBoolResult();
+		flag = _vm->_game->_script->evalBool();
 
 		// WORKAROUND: The script of the PC version of Fascination, when the protection check
-		// fails, writes on purpose everywhere in the memory in order to hang the computer. 
+		// fails, writes on purpose everywhere in the memory in order to hang the computer.
 		// This results in a crash in Scummvm. This workaround avoids that crash.
 		if (_vm->getPlatform() == Common::kPlatformPC) {
-			if ((!scumm_stricmp(_vm->_game->_curTotFile, "INTRO1.TOT") && (blockPos == 3533)) ||
-				(!scumm_stricmp(_vm->_game->_curTotFile, "INTRO2.TOT") && (blockPos == 3519)) ||
-				(!scumm_stricmp(_vm->_game->_curTotFile, "INTRO2.TOT") && (blockPos == 3265)))  //PC Hebrew
+			if (((blockPos == 3533) && _vm->isCurrentTot("INTRO1.TOT")) ||
+			    ((blockPos == 3519) && _vm->isCurrentTot("INTRO2.TOT")) ||
+			    ((blockPos == 3265) && _vm->isCurrentTot("INTRO2.TOT")))  //PC Hebrew
 				_terminate = 1;
 		}
 	} while (!flag && !_break && !_terminate && !_vm->shouldQuit());
@@ -149,10 +149,9 @@ bool Inter_Fascination::oFascin_repeatUntil(OpFuncParams &params) {
 		_break = false;
 		*_breakFromLevel = -1;
 	}
-	return false;
 }
 
-bool Inter_Fascination::oFascin_assign(OpFuncParams &params) {
+void Inter_Fascination::oFascin_assign(OpFuncParams &params) {
 	byte destType = _vm->_game->_script->peekByte();
 	int16 dest = _vm->_game->_script->readVarIndex();
 
@@ -195,11 +194,9 @@ bool Inter_Fascination::oFascin_assign(OpFuncParams &params) {
 			break;
 		}
 	}
-
-	return false;
 }
 
-bool Inter_Fascination::oFascin_copySprite(OpFuncParams &params) {
+void Inter_Fascination::oFascin_copySprite(OpFuncParams &params) {
 	_vm->_draw->_sourceSurface = _vm->_game->_script->readInt16();
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 	_vm->_draw->_spriteLeft = _vm->_game->_script->readValExpr();
@@ -213,7 +210,6 @@ bool Inter_Fascination::oFascin_copySprite(OpFuncParams &params) {
 	_vm->_draw->_transparency = _vm->_game->_script->readInt16();
 
 	_vm->_draw->spriteOperation(DRAW_BLITSURF);
-	return false;
 }
 
 void Inter_Fascination::oFascin_playTirb(OpGobParams &params) {
