@@ -18,18 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_playtoons.cpp $
- * $Id: inter_playtoons.cpp 51852 2010-08-08 00:35:18Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
+#include "common/str.h"
 
 #include "gui/message.h"
 
 #include "gob/gob.h"
 #include "gob/inter.h"
-#include "gob/helper.h"
 #include "gob/global.h"
 #include "gob/util.h"
 #include "gob/dataio.h"
@@ -73,6 +73,7 @@ void Inter_Playtoons::setupOpcodesDraw() {
 	CLEAROPCODEDRAW(0x22);
 	CLEAROPCODEDRAW(0x24);
 
+	OPCODEDRAW(0x17, oPlaytoons_loadMultObject);
 	OPCODEDRAW(0x19, oPlaytoons_getObjAnimSize);
 	OPCODEDRAW(0x20, oPlaytoons_CD_20_23);
 	OPCODEDRAW(0x23, oPlaytoons_CD_20_23);
@@ -96,7 +97,7 @@ void Inter_Playtoons::setupOpcodesFunc() {
 void Inter_Playtoons::setupOpcodesGob() {
 }
 
-bool Inter_Playtoons::oPlaytoons_printText(OpFuncParams &params) {
+void Inter_Playtoons::oPlaytoons_printText(OpFuncParams &params) {
 	char buf[60];
 	int i;
 	int16 oldTransparency;
@@ -178,16 +179,13 @@ bool Inter_Playtoons::oPlaytoons_printText(OpFuncParams &params) {
 	} while (_vm->_game->_script->peekByte() != 200);
 
 	_vm->_game->_script->skip(1);
-
-	return false;
 }
 
-bool Inter_Playtoons::oPlaytoons_F_1B(OpFuncParams &params) {
+void Inter_Playtoons::oPlaytoons_F_1B(OpFuncParams &params) {
 	_vm->_game->_hotspots->oPlaytoons_F_1B();
-	return false;
 }
 
-bool Inter_Playtoons::oPlaytoons_putPixel(OpFuncParams &params) {
+void Inter_Playtoons::oPlaytoons_putPixel(OpFuncParams &params) {
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 
 	_vm->_draw->_destSpriteX = _vm->_game->_script->readValExpr();
@@ -201,57 +199,32 @@ bool Inter_Playtoons::oPlaytoons_putPixel(OpFuncParams &params) {
 	_vm->_draw->_pattern = _vm->_game->_script->getResultInt()>>16;
 
 	_vm->_draw->spriteOperation(DRAW_PUTPIXEL);
-
-	return false;
 }
 
-bool Inter_Playtoons::oPlaytoons_freeSprite(OpFuncParams &params) {
+void Inter_Playtoons::oPlaytoons_freeSprite(OpFuncParams &params) {
 	int16 index;
 	if (_vm->_game->_script->peekByte(1) == 0)
 		index = _vm->_game->_script->readInt16();
 	else
 		index = _vm->_game->_script->readValExpr();
 	_vm->_draw->freeSprite(index);
-	return false;
 }
 
-bool Inter_Playtoons::oPlaytoons_checkData(OpFuncParams &params) {
-	int16 handle;
-	uint16 varOff;
-	int32 size;
-	char *backSlash;
-	SaveLoad::SaveMode mode;
+void Inter_Playtoons::oPlaytoons_checkData(OpFuncParams &params) {
+	Common::String file = getFile(_vm->_game->_script->evalString());
 
-	_vm->_game->_script->evalExpr(0);
-	varOff = _vm->_game->_script->readVarIndex();
+	uint16 varOff = _vm->_game->_script->readVarIndex();
 
-	size = -1;
-	handle = 1;
-
-	char *file = _vm->_game->_script->getResultStr();
-
-	// WORKAROUND: In Playtoons games, some files are read on CD (and only on CD).
-	// In this case, "@:\" is replaced by the CD drive letter.
-	// As the files are copied on the HDD, those characters are skipped.
-	if (strncmp(file, "@:\\", 3) == 0) {
-		debugC(2, kDebugFileIO, "oPlaytoons_checkData: \"%s\" instead of \"%s\"", file + 3, file);
-		file += 3;
-	}
-
-	// WORKAROUND: In the Playtoons stick files found in german Addy 4, some paths are hardcoded
-	if ((backSlash = strrchr(file, '\\'))) {
-		debugC(2, kDebugFileIO, "oPlaytoons_checkData: \"%s\" instead of \"%s\"", backSlash + 1, file);
-		file = backSlash + 1;
-	}
-
-	mode = _vm->_saveLoad->getSaveMode(file);
+	int32 size   = -1;
+	int16 handle = 1;
+	SaveLoad::SaveMode mode = _vm->_saveLoad->getSaveMode(file.c_str());
 	if (mode == SaveLoad::kSaveModeNone) {
-		if (_vm->_dataIO->existData(file))
-			size = _vm->_dataIO->getDataSize(file);
-		else
-			warning("File \"%s\" not found", file);
+		size = _vm->_dataIO->fileSize(file);
+		if (size == -1)
+			warning("File \"%s\" not found", file.c_str());
+
 	} else if (mode == SaveLoad::kSaveModeSave)
-		size = _vm->_saveLoad->getSize(file);
+		size = _vm->_saveLoad->getSize(file.c_str());
 	else if (mode == SaveLoad::kSaveModeExists)
 		size = 23;
 
@@ -259,84 +232,68 @@ bool Inter_Playtoons::oPlaytoons_checkData(OpFuncParams &params) {
 		handle = -1;
 
 	debugC(2, kDebugFileIO, "Requested size of file \"%s\": %d",
-			file, size);
+			file.c_str(), size);
 
 	WRITE_VAR_OFFSET(varOff, handle);
 	WRITE_VAR(16, (uint32) size);
-
-	return false;
 }
 
-bool Inter_Playtoons::oPlaytoons_readData(OpFuncParams &params) {
-	int32 retSize;
-	int32 size;
-	int32 offset;
-	uint16 dataVar;
-	int16 handle;
-	byte *buf;
-	SaveLoad::SaveMode mode;
+void Inter_Playtoons::oPlaytoons_readData(OpFuncParams &params) {
+	Common::String file = getFile(_vm->_game->_script->evalString());
 
-	_vm->_game->_script->evalExpr(0);
-	dataVar = _vm->_game->_script->readVarIndex();
-	size = _vm->_game->_script->readValExpr();
-	_vm->_game->_script->evalExpr(0);
-	offset = _vm->_game->_script->getResultInt();
-	retSize = 0;
-
-	char *file = _vm->_game->_script->getResultStr();
-
-	// WORKAROUND: In Playtoons games, some files are read on CD (and only on CD).
-	// In this case, "@:\" is replaced by the CD drive letter.
-	// As the files are copied on the HDD, those characters are skipped.
-	if (strncmp(file, "@:\\", 3) == 0) {
-		debugC(2, kDebugFileIO, "oPlaytoons_readData: \"%s\" instead of \"%s\"", file + 3, file);
-		file += 3;
-	}
+	uint16 dataVar = _vm->_game->_script->readVarIndex();
+	int32  size    = _vm->_game->_script->readValExpr();
+	int32  offset  = _vm->_game->_script->evalInt();
+	int32  retSize = 0;
 
 	debugC(2, kDebugFileIO, "Read from file \"%s\" (%d, %d bytes at %d)",
-			file, dataVar, size, offset);
+			file.c_str(), dataVar, size, offset);
 
-	mode = _vm->_saveLoad->getSaveMode(file);
+	SaveLoad::SaveMode mode = _vm->_saveLoad->getSaveMode(file.c_str());
 	if (mode == SaveLoad::kSaveModeSave) {
 
 		WRITE_VAR(1, 1);
 
-		if (!_vm->_saveLoad->load(file, dataVar, size, offset)) {
+		if (!_vm->_saveLoad->load(file.c_str(), dataVar, size, offset)) {
 			GUI::MessageDialog dialog("Failed to load game state from file.");
 			dialog.runModal();
 		} else
 			WRITE_VAR(1, 0);
 
-		return false;
+		return;
 
 	} else if (mode == SaveLoad::kSaveModeIgnore)
-		return false;
+		return;
 
 	if (size < 0) {
-		warning("Attempted to read a raw sprite from file \"%s\"",
-				file);
-		return false ;
+		if (readSprite(file, dataVar, size, offset))
+			WRITE_VAR(1, 0);
+		return;
 	} else if (size == 0) {
 		dataVar = 0;
 		size = _vm->_game->_script->getVariablesCount() * 4;
 	}
 
-	buf = _variables->getAddressOff8(dataVar);
+	byte *buf = _variables->getAddressOff8(dataVar);
 
 	if (file[0] == 0) {
 		WRITE_VAR(1, size);
-		return false;
+		return;
 	}
 
 	WRITE_VAR(1, 1);
-	handle = _vm->_dataIO->openData(file);
-
-	if (handle < 0)
-		return false;
-
-	DataStream *stream = _vm->_dataIO->openAsStream(handle, true);
+	Common::SeekableReadStream *stream = _vm->_dataIO->getFile(file);
+	if (!stream)
+		return;
 
 	_vm->_draw->animateCursor(4);
+	if (offset > stream->size()) {
+		warning("oPlaytoons_readData: File \"%s\", Offset (%d) > file size (%d)",
+				file.c_str(), offset, stream->size());
+		delete stream;
+		return;
+	}
+
 	if (offset < 0)
 		stream->seek(offset + 1, SEEK_END);
 	else
@@ -355,26 +312,86 @@ bool Inter_Playtoons::oPlaytoons_readData(OpFuncParams &params) {
 		WRITE_VAR(1, 0);
 
 	delete stream;
-	return false;
+}
+
+void Inter_Playtoons::oPlaytoons_loadMultObject() {
+	assert(_vm->_mult->_objects);
+
+	uint16 objIndex = _vm->_game->_script->readValExpr();
+
+	debugC(4, kDebugGameFlow, "Loading mult object %d", objIndex);
+
+	Mult::Mult_Object &obj = _vm->_mult->_objects[objIndex];
+	Mult::Mult_AnimData &objAnim = *(obj.pAnimData);
+
+	*obj.pPosX = _vm->_game->_script->readValExpr();
+	*obj.pPosY = _vm->_game->_script->readValExpr();
+
+	byte *multData = (byte *) &objAnim;
+	for (int i = 0; i < 11; i++) {
+		if (_vm->_game->_script->peekByte() != 99)
+			multData[i] = _vm->_game->_script->readValExpr();
+		else
+			_vm->_game->_script->skip(1);
+	}
+
+	if (((int32)*obj.pPosX != -1234) || ((int32)*obj.pPosY == -4321))
+		return;
+
+	warning("Stub: oPlaytoons_loadMultObject: pPosX == -1234, pPosY == -4321");
 }
 
 void Inter_Playtoons::oPlaytoons_getObjAnimSize() {
 	int16 objIndex;
 	uint16 readVar[4];
-	uint8 i;
+	uint16 types[4];
 	Mult::Mult_AnimData animData;
 
 	_vm->_game->_script->evalExpr(&objIndex);
 
-	for (i = 0; i < 4; i++)
-		readVar[i] = _vm->_game->_script->readVarIndex();
+	for (int i = 0; i < 4; i++)
+		readVar[i] = _vm->_game->_script->readVarIndex(0, &types[0]);
 
 	if (objIndex == -1) {
 		warning("oPlaytoons_getObjAnimSize case -1 not implemented");
 		return;
 	}
+
 	if (objIndex == -2) {
-		warning("oPlaytoons_getObjAnimSize case -2 not implemented");
+		bool doBreak = false;
+		for (int i = 0; i < 3; i++)
+			storeValue(readVar[i], types[i], (uint32) -1);
+
+		for (int i = readValue(readVar[3], types[3]); i < _vm->_mult->_objCount; i++) {
+			if (_vm->_mult->_objects[i].pAnimData->isStatic != 0)
+				continue;
+
+			byte *data = (byte *)_vm->_mult->_objects[i].pAnimData;
+
+			for (int j = 1; j < 39; j += 2) {
+				int32 value1 = READ_VARO_UINT32(readVar[3] +  j      * 4);
+				int32 value2 = READ_VARO_UINT32(readVar[3] + (j + 1) * 4);
+				if (value1 == -1) {
+					doBreak = true;
+					break;
+				}
+
+				if (value1 >= 0) {
+					if ((int8)data[value1] != value2)
+						break;
+				} else {
+					if ((int8)data[-value1] == value2)
+						break;
+				}
+
+			}
+
+			if (doBreak) {
+				storeValue(readVar[0], types[0], i);
+				break;
+			}
+		}
+
 		return;
 	}
 
@@ -411,36 +428,101 @@ void Inter_Playtoons::oPlaytoons_CD_25() {
 }
 
 void Inter_Playtoons::oPlaytoons_copyFile() {
-	char fileName1[128];
-	char fileName2[128];
+	Common::String path1 = _vm->_game->_script->evalString();
+	Common::String path2 = _vm->_game->_script->evalString();
 
-	_vm->_game->_script->evalExpr(0);
-	strncpy0(fileName1, _vm->_game->_script->getResultStr(), 127);
-	_vm->_game->_script->evalExpr(0);
-	strncpy0(fileName2, _vm->_game->_script->getResultStr(), 127);
+	Common::String file1 = getFile(path1.c_str());
+	Common::String file2 = getFile(path2.c_str());
 
-	warning("Playtoons Stub: copy file from \"%s\" to \"%s\"", fileName1, fileName2);
+	if (file1.equalsIgnoreCase(file2)) {
+		warning("oPlaytoons_copyFile(): \"%s\" == \"%s\"", path1.c_str(), path2.c_str());
+		return;
+	}
+
+	warning("Playtoons Stub: copy file from \"%s\" to \"%s\"", file1.c_str(), file2.c_str());
 }
 
 void Inter_Playtoons::oPlaytoons_openItk() {
-	char fileName[128];
-	char *backSlash;
+	Common::String file = getFile(_vm->_game->_script->evalString());
+	if (!file.contains('.'))
+		file += ".ITK";
 
-	_vm->_game->_script->evalExpr(0);
-	strncpy0(fileName, _vm->_game->_script->getResultStr(), 124);
+	_vm->_dataIO->openArchive(file, false);
+}
 
-	if (!strchr(fileName, '.'))
-		strcat(fileName, ".ITK");
+Common::String Inter_Playtoons::getFile(const char *path) {
+	const char *orig = path;
 
-	// Workaround for Bambou : In the script, the path is hardcoded (!!)
-	if ((backSlash = strrchr(fileName, '\\'))) {
-		debugC(2, kDebugFileIO, "Opening ITK file \"%s\" instead of \"%s\"", backSlash + 1, fileName);
-		_vm->_dataIO->openDataFile(backSlash + 1, true);
-	} else
-		_vm->_dataIO->openDataFile(fileName, true);
-	// All the other checks are meant to verify (if not found at the first try)
-	// if the file is present on the CD or not. As everything is supposed to
-	// be copied, those checks are skipped
+	if      (!strncmp(path, "@:\\", 3))
+		path += 3;
+	else if (!strncmp(path, "<ME>", 4))
+		path += 4;
+	else if (!strncmp(path, "<CD>", 4))
+		path += 4;
+	else if (!strncmp(path, "<STK>", 5))
+		path += 5;
+	else if (!strncmp(path, "<ALLCD>", 7))
+		path += 7;
+
+	const char *backslash = strrchr(path, '\\');
+	if (backslash)
+		path = backslash + 1;
+
+	if (orig != path)
+		debugC(2, kDebugFileIO, "Inter_Playtoons::getFile(): Evaluating path"
+				"\"%s\" to \"%s\"", orig, path);
+
+	return path;
+}
+
+bool Inter_Playtoons::readSprite(Common::String file, int32 dataVar,
+		int32 size, int32 offset) {
+
+	// WORKAROUND: Adibou copies TEMP.CSA to TEMP01.CSA, which isn't yet implemented
+	if (file.equalsIgnoreCase("TEMP01.CSA"))
+		file = "TEMP.CSA";
+
+	bool palette = false;
+	if (size < -1000) {
+		palette = true;
+		size += 1000;
+	}
+
+	int index = -size - 1;
+	if ((index < 0) || (index >= Draw::kSpriteCount) || !_vm->_draw->_spritesArray[index]) {
+		warning("No such sprite");
+		return false;
+	}
+
+	SurfacePtr sprite = _vm->_draw->_spritesArray[index];
+	if (sprite->getBPP() != 1) {
+		warning("bpp != 1");
+		return false;
+	}
+
+	Common::SeekableReadStream *stream = _vm->_dataIO->getFile(file);
+	if (!stream) {
+		warning("No such file \"%s\"", file.c_str());
+		return false;
+	}
+
+	int32 spriteSize = sprite->getWidth() * sprite->getHeight();
+	int32 dataSize   = stream->size();
+
+	if (palette)
+		dataSize -= 768;
+
+	int32 readSize = MIN(spriteSize, dataSize);
+	if (readSize <= 0)
+		return true;
+
+	stream->read(sprite->getData(), readSize);
+
+	if (palette)
+		stream->read((byte *)_vm->_global->_pPaletteDesc->vgaPal, 768);
+
+	delete stream;
+	return true;
 }
 
 } // End of namespace Gob
