@@ -18,17 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_v1.cpp $
- * $Id: inter_v1.cpp 54074 2010-11-04 20:42:19Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/file.h"
+#include "common/str.h"
 
 #include "gob/gob.h"
 #include "gob/inter.h"
-#include "gob/helper.h"
 #include "gob/global.h"
 #include "gob/util.h"
 #include "gob/dataio.h"
@@ -45,6 +43,7 @@
 #include "gob/palanim.h"
 #include "gob/scenery.h"
 #include "gob/video.h"
+#include "gob/videoplayer.h"
 #include "gob/sound/sound.h"
 
 namespace Gob {
@@ -350,9 +349,8 @@ void Inter_v1::o1_initCursor() {
 		_vm->_draw->_cursorSprites = _vm->_draw->_cursorSpritesBack;
 
 		_vm->_draw->_scummvmCursor =
-			_vm->_video->initSurfDesc(_vm->_global->_videoMode,
-					_vm->_draw->_cursorWidth, _vm->_draw->_cursorHeight,
-					SCUMMVM_CURSOR);
+			_vm->_video->initSurfDesc(_vm->_draw->_cursorWidth,
+					_vm->_draw->_cursorHeight, SCUMMVM_CURSOR);
 
 		for (int i = 0; i < 40; i++) {
 			_vm->_draw->_cursorAnimLow[i] = -1;
@@ -492,10 +490,10 @@ void Inter_v1::o1_initMult() {
 		_vm->_mult->_animSurf = _vm->_draw->_spritesArray[Draw::kAnimSurface];
 	}
 
-	_vm->_video->drawSprite(*_vm->_draw->_backSurface, *_vm->_mult->_animSurf,
+	_vm->_mult->_animSurf->blit(*_vm->_draw->_backSurface,
 	    _vm->_mult->_animLeft, _vm->_mult->_animTop,
 	    _vm->_mult->_animLeft + _vm->_mult->_animWidth - 1,
-	    _vm->_mult->_animTop + _vm->_mult->_animHeight - 1, 0, 0, 0);
+	    _vm->_mult->_animTop + _vm->_mult->_animHeight - 1, 0, 0);
 
 	debugC(4, kDebugGraphics, "o1_initMult: x = %d, y = %d, w = %d, h = %d",
 		  _vm->_mult->_animLeft, _vm->_mult->_animTop,
@@ -611,9 +609,8 @@ void Inter_v1::o1_loadCurLayer() {
 }
 
 void Inter_v1::o1_playCDTrack() {
-	_vm->_game->_script->evalExpr(0);
 	_vm->_sound->adlibPlayBgMusic(); // Mac version
-	_vm->_sound->cdPlay(_vm->_game->_script->getResultStr()); // PC CD version
+	_vm->_sound->cdPlay(_vm->_game->_script->evalString()); // PC CD version
 }
 
 void Inter_v1::o1_getCDTrackPos() {
@@ -652,63 +649,60 @@ void Inter_v1::o1_freeFontToSprite() {
 	_vm->_draw->_fontToSprite[i].height = -1;
 }
 
-bool Inter_v1::o1_callSub(OpFuncParams &params) {
+void Inter_v1::o1_callSub(OpFuncParams &params) {
 	uint16 offset = _vm->_game->_script->readUint16();
 
 	debugC(5, kDebugGameFlow, "tot = \"%s\", offset = %d",
-			_vm->_game->_curTotFile, offset);
+			_vm->_game->_curTotFile.c_str(), offset);
 
 	if (offset < 128) {
 		warning("Inter_v1::o1_callSub(): Offset %d points into the header. "
 				"Skipping call", offset);
-		return false;
+		return;
 	}
 
 	// Skipping the copy protection screen in Gobliiins
-	if (!_vm->_copyProtection && (_vm->getGameType() == kGameTypeGob1) && (offset == 3905)
-			&& !scumm_stricmp(_vm->_game->_curTotFile, _vm->_startTot.c_str())) {
+	if (!_vm->_copyProtection && (_vm->getGameType() == kGameTypeGob1) && (offset == 3905) &&
+	    _vm->isCurrentTot(_vm->_startTot)) {
 		debugC(2, kDebugGameFlow, "Skipping copy protection screen");
-		return false;
+		return;
 	}
 	// Skipping the copy protection screen in Gobliins 2
-	if (!_vm->_copyProtection && (_vm->getGameType() == kGameTypeGob2) && (offset == 1746)
-			&& !scumm_stricmp(_vm->_game->_curTotFile, "intro0.tot")) {
+	if (!_vm->_copyProtection && (_vm->getGameType() == kGameTypeGob2) && (offset == 1746) &&
+	    _vm->isCurrentTot("intro0.tot")) {
 		debugC(2, kDebugGameFlow, "Skipping copy protection screen");
-		return false;
+		return;
 	}
 
 	_vm->_game->_script->call(offset);
 
 	if ((params.counter == params.cmdCount) && (params.retFlag == 2)) {
 		_vm->_game->_script->pop(false);
-		return true;
+		params.doReturn = true;
+		return;
 	}
 
 	callSub(2);
 
 	_vm->_game->_script->pop();
-
-	return false;
 }
 
-bool Inter_v1::o1_printTotText(OpFuncParams &params) {
+void Inter_v1::o1_printTotText(OpFuncParams &params) {
 	_vm->_draw->printTotText(_vm->_game->_script->readInt16());
-	return false;
 }
 
-bool Inter_v1::o1_loadCursor(OpFuncParams &params) {
+void Inter_v1::o1_loadCursor(OpFuncParams &params) {
 	int16 id    = _vm->_game->_script->readInt16();
 	int8  index = _vm->_game->_script->readInt8();
 
 	if ((index * _vm->_draw->_cursorWidth) >= _vm->_draw->_cursorSprites->getWidth())
-		return false;
+		return;
 
 	Resource *resource = _vm->_game->_resources->getResource(id);
 	if (!resource)
-		return false;
+		return;
 
-	_vm->_video->fillRect(*_vm->_draw->_cursorSprites,
-			index * _vm->_draw->_cursorWidth, 0,
+	_vm->_draw->_cursorSprites->fillRect(index * _vm->_draw->_cursorWidth, 0,
 			index * _vm->_draw->_cursorWidth + _vm->_draw->_cursorWidth - 1,
 			_vm->_draw->_cursorHeight - 1, 0);
 
@@ -718,10 +712,9 @@ bool Inter_v1::o1_loadCursor(OpFuncParams &params) {
 	_vm->_draw->_cursorAnimLow[index] = 0;
 
 	delete resource;
-	return false;
 }
 
-bool Inter_v1::o1_switch(OpFuncParams &params) {
+void Inter_v1::o1_switch(OpFuncParams &params) {
 	uint32 offset;
 
 	checkSwitchTable(offset);
@@ -733,17 +726,16 @@ bool Inter_v1::o1_switch(OpFuncParams &params) {
 
 	if ((params.counter == params.cmdCount) && (params.retFlag == 2)) {
 		_vm->_game->_script->pop(false);
-		return true;
+		params.doReturn = true;
+		return;
 	}
 
 	funcBlock(0);
 
 	_vm->_game->_script->pop();
-
-	return false;
 }
 
-bool Inter_v1::o1_repeatUntil(OpFuncParams &params) {
+void Inter_v1::o1_repeatUntil(OpFuncParams &params) {
 	int16 size;
 	bool flag;
 
@@ -759,7 +751,7 @@ bool Inter_v1::o1_repeatUntil(OpFuncParams &params) {
 
 		_vm->_game->_script->seek(blockPos + size + 1);
 
-		flag = _vm->_game->_script->evalBoolResult();
+		flag = _vm->_game->_script->evalBool();
 	} while (!flag && !_break && !_terminate && !_vm->shouldQuit());
 
 	_nestLevel[0]--;
@@ -768,10 +760,9 @@ bool Inter_v1::o1_repeatUntil(OpFuncParams &params) {
 		_break = false;
 		*_breakFromLevel = -1;
 	}
-	return false;
 }
 
-bool Inter_v1::o1_whileDo(OpFuncParams &params) {
+void Inter_v1::o1_whileDo(OpFuncParams &params) {
 	bool flag;
 	int16 size;
 
@@ -779,10 +770,10 @@ bool Inter_v1::o1_whileDo(OpFuncParams &params) {
 	do {
 		uint32 startPos = _vm->_game->_script->pos();
 
-		flag = _vm->_game->_script->evalBoolResult();
+		flag = _vm->_game->_script->evalBool();
 
 		if (_terminate)
-			return false;
+			return;
 
 		uint32 blockPos = _vm->_game->_script->pos();
 
@@ -806,25 +797,26 @@ bool Inter_v1::o1_whileDo(OpFuncParams &params) {
 		_break = false;
 		*_breakFromLevel = -1;
 	}
-	return false;
 }
 
-bool Inter_v1::o1_if(OpFuncParams &params) {
+void Inter_v1::o1_if(OpFuncParams &params) {
 	byte cmd;
 	bool boolRes;
 
 	// WORKAROUND: Gob1 goblin stuck on reload bugs present in original - bugs #3018918 and 3065914
 	if ((_vm->getGameType() == kGameTypeGob1) && (_vm->_game->_script->pos() == 2933) &&
-			!scumm_stricmp(_vm->_game->_curTotFile, "inter.tot") && VAR(285) != 0) {
+			_vm->isCurrentTot("inter.tot") && VAR(285) != 0) {
 		warning("Workaround for Gob1 Goblin Stuck On Reload Bug applied...");
 		// VAR(59) actually locks goblin movement, but these variables trigger this in the script.
 		WRITE_VAR(285, 0);
 	}
 
-	boolRes = _vm->_game->_script->evalBoolResult();
+	boolRes = _vm->_game->_script->evalBool();
 	if (boolRes) {
-		if ((params.counter == params.cmdCount) && (params.retFlag == 2))
-			return true;
+		if ((params.counter == params.cmdCount) && (params.retFlag == 2)) {
+			params.doReturn = true;
+			return;
+		}
 
 		_vm->_game->_script->push();
 		funcBlock(0);
@@ -832,24 +824,26 @@ bool Inter_v1::o1_if(OpFuncParams &params) {
 
 		_vm->_game->_script->skip(_vm->_game->_script->peekUint16(2) + 2);
 
-		debugC(5, kDebugGameFlow, "cmd = %d", (int16) _vm->_game->_script->peekByte());
+		debugC(6, kDebugGameFlow, "cmd = %d", (int16) _vm->_game->_script->peekByte());
 
 		cmd = _vm->_game->_script->readByte() >> 4;
 		if (cmd != 12)
-			return false;
+			return;
 
 		_vm->_game->_script->skip(_vm->_game->_script->peekUint16(2) + 2);
 	} else {
 		_vm->_game->_script->skip(_vm->_game->_script->peekUint16(2) + 2);
 
-		debugC(5, kDebugGameFlow, "cmd = %d", (int16) _vm->_game->_script->peekByte());
+		debugC(6, kDebugGameFlow, "cmd = %d", (int16) _vm->_game->_script->peekByte());
 
 		cmd = _vm->_game->_script->readByte() >> 4;
 		if (cmd != 12)
-			return false;
+			return;
 
-		if ((params.counter == params.cmdCount) && (params.retFlag == 2))
-			return true;
+		if ((params.counter == params.cmdCount) && (params.retFlag == 2)) {
+			params.doReturn = true;
+			return;
+		}
 
 		_vm->_game->_script->push();
 		funcBlock(0);
@@ -857,10 +851,9 @@ bool Inter_v1::o1_if(OpFuncParams &params) {
 
 		_vm->_game->_script->skip(_vm->_game->_script->peekUint16(2) + 2);
 	}
-	return false;
 }
 
-bool Inter_v1::o1_assign(OpFuncParams &params) {
+void Inter_v1::o1_assign(OpFuncParams &params) {
 	byte destType = _vm->_game->_script->peekByte();
 	int16 dest = _vm->_game->_script->readVarIndex();
 
@@ -882,17 +875,16 @@ bool Inter_v1::o1_assign(OpFuncParams &params) {
 		break;
 
 	}
-	return false;
 }
 
-bool Inter_v1::o1_loadSpriteToPos(OpFuncParams &params) {
+void Inter_v1::o1_loadSpriteToPos(OpFuncParams &params) {
 	_vm->_draw->_spriteLeft = _vm->_game->_script->readInt16();
 
 	_vm->_draw->_destSpriteX = _vm->_game->_script->readValExpr();
 
 	// WORKAROUND: The EGA version of Gobliiins 1 has an invalid expression there
 	if (_vm->isEGA() && (_vm->_game->_script->pos() == 1398) &&
-			!scumm_stricmp(_vm->_game->_curTotFile, "intro.tot")) {
+			_vm->isCurrentTot("intro.tot")) {
 
 		_vm->_draw->_destSpriteY = 0;
 		_vm->_game->_script->skip(1);
@@ -908,11 +900,9 @@ bool Inter_v1::o1_loadSpriteToPos(OpFuncParams &params) {
 	_vm->_game->_script->skip(2);
 
 	_vm->_draw->spriteOperation(DRAW_LOADSPRITE);
-
-	return false;
 }
 
-bool Inter_v1::o1_printText(OpFuncParams &params) {
+void Inter_v1::o1_printText(OpFuncParams &params) {
 	char buf[60];
 	int i;
 
@@ -961,37 +951,24 @@ bool Inter_v1::o1_printText(OpFuncParams &params) {
 	} while (_vm->_game->_script->peekByte() != 200);
 
 	_vm->_game->_script->skip(1);
-
-	return false;
 }
 
-bool Inter_v1::o1_loadTot(OpFuncParams &params) {
-	char buf[20];
-	int8 size;
-
+void Inter_v1::o1_loadTot(OpFuncParams &params) {
 	if ((_vm->_game->_script->peekByte() & 0x80) != 0) {
 		_vm->_game->_script->skip(1);
-		_vm->_game->_script->evalExpr(0);
-		strncpy0(buf, _vm->_game->_script->getResultStr(), 15);
+		_vm->_game->_totToLoad = _vm->_game->_script->evalString();
 	} else {
-		size = _vm->_game->_script->readInt8();
-		memcpy(buf, _vm->_game->_script->readString(size), size);
-		buf[size] = '\0';
+		uint8 size = _vm->_game->_script->readInt8();
+		_vm->_game->_totToLoad = Common::String(_vm->_game->_script->readString(size), size);
 	}
 
-//	if (_vm->getGameType() == kGameTypeGeisha)
-//		strcat(buf, ".0ot");
-//	else
-	strcat(buf, ".tot");
+	_vm->_game->_totToLoad += ".tot";
 
 	if (_terminate != 2)
 		_terminate = 1;
-	strcpy(_vm->_game->_totToLoad, buf);
-
-	return false;
 }
 
-bool Inter_v1::o1_palLoad(OpFuncParams &params) {
+void Inter_v1::o1_palLoad(OpFuncParams &params) {
 	int index1, index2;
 	int16 id;
 	byte cmd;
@@ -1003,7 +980,7 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 		if ((_vm->_global->_fakeVideoMode < 0x32) ||
 				(_vm->_global->_fakeVideoMode > 0x63)) {
 			_vm->_game->_script->skip(48);
-			return false;
+			return;
 		}
 		break;
 
@@ -1011,55 +988,55 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 		if ((_vm->_global->_fakeVideoMode != 5) &&
 				(_vm->_global->_fakeVideoMode != 7)) {
 			_vm->_game->_script->skip(18);
-			return false;
+			return;
 		}
 		break;
 
 	case 50:
 		if (_vm->_global->_colorCount == 256) {
 			_vm->_game->_script->skip(16);
-			return false;
+			return;
 		}
 		break;
 
 	case 51:
 		if (_vm->_global->_fakeVideoMode < 0x64) {
 			_vm->_game->_script->skip(2);
-			return false;
+			return;
 		}
 		break;
 
 	case 52:
 		if (_vm->_global->_colorCount == 256) {
 			_vm->_game->_script->skip(48);
-			return false;
+			return;
 		}
 		break;
 
 	case 53:
 		if (_vm->_global->_colorCount != 256) {
 			_vm->_game->_script->skip(2);
-			return false;
+			return;
 		}
 		break;
 
 	case 54:
 		if (_vm->_global->_fakeVideoMode < 0x13) {
-			return false;
+			return;
 		}
 		break;
 
 	case 61:
 		if (_vm->_global->_fakeVideoMode < 0x13) {
 			_vm->_game->_script->skip(4);
-			return false;
+			return;
 		}
 		break;
 	}
 
 	if ((cmd & 0x7F) == 0x30) {
 		_vm->_game->_script->skip(48);
-		return false;
+		return;
 	}
 
 	_vm->_draw->_applyPal = !(cmd & 0x80);
@@ -1075,10 +1052,10 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 			}
 		}
 		if (!allZero) {
-			_vm->_video->clearSurf(*_vm->_draw->_frontSurface);
+			_vm->_draw->_frontSurface->clear();
 			_vm->_draw->_noInvalidated57 = true;
 			_vm->_game->_script->skip(48);
-			return false;
+			return;
 		}
 		_vm->_draw->_noInvalidated57 = false;
 
@@ -1105,7 +1082,7 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 
 		_vm->_global->_pPaletteDesc->unused1 = _vm->_draw->_unusedPalette1;
 		_vm->_video->setFullPalette(_vm->_global->_pPaletteDesc);
-		return false;
+		return;
 	}
 
 	switch (cmd) {
@@ -1157,7 +1134,7 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 		if (_vm->_draw->_applyPal) {
 			_vm->_draw->_applyPal = false;
 			_vm->_video->setFullPalette(_vm->_global->_pPaletteDesc);
-			return false;
+			return;
 		}
 		break;
 	}
@@ -1169,27 +1146,30 @@ bool Inter_v1::o1_palLoad(OpFuncParams &params) {
 		if (_vm->_global->_videoMode < 0x13) {
 			_vm->_global->_pPaletteDesc->vgaPal = _vm->_draw->_vgaPalette;
 			_vm->_palAnim->fade(_vm->_global->_pPaletteDesc, 0, 0);
-			return false;
+			return;
 		}
 		if ((_vm->_global->_videoMode < 0x32) ||
 				(_vm->_global->_videoMode >= 0x64)) {
 			_vm->_global->_pPaletteDesc->vgaPal = _vm->_draw->_vgaPalette;
 			_vm->_palAnim->fade(_vm->_global->_pPaletteDesc, 0, 0);
-			return false;
+			return;
 		}
 		_vm->_global->_pPaletteDesc->vgaPal = _vm->_draw->_vgaSmallPalette;
 		_vm->_palAnim->fade(_vm->_global->_pPaletteDesc, 0, 0);
 	}
-
-	return false;
 }
 
-bool Inter_v1::o1_keyFunc(OpFuncParams &params) {
+void Inter_v1::o1_keyFunc(OpFuncParams &params) {
 	static uint32 lastCalled = 0;
 	int16 cmd;
 	int16 key;
 	uint32 now;
 
+	if (!_vm->_vidPlayer->isPlayingLive()) {
+		_vm->_draw->forceBlit();
+		_vm->_video->retrace();
+	}
+
 	cmd = _vm->_game->_script->readInt16();
 	animPalette();
 	_vm->_draw->blitInvalidated();
@@ -1205,11 +1185,13 @@ bool Inter_v1::o1_keyFunc(OpFuncParams &params) {
 	// to become 5000. We deliberately slow down busy-waiting, so we shorten
 	// the counting, too.
 	if ((_vm->getGameType() == kGameTypeWeen) && (VAR(59) < 4000) &&
-	    (_vm->_game->_script->pos() == 729) &&
-	    !scumm_stricmp(_vm->_game->_curTotFile, "intro5.tot"))
+	    (_vm->_game->_script->pos() == 729) && _vm->isCurrentTot("intro5.tot"))
 		WRITE_VAR(59, 4000);
 
 	switch (cmd) {
+	case -1:
+		break;
+
 	case 0:
 		_vm->_draw->_showCursor &= ~2;
 		_vm->_util->longDelay(1);
@@ -1244,11 +1226,9 @@ bool Inter_v1::o1_keyFunc(OpFuncParams &params) {
 			_vm->_util->longDelay(cmd);
 		break;
 	}
-
-	return false;
 }
 
-bool Inter_v1::o1_capturePush(OpFuncParams &params) {
+void Inter_v1::o1_capturePush(OpFuncParams &params) {
 	int16 left, top;
 	int16 width, height;
 
@@ -1258,78 +1238,68 @@ bool Inter_v1::o1_capturePush(OpFuncParams &params) {
 	height = _vm->_game->_script->readValExpr();
 
 	if ((width < 0) || (height < 0))
-		return false;
+		return;
 
 	_vm->_game->capturePush(left, top, width, height);
 	(*_vm->_scenery->_pCaptureCounter)++;
-	return false;
 }
 
-bool Inter_v1::o1_capturePop(OpFuncParams &params) {
+void Inter_v1::o1_capturePop(OpFuncParams &params) {
 	if (*_vm->_scenery->_pCaptureCounter != 0) {
 		(*_vm->_scenery->_pCaptureCounter)--;
 		_vm->_game->capturePop(1);
 	}
-	return false;
 }
 
-bool Inter_v1::o1_animPalInit(OpFuncParams &params) {
+void Inter_v1::o1_animPalInit(OpFuncParams &params) {
 	_animPalDir[0] = _vm->_game->_script->readInt16();
 	_animPalLowIndex[0] = _vm->_game->_script->readValExpr();
 	_animPalHighIndex[0] = _vm->_game->_script->readValExpr();
-	return false;
 }
 
-bool Inter_v1::o1_drawOperations(OpFuncParams &params) {
+void Inter_v1::o1_drawOperations(OpFuncParams &params) {
 	byte cmd;
 
 	cmd = _vm->_game->_script->readByte();
 
 	executeOpcodeDraw(cmd);
-
-	return false;
 }
 
-bool Inter_v1::o1_setcmdCount(OpFuncParams &params) {
+void Inter_v1::o1_setcmdCount(OpFuncParams &params) {
 	params.cmdCount = _vm->_game->_script->readByte();
 	params.counter = 0;
-	return false;
 }
 
-bool Inter_v1::o1_return(OpFuncParams &params) {
+void Inter_v1::o1_return(OpFuncParams &params) {
 	if (params.retFlag != 2)
 		_break = true;
 
 	_vm->_game->_script->setFinished(true);
-	return true;
+	params.doReturn = true;
 }
 
-bool Inter_v1::o1_renewTimeInVars(OpFuncParams &params) {
+void Inter_v1::o1_renewTimeInVars(OpFuncParams &params) {
 	renewTimeInVars();
-	return false;
 }
 
-bool Inter_v1::o1_speakerOn(OpFuncParams &params) {
+void Inter_v1::o1_speakerOn(OpFuncParams &params) {
 	_vm->_sound->speakerOn(_vm->_game->_script->readValExpr(), -1);
-	return false;
 }
 
-bool Inter_v1::o1_speakerOff(OpFuncParams &params) {
+void Inter_v1::o1_speakerOff(OpFuncParams &params) {
 	_vm->_sound->speakerOff();
-	return false;
 }
 
-bool Inter_v1::o1_putPixel(OpFuncParams &params) {
+void Inter_v1::o1_putPixel(OpFuncParams &params) {
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 
 	_vm->_draw->_destSpriteX = _vm->_game->_script->readValExpr();
 	_vm->_draw->_destSpriteY = _vm->_game->_script->readValExpr();
 	_vm->_draw->_frontColor = _vm->_game->_script->readValExpr();
 	_vm->_draw->spriteOperation(DRAW_PUTPIXEL);
-	return false;
 }
 
-bool Inter_v1::o1_goblinFunc(OpFuncParams &params) {
+void Inter_v1::o1_goblinFunc(OpFuncParams &params) {
 	OpGobParams gobParams;
 	bool objDescSet = false;
 	int16 cmd;
@@ -1377,14 +1347,12 @@ bool Inter_v1::o1_goblinFunc(OpFuncParams &params) {
 */
 
 	if ((cmd < 40) && objDescSet && !gobParams.objDesc)
-		return false;
+		return;
 
 	executeOpcodeGob(cmd, gobParams);
-
-	return false;
 }
 
-bool Inter_v1::o1_createSprite(OpFuncParams &params) {
+void Inter_v1::o1_createSprite(OpFuncParams &params) {
 	int16 index;
 	int16 width, height;
 	int16 flag;
@@ -1401,32 +1369,31 @@ bool Inter_v1::o1_createSprite(OpFuncParams &params) {
 
 	flag = _vm->_game->_script->readInt16();
 	_vm->_draw->initSpriteSurf(index, width, height, flag ? 2 : 0);
-
-	return false;
 }
 
-bool Inter_v1::o1_freeSprite(OpFuncParams &params) {
+void Inter_v1::o1_freeSprite(OpFuncParams &params) {
 	_vm->_draw->freeSprite(_vm->_game->_script->readInt16());
-	return false;
 }
 
-bool Inter_v1::o1_returnTo(OpFuncParams &params) {
+void Inter_v1::o1_returnTo(OpFuncParams &params) {
 	if (params.retFlag == 1) {
 		_break = true;
 		_vm->_game->_script->setFinished(true);
-		return true;
+		params.doReturn = true;
+		return;
 	}
 
 	if (*_nestLevel == 0)
-		return false;
+		return;
 
 	*_breakFromLevel = *_nestLevel;
 	_break = true;
 	_vm->_game->_script->setFinished(true);
-	return true;
+
+	params.doReturn = true;
 }
 
-bool Inter_v1::o1_loadSpriteContent(OpFuncParams &params) {
+void Inter_v1::o1_loadSpriteContent(OpFuncParams &params) {
 	_vm->_draw->_spriteLeft = _vm->_game->_script->readInt16();
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 	_vm->_draw->_transparency = _vm->_game->_script->readInt16();
@@ -1434,10 +1401,9 @@ bool Inter_v1::o1_loadSpriteContent(OpFuncParams &params) {
 	_vm->_draw->_destSpriteY = 0;
 
 	_vm->_draw->spriteOperation(DRAW_LOADSPRITE);
-	return false;
 }
 
-bool Inter_v1::o1_copySprite(OpFuncParams &params) {
+void Inter_v1::o1_copySprite(OpFuncParams &params) {
 	if (_vm->_game->_script->peekByte(1) == 0)
 		_vm->_draw->_sourceSurface = _vm->_game->_script->readInt16();
 	else
@@ -1459,10 +1425,9 @@ bool Inter_v1::o1_copySprite(OpFuncParams &params) {
 	_vm->_draw->_transparency = _vm->_game->_script->readInt16();
 
 	_vm->_draw->spriteOperation(DRAW_BLITSURF);
-	return false;
 }
 
-bool Inter_v1::o1_fillRect(OpFuncParams &params) {
+void Inter_v1::o1_fillRect(OpFuncParams &params) {
 	int16 destSurf;
 
 	_vm->_draw->_destSurface = destSurf = _vm->_game->_script->readInt16();
@@ -1475,7 +1440,7 @@ bool Inter_v1::o1_fillRect(OpFuncParams &params) {
 	_vm->_draw->_backColor = _vm->_game->_script->readValExpr();
 
 	if (!_vm->_draw->_spritesArray[(destSurf >= 100) ? (destSurf - 80) : destSurf])
-		return false;
+		return;
 
 	if (_vm->_draw->_spriteRight < 0) {
 		_vm->_draw->_destSpriteX += _vm->_draw->_spriteRight - 1;
@@ -1487,10 +1452,9 @@ bool Inter_v1::o1_fillRect(OpFuncParams &params) {
 	}
 
 	_vm->_draw->spriteOperation(DRAW_FILLRECT);
-	return false;
 }
 
-bool Inter_v1::o1_drawLine(OpFuncParams &params) {
+void Inter_v1::o1_drawLine(OpFuncParams &params) {
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 
 	_vm->_draw->_destSpriteX = _vm->_game->_script->readValExpr();
@@ -1500,41 +1464,37 @@ bool Inter_v1::o1_drawLine(OpFuncParams &params) {
 
 	_vm->_draw->_frontColor = _vm->_game->_script->readValExpr();
 	_vm->_draw->spriteOperation(DRAW_DRAWLINE);
-	return false;
 }
 
-bool Inter_v1::o1_strToLong(OpFuncParams &params) {
+void Inter_v1::o1_strToLong(OpFuncParams &params) {
 	char str[20];
 	int16 strVar;
 	int16 destVar;
 	int32 res;
 
 	strVar = _vm->_game->_script->readVarIndex();
-	strncpy0(str, GET_VARO_STR(strVar), 19);
+	Common::strlcpy(str, GET_VARO_STR(strVar), 20);
 	res = atoi(str);
 
 	destVar = _vm->_game->_script->readVarIndex();
 	WRITE_VAR_OFFSET(destVar, res);
-	return false;
 }
 
-bool Inter_v1::o1_invalidate(OpFuncParams &params) {
+void Inter_v1::o1_invalidate(OpFuncParams &params) {
 	_vm->_draw->_destSurface = _vm->_game->_script->readInt16();
 	_vm->_draw->_destSpriteX = _vm->_game->_script->readValExpr();
 	_vm->_draw->_destSpriteY = _vm->_game->_script->readValExpr();
 	_vm->_draw->_spriteRight = _vm->_game->_script->readValExpr();
 	_vm->_draw->_frontColor = _vm->_game->_script->readValExpr();
 	_vm->_draw->spriteOperation(DRAW_INVALIDATE);
-	return false;
 }
 
-bool Inter_v1::o1_setBackDelta(OpFuncParams &params) {
+void Inter_v1::o1_setBackDelta(OpFuncParams &params) {
 	_vm->_draw->_backDeltaX = _vm->_game->_script->readValExpr();
 	_vm->_draw->_backDeltaY = _vm->_game->_script->readValExpr();
-	return false;
 }
 
-bool Inter_v1::o1_playSound(OpFuncParams &params) {
+void Inter_v1::o1_playSound(OpFuncParams &params) {
 	int16 frequency;
 	int16 freq2;
 	int16 repCount;
@@ -1549,11 +1509,11 @@ bool Inter_v1::o1_playSound(OpFuncParams &params) {
 
 	_soundEndTimeKey = 0;
 	if (!sample || sample->empty())
-		return false;
+		return;
 
 	if (repCount < 0) {
 		if (_vm->_global->_soundFlags < 2)
-			return false;
+			return;
 
 		repCount = -repCount;
 		_soundEndTimeKey = _vm->_util->getTimeKey();
@@ -1573,34 +1533,28 @@ bool Inter_v1::o1_playSound(OpFuncParams &params) {
 		_vm->_sound->blasterStop(0);
 		_vm->_sound->blasterPlay(sample, repCount - 1, frequency);
 	}
-
-	return false;
 }
 
-bool Inter_v1::o1_stopSound(OpFuncParams &params) {
+void Inter_v1::o1_stopSound(OpFuncParams &params) {
 	_vm->_sound->adlibStop();
 	_vm->_sound->blasterStop(_vm->_game->_script->readValExpr());
 
 	_soundEndTimeKey = 0;
-	return false;
 }
 
-bool Inter_v1::o1_loadSound(OpFuncParams &params) {
+void Inter_v1::o1_loadSound(OpFuncParams &params) {
 	loadSound(-1);
-	return false;
 }
 
-bool Inter_v1::o1_freeSoundSlot(OpFuncParams &params) {
+void Inter_v1::o1_freeSoundSlot(OpFuncParams &params) {
 	_vm->_game->freeSoundSlot(-1);
-	return false;
 }
 
-bool Inter_v1::o1_waitEndPlay(OpFuncParams &params) {
+void Inter_v1::o1_waitEndPlay(OpFuncParams &params) {
 	_vm->_sound->blasterWaitEndPlay();
-	return false;
 }
 
-bool Inter_v1::o1_playComposition(OpFuncParams &params) {
+void Inter_v1::o1_playComposition(OpFuncParams &params) {
 	int16 composition[50];
 	int16 dataVar;
 	int16 freqVal;
@@ -1611,10 +1565,9 @@ bool Inter_v1::o1_playComposition(OpFuncParams &params) {
 		composition[i] = (int16) VAR_OFFSET(dataVar + i * 4);
 
 	_vm->_sound->blasterPlayComposition(composition, freqVal);
-	return false;
 }
 
-bool Inter_v1::o1_getFreeMem(OpFuncParams &params) {
+void Inter_v1::o1_getFreeMem(OpFuncParams &params) {
 	int16 freeVar;
 	int16 maxFreeVar;
 
@@ -1624,34 +1577,27 @@ bool Inter_v1::o1_getFreeMem(OpFuncParams &params) {
 	// HACK
 	WRITE_VAR_OFFSET(freeVar, 1000000);
 	WRITE_VAR_OFFSET(maxFreeVar, 1000000);
-	return false;
 }
 
-bool Inter_v1::o1_checkData(OpFuncParams &params) {
-	int16 handle;
-	int16 varOff;
+void Inter_v1::o1_checkData(OpFuncParams &params) {
+	const char *file   = _vm->_game->_script->evalString();
+	      int16 varOff = _vm->_game->_script->readVarIndex();
 
-	_vm->_game->_script->evalExpr(0);
-	varOff = _vm->_game->_script->readVarIndex();
-	handle = _vm->_dataIO->openData(_vm->_game->_script->getResultStr());
-
-	WRITE_VAR_OFFSET(varOff, handle);
-	if (handle >= 0)
-		_vm->_dataIO->closeData(handle);
-	else
-		warning("File \"%s\" not found", _vm->_game->_script->getResultStr());
-	return false;
+	if (!_vm->_dataIO->hasFile(file)) {
+		warning("File \"%s\" not found", file);
+		WRITE_VAR_OFFSET(varOff, (uint32) -1);
+	} else
+		WRITE_VAR_OFFSET(varOff, 50); // "handle" between 50 and 128 = in archive
 }
 
-bool Inter_v1::o1_cleanupStr(OpFuncParams &params) {
+void Inter_v1::o1_cleanupStr(OpFuncParams &params) {
 	int16 strVar;
 
 	strVar = _vm->_game->_script->readVarIndex();
 	_vm->_util->cleanupStr(GET_VARO_FSTR(strVar));
-	return false;
 }
 
-bool Inter_v1::o1_insertStr(OpFuncParams &params) {
+void Inter_v1::o1_insertStr(OpFuncParams &params) {
 	int16 pos;
 	int16 strVar;
 
@@ -1661,10 +1607,9 @@ bool Inter_v1::o1_insertStr(OpFuncParams &params) {
 
 	char *str = GET_VARO_FSTR(strVar);
 	_vm->_util->insertStr(_vm->_game->_script->getResultStr(), str, pos);
-	return false;
 }
 
-bool Inter_v1::o1_cutStr(OpFuncParams &params) {
+void Inter_v1::o1_cutStr(OpFuncParams &params) {
 	int16 strVar;
 	int16 pos;
 	int16 size;
@@ -1673,10 +1618,9 @@ bool Inter_v1::o1_cutStr(OpFuncParams &params) {
 	pos = _vm->_game->_script->readValExpr();
 	size = _vm->_game->_script->readValExpr();
 	_vm->_util->cutFromStr(GET_VARO_STR(strVar), pos, size);
-	return false;
 }
 
-bool Inter_v1::o1_strstr(OpFuncParams &params) {
+void Inter_v1::o1_strstr(OpFuncParams &params) {
 	int16 strVar;
 	int16 resVar;
 	int16 pos;
@@ -1688,10 +1632,9 @@ bool Inter_v1::o1_strstr(OpFuncParams &params) {
 	char *res = strstr(GET_VARO_STR(strVar), _vm->_game->_script->getResultStr());
 	pos = res ? (res - (GET_VARO_STR(strVar))) : -1;
 	WRITE_VAR_OFFSET(resVar, pos);
-	return false;
 }
 
-bool Inter_v1::o1_istrlen(OpFuncParams &params) {
+void Inter_v1::o1_istrlen(OpFuncParams &params) {
 	int16 len;
 	int16 strVar;
 
@@ -1700,10 +1643,9 @@ bool Inter_v1::o1_istrlen(OpFuncParams &params) {
 	strVar = _vm->_game->_script->readVarIndex();
 
 	WRITE_VAR_OFFSET(strVar, len);
-	return false;
 }
 
-bool Inter_v1::o1_setMousePos(OpFuncParams &params) {
+void Inter_v1::o1_setMousePos(OpFuncParams &params) {
 	_vm->_global->_inter_mouseX = _vm->_game->_script->readValExpr();
 	_vm->_global->_inter_mouseY = _vm->_game->_script->readValExpr();
 	_vm->_global->_inter_mouseX -= _vm->_video->_scrollOffsetX;
@@ -1711,121 +1653,102 @@ bool Inter_v1::o1_setMousePos(OpFuncParams &params) {
 	if (_vm->_global->_useMouse != 0)
 		_vm->_util->setMousePos(_vm->_global->_inter_mouseX,
 				_vm->_global->_inter_mouseY);
-	return false;
 }
 
-bool Inter_v1::o1_setFrameRate(OpFuncParams &params) {
+void Inter_v1::o1_setFrameRate(OpFuncParams &params) {
 	_vm->_util->setFrameRate(_vm->_game->_script->readValExpr());
-	return false;
 }
 
-bool Inter_v1::o1_animatePalette(OpFuncParams &params) {
+void Inter_v1::o1_animatePalette(OpFuncParams &params) {
 	_vm->_draw->blitInvalidated();
 	_vm->_util->waitEndFrame();
 	animPalette();
 	storeKey(_vm->_game->checkKeys(&_vm->_global->_inter_mouseX,
 		&_vm->_global->_inter_mouseY, &_vm->_game->_mouseButtons, 0));
-	return false;
 }
 
-bool Inter_v1::o1_animateCursor(OpFuncParams &params) {
+void Inter_v1::o1_animateCursor(OpFuncParams &params) {
 	_vm->_draw->animateCursor(1);
-	return false;
 }
 
-bool Inter_v1::o1_blitCursor(OpFuncParams &params) {
+void Inter_v1::o1_blitCursor(OpFuncParams &params) {
 	_vm->_draw->blitCursor();
-	return false;
 }
 
-bool Inter_v1::o1_loadFont(OpFuncParams &params) {
-	int16 index;
-
-	_vm->_game->_script->evalExpr(0);
-	index = _vm->_game->_script->readInt16();
+void Inter_v1::o1_loadFont(OpFuncParams &params) {
+	const char  *font  = _vm->_game->_script->evalString();
+	      uint16 index = _vm->_game->_script->readInt16();
 
 	_vm->_draw->animateCursor(4);
-
-	_vm->_draw->loadFont(index, _vm->_game->_script->getResultStr());
-
-	return false;
+	_vm->_draw->loadFont(index, font);
 }
 
-bool Inter_v1::o1_freeFont(OpFuncParams &params) {
+void Inter_v1::o1_freeFont(OpFuncParams &params) {
 	int16 index;
 
 	index = _vm->_game->_script->readInt16();
-	delete _vm->_draw->_fonts[index];
-	_vm->_draw->_fonts[index] = 0;
-	return false;
-}
 
-bool Inter_v1::o1_readData(OpFuncParams &params) {
-	int16 retSize;
-	int16 size;
-	int16 dataVar;
-	int16 offset;
-	int16 handle;
-
-	_vm->_game->_script->evalExpr(0);
-	dataVar = _vm->_game->_script->readVarIndex();
-	size = _vm->_game->_script->readValExpr();
-	offset = _vm->_game->_script->readValExpr();
-	retSize = 0;
-
-	WRITE_VAR(1, 1);
-	handle = _vm->_dataIO->openData(_vm->_game->_script->getResultStr());
-	if (handle >= 0) {
-		DataStream *stream = _vm->_dataIO->openAsStream(handle, true);
-
-		_vm->_draw->animateCursor(4);
-		if (offset < 0)
-			stream->seek(offset + 1, SEEK_END);
-		else
-			stream->seek(offset);
-
-		if (((dataVar >> 2) == 59) && (size == 4))
-			WRITE_VAR(59, stream->readUint32LE());
-		else
-			retSize = stream->read((byte *)_variables->getAddressOff8(dataVar), size);
-
-		if (retSize == size)
-			WRITE_VAR(1, 0);
-
-		delete stream;
+	if (index >= Draw::kFontCount) {
+		warning("o1_freeFont(): Index %d > count %d", index, Draw::kFontCount);
+		return;
 	}
 
-	return false;
+	delete _vm->_draw->_fonts[index];
+	_vm->_draw->_fonts[index] = 0;
 }
 
-bool Inter_v1::o1_writeData(OpFuncParams &params) {
-	int16 offset;
-	int16 size;
-	int16 dataVar;
+void Inter_v1::o1_readData(OpFuncParams &params) {
+	const char *file    = _vm->_game->_script->evalString();
+	      int16 dataVar = _vm->_game->_script->readVarIndex();
+	      int16 size    = _vm->_game->_script->readValExpr();
+	      int16 offset  = _vm->_game->_script->readValExpr();
+	      int16 retSize = 0;
 
+	WRITE_VAR(1, 1);
+
+	Common::SeekableReadStream *stream = _vm->_dataIO->getFile(file);
+	if (!stream)
+		return;
+
+	_vm->_draw->animateCursor(4);
+	if (offset < 0)
+		stream->seek(offset + 1, SEEK_END);
+	else
+		stream->seek(offset);
+
+	if (((dataVar >> 2) == 59) && (size == 4))
+		WRITE_VAR(59, stream->readUint32LE());
+	else
+		retSize = stream->read((byte *)_variables->getAddressOff8(dataVar), size);
+
+	if (retSize == size)
+		WRITE_VAR(1, 0);
+
+	delete stream;
+}
+
+void Inter_v1::o1_writeData(OpFuncParams &params) {
 	// This writes into a file. It's not portable and isn't needed anyway
 	// (Gobliiins 1 doesn't use save file), so we just warn should it be
 	// called regardless.
 
-	_vm->_game->_script->evalExpr(0);
-	dataVar = _vm->_game->_script->readVarIndex();
-	size = _vm->_game->_script->readValExpr();
-	offset = _vm->_game->_script->readValExpr();
+	const char *file = _vm->_game->_script->evalString();
 
-	warning("Attempted to write to file \"%s\"", _vm->_game->_script->getResultStr());
+	int16 dataVar = _vm->_game->_script->readVarIndex();
+	int16 size    = _vm->_game->_script->readValExpr();
+	int16 offset  = _vm->_game->_script->readValExpr();
+
+	warning("Attempted to write to file \"%s\" (%d, %d, %d)", file, dataVar, size, offset);
 	WRITE_VAR(1, 0);
-
-	return false;
 }
 
-bool Inter_v1::o1_manageDataFile(OpFuncParams &params) {
-	_vm->_game->_script->evalExpr(0);
+void Inter_v1::o1_manageDataFile(OpFuncParams &params) {
+	Common::String file = _vm->_game->_script->evalString();
 
-	if (_vm->_game->_script->getResultStr()[0] != 0)
-		_vm->_dataIO->openDataFile(_vm->_game->_script->getResultStr());
+	if (!file.empty())
+		_vm->_dataIO->openArchive(file, true);
 	else
-		_vm->_dataIO->closeDataFile();
-	return false;
+		_vm->_dataIO->closeArchive(true);
 }
 
 void Inter_v1::o1_setState(OpGobParams &params) {
@@ -2560,8 +2483,8 @@ void Inter_v1::animPalette() {
 }
 
 void Inter_v1::manipulateMap(int16 xPos, int16 yPos, int16 item) {
-	for (int y = 0; y < _vm->_map->_mapHeight; y++) {
-		for (int x = 0; x < _vm->_map->_mapWidth; x++) {
+	for (int y = 0; y < _vm->_map->getMapHeight(); y++) {
+		for (int x = 0; x < _vm->_map->getMapWidth(); x++) {
 			if ((_vm->_map->getItem(x, y) & 0xFF) == item)
 				_vm->_map->setItem(x, y, _vm->_map->getItem(x, y) & 0xFF00);
 			else if (((_vm->_map->getItem(x, y) & 0xFF00) >> 8) == item)
@@ -2569,7 +2492,7 @@ void Inter_v1::manipulateMap(int16 xPos, int16 yPos, int16 item) {
 		}
 	}
 
-	if (xPos < _vm->_map->_mapWidth - 1) {
+	if (xPos < _vm->_map->getMapWidth() - 1) {
 		if (yPos > 0) {
 			if (((_vm->_map->getItem(xPos, yPos) & 0xFF00) != 0) ||
 					((_vm->_map->getItem(xPos, yPos - 1) & 0xFF00) != 0) ||
@@ -2658,7 +2581,7 @@ void Inter_v1::manipulateMap(int16 xPos, int16 yPos, int16 item) {
 		return;
 	}
 
-	if ((xPos < _vm->_map->_mapWidth - 2) &&
+	if ((xPos < _vm->_map->getMapWidth() - 2) &&
 			(_vm->_map->getPass(xPos + 2, yPos) == 1)) {
 		_vm->_map->_itemPoses[item].x = xPos + 2;
 		_vm->_map->_itemPoses[item].y = yPos;
@@ -2666,7 +2589,7 @@ void Inter_v1::manipulateMap(int16 xPos, int16 yPos, int16 item) {
 		return;
 	}
 
-	if ((xPos < _vm->_map->_mapWidth - 1) &&
+	if ((xPos < _vm->_map->getMapWidth() - 1) &&
 			(_vm->_map->getPass(xPos + 1, yPos) == 1)) {
 		_vm->_map->_itemPoses[item].x = xPos + 1;
 		_vm->_map->_itemPoses[item].y = yPos;
