@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_v3.cpp $
- * $Id: inter_v3.cpp 51852 2010-08-08 00:35:18Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -66,7 +66,7 @@ void Inter_v3::setupOpcodesGob() {
 	OPCODEGOB(100, o3_wobble);
 }
 
-bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
+void Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 	byte *totData;
 	int16 totTextItem;
 	int16 part, curPart = 0;
@@ -89,7 +89,7 @@ bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 
 	TextItem *textItem = _vm->_game->_resources->getTextItem(totTextItem);
 	if (!textItem)
-		return false;
+		return;
 
 	totData = textItem->getData();
 
@@ -143,7 +143,7 @@ bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 							(*totData == 6) || (*totData == 7)) {
 						WRITE_VARO_UINT8(stringVar, 0);
 						delete textItem;
-						return false;
+						return;
 					}
 
 					switch (*totData) {
@@ -177,7 +177,7 @@ bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 						totData - _vm->_game->_resources->getTexts());
 				WRITE_VARO_UINT8(stringVar + 6, 0);
 				delete textItem;
-				return false;
+				return;
 			}
 
 			end = false;
@@ -224,7 +224,7 @@ bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 
 					if (curPart == part) {
 						delete textItem;
-						return false;
+						return;
 					}
 
 					stringVar = stringStartVar;
@@ -246,16 +246,14 @@ bool Inter_v3::o3_getTotTextItemPart(OpFuncParams &params) {
 	}
 
 	delete textItem;
-	return false;
 }
 
-bool Inter_v3::o3_copySprite(OpFuncParams &params) {
+void Inter_v3::o3_copySprite(OpFuncParams &params) {
 	o1_copySprite(params);
 
 	// For the close-up "fading" in the CD version
 	if (_vm->_draw->_destSurface == Draw::kFrontSurface)
 		_vm->_video->sparseRetrace(Draw::kFrontSurface);
-	return false;
 }
 
 void Inter_v3::o3_wobble(OpGobParams &params) {
