@@ -18,18 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/inter_v6.cpp $
- * $Id: inter_v6.cpp 52142 2010-08-17 10:19:06Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/file.h"
+#include "common/str.h"
 #include "graphics/dither.h"
 
 #include "gob/gob.h"
 #include "gob/inter.h"
-#include "gob/helper.h"
 #include "gob/global.h"
 #include "gob/dataio.h"
 #include "gob/game.h"
@@ -57,7 +55,6 @@ void Inter_v6::setupOpcodesDraw() {
 
 	OPCODEDRAW(0x40, o6_totSub);
 	OPCODEDRAW(0x83, o6_playVmdOrMusic);
-	OPCODEDRAW(0x85, o6_openItk);
 }
 
 void Inter_v6::setupOpcodesFunc() {
@@ -65,8 +62,8 @@ void Inter_v6::setupOpcodesFunc() {
 
 	OPCODEFUNC(0x03, o6_loadCursor);
 	OPCODEFUNC(0x09, o6_assign);
-	OPCODEFUNC(0x13, o6_palLoad);
 	OPCODEFUNC(0x19, o6_removeHotspot);
+	OPCODEFUNC(0x32, o1_copySprite);
 	OPCODEFUNC(0x33, o6_fillRect);
 }
 
@@ -74,26 +71,18 @@ void Inter_v6::setupOpcodesGob() {
 }
 
 void Inter_v6::o6_totSub() {
-	char totFile[14];
-	byte length;
-	int flags;
-	int i;
-
-	length = _vm->_game->_script->readByte();
+	uint8 length = _vm->_game->_script->readByte();
 	if ((length & 0x7F) > 13)
-		error("Length in o2_totSub is greater than 13 (%d)", length);
+		error("Length in o6_totSub is greater than 13 (%d)", length);
 
-	if (length & 0x80) {
-		_vm->_game->_script->evalExpr(0);
-		strcpy(totFile, _vm->_game->_script->getResultStr());
-	} else {
-		for (i = 0; i < length; i++)
-			totFile[i] = _vm->_game->_script->readChar();
-		totFile[i] = 0;
-	}
-
-	flags = _vm->_game->_script->readByte();
+	Common::String totFile;
+	if (length & 0x80)
+		totFile = _vm->_game->_script->evalString();
+	else
+		for (uint8 i = 0; i < length; i++)
+			totFile += _vm->_game->_script->readChar();
 
+	uint8 flags = _vm->_game->_script->readByte();
 	if (flags & 0x40)
 		warning("Urban Stub: o6_totSub(), flags & 0x40");
 
@@ -101,11 +90,7 @@ void Inter_v6::o6_totSub() {
 }
 
 void Inter_v6::o6_playVmdOrMusic() {
-	char fileName[128];
-	bool close;
-
-	_vm->_game->_script->evalExpr(0);
-	strncpy0(fileName, _vm->_game->_script->getResultStr(), 127);
+	Common::String file = _vm->_game->_script->evalString();
 
 	VideoPlayer::Properties props;
 
@@ -121,11 +106,22 @@ void Inter_v6::o6_playVmdOrMusic() {
 	props.forceSeek  = true;
 
 	debugC(1, kDebugVideo, "Playing video \"%s\" @ %d+%d, frames %d - %d, "
-			"paletteCmd %d (%d - %d), flags %X", fileName,
+			"paletteCmd %d (%d - %d), flags %X", file.c_str(),
 			props.x, props.y, props.startFrame, props.lastFrame,
 			props.palCmd, props.palStart, props.palEnd, props.flags);
 
-	close = false;
+	// WORKAROUND: When taking the music sheet from Dr. Dramish's car,
+	//             the video that lets the sheet vanish is missing. We'll
+	//             play the one where the sheet is already gone instead.
+	if (_vm->isCurrentTot("avt005.tot") && file.equalsIgnoreCase("MXRAMPART"))
+		file = "PLCOFDR2";
+
+	if (file == "RIEN") {
+		_vm->_vidPlayer->closeAll();
+		return;
+	}
+
+	bool close = false;
 	if (props.lastFrame == -1) {
 		close = true;
 	} else if (props.lastFrame == -5) {
@@ -139,73 +135,61 @@ void Inter_v6::o6_playVmdOrMusic() {
 //		warning("Urban/Playtoons Stub: Video/Music command -6 (flush cache)");
 		return;
 	} else if ((props.lastFrame == -8) || (props.lastFrame == -9)) {
-		if (!strchr(fileName, '.'))
-			strcat(fileName, ".WA8");
+		if (!file.contains('.'))
+			file += ".WA8";
 
-		probe16bitMusic(fileName);
+		probe16bitMusic(file);
+
+		if (props.lastFrame == -9)
+			debugC(0, kDebugVideo, "Urban/Playtoons Stub: Delayed music stop?");
 
-		if (props.lastFrame == -9) {
-			warning("Urban/Playtoons Stub: delayed stop not implemented");
-		}
 		_vm->_sound->bgStop();
-		_vm->_sound->bgPlay(fileName, SOUND_WAV);
+		_vm->_sound->bgPlay(file.c_str(), SOUND_WAV);
 		return;
 	} else if (props.lastFrame <= -10) {
 		_vm->_vidPlayer->closeVideo();
-		warning("Urban/Playtoons Stub: Video/Music command %d (close video?), %s", props.lastFrame, fileName);
-		if (props.lastFrame <= -100)
-			props.lastFrame += 100;
 
-		if (((-props.lastFrame) % 10 == 3) && (props.lastFrame <= -20))
-			_vm->_sound->bgPlay(fileName, SOUND_WAV);
+		if (!(props.flags & VideoPlayer::kFlagNoVideo))
+			props.loop = true;
+
 	} else if (props.lastFrame < 0) {
-		warning("Urban/Playtoons Stub: Unknown Video/Music command: %d, %s", props.lastFrame, fileName);
+		warning("Urban/Playtoons Stub: Unknown Video/Music command: %d, %s", props.lastFrame, file.c_str());
 		return;
 	}
 
 	if (props.startFrame == -2) {
 		props.startFrame = 0;
-		props.lastFrame = -1;
-		close = false;
+		props.lastFrame  = -1;
+		props.noBlock    = true;
 	}
 
 	_vm->_vidPlayer->evaluateFlags(props);
 
+	bool primary = true;
+	if (props.noBlock && (props.flags & VideoPlayer::kFlagNoVideo))
+		primary = false;
+
 	int slot = 0;
-	if ((fileName[0] != 0) && ((slot = _vm->_vidPlayer->openVideo(true, fileName, props)) < 0)) {
+	if (!file.empty() && ((slot = _vm->_vidPlayer->openVideo(primary, file, props)) < 0)) {
 		WRITE_VAR(11, (uint32) -1);
 		return;
 	}
 
+	if (props.hasSound)
+		_vm->_vidPlayer->closeLiveSound();
+
 	if (props.startFrame >= 0)
 		_vm->_vidPlayer->play(slot, props);
 
-	if (close)
+	if (close && !props.noBlock) {
+		if (!props.canceled)
+			_vm->_vidPlayer->waitSoundEnd(slot);
 		_vm->_vidPlayer->closeVideo(slot);
-}
-
-void Inter_v6::o6_openItk() {
-	char fileName[32];
-
-	_vm->_game->_script->evalExpr(0);
-	strncpy0(fileName, _vm->_game->_script->getResultStr(), 27);
-	if (!strchr(fileName, '.'))
-		strcat(fileName, ".ITK");
-
-	_vm->_dataIO->openDataFile(fileName, true);
-
-	// WORKAROUND: The CD number detection in Urban Runner is quite daft
-	// (it checks CD1.ITK - CD4.ITK and the first that's found determines
-	// the CD number), while its NO_CD modus wants everything in CD1.ITK.
-	// So we just open the other ITKs, too.
-	if (_vm->_global->_noCd && !scumm_stricmp(fileName, "CD1.ITK")) {
-		_vm->_dataIO->openDataFile("CD2.ITK", true);
-		_vm->_dataIO->openDataFile("CD3.ITK", true);
-		_vm->_dataIO->openDataFile("CD4.ITK", true);
 	}
+
 }
 
-bool Inter_v6::o6_loadCursor(OpFuncParams &params) {
+void Inter_v6::o6_loadCursor(OpFuncParams &params) {
 	int16 id = _vm->_game->_script->readInt16();
 
 	if ((id == -1) || (id == -2)) {
@@ -229,20 +213,20 @@ bool Inter_v6::o6_loadCursor(OpFuncParams &params) {
 		int vmdSlot = _vm->_vidPlayer->openVideo(false, file, props);
 		if (vmdSlot == -1) {
 			warning("Can't open video \"%s\" as cursor", file);
-			return false;
+			return;
 		}
 
 		int16 framesCount = _vm->_vidPlayer->getFrameCount(vmdSlot);
 
 		for (int i = 0; i < framesCount; i++) {
-			props.startFrame = i;
-			props.lastFrame  = i;
+			props.startFrame   = i;
+			props.lastFrame    = i;
+			props.waitEndFrame = false;
 
 			_vm->_vidPlayer->play(vmdSlot, props);
-			_vm->_vidPlayer->copyFrame(vmdSlot, _vm->_draw->_cursorSprites->getVidMem(),
+			_vm->_vidPlayer->copyFrame(vmdSlot, *_vm->_draw->_cursorSprites,
 					0, 0, _vm->_draw->_cursorWidth, _vm->_draw->_cursorWidth,
-					(start + i) * _vm->_draw->_cursorWidth, 0,
-					_vm->_draw->_cursorSprites->getWidth());
+					(start + i) * _vm->_draw->_cursorWidth, 0);
 		}
 
 		_vm->_vidPlayer->closeVideo(vmdSlot);
@@ -251,20 +235,19 @@ bool Inter_v6::o6_loadCursor(OpFuncParams &params) {
 		_vm->_draw->_cursorAnimHigh[index] = framesCount + start - 1;
 		_vm->_draw->_cursorAnimDelays[index] = 10;
 
-		return false;
+		return;
 	}
 
 	int8 index = _vm->_game->_script->readInt8();
 
 	if ((index * _vm->_draw->_cursorWidth) >= _vm->_draw->_cursorSprites->getWidth())
-		return false;
+		return;
 
 	Resource *resource = _vm->_game->_resources->getResource((uint16) id);
 	if (!resource)
-		return false;
+		return;
 
-	_vm->_video->fillRect(*_vm->_draw->_cursorSprites,
-			index * _vm->_draw->_cursorWidth, 0,
+	_vm->_draw->_cursorSprites->fillRect(index * _vm->_draw->_cursorWidth, 0,
 			index * _vm->_draw->_cursorWidth + _vm->_draw->_cursorWidth - 1,
 			_vm->_draw->_cursorHeight - 1, 0);
 
@@ -274,10 +257,9 @@ bool Inter_v6::o6_loadCursor(OpFuncParams &params) {
 	_vm->_draw->_cursorAnimLow[index] = 0;
 
 	delete resource;
-	return false;
 }
 
-bool Inter_v6::o6_assign(OpFuncParams &params) {
+void Inter_v6::o6_assign(OpFuncParams &params) {
 	uint16 size, destType;
 	uint16 dest = _vm->_game->_script->readVarIndex(&size, &destType);
 
@@ -295,7 +277,7 @@ bool Inter_v6::o6_assign(OpFuncParams &params) {
 
 		_vm->_game->_script->evalExpr(&src);
 
-		return false;
+		return;
 	}
 
 	byte loopCount;
@@ -312,7 +294,7 @@ bool Inter_v6::o6_assign(OpFuncParams &params) {
 			dest += n;
 		}
 
-		return false;
+		return;
 
 	} else if (_vm->_game->_script->peekByte() == 99) {
 		_vm->_game->_script->skip(1);
@@ -353,22 +335,9 @@ bool Inter_v6::o6_assign(OpFuncParams &params) {
 			break;
 		}
 	}
-
-	return false;
 }
 
-bool Inter_v6::o6_palLoad(OpFuncParams &params) {
-	o1_palLoad(params);
-
-	if (_gotFirstPalette)
-		_vm->_video->_palLUT->setPalette((const byte *)_vm->_global->_pPaletteDesc->vgaPal,
-				Graphics::PaletteLUT::kPaletteRGB, 6, 0);
-
-	_gotFirstPalette = true;
-	return false;
-}
-
-bool Inter_v6::o6_removeHotspot(OpFuncParams &params) {
+void Inter_v6::o6_removeHotspot(OpFuncParams &params) {
 	int16 id;
 	uint8 stateType1    = Hotspots::kStateFilledDisabled | Hotspots::kStateType1;
 	uint8 stateType2    = Hotspots::kStateFilledDisabled | Hotspots::kStateType2;
@@ -397,11 +366,9 @@ bool Inter_v6::o6_removeHotspot(OpFuncParams &params) {
 		_vm->_game->_hotspots->remove((stateType2 << 12) + id);
 		break;
 	}
-
-	return false;
 }
 
-bool Inter_v6::o6_fillRect(OpFuncParams &params) {
+void Inter_v6::o6_fillRect(OpFuncParams &params) {
 	int16 destSurf;
 
 	_vm->_draw->_destSurface = destSurf = _vm->_game->_script->readInt16();
@@ -411,11 +378,10 @@ bool Inter_v6::o6_fillRect(OpFuncParams &params) {
 	_vm->_draw->_spriteRight = _vm->_game->_script->readValExpr();
 	_vm->_draw->_spriteBottom = _vm->_game->_script->readValExpr();
 
-	_vm->_game->_script->evalExpr(0);
+	uint32 patternColor = _vm->_game->_script->evalInt();
 
-	_vm->_draw->_backColor = _vm->_game->_script->getResultInt() & 0xFFFF;
-
-	_vm->_draw->_pattern = _vm->_game->_script->getResultInt() >> 16;
+	_vm->_draw->_backColor = patternColor & 0xFFFF;
+	_vm->_draw->_pattern   = patternColor >> 16;
 
 	if (_vm->_draw->_pattern != 0)
 		warning("Urban Stub: o6_fillRect(), _pattern = %d", _vm->_draw->_pattern);
@@ -431,31 +397,25 @@ bool Inter_v6::o6_fillRect(OpFuncParams &params) {
 
 	if (destSurf & 0x80) {
 		warning("Urban Stub: o6_fillRect(), destSurf & 0x80");
-		return false;
+		return;
 	}
 
 	if (!_vm->_draw->_spritesArray[(destSurf > 100) ? (destSurf - 80) : destSurf])
-		return false;
+		return;
 
 	_vm->_draw->spriteOperation(DRAW_FILLRECT);
-	return false;
 }
 
-void Inter_v6::probe16bitMusic(char *fileName) {
-	int len = strlen(fileName);
-
-	if (len < 4)
+void Inter_v6::probe16bitMusic(Common::String &fileName) {
+	if (fileName[fileName.size() - 1] != '8')
 		return;
 
-	if (scumm_stricmp(fileName + len - 4, ".WA8"))
+	fileName.setChar('V', fileName.size() - 1);
+
+	if (_vm->_dataIO->hasFile(fileName))
 		return;
 
-	fileName[len - 1] = 'V';
-
-	if (_vm->_dataIO->existData(fileName))
-		return;
-
-	fileName[len - 1] = '8';
+	fileName.setChar('8', fileName.size() - 1);
 }
 
 } // End of namespace Gob
