@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/map.cpp $
- * $Id: map.cpp 53795 2010-10-25 03:47:53Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,33 +32,42 @@
 namespace Gob {
 
 Map::Map(GobEngine *vm) : _vm(vm) {
-	_widthByte = 0;
-	_mapWidth = -1;
+	_mapVersion = 0;
+
+	_passWidth =  0;
+	_mapWidth  = -1;
 	_mapHeight = -1;
-	_screenWidth = 0;
+	_passMap   =  0;
+
+	_screenWidth  = 0;
 	_screenHeight = 0;
-	_tilesWidth = 0;
+
+	_tilesWidth  = 0;
 	_tilesHeight = 0;
-	_passWidth = 0;
 
-	_passMap = 0;
-	_itemsMap = 0;
-	_wayPointsCount = 0;
-	_wayPoints = 0;
 	_bigTiles = false;
 
+	_mapUnknownBool = false;
+
+	_wayPointCount = 0;
+	_wayPoints = 0;
+
+	_nearestWayPoint = 0;
+	_nearestDest     = 0;
+
+	_itemsMap = 0;
+
 	for (int i = 0; i < 40; i++) {
-		_itemPoses[i].x = 0;
-		_itemPoses[i].y = 0;
+		_itemPoses[i].x      = 0;
+		_itemPoses[i].y      = 0;
 		_itemPoses[i].orient = 0;
 	}
 
-	_nearestWayPoint = 0;
-	_nearestDest = 0;
 	_curGoblinX = 0;
 	_curGoblinY = 0;
 	_destX = 0;
 	_destY = 0;
+
 	_sourceFile[0] = 0;
 
 	_loadFromAvo = false;
@@ -76,6 +85,87 @@ Map::~Map() {
 	delete[] _wayPoints;
 }
 
+uint8 Map::getVersion() const {
+	return _mapVersion;
+}
+
+int16 Map::getMapWidth() const {
+	return _mapWidth;
+}
+
+int16 Map::getMapHeight() const {
+	return _mapHeight;
+}
+
+int16 Map::getScreenWidth() const {
+	return _screenWidth;
+}
+
+int16 Map::getScreenHeight() const {
+	return _screenHeight;
+}
+
+int16 Map::getTilesWidth() const {
+	return _tilesWidth;
+}
+
+int16 Map::getTilesHeight() const {
+	return _tilesHeight;
+}
+
+bool Map::hasBigTiles() const {
+	return _bigTiles;
+}
+
+int8 Map::getPass(int x, int y, int width) const {
+	if (!_passMap)
+		return 0;
+
+	if ((x < 0) || (y < 0) || (x >= _mapWidth) || (y >= _mapHeight))
+		return 0;
+
+	if (width == -1)
+		width = _passWidth;
+	return _passMap[y * width + x];
+}
+
+void Map::setPass(int x, int y, int8 pass, int width) {
+	if (!_passMap)
+		return;
+
+	if ((x < 0) || (y < 0) || (x >= _mapWidth) || (y >= _mapHeight))
+		return;
+
+	if (width == -1)
+		width = _passWidth;
+	_passMap[y * width + x] = pass;
+}
+
+const WayPoint &Map::getWayPoint(int n) const {
+	assert(_wayPoints);
+	assert(n < _wayPointCount);
+
+	return _wayPoints[n];
+}
+
+int16 Map::getItem(int x, int y) const {
+	assert(_itemsMap);
+
+	x = CLIP<int>(x, 0, _mapWidth - 1);
+	y = CLIP<int>(y, 0, _mapHeight - 1);
+
+	return _itemsMap[y][x];
+}
+
+void Map::setItem(int x, int y, int16 item) {
+	assert(_itemsMap);
+
+	x = CLIP<int>(x, 0, _mapWidth - 1);
+	y = CLIP<int>(y, 0, _mapHeight - 1);
+
+	_itemsMap[y][x] = item;
+}
+
 void Map::placeItem(int16 x, int16 y, int16 id) {
 	if ((getItem(x, y) & 0xFF00) != 0)
 		setItem(x, y, (getItem(x, y) & 0xFF00) | id);
@@ -83,14 +173,7 @@ void Map::placeItem(int16 x, int16 y, int16 id) {
 		setItem(x, y, (getItem(x, y) & 0x00FF) | (id << 8));
 }
 
-enum {
-	kLeft  = (1 << 0),
-	kUp    = (1 << 1),
-	kRight = (1 << 2),
-	kDown  = (1 << 3)
-};
-
-Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
+Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	if ((x0 == x1) && (y0 == y1))
 		// Already at the destination
 		return kDirNone;
@@ -99,36 +182,36 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 		// Destination out of range
 		return kDirNone;
 
-	int16 dir = 0;
+	RelativeDirection relDir = kRelDirNone;
 
 	// Find the direct direction we want to move
 	if (y1 > y0)
-		dir |= kDown;
+		relDir = kRelDirDown;
 	else if (y1 < y0)
-		dir |= kUp;
+		relDir = kRelDirUp;
 
 	if (x1 > x0)
-		dir |= kRight;
+		relDir = (RelativeDirection)(relDir | kRelDirRight);
 	else if (x1 < x0)
-		dir |= kLeft;
+		relDir = (RelativeDirection)(relDir | kRelDirLeft);
 
 
 	// Are we on ladders and can continue the ladder in the wanted direction?
-	if ((getPass(x0, y0) == 3) && (dir & kUp  ) && (getPass(x0, y0 - 1) != 0))
+	if ((getPass(x0, y0) == 3) && (relDir & kRelDirUp  ) && (getPass(x0, y0 - 1) != 0))
 		return kDirN;
 
-	if ((getPass(x0, y0) == 3) && (dir & kDown) && (getPass(x0, y0 + 1) != 0))
+	if ((getPass(x0, y0) == 3) && (relDir & kRelDirDown) && (getPass(x0, y0 + 1) != 0))
 		return kDirS;
 
-	if ((getPass(x0, y0) == 6) && (dir & kUp  ) && (getPass(x0, y0 - 1) != 0))
+	if ((getPass(x0, y0) == 6) && (relDir & kRelDirUp  ) && (getPass(x0, y0 - 1) != 0))
 		return kDirN;
 
-	if ((getPass(x0, y0) == 6) && (dir & kDown) && (getPass(x0, y0 + 1) != 0))
+	if ((getPass(x0, y0) == 6) && (relDir & kRelDirDown) && (getPass(x0, y0 + 1) != 0))
 		return kDirS;
 
 
 	// Want to go left
-	if (dir == kLeft) {
+	if (relDir == kRelDirLeft) {
 		if (getPass(x0 - 1, y0) != 0)
 			// Can go west
 			return kDirW;
@@ -138,7 +221,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	}
 
 	// Want to go left
-	if (dir == kRight) {
+	if (relDir == kRelDirRight) {
 		if (getPass(x0 + 1, y0) != 0)
 			// Can go east
 			return kDirE;
@@ -149,7 +232,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 
 
 	// Want to go up
-	if (dir == kUp) {
+	if (relDir == kRelDirUp) {
 		if (getPass(x0    , y0 - 1) != 0)
 			// Can go north
 			return kDirN;
@@ -167,7 +250,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	}
 
 	// Want to go down
-	if (dir == kDown) {
+	if (relDir == kRelDirDown) {
 		if (getPass(x0    , y0 + 1) != 0)
 			// Can go south
 			return kDirS;
@@ -186,7 +269,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 
 
 	// Want to go up and right
-	if (dir == (kRight | kUp)) {
+	if (relDir == kRelDirRightUp) {
 		if (getPass(x0 + 1, y0 - 1) != 0)
 			// Can go north-east
 			return kDirNE;
@@ -204,7 +287,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	}
 
 	// Want to go down and right
-	if (dir == (kRight | kDown)) {
+	if (relDir == kRelDirRightDown) {
 		if (getPass(x0 + 1, y0 + 1) != 0)
 			// Can go south-east
 			return kDirSE;
@@ -222,7 +305,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	}
 
 	// Want to go up and left
-	if (dir == (kLeft | kUp)) {
+	if (relDir == kRelDirLeftUp) {
 		if (getPass(x0 - 1, y0 - 1) != 0)
 			// Can go north-west
 			return kDirNW;
@@ -240,7 +323,7 @@ Map::Direction Map::getDirection(int16 x0, int16 y0, int16 x1, int16 y1) {
 	}
 
 	// Want to go left and down
-	if (dir == (kLeft | kDown)) {
+	if (relDir == kRelDirLeftDown) {
 		if (getPass(x0 - 1, y0 + 1) != 0)
 			// Can go south-west
 			return kDirSW;
@@ -268,7 +351,7 @@ int16 Map::findNearestWayPoint(int16 x, int16 y) {
 
 	length = 30000;
 
-	for (int i = 0; i < _wayPointsCount; i++) {
+	for (int i = 0; i < _wayPointCount; i++) {
 		if ((_wayPoints[i].x < 0) || (_wayPoints[i].x >= _mapWidth) ||
 				(_wayPoints[i].y < 0) || (_wayPoints[i].y >= _mapHeight))
 			break;
@@ -402,7 +485,7 @@ int16 Map::checkDirectPath(Mult::Mult_Object *obj, int16 x0, int16 y0, int16 x1,
 			// Check for a blocking waypoint
 
 			if (obj->nearestWayPoint < obj->nearestDest)
-				if ((obj->nearestWayPoint + 1) < _wayPointsCount)
+				if ((obj->nearestWayPoint + 1) < _wayPointCount)
 					if (_wayPoints[obj->nearestWayPoint + 1].notWalkable == 1)
 						return 3;
 
