@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/mult_v2.cpp $
- * $Id: mult_v2.cpp 53038 2010-10-05 21:23:04Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -37,6 +37,7 @@
 #include "gob/goblin.h"
 #include "gob/inter.h"
 #include "gob/scenery.h"
+#include "gob/map.h"
 #include "gob/video.h"
 #include "gob/videoplayer.h"
 
@@ -582,9 +583,8 @@ void Mult_v2::playMultInit() {
 		_vm->_draw->initSpriteSurf(Draw::kAnimSurface, width, height, 0);
 		_animSurf = _vm->_draw->_spritesArray[Draw::kAnimSurface];
 
-		_vm->_video->drawSprite(*_vm->_draw->_spritesArray[Draw::kBackSurface],
-				*_vm->_draw->_spritesArray[Draw::kAnimSurface], 0, 0,
-				_vm->_video->_surfWidth, _vm->_video->_surfHeight, 0, 0, 0);
+		_vm->_draw->_spritesArray[Draw::kAnimSurface]->blit(*_vm->_draw->_spritesArray[Draw::kBackSurface],
+				0, 0, _vm->_video->_surfWidth, _vm->_video->_surfHeight, 0, 0);
 
 		for (_counter = 0; _counter < _objCount; _counter++)
 			_multData->palAnimIndices[_counter] = _counter;
@@ -639,9 +639,8 @@ void Mult_v2::drawStatics(bool &stop) {
 			_vm->_scenery->_curStatic = -1;
 		}
 
-		_vm->_video->drawSprite(*_vm->_draw->_spritesArray[Draw::kBackSurface],
-				*_vm->_draw->_spritesArray[Draw::kAnimSurface], 0, 0,
-				_vm->_video->_surfWidth, _vm->_video->_surfHeight, 0, 0, 0);
+		_vm->_draw->_spritesArray[Draw::kAnimSurface]->blit(*_vm->_draw->_spritesArray[Draw::kBackSurface],
+				0, 0, _vm->_video->_surfWidth, _vm->_video->_surfHeight, 0, 0);
 	}
 }
 
@@ -717,8 +716,10 @@ void Mult_v2::newCycleAnim(Mult_Object &animObj) {
 	if (animData.animType == 4) {
 		animData.frame = 0;
 		animData.isPaused = 1;
-		if (animData.animation < 0)
-			warning("Woodruff Stub: AnimType 4, animation: %d", animData.animation);
+		if ((animData.animation < 0) && (animObj.videoSlot > 0)) {
+			_vm->_vidPlayer->closeVideo(animObj.videoSlot - 1);
+			animObj.videoSlot = 0;
+		}
 		return;
 	}
 
@@ -828,6 +829,10 @@ void Mult_v2::animate() {
 		Mult_Object &animObj = _objects[i];
 		Mult_AnimData &animData = *(animObj.pAnimData);
 
+		if (_vm->_map->_mapUnknownBool) {
+			// TODO!
+		}
+
 		animData.intersected = 200;
 		if (animData.isStatic != 2) {
 			if ((animData.isStatic == 0) || (animObj.lastLeft != -1)) {
@@ -844,10 +849,10 @@ void Mult_v2::animate() {
 		Mult_AnimData &animData = *(animObj.pAnimData);
 
 		animObj.needRedraw = 0;
-		animObj.newTop = 1000;
-		animObj.newLeft = 1000;
-		animObj.newBottom = 0;
-		animObj.newRight = 0;
+		animObj.newTop     = 1000;
+		animObj.newLeft    = 1000;
+		animObj.newBottom  = 0;
+		animObj.newRight   = 0;
 
 		if (animData.isStatic == 2)
 			continue;
