@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/save/saveconverter.h $
- * $Id: saveconverter.h 41079 2009-05-31 17:00:38Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -77,7 +77,7 @@ protected:
 	Common::String _fileName;
 
 	byte *_data;
-	Common::MemoryReadStream *_stream;
+	Common::SeekableReadStream *_stream;
 
 	Common::InSaveFile *openSave() const;
 
@@ -182,25 +182,6 @@ private:
 			SavePartMem *props, Common::InSaveFile *save);
 };
 
-/** A wrapper for old v6-style saves (Urban Runner). */
-class SaveConverter_v6 : public SaveConverter {
-public:
-	SaveConverter_v6(GobEngine *vm, const Common::String &fileName = "");
-	~SaveConverter_v6();
-
-	int isOldSave(Common::InSaveFile **save = 0) const;
-	char *getDescription(Common::SeekableReadStream &save) const;
-
-	bool load();
-
-private:
-	static const uint32 kSlotCount = 15;
-	static const uint32 kSlotNameLength = 40;
-
-	bool loadFail(SavePartInfo *info, SavePartVars *vars,
-			Common::InSaveFile *save);
-};
-
 } // End of namespace Gob
 
 #endif // GOB_SAVE_SAVECONVERTER_H
