@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/save/savehandler.h $
- * $Id: savehandler.h 43654 2009-08-22 15:46:43Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,9 @@
 #define GOB_SAVE_SAVEHANDLER_H
 
 #include "common/savefile.h"
-#include "engines/gob/video.h"	// for SurfaceDescPtr
+#include "common/array.h"
+
+#include "engines/gob/video.h" // for SurfacePtr
 
 namespace Gob {
 
@@ -78,7 +80,7 @@ public:
 
 	/** Creates an index in buffer. */
 	virtual void buildIndex(byte *buffer, SavePartInfo &info,
-			SaveConverter *converter = 0) const;
+			SaveConverter *converter = 0, bool setLongest = false) const;
 
 	virtual bool exists(int slot) const;
 	virtual Common::InSaveFile *openRead(int slot) const;
@@ -121,6 +123,9 @@ public:
 	/** Saves (parts of) the file. */
 	virtual bool save(int16 dataVar, int32 size, int32 offset) = 0;
 
+	/** Deletes the file. */
+	virtual bool deleteFile();
+
 	static uint32 getVarSize(GobEngine *vm);
 
 protected:
@@ -137,9 +142,8 @@ public:
 	bool load(int16 dataVar, int32 size, int32 offset);
 	bool save(int16 dataVar, int32 size, int32 offset);
 
-	/** Create a fitting sprite. */
-	bool createSprite(int16 dataVar, int32 size,
-			int32 offset, SurfaceDescPtr *sprite = 0);
+	bool create(uint32 width, uint32 height, bool trueColor);
+	bool createFromSprite(int16 dataVar, int32 size, int32 offset);
 
 protected:
 	SavePartSprite *_sprite;
@@ -152,6 +156,8 @@ protected:
 	static int getIndex(int32 size);
 	/** Determine whether the palette should be used too. */
 	static bool usesPalette(int32 size);
+
+	SurfacePtr createSprite(int16 dataVar, int32 size, int32 offset);
 };
 
 /** A handler for notes. */
@@ -176,6 +182,22 @@ private:
 	SavePartVars *_notes;
 };
 
+/** A handler that behaves like a file but keeps the contents in memory. */
+class FakeFileHandler : public SaveHandler {
+public:
+	FakeFileHandler(GobEngine *vm);
+	~FakeFileHandler();
+
+	int32 getSize();
+	bool load(int16 dataVar, int32 size, int32 offset);
+	bool save(int16 dataVar, int32 size, int32 offset);
+
+	bool deleteFile();
+
+private:
+	Common::Array<byte> _data;
+};
+
 } // End of namespace Gob
 
 #endif // GOB_SAVE_SAVEHANDLER_H
