@@ -18,14 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/save/saveload.cpp $
- * $Id: saveload.cpp 43464 2009-08-17 10:05:02Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/savefile.h"
-
 #include "gob/gob.h"
 #include "gob/save/saveload.h"
 #include "gob/global.h"
@@ -117,6 +114,30 @@ bool SaveLoad::save(const char *fileName, int16 dataVar, int32 size, int32 offse
 	return true;
 }
 
+bool SaveLoad::deleteFile(const char *fileName) {
+	debugC(3, kDebugSaveLoad, "Requested deletion save file \"%s\"", fileName);
+
+	SaveHandler *handler = getHandler(fileName);
+
+	if (!handler) {
+		warning("No save handler for \"%s\"", fileName);
+		return false;
+	}
+
+	if (!handler->deleteFile()) {
+		const char *desc = getDescription(fileName);
+
+		if (!desc)
+			desc = "Unknown";
+
+		warning("Could not delete %s (\"%s\")", desc, fileName);
+		return false;
+	}
+
+	debugC(3, kDebugSaveLoad, "Successfully deleted file");
+	return true;
+}
+
 SaveLoad::SaveMode SaveLoad::getSaveMode(const char *fileName) const {
 	return kSaveModeNone;
 }
