@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/save/saveload.h $
- * $Id: saveload.h 47845 2010-02-03 09:32:16Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -64,6 +64,9 @@ public:
 	/** Saves size bytes from the variables starting with data dataVar at offset. */
 	bool save(const char *fileName, int16 dataVar, int32 size, int32 offset);
 
+	/** Deletes the file. */
+	bool deleteFile(const char *fileName);
+
 protected:
 	GobEngine *_vm;
 
@@ -302,7 +305,7 @@ protected:
 			int getSlot(int32 offset) const;
 			int getSlotRemainder(int32 offset) const;
 
-			void buildIndex(byte *buffer) const;
+			void buildScreenshotIndex(byte *buffer) const;
 
 		protected:
 			uint32 _shotSize;
@@ -334,6 +337,122 @@ protected:
 	SaveFile *getSaveFile(const char *fileName);
 };
 
+/** Save/Load class for Inca 2. */
+class SaveLoad_Inca2 : public SaveLoad {
+public:
+	static const uint32 kSlotCount =  40;
+	static const uint32 kPropsSize = 500;
+
+	SaveLoad_Inca2(GobEngine *vm, const char *targetName);
+	virtual ~SaveLoad_Inca2();
+
+	SaveMode getSaveMode(const char *fileName) const;
+
+protected:
+	struct SaveFile {
+		const char *sourceName;
+		SaveMode mode;
+		SaveHandler *handler;
+		const char *description;
+	};
+
+	/** Handles the voice language info file. */
+	class VoiceHandler : public SaveHandler {
+	public:
+		VoiceHandler(GobEngine *vm);
+		~VoiceHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+	};
+
+	class ScreenshotHandler;
+
+	/** Handles the save slots. */
+	class GameHandler : public SaveHandler {
+	friend class SaveLoad_Inca2::ScreenshotHandler;
+	public:
+
+		GameHandler(GobEngine *vm, const char *target);
+		~GameHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+
+		bool saveScreenshot(int slot, const SavePartSprite *screenshot);
+		bool loadScreenshot(int slot, SavePartSprite *screenshot);
+
+		/** Slot file construction. */
+		class File : public SlotFileIndexed {
+		public:
+			File(GobEngine *vm, const char *base);
+			File(const File &file);
+			~File();
+
+			int getSlot(int32 offset) const;
+			int getSlotRemainder(int32 offset) const;
+		};
+
+	private:
+
+		File *_slotFile;
+
+		byte _props[kPropsSize];
+
+		SaveReader *_reader;
+		SaveWriter *_writer;
+
+		void buildIndex();
+
+		bool createReader(int slot);
+		bool createWriter(int slot);
+	};
+
+	/** Handles the screenshots. */
+	class ScreenshotHandler : public TempSpriteHandler {
+	public:
+		ScreenshotHandler(GobEngine *vm, GameHandler *gameHandler);
+		~ScreenshotHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+
+	private:
+		/** Slot file construction. */
+		class File : public SaveLoad_Inca2::GameHandler::File {
+		public:
+			File(const SaveLoad_Inca2::GameHandler::File &file);
+			~File();
+
+			int getSlot(int32 offset) const;
+			int getSlotRemainder(int32 offset) const;
+
+			void buildScreenshotIndex(byte *buffer) const;
+		};
+
+		File *_file;
+		GameHandler *_gameHandler;
+
+		byte _index[80];
+	};
+
+	static SaveFile _saveFiles[];
+
+	VoiceHandler      *_voiceHandler;
+	TempSpriteHandler *_tempSpriteHandler;
+	GameHandler       *_gameHandler;
+	ScreenshotHandler *_screenshotHandler;
+
+	SaveHandler *getHandler(const char *fileName) const;
+	const char *getDescription(const char *fileName) const;
+
+	const SaveFile *getSaveFile(const char *fileName) const;
+	SaveFile *getSaveFile(const char *fileName);
+};
+
 /** Save/Load class for Woodruff. */
 class SaveLoad_v4 : public SaveLoad {
 public:
@@ -486,16 +605,30 @@ protected:
 		const char *description;
 	};
 
+	/** Handles the temp sprites. */
+	class SpriteHandler : public TempSpriteHandler {
+	public:
+		SpriteHandler(GobEngine *vm);
+		~SpriteHandler();
+
+		bool set(SaveReader *reader, uint32 part);
+		bool get(SaveWriter *writer, uint32 part);
+	};
+
 	/** Handles the save slots. */
 	class GameHandler : public SaveHandler {
 	public:
-		GameHandler(GobEngine *vm, const char *target);
+		GameHandler(GobEngine *vm, const char *target, SpriteHandler &spriteHandler);
 		~GameHandler();
 
 		int32 getSize();
 		bool load(int16 dataVar, int32 size, int32 offset);
 		bool save(int16 dataVar, int32 size, int32 offset);
 
+		uint8 getExtraID(int slot);
+		bool loadExtra(int slot, uint8 id, int16 dataVar, int32 size, int32 offset);
+		bool saveExtra(int slot, uint8 id, int16 dataVar, int32 size, int32 offset);
+
 	private:
 		/** Slot file construction. */
 		class File : public SlotFileIndexed {
@@ -507,19 +640,109 @@ protected:
 			int getSlotRemainder(int32 offset) const;
 		};
 
+		SpriteHandler *_spriteHandler;
+
 		byte _props[kPropsSize];
 		byte _index[kIndexSize];
 
 		File *_slotFile;
 
+		SaveReader *_reader;
+		SaveWriter *_writer;
+
+		bool _hasExtra;
+
 		void buildIndex(byte *buffer) const;
 
 		void refreshProps();
+
+		bool createReader(int slot);
+		bool createWriter(int slot);
+	};
+
+	/** Handles the autosave. */
+	class AutoHandler : public SaveHandler {
+	public:
+		AutoHandler(GobEngine *vm, const Common::String &target);
+		~AutoHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+
+	private:
+		class File : public SlotFileStatic {
+		public:
+			File(GobEngine *vm, const Common::String &base);
+			~File();
+		};
+
+		File _file;
+	};
+
+	/** Handles the autosave temp sprite. */
+	class AutoSpriteHandler : public TempSpriteHandler {
+	public:
+		AutoSpriteHandler(GobEngine *vm, const Common::String &target);
+		~AutoSpriteHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+
+	private:
+		class File : public SlotFileStatic {
+		public:
+			File(GobEngine *vm, const Common::String &base);
+			~File();
+		};
+
+		File _file;
+	};
+
+	/** Handles the temporary saves. */
+	class TempHandler : public SaveHandler {
+	public:
+		TempHandler(GobEngine *vm);
+		~TempHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+		bool deleteFile();
+
+	private:
+		bool _empty;
+
+		uint32 _size;
+		byte *_data;
+	};
+
+	class ExtraHandler : public SaveHandler {
+	public:
+		ExtraHandler(GobEngine *vm, GameHandler &game, uint8 id, int slot);
+		~ExtraHandler();
+
+		int32 getSize();
+		bool load(int16 dataVar, int32 size, int32 offset);
+		bool save(int16 dataVar, int32 size, int32 offset);
+
+	private:
+		uint8 _id;
+		int   _slot;
+
+		TempHandler *_tmp;
+		GameHandler *_game;
 	};
 
 	static SaveFile _saveFiles[];
 
-	GameHandler *_gameHandler;
+	SpriteHandler     *_spriteHandler;
+	GameHandler       *_gameHandler;
+	AutoHandler       *_autoHandler;
+	AutoSpriteHandler *_autoSpriteHandler;
+	TempHandler       *_tmpHandler[2];
+	ExtraHandler      *_extraHandler[120];
 
 	SaveHandler *getHandler(const char *fileName) const;
 	const char *getDescription(const char *fileName) const;
@@ -592,6 +815,40 @@ protected:
 	SaveFile *getSaveFile(const char *fileName);
 };
 
+/** Save/Load class for Playtoons. */
+class SaveLoad_v7: public SaveLoad {
+public:
+	static const uint32 kChildrenCount = 16;
+
+	SaveLoad_v7(GobEngine *vm, const char *targetName);
+	virtual ~SaveLoad_v7();
+
+	SaveMode getSaveMode(const char *fileName) const;
+
+protected:
+	struct SaveFile {
+		const char *sourceName;
+		SaveMode mode;
+		SaveHandler *handler;
+		const char *description;
+	};
+
+	static SaveFile _saveFiles[];
+
+	TempSpriteHandler *_faceHandler[kChildrenCount];
+	FakeFileHandler   *_childrenHandler;
+	FakeFileHandler   *_debilHandler;
+	FakeFileHandler   *_configHandler;
+	FakeFileHandler   *_addy4BaseHandler[2];
+	FakeFileHandler   *_addy4GrundschuleHandler[11];
+
+	SaveHandler *getHandler(const char *fileName) const;
+	const char *getDescription(const char *fileName) const;
+
+	const SaveFile *getSaveFile(const char *fileName) const;
+	SaveFile *getSaveFile(const char *fileName);
+};
+
 } // End of namespace Gob
 
 #endif // GOB_SAVE_SAVELOAD_H
