@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/scenery.cpp $
- * $Id: scenery.cpp 53044 2010-10-07 09:18:40Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -65,7 +65,7 @@ Scenery::Scenery(GobEngine *vm) : _vm(vm) {
 
 	_pCaptureCounter = 0;
 
-	for (int i = 0; i < 70; i++ ) {
+	for (int i = 0; i < 70; i++) {
 		_staticPictToSprite[i] = 0;
 		_animPictToSprite[i]   = 0;
 	}
@@ -196,7 +196,7 @@ int16 Scenery::loadStatic(char search) {
 			_spriteResId[sprIndex] = sprResId;
 			_vm->_draw->initSpriteSurf(sprIndex, width, height, 2);
 
-			_vm->_video->clearSurf(*_vm->_draw->_spritesArray[sprIndex]);
+			_vm->_draw->_spritesArray[sprIndex]->clear();
 			_vm->_draw->_destSurface  = sprIndex;
 			_vm->_draw->_spriteLeft   = sprResId;
 			_vm->_draw->_transparency = 0;
@@ -526,7 +526,7 @@ int16 Scenery::loadAnim(char search) {
 			_spriteResId[sprIndex] = sprResId;
 			_vm->_draw->initSpriteSurf(sprIndex, width, height, 2);
 
-			_vm->_video->clearSurf(*_vm->_draw->_spritesArray[sprIndex]);
+			_vm->_draw->_spritesArray[sprIndex]->clear();
 			_vm->_draw->_destSurface  = sprIndex;
 			_vm->_draw->_spriteLeft   = sprResId;
 			_vm->_draw->_transparency = 0;
@@ -597,7 +597,9 @@ void Scenery::updateAnim(int16 layer, int16 frame, int16 animation, int16 flags,
 	int16 destX;
 	int16 destY;
 
-	if ((_vm->getGameType() == kGameTypeWoodruff) && (animation < 0)) {
+	if ((animation < 0) &&
+	    ((_vm->getGameType() == kGameTypeWoodruff) ||
+	     (_vm->getGameType() == kGameTypeAdibou2))) {
 		// Object video
 
 		if (flags & 1) { // Do capture
@@ -733,11 +735,10 @@ void Scenery::updateAnim(int16 layer, int16 frame, int16 animation, int16 flags,
 				_vm->_draw->_spriteLeft = _vm->_vidPlayer->getWidth(obj.videoSlot - 1)  -
 					(destX + _vm->_draw->_spriteRight);
 
-			_vm->_vidPlayer->copyFrame(obj.videoSlot - 1, _vm->_draw->_backSurface->getVidMem(),
+			_vm->_vidPlayer->copyFrame(obj.videoSlot - 1, *_vm->_draw->_backSurface,
 					_vm->_draw->_spriteLeft,  _vm->_draw->_spriteTop,
 					_vm->_draw->_spriteRight, _vm->_draw->_spriteBottom,
 					_vm->_draw->_destSpriteX, _vm->_draw->_destSpriteY,
-					_vm->_draw->_backSurface->getWidth(),
 					(_vm->_draw->_transparency != 0) ? 0 : -1);
 
 			_vm->_draw->invalidateRect(_vm->_draw->_destSpriteX, _vm->_draw->_destSpriteY,
