@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/adlib.h $
- * $Id: adlib.h 41781 2009-06-22 20:27:47Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,9 +27,9 @@
 #define GOB_SOUND_ADLIB_H
 
 #include "common/mutex.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
-#include "sound/fmopl.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/fmopl.h"
 
 namespace Gob {
 
