@@ -18,13 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/bgatmosphere.cpp $
- * $Id: bgatmosphere.cpp 42751 2009-07-25 12:59:46Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/system.h"
-#include "common/events.h"
 #include "common/EventRecorder.h"
 
 #include "gob/sound/bgatmosphere.h"
@@ -47,7 +45,7 @@ BackgroundAtmosphere::~BackgroundAtmosphere() {
 	queueClear();
 }
 
-void BackgroundAtmosphere::play() {
+void BackgroundAtmosphere::playBA() {
 	Common::StackLock slock(_mutex);
 
 	_queuePos = -1;
@@ -59,7 +57,7 @@ void BackgroundAtmosphere::play() {
 	SoundMixer::play(*_queue[_queuePos], 1, 0);
 }
 
-void BackgroundAtmosphere::stop() {
+void BackgroundAtmosphere::stopBA() {
 	SoundMixer::stop(0);
 }
 
