@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/infogrames.h $
- * $Id: infogrames.h 31937 2008-05-08 00:47:23Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef GOB_SOUND_INFOGRAMES_H
 #define GOB_SOUND_INFOGRAMES_H
 
-#include "sound/mixer.h"
-#include "sound/mods/infogrames.h"
+#include "audio/mixer.h"
+#include "audio/mods/infogrames.h"
 
 namespace Gob {
 
