@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/protracker.cpp $
- * $Id: protracker.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/file.h"
 
-#include "sound/mods/protracker.h"
+#include "audio/mods/protracker.h"
 
 #include "gob/sound/protracker.h"
 
