@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/protracker.h $
- * $Id: protracker.h 41632 2009-06-18 13:27:14Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef GOB_SOUND_PROTRACKER_H
 #define GOB_SOUND_PROTRACKER_H
 
-#include "sound/mixer.h"
-#include "sound/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/audiostream.h"
 
 namespace Gob {
 
