@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/soundblaster.h $
- * $Id: soundblaster.h 41632 2009-06-18 13:27:14Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,7 @@
 #define GOB_SOUND_SOUNDBLASTER_H
 
 #include "common/mutex.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 #include "gob/sound/soundmixer.h"
 
