@@ -18,16 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/sounddesc.cpp $
- * $Id: sounddesc.cpp 47579 2010-01-26 22:48:45Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/util.h"
-#include "common/stream.h"
-#include "sound/mixer.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/wave.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
+
+#include "audio/mixer.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/wave.h"
 
 #include "gob/sound/sounddesc.h"
 #include "gob/resources.h"
@@ -53,6 +55,19 @@ SoundDesc::~SoundDesc() {
 	free();
 }
 
+void SoundDesc::swap(SoundDesc &desc) {
+	SWAP(_repCount  , desc._repCount);
+	SWAP(_frequency , desc._frequency);
+	SWAP(_flag      , desc._flag);
+	SWAP(_id        , desc._id);
+	SWAP(_mixerFlags, desc._mixerFlags);
+	SWAP(_resource  , desc._resource);
+	SWAP(_data      , desc._data);
+	SWAP(_dataPtr   , desc._dataPtr);
+	SWAP(_size      , desc._size);
+	SWAP(_type      , desc._type);
+}
+
 void SoundDesc::set(SoundType type, byte *data, uint32 dSize) {
 	free();
 
