@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/sounddesc.h $
- * $Id: sounddesc.h 41839 2009-06-24 21:49:37Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -46,6 +46,11 @@ public:
 	int16 _id;
 	byte _mixerFlags;
 
+	SoundDesc();
+	~SoundDesc();
+
+	void swap(SoundDesc &desc);
+
 	byte *getData() { return _dataPtr; }
 
 	uint32    size()         const { return _size;     }
@@ -66,9 +71,6 @@ public:
 	int16 calcFadeOutLength(int16 frequency);
 	uint32 calcLength(int16 repCount, int16 frequency, bool fade);
 
-	SoundDesc();
-	~SoundDesc();
-
 private:
 	Resource *_resource;
 	byte *_data;
