@@ -18,15 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/soundmixer.cpp $
- * $Id: soundmixer.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/util.h"
+
 #include "gob/sound/soundmixer.h"
 #include "gob/sound/sounddesc.h"
 
-#include "sound/decoders/raw.h"
+#include "audio/decoders/raw.h"
 
 namespace Gob {
 
