@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/soundmixer.h $
- * $Id: soundmixer.h 42858 2009-07-28 16:28:32Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,8 +28,8 @@
 
 #include "common/mutex.h"
 #include "common/frac.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 namespace Gob {
 
