@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/util.cpp $
- * $Id: util.cpp 52106 2010-08-15 23:37:56Z strangerke $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,10 +31,13 @@
 #include "gob/draw.h"
 #include "gob/game.h"
 #include "gob/video.h"
+#include "gob/videoplayer.h"
 #include "gob/sound/sound.h"
 
 #include "common/events.h"
 
+#include "graphics/palette.h"
+
 namespace Gob {
 
 Util::Util(GobEngine *vm) : _vm(vm) {
@@ -94,6 +97,8 @@ void Util::processInput(bool scroll) {
 	int16 x = 0, y = 0;
 	bool hasMove = false;
 
+	_vm->_vidPlayer->updateLive();
+
 	while (eventMan->pollEvent(event)) {
 		switch (event.type) {
 		case Common::EVENT_MOUSEMOVE:
@@ -121,6 +126,10 @@ void Util::processInput(bool scroll) {
 					_fastMode ^= 2;
 				else if (event.kbd.keycode == Common::KEYCODE_p)
 					_vm->pauseGame();
+				else if (event.kbd.keycode == Common::KEYCODE_d) {
+					_vm->getDebugger()->attach();
+					_vm->getDebugger()->onFrame();
+				}
 				break;
 			}
 			addKeyToBuffer(event.kbd);
@@ -146,7 +155,7 @@ void Util::processInput(bool scroll) {
 		// WORKAROUND:
 		// Force a check of the mouse in order to fix the sofa bug. This apply only for Gob3, and only
 		// in the impacted TOT file so that the second screen animation is not broken.
-		if ((_vm->getGameType() == kGameTypeGob3) && !strncmp(_vm->_game->_curTotFile, "EMAP1008.TOT", 12))
+		if ((_vm->getGameType() == kGameTypeGob3) && _vm->isCurrentTot("EMAP1008.TOT"))
 			_vm->_game->evaluateScroll();
 	}
 }
@@ -311,13 +320,16 @@ void Util::forceMouseUp(bool onlyWhenSynced) {
 
 void Util::clearPalette() {
 	int16 i;
-	byte colors[1024];
+	byte colors[768];
 
 	_vm->validateVideoMode(_vm->_global->_videoMode);
 
 	if (_vm->_global->_setAllPalette) {
-		memset(colors, 0, 1024);
-		g_system->setPalette(colors, 0, 256);
+		if (_vm->getPixelFormat().bytesPerPixel == 1) {
+			memset(colors, 0, sizeof(colors));
+			g_system->getPaletteManager()->setPalette(colors, 0, 256);
+		}
+
 		return;
 	}
 
@@ -508,6 +520,23 @@ void Util::deleteList(List *list) {
 	delete list;
 }
 
+char *Util::setExtension(char *str, const char *ext) {
+	char *dot = strrchr(str, '.');
+	if (dot)
+		*dot = '\0';
+
+	strcat(str, ext);
+	return str;
+}
+
+Common::String Util::setExtension(const Common::String &str, const Common::String &ext) {
+	const char *dot = strrchr(str.c_str(), '.');
+	if (dot)
+		return Common::String(str.c_str(), dot - str.c_str()) + ext;
+
+	return str + ext;
+}
+
 /* NOT IMPLEMENTED */
 void Util::checkJoystick() {
 	_vm->_global->_useJoystick = 0;
