@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/variables.h $
- * $Id: variables.h 47839 2010-02-03 03:25:50Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -148,6 +148,23 @@ private:
 	Variables::Type _type;
 };
 
+class VariableStack {
+public:
+	VariableStack(uint32 size);
+	~VariableStack();
+
+	void pushData(const Variables &vars, uint32 offset, uint32 size);
+	void pushInt(uint32 value);
+
+	void pop(Variables &vars, uint32 offset);
+
+private:
+	byte *_stack;
+
+	uint32 _size;
+	uint32 _position;
+};
+
 } // End of namespace Gob
 
 #endif // GOB_VARIABLES_H
