@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/videoplayer.h $
- * $Id: videoplayer.h 51916 2010-08-08 01:05:46Z drmccoy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,7 +32,7 @@
 #include "common/str.h"
 
 #include "graphics/surface.h"
-#include "graphics/video/coktel_decoder.h"
+#include "video/coktel_decoder.h"
 
 #include "gob/util.h"
 #include "gob/draw.h"
@@ -74,6 +74,8 @@ public:
 
 		uint32 flags; ///< Video flags.
 
+		bool switchColorMode; ///< Switch between paletted / true color modes?
+
 		int32 startFrame; ///< Frame to start playback from.
 		int32 lastFrame;  ///< Frame to stop playback at.
 		int32 endFrame;   ///< Last frame of this playback cycle.
@@ -87,10 +89,14 @@ public:
 		 int16 palEnd;      ///< Palette entry to end at.
 		 int32 palFrame;    ///< Frame to apply the palette command at.
 
+		bool noBlock; ///< Non-blocking "live" video?
+
+		bool loop; ///< Loop the video?
 		bool fade; ///< Fade in?
 
 		bool waitEndFrame; ///< Wait for the frame's time to run out?
 
+		bool hasSound; ///< Does the video have sound?
 		bool canceled; ///< Was the video canceled?
 
 		Properties();
@@ -104,9 +110,22 @@ public:
 	int  openVideo(bool primary, const Common::String &file, Properties &properties);
 	bool closeVideo(int slot = 0);
 
+	void closeLiveSound();
+	void closeAll();
+
+	void pauseVideo(int slot, bool pause);
+	void pauseAll(bool pause);
+
+	void finishVideoSound(int slot);
+	void waitSoundEnd(int slot);
+
 	bool play(int slot, Properties &properties);
 	void waitEndFrame(int slot, bool onlySound = false);
 
+	bool isPlayingLive() const;
+
+	void updateLive(bool force = false);
+
 	bool slotIsOpen(int slot = 0) const;
 
 	Common::String getFileName(int slot = 0) const;
@@ -121,23 +140,27 @@ public:
 	const Common::List<Common::Rect> *getDirtyRects(int slot = 0) const;
 
 	bool                      hasEmbeddedFile(const Common::String &fileName, int slot = 0) const;
-	Common::MemoryReadStream *getEmbeddedFile(const Common::String &fileName, int slot = 0);
+	Common::SeekableReadStream *getEmbeddedFile(const Common::String &fileName, int slot = 0);
 
 	int32 getSubtitleIndex(int slot = 0) const;
 
 	void writeVideoInfo(const Common::String &file, int16 varX, int16 varY,
 			int16 varFrames, int16 varWidth, int16 varHeight);
 
-	bool copyFrame(int slot, byte *dest,
-			uint16 left, uint16 top, uint16 width, uint16 height,
-			uint16 x, uint16 y, uint16 pitch, int16 transp = -1) const;
+	bool copyFrame(int slot, Surface &dest,
+			uint16 left, uint16 top, uint16 width, uint16 height, uint16 x, uint16 y,
+			int32 transp = -1) const;
 
 private:
 	struct Video {
-		Graphics::CoktelDecoder *decoder;
+		::Video::CoktelDecoder *decoder;
 		Common::String fileName;
 
-		SurfaceDescPtr surface;
+		SurfacePtr surface;
+
+		Properties properties;
+
+		bool live;
 
 		Video();
 
@@ -166,7 +189,7 @@ private:
 
 	Common::String findFile(const Common::String &file, Properties &properties);
 
-	Graphics::CoktelDecoder *openVideo(const Common::String &file, Properties &properties);
+	::Video::CoktelDecoder *openVideo(const Common::String &file, Properties &properties);
 
 	bool playFrame(int slot, Properties &properties);
 
@@ -174,6 +197,8 @@ private:
 	void evalBgShading(Video &video);
 
 	void copyPalette(const Video &video, int16 palStart, int16 palEnd);
+
+	void updateLive(int slot, bool force = false);
 };
 
 } // End of namespace Gob
