@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/detection.cpp $
- * $Id: detection.cpp 52633 2010-09-08 09:37:33Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -64,13 +64,41 @@ static const GroovieGameDescription gameDescriptions[] = {
 	{
 		{
 			"t7g", "",
-			AD_ENTRY1s("T7GMac", "a139540fa2be2247005ccf888b7231e3", 1830783),
+			AD_ENTRY1s("T7GMac", "acdc4a58dd3f007f65e99b99d78e0bce", 1814029),
 			Common::EN_ANY, Common::kPlatformMacintosh, ADGF_MACRESFORK,
 			Common::GUIO_MIDIADLIB | Common::GUIO_MIDIMT32 | Common::GUIO_MIDIGM
 		},
 		kGroovieT7G, 0
 	},
 
+#if 0
+	// These entries should now be identical to the first T7G Mac entry after
+	// changing the app to only use the data part of the resource fork. They
+	// are left disabled here as a reference.
+
+	// The 7th Guest Mac English (Aztec single disc)
+	{
+		{
+			"t7g", "",
+			AD_ENTRY1s("T7GMac", "6bdee8d0f9eef6d58d02fcd7deec3fb2", 1830783),
+			Common::EN_ANY, Common::kPlatformMacintosh, ADGF_MACRESFORK,
+			Common::GUIO_MIDIADLIB | Common::GUIO_MIDIMT32 | Common::GUIO_MIDIGM
+		},
+		kGroovieT7G, 0
+	},
+
+	// The 7th Guest Mac English (Aztec bundle, provided by Thefinaleofseem)
+	{
+		{
+			"t7g", "",
+			AD_ENTRY1s("T7GMac", "0d595d4b44ae1814082938d051e5174e", 1830783),
+			Common::EN_ANY, Common::kPlatformMacintosh, ADGF_MACRESFORK,
+			Common::GUIO_MIDIADLIB | Common::GUIO_MIDIMT32 | Common::GUIO_MIDIGM
+		},
+		kGroovieT7G, 0
+	},
+#endif
+
 	// The 7th Guest DOS Russian (Akella)
 	{
 		{
