@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/groovie.cpp $
- * $Id: groovie.cpp 52633 2010-09-08 09:37:33Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -35,11 +35,14 @@
 #include "common/config-manager.h"
 #include "common/debug-channels.h"
 #include "common/events.h"
+#include "common/file.h"
 #include "common/macresman.h"
+#include "common/textconsole.h"
 
+#include "backends/audiocd/audiocd.h"
 #include "engines/util.h"
 #include "graphics/fontman.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Groovie {
 
@@ -217,7 +220,7 @@ Common::Error GroovieEngine::run() {
 	// Initialize the CD
 	int cd_num = ConfMan.getInt("cdrom");
 	if (cd_num >= 0)
-		_system->openCD(cd_num);
+		_system->getAudioCDManager()->openCD(cd_num);
 
 	while (!shouldQuit()) {
 		// Give the debugger a chance to act
@@ -321,6 +324,8 @@ void GroovieEngine::errorString(const char *buf_input, char *buf_output, int buf
 }
 
 void GroovieEngine::syncSoundSettings() {
+	Engine::syncSoundSettings();
+
 	bool mute = ConfMan.getBool("mute");
 
 	// Set the music volume
