@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/player.cpp $
- * $Id: player.cpp 49487 2010-06-07 17:14:42Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/debug.h"
+
 #include "groovie/player.h"
 #include "groovie/groovie.h"
 
