@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/saveload.cpp $
- * $Id: saveload.cpp 48287 2010-03-18 15:54:40Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "groovie/saveload.h"
 
 #include "common/system.h"
+#include "common/substream.h"
 
 #define SUPPORTED_SAVEFILE_VERSION 1
 // 0 - Just script variables, compatible with the original
