@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/saveload.h $
- * $Id: saveload.h 35855 2009-01-13 23:22:47Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "common/savefile.h"
 #include "engines/game.h"
+#include "engines/savestate.h"
 
 namespace Groovie {
 
