@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/vdx.h $
- * $Id: vdx.h 49487 2010-06-07 17:14:42Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,7 +29,7 @@
 #include "groovie/player.h"
 
 namespace Common {
-	class ReadStream;
+class ReadStream;
 }
 
 namespace Groovie {
@@ -73,9 +73,9 @@ private:
 
 	void getStill(Common::ReadStream *in);
 	void getDelta(Common::ReadStream *in);
-	void expandColourMap(byte *out, uint16 colourMap, uint8 colour1, uint8 colour0);
-	void decodeBlockStill(byte *buf, byte *colours, uint16 imageWidth, uint8 mask);
-	void decodeBlockDelta(uint32 offset, byte *colours, uint16 imageWidth);
+	void expandColorMap(byte *out, uint16 colorMap, uint8 color1, uint8 color0);
+	void decodeBlockStill(byte *buf, byte *colors, uint16 imageWidth, uint8 mask);
+	void decodeBlockDelta(uint32 offset, byte *colors, uint16 imageWidth);
 	void chunkSound(Common::ReadStream *in);
 	void setPalette(uint8 *palette);
 	void fadeIn(uint8 *palette);
