@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/animator_hof.cpp $
- * $Id: animator_hof.cpp 47685 2010-01-29 22:43:23Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "kyra/kyra_hof.h"
 #include "kyra/wsamovie.h"
 
-#include "common/endian.h"
+#include "common/system.h"
 
 namespace Kyra {
 
