@@ -18,21 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/animator_lok.cpp $
- * $Id: animator_lok.cpp 49069 2010-05-17 23:29:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-
 #include "kyra/kyra_lok.h"
 #include "kyra/screen.h"
 #include "kyra/animator_lok.h"
 #include "kyra/sprites.h"
 
-#include "common/system.h"
-
 namespace Kyra {
+
 Animator_LoK::Animator_LoK(KyraEngine_LoK *vm, OSystem *system) {
 	_vm = vm;
 	_screen = vm->screen();
