@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/animator_mr.cpp $
- * $Id: animator_mr.cpp 47685 2010-01-29 22:43:23Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,8 @@
 #include "kyra/resource.h"
 #include "kyra/wsamovie.h"
 
+#include "common/system.h"
+
 namespace Kyra {
 
 void KyraEngine_MR::restorePage3() {
@@ -336,7 +338,6 @@ void KyraEngine_MR::setupSceneAnimObject(int animId, uint16 flags, int x, int y,
 
 	if (flags & 8) {
 		_sceneAnimMovie[animId]->open(filename, 1, 0);
-		musicUpdate(0);
 		if (_sceneAnimMovie[animId]->opened()) {
 			anim.wsaFlag = 1;
 			if (x2 == -1)
