@@ -18,23 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/debugger.cpp $
- * $Id: debugger.cpp 52340 2010-08-24 13:41:24Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-
-#include "common/config-manager.h"
-#include "common/system.h"
 #include "kyra/debugger.h"
 #include "kyra/kyra_lok.h"
-#include "kyra/kyra_v2.h"
 #include "kyra/kyra_hof.h"
-#include "kyra/screen.h"
 #include "kyra/timer.h"
 #include "kyra/resource.h"
 #include "kyra/lol.h"
 
+#include "common/system.h"
+
 namespace Kyra {
 
 Debugger::Debugger(KyraEngine_v1 *vm)
@@ -201,14 +198,6 @@ Debugger_LoK::Debugger_LoK(KyraEngine_LoK *vm)
 	DCmd_Register("birthstones",		WRAP_METHOD(Debugger_LoK, cmd_listBirthstones));
 }
 
-void Debugger_LoK::preEnter() {
-	//_vm->midi.pause(1);
-}
-
-void Debugger_LoK::postEnter() {
-	//_vm->midi.pause(0);
-}
-
 bool Debugger_LoK::cmd_enterRoom(int argc, const char **argv) {
 	uint direction = 0;
 	if (argc > 1) {
@@ -331,7 +320,7 @@ bool Debugger_v2::cmd_enterScene(int argc, const char **argv) {
 		return false;
 	}
 
-	DebugPrintf("Syntax: %d <scenenum> <direction>\n", argv[0]);
+	DebugPrintf("Syntax: %s <scenenum> <direction>\n", argv[0]);
 	return true;
 }
 
