@@ -18,18 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/gui.cpp $
- * $Id: gui.cpp 52340 2010-08-24 13:41:24Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "kyra/gui.h"
 
-#include "kyra/screen.h"
 #include "kyra/text.h"
 #include "kyra/wsamovie.h"
 
 #include "common/savefile.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -490,7 +490,7 @@ void MainMenu::updateAnimation() {
 			_nextUpdate = now + _anim.delay * _vm->tickLength();
 
 			_anim.anim->displayFrame(_animIntern.curFrame, 0, 0, 0, 0, 0, 0);
-			_animIntern.curFrame += _animIntern.direction ;
+			_animIntern.curFrame += _animIntern.direction;
 			if (_animIntern.curFrame < _anim.startFrame) {
 				_animIntern.curFrame = _anim.startFrame;
 				_animIntern.direction = 1;
