@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/gui_lok.h $
- * $Id: gui_lok.h 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #define KYRA_GUI_LOK_H
 
 #include "kyra/gui.h"
+#include "kyra/screen_lok.h"
 
 namespace Kyra {
 
@@ -166,6 +167,7 @@ private:
 	uint8 _toplevelMenu;
 	int _savegameOffset;
 	char _savegameName[35];
+	char _savegameNames[5][35];
 	const char *_specialSavegameString;
 
 	Button::Callback _scrollUpFunctor;
