@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/gui_mr.h $
- * $Id: gui_mr.h 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -50,8 +50,6 @@ public:
 
 	void createScreenThumbnail(Graphics::Surface &dst);
 private:
-	void getInput();
-
 	const char *getMenuTitle(const Menu &menu);
 	const char *getMenuItemTitle(const MenuItem &menuItem);
 	const char *getMenuItemLabel(const MenuItem &menuItem);
