@@ -18,18 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/gui_v2.cpp $
- * $Id: gui_v2.cpp 50952 2010-07-16 23:30:29Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "kyra/gui_v2.h"
-#include "kyra/kyra_v2.h"
 #include "kyra/screen_v2.h"
 #include "kyra/text.h"
 #include "kyra/util.h"
 
 #include "common/savefile.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -625,7 +625,7 @@ int GUI_v2::saveMenu(Button *caller) {
 	Graphics::Surface thumb;
 	createScreenThumbnail(thumb);
 	Util::convertDOSToISO(_saveDescription);
-	_vm->saveGameState(_saveSlot, _saveDescription, &thumb);
+	_vm->saveGameStateIntern(_saveSlot, _saveDescription, &thumb);
 	thumb.free();
 
 	_displayMenu = false;
