@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/kyra_lok.h $
- * $Id: kyra_lok.h 51757 2010-08-05 14:41:00Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,6 +30,11 @@
 #include "kyra/script.h"
 #include "kyra/screen_lok.h"
 #include "kyra/gui_lok.h"
+#include "kyra/item.h"
+
+namespace Graphics {
+struct Surface;
+}
 
 namespace Kyra {
 
@@ -46,7 +51,7 @@ struct Character {
 	uint8 height;
 	uint8 facing;
 	uint16 currentAnimFrame;
-	uint8 inventoryItems[10];
+	int8 inventoryItems[10];
 	int16 x1, y1, x2, y2;
 };
 
@@ -62,19 +67,12 @@ struct Room {
 	uint16 eastExit;
 	uint16 southExit;
 	uint16 westExit;
-	uint8 itemsTable[12];
+	int8 itemsTable[12];
 	uint16 itemsXPos[12];
 	uint8 itemsYPos[12];
 	uint8 needInit[12];
 };
 
-struct Item {
-	uint8 unk1;
-	uint8 height;
-	uint8 unk2;
-	uint8 unk3;
-};
-
 struct SeqLoop {
 	const uint8 *ptr;
 	uint16 count;
@@ -218,7 +216,7 @@ public:
 protected:
 	int32 _speechPlayTime;
 
-	Common::Error saveGameState(int slot, const char *saveName, const Graphics::Surface *thumbnail);
+	Common::Error saveGameStateIntern(int slot, const char *saveName, const Graphics::Surface *thumbnail);
 	Common::Error loadGameState(int slot);
 protected:
 	// input
@@ -288,11 +286,11 @@ protected:
 	void placeItemInGenericMapScene(int item, int index);
 
 	// -> mouse item
-	void setHandItem(uint16 item);
+	void setHandItem(Item item);
 	void removeHandItem();
-	void setMouseItem(uint16 item);
+	void setMouseItem(Item item);
 
-	int getItemListIndex(uint16 item);
+	int getItemListIndex(Item item);
 
 	// -> graphics effects
 	void wipeDownMouseItem(int xpos, int ypos);
@@ -402,7 +400,7 @@ protected:
 	bool _menuDirectlyToLoad;
 	uint8 *_itemBkgBackUp[2];
 	uint8 *_shapes[373];
-	int8 _itemInHand;
+	Item _itemInHand;
 	bool _changedScene;
 	int _unkScreenVar1, _unkScreenVar2, _unkScreenVar3;
 	int _beadStateVar;
@@ -453,9 +451,12 @@ protected:
 	uint16 _currentChatPartnerBackupFrame;
 	uint16 _currentCharAnimFrame;
 
+	int _characterFacingZeroCount[8];
+	int _characterFacingFourCount[8];
+
 	int8 *_sceneAnimTable[50];
 
-	Item _itemTable[145];
+	uint8 _itemHtDat[145];
 	int _lastProcessedItem;
 	int _lastProcessedItemHeight;
 
@@ -477,6 +478,7 @@ protected:
 	int8 _charSayUnk2;
 	int8 _charSayUnk3;
 	int8 _currHeadShape;
+	int _currentHeadFrameTableIndex;
 	int8 _disabledTalkAnimObject;
 	int8 _enabledTalkAnimObject;
 	uint8 _currSentenceColor[3];
@@ -504,6 +506,15 @@ protected:
 	Button *_buttonList;
 	GUI_LoK *_gui;
 
+	uint16 _malcolmFrame;
+	uint32 _malcolmTimer1;
+	uint32 _malcolmTimer2;
+
+	uint32 _beadStateTimer1;
+	uint32 _beadStateTimer2;
+	BeadState _beadState1;
+	BeadState _beadState2;
+
 	struct KyragemState {
 		uint16 nextOperation;
 		uint16 rOffset;
