@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/kyra_v1.h $
- * $Id: kyra_v1.h 52579 2010-09-05 22:56:25Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,20 +29,25 @@
 #include "engines/engine.h"
 
 #include "common/array.h"
+#include "common/error.h"
 #include "common/events.h"
 #include "common/random.h"
 #include "common/hashmap.h"
-#include "common/system.h"
 
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 #include "kyra/script.h"
+#include "kyra/item.h"
 
 namespace Common {
 class SeekableReadStream;
 class WriteStream;
 } // End of namespace Common
 
+namespace Graphics {
+struct Surface;
+}
+
 class KyraMetaEngine;
 
 /**
@@ -93,7 +98,7 @@ class KyraMetaEngine;
  * is pretty minor priority though, since the benefit would be mostly nicer code). The biggest
  * task left is the kyra.dat handling, which is currently being revised by LordHoto.
  *
- * Supported games:
+ * Games using this engine:
  * - The Legend of Kyrandia (fully supported, except for Macintosh port, which lacks sound)
  * - (The) Hand of Fate (fully supported)
  * - Malcolm's Revenge (fully supported)
@@ -165,7 +170,6 @@ enum MusicDataID {
 class Screen;
 class Resource;
 class Sound;
-class Movie;
 class TextDisplayer;
 class StaticResource;
 class TimerManager;
@@ -246,7 +250,7 @@ protected:
 		Common::Error err;
 		registerDefaultSettings();
 		err = init();
-		if (err != Common::kNoError)
+		if (err.getCode() != Common::kNoError)
 			return err;
 		return go();
 	}
@@ -339,9 +343,12 @@ protected:
 	// items
 	int _mouseState;
 
-	virtual void setHandItem(uint16 item) = 0;
+	virtual void setHandItem(Item item) = 0;
 	virtual void removeHandItem() = 0;
 
+	void setDelayedCursorUpdate() { _updateHandItemCursor = true; }
+	bool _updateHandItemCursor;
+
 	// game flags
 	uint8 _flagsTable[100]; // TODO: check this value
 
@@ -414,8 +421,8 @@ protected:
 
 	void loadGameStateCheck(int slot);
 	virtual Common::Error loadGameState(int slot) = 0;
-	Common::Error saveGameState(int slot, const char *saveName) { return saveGameState(slot, saveName, 0); }
-	virtual Common::Error saveGameState(int slot, const char *saveName, const Graphics::Surface *thumbnail) = 0;
+	Common::Error saveGameState(int slot, const char *saveName) { return saveGameStateIntern(slot, saveName, 0); }
+	virtual Common::Error saveGameStateIntern(int slot, const char *saveName, const Graphics::Surface *thumbnail) = 0;
 
 	Common::SeekableReadStream *openSaveForReading(const char *filename, SaveHeader &header);
 	Common::WriteStream *openSaveForWriting(const char *filename, const char *saveName, const Graphics::Surface *thumbnail) const;
