@@ -18,16 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/kyra_v2.cpp $
- * $Id: kyra_v2.cpp 51757 2010-08-05 14:41:00Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/config-manager.h"
-
 #include "kyra/kyra_v2.h"
 #include "kyra/screen_v2.h"
-#include "kyra/debugger.h"
+
+#include "common/config-manager.h"
+#include "common/error.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -74,6 +75,9 @@ KyraEngine_v2::KyraEngine_v2(OSystem *system, const GameFlags &flags, const Engi
 
 	_pauseStart = 0;
 
+	_pathfinderFlag = 0;
+	_smoothingPath = false;
+
 	_lang = 0;
 	Common::Language lang = Common::parseLanguage(ConfMan.get("language"));
 	if (lang == _flags.fanLang && _flags.replacedLang != Common::UNK_LANG)
@@ -236,7 +240,7 @@ int KyraEngine_v2::updateCharPos(int *table, int force) {
 		return 0;
 	_mainCharacter.x1 += _charAddXPosTable[_mainCharacter.facing];
 	_mainCharacter.y1 += _charAddYPosTable[_mainCharacter.facing];
-	updateCharAnimFrame(0, table);
+	updateCharAnimFrame(table);
 	_updateCharPosNextUpdate = _system->getMillis() + getCharacterWalkspeed() * _tickLength;
 	return 1;
 }
