@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/kyra_v2.h $
- * $Id: kyra_v2.h 51757 2010-08-05 14:41:00Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,6 +29,7 @@
 #include "kyra/kyra_v1.h"
 #include "kyra/gui.h"
 #include "kyra/wsamovie.h"
+#include "kyra/item.h"
 
 #include "common/list.h"
 #include "common/hashmap.h"
@@ -41,7 +42,7 @@ struct FrameControl {
 };
 
 struct ItemAnimData_v2 {
-	int16 itemIndex;
+	Item itemIndex;
 	uint8 numFrames;
 	const FrameControl *frames;
 };
@@ -69,7 +70,7 @@ public:
 		int animScriptFrameAdd;
 
 		// Item specific
-		int maxItemId;
+		Item maxItemId;
 	};
 
 	KyraEngine_v2(OSystem *system, const GameFlags &flags, const EngineDesc &desc);
@@ -96,9 +97,6 @@ protected:
 	// detection
 	int _lang;
 
-	// MainMenu
-	MainMenu *_menu;
-
 	// Input
 	virtual int inputSceneChange(int x, int y, int unk1, int unk2) = 0;
 
@@ -271,6 +269,7 @@ protected:
 	// pathfinder
 	int _movFacingTable[600];
 	int _pathfinderFlag;
+	bool _smoothingPath;
 
 	int findWay(int curX, int curY, int dstX, int dstY, int *moveTable, int moveTableSize);
 
@@ -286,8 +285,8 @@ protected:
 	int _pathfinderPositionIndexTable[200];
 
 	// items
-	struct Item {
-		uint16 id;
+	struct ItemDefinition {
+		Item id;
 		uint16 sceneId;
 		int16 x;
 		uint8 y;
@@ -295,25 +294,26 @@ protected:
 
 	void initItemList(int size);
 
-	uint16 _hiddenItems[100];
+	Item _hiddenItems[100];
 
-	Item *_itemList;
+	ItemDefinition *_itemList;
 	int _itemListSize;
 
 	int _itemInHand;
+	int _savedMouseState;
 
 	int findFreeItem();
 	int countAllItems();
 
-	int findItem(uint16 sceneId, uint16 id);
-	int findItem(uint16 item);
+	int findItem(uint16 sceneId, Item id);
+	int findItem(Item item);
 
 	void resetItemList();
 	void resetItem(int index);
 
-	virtual void setMouseCursor(uint16 item) = 0;
+	virtual void setMouseCursor(Item item) = 0;
 
-	void setHandItem(uint16 item);
+	void setHandItem(Item item);
 	void removeHandItem();
 
 	// character
@@ -324,7 +324,7 @@ protected:
 		uint8 facing;
 		uint16 animFrame;
 		byte walkspeed;
-		uint16 inventory[20];
+		Item inventory[20];
 		int16 x1, y1;
 		int16 x2, y2;
 		int16 x3, y3;
@@ -341,7 +341,7 @@ protected:
 	uint32 _updateCharPosNextUpdate;
 
 	virtual int getCharacterWalkspeed() const = 0;
-	virtual void updateCharAnimFrame(int num, int *table) = 0;
+	virtual void updateCharAnimFrame(int *table) = 0;
 
 	// chat
 	int _vocHigh;
@@ -360,7 +360,7 @@ protected:
 	virtual void randomSceneChat() = 0;
 
 	// unknown
-	int _unk3, _unk4, _unk5;
+	int _unk4, _unk5;
 	bool _unkSceneScreenFlag1;
 	bool _unkHandleSceneChangeFlag;
 
