@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/resource.cpp $
- * $Id: resource.cpp 52348 2010-08-24 15:48:43Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,11 +27,7 @@
 #include "kyra/resource_intern.h"
 
 #include "common/config-manager.h"
-#include "common/endian.h"
-#include "common/file.h"
 #include "common/fs.h"
-#include "common/func.h"
-#include "common/system.h"
 
 namespace Kyra {
 
