@@ -18,24 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/saveload_hof.cpp $
- * $Id: saveload_hof.cpp 47180 2010-01-08 22:07:35Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/savefile.h"
-#include "common/system.h"
-
-#include "kyra/kyra_v2.h"
+#include "kyra/kyra_hof.h"
 #include "kyra/screen_v2.h"
-#include "kyra/resource.h"
 #include "kyra/sound.h"
 #include "kyra/timer.h"
 
+#include "common/savefile.h"
+#include "common/substream.h"
+#include "common/system.h"
+
 namespace Kyra {
 
-Common::Error KyraEngine_HoF::saveGameState(int slot, const char *saveName, const Graphics::Surface *thumb) {
+Common::Error KyraEngine_HoF::saveGameStateIntern(int slot, const char *saveName, const Graphics::Surface *thumb) {
 	const char *fileName = getSavegameFilename(slot);
 
 	Common::OutSaveFile *out = openSaveForWriting(fileName, saveName, thumb);
@@ -64,7 +63,7 @@ Common::Error KyraEngine_HoF::saveGameState(int slot, const char *saveName, cons
 	for (int i = 0; i < 25; ++i)
 		out->writeSint16BE(_cauldronTable[i]);
 	for (int i = 0; i < 20; ++i)
-		out->writeUint16BE(_hiddenItems[i]);
+		out->writeSint16BE(_hiddenItems[i]);
 	for (int i = 0; i < 19; ++i)
 		out->write(_conversationState[i], 14);
 	out->write(_newSceneDlgState, 32);
@@ -83,7 +82,7 @@ Common::Error KyraEngine_HoF::saveGameState(int slot, const char *saveName, cons
 	out->writeSint16BE(_mainCharacter.y2);
 
 	for (int i = 0; i < 30; ++i) {
-		out->writeUint16BE(_itemList[i].id);
+		out->writeSint16BE(_itemList[i].id);
 		out->writeUint16BE(_itemList[i].sceneId);
 		out->writeSint16BE(_itemList[i].x);
 		out->writeByte(_itemList[i].y);
@@ -183,7 +182,7 @@ Common::Error KyraEngine_HoF::loadGameState(int slot) {
 	for (int i = 0; i < 25; ++i)
 		_cauldronTable[i] = in.readSint16();
 	for (int i = 0; i < 20; ++i)
-		_hiddenItems[i] = in.readUint16();
+		_hiddenItems[i] = in.readSint16();
 
 	if (header.originalSave) {
 		assert(sizeof(_flagsTable) >= 0x41);
@@ -222,7 +221,7 @@ Common::Error KyraEngine_HoF::loadGameState(int slot) {
 	_mainCharacter.y2 = in.readSint16();
 
 	for (int i = 0; i < 30; ++i) {
-		_itemList[i].id = in.readUint16();
+		_itemList[i].id = in.readSint16();
 		_itemList[i].sceneId = in.readUint16();
 		_itemList[i].x = in.readSint16();
 		_itemList[i].y = in.readByte();
@@ -310,7 +309,7 @@ Common::Error KyraEngine_HoF::loadGameState(int slot) {
 	_mainCharacter.facing = 4;
 
 	enterNewScene(_mainCharacter.sceneId, _mainCharacter.facing, 0, 0, 1);
-	setHandItem(_itemInHand);
+	setDelayedCursorUpdate();
 
 	if (_lastMusicCommand >= 0 && !_unkSceneScreenFlag1)
 		snd_playWanderScoreViaMap(_lastMusicCommand, 1);
