@@ -18,22 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/saveload_lok.cpp $
- * $Id: saveload_lok.cpp 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/savefile.h"
-#include "common/system.h"
-
 #include "kyra/kyra_lok.h"
 #include "kyra/animator_lok.h"
-#include "kyra/screen.h"
 #include "kyra/resource.h"
 #include "kyra/sound.h"
 #include "kyra/timer.h"
 
+#include "common/savefile.h"
+
 namespace Kyra {
 
 Common::Error KyraEngine_LoK::loadGameState(int slot) {
@@ -80,7 +77,7 @@ Common::Error KyraEngine_LoK::loadGameState(int slot) {
 	}
 
 	_marbleVaseItem = in->readSint16BE();
-	_itemInHand = in->readByte();
+	_itemInHand = (int8)in->readByte();
 
 	for (int i = 0; i < 4; ++i)
 		_birthstoneGemTable[i] = in->readByte();
@@ -109,7 +106,7 @@ Common::Error KyraEngine_LoK::loadGameState(int slot) {
 
 	for (int i = 0; i < _roomTableSize; ++i) {
 		for (int item = 0; item < 12; ++item) {
-			_roomTable[i].itemsTable[item] = 0xFF;
+			_roomTable[i].itemsTable[item] = kItemNone;
 			_roomTable[i].itemsXPos[item] = 0xFFFF;
 			_roomTable[i].itemsYPos[item] = 0xFF;
 			_roomTable[i].needInit[item] = 0;
@@ -176,7 +173,7 @@ Common::Error KyraEngine_LoK::loadGameState(int slot) {
 		_screen->copyRegion(8, 8, 8, 8, 304, 212, 10, 0);
 	}
 
-	setHandItem(_itemInHand);
+	setDelayedCursorUpdate();
 
 	// Will-O-Wisp uses a different shape size than Brandon's usual
 	// shape, thus we need to setup the correct size depending on
@@ -241,7 +238,7 @@ Common::Error KyraEngine_LoK::loadGameState(int slot) {
 	return Common::kNoError;
 }
 
-Common::Error KyraEngine_LoK::saveGameState(int slot, const char *saveName, const Graphics::Surface *thumb) {
+Common::Error KyraEngine_LoK::saveGameStateIntern(int slot, const char *saveName, const Graphics::Surface *thumb) {
 	const char *fileName = getSavegameFilename(slot);
 
 	if (shouldQuit())
