@@ -18,25 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/scene_lok.cpp $
- * $Id: scene_lok.cpp 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "kyra/kyra_lok.h"
-#include "kyra/seqplayer.h"
-#include "kyra/screen.h"
 #include "kyra/resource.h"
 #include "kyra/sound.h"
 #include "kyra/sprites.h"
-#include "kyra/wsamovie.h"
 #include "kyra/animator_lok.h"
-#include "kyra/text.h"
-#include "kyra/script.h"
 #include "kyra/timer.h"
 
 #include "common/system.h"
-#include "common/savefile.h"
 
 namespace Kyra {
 
@@ -314,38 +308,35 @@ void KyraEngine_LoK::setCharacterPositionHelper(int character, int *facingTable)
 		}
 	}
 
-	static uint8 facingIsZero[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
-	static uint8 facingIsFour[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
-
 	if (facing == 0) {
-		++facingIsZero[character];
+		++_characterFacingZeroCount[character];
 	} else {
 		bool resetTables = false;
 		if (facing != 7) {
 			if (facing - 1 != 0) {
 				if (facing != 4) {
 					if (facing == 3 || facing == 5) {
-						if (facingIsFour[character] > 2)
+						if (_characterFacingFourCount[character] > 2)
 							facing = 4;
 						resetTables = true;
 					}
 				} else {
-					++facingIsFour[character];
+					++_characterFacingFourCount[character];
 				}
 			} else {
-				if (facingIsZero[character] > 2)
+				if (_characterFacingZeroCount[character] > 2)
 					facing = 0;
 				resetTables = true;
 			}
 		} else {
-			if (facingIsZero[character] > 2)
+			if (_characterFacingZeroCount[character] > 2)
 				facing = 0;
 			resetTables = true;
 		}
 
 		if (resetTables) {
-			facingIsZero[character] = 0;
-			facingIsFour[character] = 0;
+			_characterFacingZeroCount[character] = 0;
+			_characterFacingFourCount[character] = 0;
 		}
 	}
 
@@ -824,13 +815,14 @@ void KyraEngine_LoK::initSceneScreen(int brandonAlive) {
 		_emc->run(&_scriptClick);
 
 	setTextFadeTimerCountdown(-1);
+
 	if (_currentCharacter->sceneId == 210) {
-		if (_itemInHand != -1)
+		if (_itemInHand != kItemNone)
 			magicOutMouseItem(2, -1);
 
 		_screen->hideMouse();
 		for (int i = 0; i < 10; ++i) {
-			if (_currentCharacter->inventoryItems[i] != 0xFF)
+			if (_currentCharacter->inventoryItems[i] != kItemNone)
 				magicOutMouseItem(2, i);
 		}
 		_screen->showMouse();
