@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/scene_lol.cpp $
- * $Id: scene_lol.cpp 51704 2010-08-03 16:22:12Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,9 +29,9 @@
 #include "kyra/screen_lol.h"
 #include "kyra/resource.h"
 #include "kyra/timer.h"
-#include "kyra/sound.h"
 
 #include "common/endian.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -1618,7 +1618,7 @@ void LoLEngine::generateBlockDrawingBuffer() {
 	_sceneDrawVarLeft = _dscBlockMap[_currentDirection + 8];
 
 	/*******************************************
-    *             _visibleBlocks map           *
+	*             _visibleBlocks map           *
 	*                                          *
 	*     |     |     |     |     |     |      *
 	*  00 |  01 |  02 |  03 |  04 |  05 |  06  *
