@@ -18,13 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/scene_v1.cpp $
- * $Id: scene_v1.cpp 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "kyra/kyra_v1.h"
-#include "kyra/screen.h"
 
 namespace Kyra {
 
