@@ -18,24 +18,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/screen.cpp $
- * $Id: screen.cpp 52340 2010-08-24 13:41:24Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "kyra/screen.h"
+#include "kyra/kyra_v1.h"
+#include "kyra/resource.h"
 
 #include "common/endian.h"
+#include "common/memstream.h"
 #include "common/system.h"
 
 #include "engines/util.h"
 
 #include "graphics/cursorman.h"
+#include "graphics/palette.h"
 #include "graphics/sjis.h"
 
-#include "kyra/screen.h"
-#include "kyra/kyra_v1.h"
-#include "kyra/resource.h"
-
 namespace Kyra {
 
 Screen::Screen(KyraEngine_v1 *vm, OSystem *system)
@@ -136,16 +137,15 @@ bool Screen::init() {
 	// We setup the PC98 text mode palette at [16, 24], since that will be used
 	// for KANJI characters in Lands of Lore.
 	if (_use16ColorMode && _vm->gameFlags().platform == Common::kPlatformPC98) {
-		uint8 palette[8 * 4];
+		uint8 palette[8 * 3];
 
 		for (int i = 0; i < 8; ++i) {
-			palette[i * 4 + 0] = ((i >> 1) & 1) * 0xFF;
-			palette[i * 4 + 1] = ((i >> 2) & 1) * 0xFF;
-			palette[i * 4 + 2] = ((i >> 0) & 1) * 0xFF;
-			palette[i * 4 + 3] = 0;
-
-			_system->setPalette(palette, 16, 8);
+			palette[i * 3 + 0] = ((i >> 1) & 1) * 0xFF;
+			palette[i * 3 + 1] = ((i >> 2) & 1) * 0xFF;
+			palette[i * 3 + 2] = ((i >> 0) & 1) * 0xFF;
 		}
+
+		_system->getPaletteManager()->setPalette(palette, 16, 8);
 	}
 
 	_curDim = 0;
@@ -179,8 +179,8 @@ bool Screen::enableScreenDebug(bool enable) {
 }
 
 void Screen::setResolution() {
-	byte palette[4*256];
-	_system->grabPalette(palette, 0, 256);
+	byte palette[3*256];
+	_system->getPaletteManager()->grabPalette(palette, 0, 256);
 
 	int width = 320, height = 200;
 	bool defaultTo1xScaler = false;
@@ -202,7 +202,7 @@ void Screen::setResolution() {
 
 	initGraphics(width, height, defaultTo1xScaler);
 
-	_system->setPalette(palette, 0, 256);
+	_system->getPaletteManager()->setPalette(palette, 0, 256);
 }
 
 void Screen::updateScreen() {
@@ -699,18 +699,17 @@ void Screen::getRealPalette(int num, uint8 *dst) {
 }
 
 void Screen::setScreenPalette(const Palette &pal) {
-	uint8 screenPal[256 * 4];
+	uint8 screenPal[256 * 3];
 	_screenPalette->copy(pal);
 
 	for (int i = 0; i < pal.getNumColors(); ++i) {
-		screenPal[4 * i + 0] = (pal[i * 3 + 0] * 0xFF) / 0x3F;
-		screenPal[4 * i + 1] = (pal[i * 3 + 1] * 0xFF) / 0x3F;
-		screenPal[4 * i + 2] = (pal[i * 3 + 2] * 0xFF) / 0x3F;
-		screenPal[4 * i + 3] = 0;
+		screenPal[3 * i + 0] = (pal[i * 3 + 0] * 0xFF) / 0x3F;
+		screenPal[3 * i + 1] = (pal[i * 3 + 1] * 0xFF) / 0x3F;
+		screenPal[3 * i + 2] = (pal[i * 3 + 2] * 0xFF) / 0x3F;
 	}
 
 	_paletteChanged = true;
-	_system->setPalette(screenPal, 0, pal.getNumColors());
+	_system->getPaletteManager()->setPalette(screenPal, 0, pal.getNumColors());
 }
 
 void Screen::enableInterfacePalette(bool e) {
@@ -728,25 +727,24 @@ void Screen::setInterfacePalette(const Palette &pal, uint8 r, uint8 g, uint8 b)
 	if (!_isAmiga)
 		return;
 
-	uint8 screenPal[32 * 4];
+	uint8 screenPal[32 * 3];
 
 	assert(32 <= pal.getNumColors());
 
 	for (int i = 0; i < pal.getNumColors(); ++i) {
 		if (i != 0x10) {
-			screenPal[4 * i + 0] = (pal[i * 3 + 0] * 0xFF) / 0x3F;
-			screenPal[4 * i + 1] = (pal[i * 3 + 1] * 0xFF) / 0x3F;
-			screenPal[4 * i + 2] = (pal[i * 3 + 2] * 0xFF) / 0x3F;
+			screenPal[3 * i + 0] = (pal[i * 3 + 0] * 0xFF) / 0x3F;
+			screenPal[3 * i + 1] = (pal[i * 3 + 1] * 0xFF) / 0x3F;
+			screenPal[3 * i + 2] = (pal[i * 3 + 2] * 0xFF) / 0x3F;
 		} else {
-			screenPal[4 * i + 0] = (r * 0xFF) / 0x3F;
-			screenPal[4 * i + 1] = (g * 0xFF) / 0x3F;
-			screenPal[4 * i + 2] = (b * 0xFF) / 0x3F;
+			screenPal[3 * i + 0] = (r * 0xFF) / 0x3F;
+			screenPal[3 * i + 1] = (g * 0xFF) / 0x3F;
+			screenPal[3 * i + 2] = (b * 0xFF) / 0x3F;
 		}
-		screenPal[4 * i + 3] = 0;
 	}
 
 	_paletteChanged = true;
-	_system->setPalette(screenPal, 32, pal.getNumColors());
+	_system->getPaletteManager()->setPalette(screenPal, 32, pal.getNumColors());
 }
 
 void Screen::copyToPage0(int y, int h, uint8 page, uint8 *seqBuf) {
@@ -787,7 +785,7 @@ void Screen::copyRegion(int x1, int y1, int x2, int y2, int w, int h, int srcPag
 	}
 
 	if (y2 < 0) {
-		if (y2 <= -h )
+		if (y2 <= -h)
 			return;
 		h += y2;
 		y1 -= y2;
@@ -1084,7 +1082,7 @@ void Screen::setTextColor(const uint8 *cmap, int a, int b) {
 
 bool Screen::loadFont(FontId fontId, const char *filename) {
 	if (fontId == FID_SJIS_FNT) {
-		warning("Trying to replace system SJIS font.");
+		warning("Trying to replace system SJIS font");
 		return true;
 	}
 
@@ -2377,7 +2375,7 @@ uint8 *Screen::encodeShape(int x, int y, int w, int h, int flags) {
 	if (flags & 1)
 		shapeSize += 16;
 
-	static uint8 table[274];
+	uint8 table[274];
 	int tableIndex = 0;
 
 	uint8 *newShape = 0;
@@ -2399,7 +2397,7 @@ uint8 *Screen::encodeShape(int x, int y, int w, int h, int flags) {
 	byte *src = srcPtr;
 	if (flags & 1) {
 		dst += 16;
-		memset(table, 0, sizeof(uint8)*274);
+		memset(table, 0, sizeof(table));
 		tableIndex = 1;
 	}
 
@@ -3313,7 +3311,7 @@ SJISFont::SJISFont(Screen *s, Graphics::FontSJIS *font, const uint8 invisColor,
     : _colorMap(0), _font(font), _invisColor(invisColor), _is16Color(is16Color), _screen(s) {
 	assert(_font);
 
-	_font->enableOutline(outlineSize);
+	_font->setDrawingMode(outlineSize ? Graphics::FontSJIS::kOutlineMode : Graphics::FontSJIS::kDefaultMode);
 
 	_sjisWidth = _font->getMaxFontWidth() >> 1;
 	_fontHeight = _font->getFontHeight() >> 1;
@@ -3345,9 +3343,9 @@ void SJISFont::setColorMap(const uint8 *src) {
 
 	if (!_is16Color) {
 		if (_colorMap[0] == _invisColor)
-			_font->enableOutline(false);
+			_font->setDrawingMode(Graphics::FontSJIS::kDefaultMode);
 		else
-			_font->enableOutline(true);
+			_font->setDrawingMode(Graphics::FontSJIS::kOutlineMode);
 	}
 }
 
