@@ -18,15 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/screen_hof.cpp $
- * $Id: screen_hof.cpp 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-
-#include "kyra/kyra_hof.h"
 #include "kyra/screen_hof.h"
+#include "kyra/kyra_hof.h"
 
 namespace Kyra {
 
