@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/screen_lol.cpp $
- * $Id: screen_lol.cpp 51704 2010-08-03 16:22:12Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,10 @@
 
 #include "kyra/screen_lol.h"
 #include "kyra/lol.h"
-#include "kyra/resource.h"
+
+#include "common/system.h"
+
+#include "graphics/palette.h"
 
 namespace Kyra {
 
@@ -637,7 +640,7 @@ void Screen_LoL::copyRegionSpecial(int page1, int w1, int h1, int x1, int y1, in
 				d++;
 			}
 
-			for (int ii = (i & 1) ^ 1; ii < ibw_2; ii += 2 ) {
+			for (int ii = (i & 1) ^ 1; ii < ibw_2; ii += 2) {
 				*d = *s;
 				d += 2;
 				s += 2;
@@ -795,13 +798,12 @@ void Screen_LoL::copyColor(int dstColorIndex, int srcColorIndex) {
 	uint8 *d = _screenPalette->getData() + dstColorIndex * 3;
 	memcpy(d, s, 3);
 
-	uint8 ci[4];
+	uint8 ci[3];
 	ci[0] = (d[0] << 2) | (d[0] & 3);
 	ci[1] = (d[1] << 2) | (d[1] & 3);
 	ci[2] = (d[2] << 2) | (d[2] & 3);
-	ci[3] = 0;
 
-	_system->setPalette(ci, dstColorIndex, 1);
+	_system->getPaletteManager()->setPalette(ci, dstColorIndex, 1);
 }
 
 bool Screen_LoL::fadeColor(int dstColorIndex, int srcColorIndex, uint32 elapsedTicks, uint32 totalTicks) {
