@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/screen_v2.cpp $
- * $Id: screen_v2.cpp 52340 2010-08-24 13:41:24Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -64,9 +64,9 @@ uint8 *Screen_v2::generateOverlay(const Palette &pal, uint8 *buffer, int opColor
 	}
 
 	for (int i = 1; i != 256; ++i) {
-		const byte curR = pal[i * 3 + 0] - ((((pal[i * 3 + 0] - opR) * weight) >> 7) & 0x7F);
-		const byte curG = pal[i * 3 + 1] - ((((pal[i * 3 + 1] - opG) * weight) >> 7) & 0x7F);
-		const byte curB = pal[i * 3 + 2] - ((((pal[i * 3 + 2] - opB) * weight) >> 7) & 0x7F);
+		const byte curR = pal[i * 3 + 0] - (((pal[i * 3 + 0] - opR) * weight) >> 7);
+		const byte curG = pal[i * 3 + 1] - (((pal[i * 3 + 1] - opG) * weight) >> 7);
+		const byte curB = pal[i * 3 + 2] - (((pal[i * 3 + 2] - opB) * weight) >> 7);
 
 		uint16 idxSum = _use16ColorMode ? 0xFFFF : 0x7FFF;
 		byte index = opColor;
@@ -187,16 +187,22 @@ uint8 *Screen_v2::getPtrToShape(uint8 *shpFile, int shape) {
 }
 
 int Screen_v2::getShapeScaledWidth(const uint8 *shpFile, int scale) {
+	if (!shpFile)
+		return 0;
 	int width = READ_LE_UINT16(shpFile+3);
 	return (width * scale) >> 8;
 }
 
 int Screen_v2::getShapeScaledHeight(const uint8 *shpFile, int scale) {
+	if (!shpFile)
+		return 0;
 	int height = shpFile[2];
 	return (height * scale) >> 8;
 }
 
 uint16 Screen_v2::getShapeSize(const uint8 *shp) {
+	if (!shp)
+		return 0;
 	return READ_LE_UINT16(shp+6);
 }
 
