@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/script_tim.h $
- * $Id: script_tim.h 49069 2010-05-17 23:29:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -36,6 +36,7 @@ namespace Kyra {
 
 class WSAMovie_v2;
 class Screen_v2;
+class Movie;
 class LoLEngine;
 
 class TimAnimator {
