@@ -18,19 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sequences_hof.cpp $
- * $Id: sequences_hof.cpp 49069 2010-05-17 23:29:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "kyra/kyra_v1.h"
 #include "kyra/kyra_hof.h"
-#include "kyra/screen.h"
-#include "kyra/wsamovie.h"
-#include "kyra/sound.h"
-#include "kyra/text_hof.h"
 #include "kyra/timer.h"
 #include "kyra/resource.h"
+#include "kyra/sound.h"
 
 #include "common/system.h"
 
@@ -1216,7 +1212,7 @@ int KyraEngine_HoF::seq_finaleFuards(WSAMovie_v2 *wsaObj, int x, int y, int frm)
 	int chatW = 0;
 	int chatFirstFrame = 0;
 	int chatLastFrame = 0;
-	int textCol = 0;
+	//int textCol = 0;
 
 	uint16 voiceIndex = 0;
 
@@ -1257,13 +1253,13 @@ int KyraEngine_HoF::seq_finaleFuards(WSAMovie_v2 *wsaObj, int x, int y, int frm)
 
 		if (_flags.isTalkie) {
 			chatX = 82;
-			textCol = 143;
+			//textCol = 143;
 			chatFirstFrame = 16;
 			chatLastFrame = 21;
 			voiceIndex = 41;
 		} else {
 			chatX = 62;
-			textCol = 137;
+			//textCol = 137;
 			chatFirstFrame = 9;
 			chatLastFrame = 13;
 		}
@@ -1281,7 +1277,7 @@ int KyraEngine_HoF::seq_finaleFuards(WSAMovie_v2 *wsaObj, int x, int y, int frm)
 			if (frm == 16)
 				break;
 			chatX = 64;
-			textCol = 137;
+			//textCol = 137;
 			chatFirstFrame = 9;
 			chatLastFrame = 13;
 			voiceIndex = 42;
@@ -1289,7 +1285,7 @@ int KyraEngine_HoF::seq_finaleFuards(WSAMovie_v2 *wsaObj, int x, int y, int frm)
 			if (frm == 9)
 				break;
 			chatX = 80;
-			textCol = 143;
+			//textCol = 143;
 			chatFirstFrame = 16;
 			chatLastFrame = 21;
 		}
@@ -2002,7 +1998,7 @@ void KyraEngine_HoF::seq_processText() {
 					outputStr[linePos] = *srcStr;
 					srcStr++;
 				}
-                outputStr[linePos] = 0;
+				outputStr[linePos] = 0;
 				if (*srcStr == 0x0d)
 					srcStr++;
 
@@ -2130,7 +2126,7 @@ void KyraEngine_HoF::seq_cmpFadeFrame(const char *cmpFile) {
 		_screen->cmpFadeFrameStep(4, 320, 200, 0, 0, 2, 320, 200, 0, 0, 320, 200, 6);
 		_screen->copyRegion(0, 0, 0, 0, 320, 200, 2, 0);
 		_screen->updateScreen();
-        delayUntil(endtime);
+		delayUntil(endtime);
 	}
 
 	_screen->copyPage(4, 0);
@@ -2455,8 +2451,10 @@ void KyraEngine_HoF::seq_printCreditsString(uint16 strIndex, int x, int y, const
 
 void KyraEngine_HoF::seq_playWsaSyncDialogue(uint16 strIndex, uint16 vocIndex, int textColor, int x, int y, int width, WSAMovie_v2 *wsa, int firstframe, int lastframe, int wsaXpos, int wsaYpos) {
 	int dur = int(strlen(_sequenceStrings[strIndex])) * (_flags.isTalkie ? 7 : 15);
-	int entry = textEnabled() ? seq_setTextEntry(strIndex, x, y, dur, width) : strIndex;
-	_activeText[entry].textcolor = textColor;
+	if (textEnabled()) {
+		int entry = seq_setTextEntry(strIndex, x, y, dur, width);
+		_activeText[entry].textcolor = textColor;
+	}
 	_seqWsaChatTimeout = _system->getMillis() + dur * _tickLength;
 	int curframe = firstframe;
 
