@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sequences_lol.cpp $
- * $Id: sequences_lol.cpp 52627 2010-09-07 18:50:48Z athrxx $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,9 +28,12 @@
 #include "kyra/lol.h"
 #include "kyra/screen_lol.h"
 #include "kyra/resource.h"
+#include "kyra/sound.h"
 
 #include "base/version.h"
 
+#include "common/system.h"
+
 namespace Kyra {
 
 #pragma mark - Intro
@@ -81,6 +84,13 @@ int LoLEngine::processPrologue() {
 		}
 
 		switch (selection) {
+		case -1:
+			// This is sent on RTL for example, if we would not have any
+			// special case for this the default path would call quitGame
+			// and thus make the next game launched from the launcher
+			// quit instantly.
+			break;
+
 		case 0:		// New game
 			processSelection = 0;
 			break;
@@ -1428,7 +1438,7 @@ void LoLEngine::processCredits(char *t, int dimState, int page, int delayTime) {
 				if (monsterAnimFrame >= 8)
 					_screen->drawShape(page, doorShape, doorX, doorY, doorSD, (doorSD == 22) ? 0 : 1);
 
-				_screen->drawShape(page, monsterShape, monsterX, monsterY, 0, 0x104 | ((!isRightMonster | (monsterAnimFrame < 20)) ? 0 : 1), _outroShapeTable, 1, _outroMonsterScaleTableX[monsterAnimFrame], _outroMonsterScaleTableY[monsterAnimFrame]);
+				_screen->drawShape(page, monsterShape, monsterX, monsterY, 0, 0x104 | ((!isRightMonster || monsterAnimFrame < 20) ? 0 : 1), _outroShapeTable, 1, _outroMonsterScaleTableX[monsterAnimFrame], _outroMonsterScaleTableY[monsterAnimFrame]);
 
 				if (monsterAnimFrame < 8)
 					_screen->drawShape(page, doorShape, doorX, doorY, doorSD, (doorSD == 22) ? 0 : 1);
