@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sound.h $
- * $Id: sound.h 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,7 +31,7 @@
 #include "common/scummsys.h"
 #include "common/str.h"
 
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Audio {
 class AudioStream;
@@ -94,7 +94,7 @@ public:
 	 * @param track track number
 	 * @return true if available, false otherwise
 	 */
-	virtual bool hasSoundFile(uint file) { return (fileListEntry(file) != 0); }
+	virtual bool hasSoundFile(uint file) const { return (fileListEntry(file) != 0); }
 
 	/**
 	 * Load a specifc sound file for use of
