@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sound_lok.cpp $
- * $Id: sound_lok.cpp 51708 2010-08-03 18:19:25Z athrxx $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "kyra/sound.h"
 #include "kyra/kyra_lok.h"
+#include "kyra/sound.h"
+
+#include "common/system.h"
 
 namespace Kyra {
 
