@@ -18,24 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sprites.cpp $
- * $Id: sprites.cpp 45572 2009-10-31 18:32:17Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-
-#include "common/endian.h"
-#include "common/stream.h"
-#include "common/util.h"
-#include "common/system.h"
-#include "common/EventRecorder.h"
-
-#include "kyra/screen.h"
-#include "kyra/kyra_lok.h"
 #include "kyra/sprites.h"
 #include "kyra/resource.h"
 #include "kyra/animator_lok.h"
 
+#include "common/system.h"
+#include "common/EventRecorder.h"
+
 namespace Kyra {
 
 Sprites::Sprites(KyraEngine_LoK *vm, OSystem *system) {
@@ -71,7 +65,7 @@ void Sprites::setupSceneAnims() {
 		if (_anims[i].script != 0) {
 			data = _anims[i].script;
 
-			assert( READ_LE_UINT16(data) == 0xFF86 );
+			assert(READ_LE_UINT16(data) == 0xFF86);
 			data += 4;
 
 			_anims[i].disable = READ_LE_UINT16(data) != 0;
@@ -509,7 +503,7 @@ void Sprites::loadDat(const char *filename, SceneExits &exits) {
 }
 
 void Sprites::freeSceneShapes() {
-	for (int i = 0; i < ARRAYSIZE(_sceneShapes); i++ ) {
+	for (int i = 0; i < ARRAYSIZE(_sceneShapes); i++) {
 		delete[] _sceneShapes[i];
 		_sceneShapes[i] = 0;
 	}
