@@ -18,31 +18,30 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/staticres.cpp $
- * $Id: staticres.cpp 51834 2010-08-07 14:38:07Z athrxx $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/endian.h"
-#include "common/md5.h"
-#include "kyra/kyra_v1.h"
+#include "kyra/resource.h"
 #include "kyra/kyra_lok.h"
-#include "kyra/kyra_v2.h"
 #include "kyra/kyra_hof.h"
 #include "kyra/kyra_mr.h"
 #include "kyra/screen.h"
 #include "kyra/screen_lok.h"
 #include "kyra/screen_hof.h"
 #include "kyra/screen_mr.h"
-#include "kyra/resource.h"
 #include "kyra/gui_lok.h"
 #include "kyra/gui_hof.h"
 #include "kyra/gui_mr.h"
 #include "kyra/sound_intern.h"
 
+#include "common/endian.h"
+#include "common/md5.h"
+
 namespace Kyra {
 
-#define RESFILE_VERSION 72
+#define RESFILE_VERSION 73
 
 namespace {
 bool checkKyraDat(Common::SeekableReadStream *file) {
@@ -57,7 +56,7 @@ bool checkKyraDat(Common::SeekableReadStream *file) {
 
 	uint8 digestCalc[16];
 	file->seek(0, SEEK_SET);
-	if (!Common::md5_file(*file, digestCalc, size))
+	if (!Common::computeStreamMD5(*file, digestCalc, size))
 		return false;
 
 	for (int i = 0; i < 16; ++i)
@@ -209,7 +208,7 @@ bool StaticResource::tryKyraDatLoad() {
 		return false;
 
 	// load the ID map for our game
-	const Common::String filenamePattern = Common::String::printf("0%01X%01X%01X000%01X", game, platform, special, lang);
+	const Common::String filenamePattern = Common::String::format("0%01X%01X%01X000%01X", game, platform, special, lang);
 	Common::SeekableReadStream *idMap = _vm->resource()->createReadStream(filenamePattern);
 	if (!idMap)
 		return false;
@@ -328,7 +327,7 @@ bool StaticResource::prefetchId(int id) {
 	ResData data;
 	data.id = id;
 	data.type = dDesc->_value.type;
-	Common::SeekableReadStream *fileStream = _vm->resource()->createReadStream(Common::String::printf("%08X", dDesc->_value.filename));
+	Common::SeekableReadStream *fileStream = _vm->resource()->createReadStream(Common::String::format("%08X", dDesc->_value.filename));
 	if (!fileStream)
 		return false;
 
@@ -878,7 +877,7 @@ void KyraEngine_LoK::loadItems() {
 
 	_shapes[323] = 0;
 
-	for (shape = 1; shape < 6; shape++ )
+	for (shape = 1; shape < 6; shape++)
 		_shapes[323 + shape] = _screen->encodeShape((shape - 1) * 32, 0, 32, 17, 0);
 
 	for (shape = 330; shape <= 334; shape++)
@@ -912,16 +911,7 @@ void KyraEngine_LoK::loadItems() {
 			_shapes[216 + i] = _screen->encodeShape( (i % 20) * 16, i/20 * 16, 16, 16, 0);
 	}
 
-	uint32 size;
-	uint8 *fileData = _res->fileData("_ITEM_HT.DAT", &size);
-	assert(fileData);
-
-	for (int i = 0; i < 107; i++) {
-		_itemTable[i].height = fileData[i];
-		_itemTable[i].unk1 = _itemTable[i].unk2 = 0;
-	}
-
-	delete[] fileData;
+	_res->loadFileToBuf("_ITEM_HT.DAT", &_itemHtDat, sizeof(_itemHtDat));
 }
 
 void KyraEngine_LoK::loadButtonShapes() {
@@ -1866,9 +1856,9 @@ const uint8 KyraEngine_HoF::_cauldronStateTable[] = {
 	3, 3, 3, 3, 3, 3, 3
 };
 
-const int16 KyraEngine_HoF::_flaskTable[] = {
+const Item KyraEngine_HoF::_flaskTable[] = {
 	0x19, 0x14, 0x15, 0x16, 0x17, 0x18, 0x34,
-	0x1B, 0x39, 0x1A, 0x3A, 0x4D, 0x72, -1
+	0x1B, 0x39, 0x1A, 0x3A, 0x4D, 0x72, kItemNone
 };
 
 const uint8 KyraEngine_HoF::_rainbowRoomData[] = {
@@ -1964,10 +1954,10 @@ const uint8 KyraEngine_MR::_inventoryY[] = {
 	0xB2, 0xB2, 0xB2, 0xB2, 0xB2
 };
 
-const uint8 KyraEngine_MR::_trashItemList[] = {
+const Item KyraEngine_MR::_trashItemList[] = {
 	0x1E, 0x1D, 0x1C, 0x1F, 0x0F, 0x05, 0x04, 0x00,
 	0x03, 0x22, 0x0B, 0x20, 0x21, 0x10, 0x11, 0x3A,
-	0x39, 0x40, 0x3E, 0x3D, 0x3C, 0x3F, 0xFF
+	0x39, 0x40, 0x3E, 0x3D, 0x3C, 0x3F, kItemNone
 };
 
 const uint8 KyraEngine_MR::_itemStringPickUp[] = {
