@@ -18,17 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/text_lol.cpp $
- * $Id: text_lol.cpp 52578 2010-09-05 22:56:03Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifdef ENABLE_LOL
 
+#include "kyra/text_lol.h"
 #include "kyra/lol.h"
 #include "kyra/screen_lol.h"
 #include "kyra/timer.h"
-#include "kyra/util.h"
+#include "kyra/sound.h"
+
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -46,7 +49,9 @@ TextDisplayer_LoL::TextDisplayer_LoL(LoLEngine *vm, Screen_LoL *screen) : _vm(vm
 	_currentLine = new char[85];
 	memset(_currentLine, 0, 85);
 
-	for (int i = 0; i < 14; i++){
+	_textDimData = new TextDimData[_screen->screenDimTableCount()];
+
+	for (int i = 0; i < _screen->screenDimTableCount(); i++){
 		const ScreenDim *d = _screen->getScreenDim(i);
 		_textDimData[i].color1 = d->unk8;
 		_textDimData[i].color2 = d->unkA;
@@ -59,6 +64,7 @@ TextDisplayer_LoL::~TextDisplayer_LoL() {
 	delete[] _buffer;
 	delete[] _dialogueBuffer;
 	delete[] _currentLine;
+	delete[] _textDimData;
 }
 
 void TextDisplayer_LoL::setupField(bool mode) {
@@ -185,6 +191,7 @@ void TextDisplayer_LoL::printDialogueText(int dim, char *str, EMCState *script,
 	} else {
 		oldDim = _screen->curDimIndex();
 		_screen->setScreenDim(dim);
+		_lineCount = 0;
 		_textDimData[dim].color1 = isPc98 ? 0x33 : 254;
 		_textDimData[dim].color2 = _screen->_curDim->unkA;
 	}
@@ -197,6 +204,7 @@ void TextDisplayer_LoL::printDialogueText(int dim, char *str, EMCState *script,
 	displayText(_dialogueBuffer);
 
 	_screen->setScreenDim(oldDim);
+	_lineCount = 0;
 	_screen->setCurPage(cp);
 	_screen->setFont(of);
 
@@ -243,6 +251,7 @@ void TextDisplayer_LoL::printMessage(uint16 type, const char *str, ...) {
 	displayText(_buffer);
 
 	_screen->setScreenDim(od);
+	_lineCount = 0;
 
 	if (!(type & 0x8000)) {
 		if (soundEffect[type])
@@ -373,7 +382,6 @@ void TextDisplayer_LoL::displayText(char *str, ...) {
 	_tempString2 = 0;
 
 	_currentLine[0] = 0;
-
 	memset(_ctrl, 0, 3);
 
 	char c = parseCommand();
@@ -591,13 +599,13 @@ void TextDisplayer_LoL::printLine(char *str) {
 			int n2 = 0;
 			int n1 = (w / 4) - 1;
 
-			do {
+			while (n2 < n1 && n2 < s) {
 				c = str[n2];
 				uint8 cu = (uint8) c;
 				if (cu >= 0xE0 || (cu > 0x80 && cu < 0xA0))
 					n2++;
 				n2++;
-			} while (n2 < n1 && n2 < s);
+			}
 			s = n2;
 		}
 	} else {
