@@ -18,19 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/timer_lok.cpp $
- * $Id: timer_lok.cpp 51757 2010-08-05 14:41:00Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "kyra/kyra_v1.h"
 #include "kyra/kyra_lok.h"
-#include "kyra/screen.h"
 #include "kyra/animator_lok.h"
 #include "kyra/timer.h"
 
-#include "common/system.h"
-
 namespace Kyra {
 
 #define TimerV1(x) new Common::Functor1Mem<int, void, KyraEngine_LoK>(this, &KyraEngine_LoK::x)
@@ -75,7 +71,6 @@ void KyraEngine_LoK::setupTimers() {
 }
 
 void KyraEngine_LoK::timerUpdateHeadAnims(int timerNum) {
-	static int8 currentFrame = 0;
 	static const int8 frameTable[] = {
 		4, 5, 4, 5, 4, 5, 0, 1,
 		4, 5, 4, 4, 6, 4, 8, 1,
@@ -85,11 +80,11 @@ void KyraEngine_LoK::timerUpdateHeadAnims(int timerNum) {
 	if (_talkingCharNum < 0)
 		return;
 
-	_currHeadShape = frameTable[currentFrame];
-	currentFrame++;
+	_currHeadShape = frameTable[_currentHeadFrameTableIndex];
+	++_currentHeadFrameTableIndex;
 
-	if (frameTable[currentFrame] == -1)
-		currentFrame = 0;
+	if (frameTable[_currentHeadFrameTableIndex] == -1)
+		_currentHeadFrameTableIndex = 0;
 
 	_animator->animRefreshNPC(0);
 	_animator->animRefreshNPC(_talkingCharNum);
