@@ -18,17 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/timer_lol.cpp $
- * $Id: timer_lol.cpp 46587 2009-12-26 14:12:38Z athrxx $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifdef ENABLE_LOL
 
 #include "kyra/lol.h"
-#include "kyra/screen_lol.h"
 #include "kyra/timer.h"
 
+#include "common/system.h"
+
 namespace Kyra {
 
 #define TimerV2(x) new Common::Functor1Mem<int, void, LoLEngine>(this, &LoLEngine::x)
