@@ -18,23 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/wsamovie.cpp $
- * $Id: wsamovie.cpp 45414 2009-10-26 20:07:37Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
-
-#include "common/endian.h"
-#include "common/system.h"
-
-#include "kyra/kyra_v1.h"
-#include "kyra/kyra_v2.h"
-#include "kyra/screen.h"
-#include "kyra/screen_v2.h"
 #include "kyra/wsamovie.h"
 #include "kyra/resource.h"
 
+#include "common/endian.h"
+
 namespace Kyra {
+
 WSAMovie_v1::WSAMovie_v1(KyraEngine_v1 *vm)
     : Movie(vm), _frameData(0), _frameOffsTable(0), _offscreenBuffer(0), _deltaBuffer(0) {
 }
