@@ -18,12 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/debugger.cpp $
- * $Id: debugger.cpp 50963 2010-07-17 18:38:42Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-
 #include "common/config-manager.h"
 #include "common/endian.h"
 #include "lure/luredefs.h"
@@ -313,7 +312,7 @@ bool Debugger::cmd_hotspot(int argc, const char **argv) {
 			hs->width, hs->height,  hs->widthCopy, hs->heightCopy, hs->yCorrection);
 		DebugPrintf("Talk bubble offset = %d,%d\n", hs->talkX, hs->talkY);
 		DebugPrintf("load offset = %xh, script load = %d\n", hs->loadOffset, hs->scriptLoadFlag);
-		DebugPrintf("Animation Id = %xh, Colour offset = %d\n", hs->animRecordId, hs->colourOffset);
+		DebugPrintf("Animation Id = %xh, Color offset = %d\n", hs->animRecordId, hs->colorOffset);
 		DebugPrintf("Talk Script offset = %xh, Tick Script offset = %xh\n",
 			hs->talkScriptOffset, hs->tickScriptOffset);
 		DebugPrintf("Tick Proc offset = %xh\n", hs->tickProcId);
@@ -323,7 +322,7 @@ bool Debugger::cmd_hotspot(int argc, const char **argv) {
 
 		if (h != NULL) {
 			DebugPrintf("Frame Number = %d of %d\n", h->frameNumber(), h->numFrames());
-			DebugPrintf("Persistant = %s\n", h->persistant() ? "true" : "false");
+			DebugPrintf("Persistent = %s\n", h->persistant() ? "true" : "false");
 		}
 
 	} else if (strcmp(argv[2], "actions") == 0) {
@@ -353,15 +352,13 @@ bool Debugger::cmd_hotspot(int argc, const char **argv) {
 	} else {
 		if (strcmp(argv[2], "schedule") == 0) {
 			// List any current schedule for the character
-			hs->npcSchedule.list(buffer);
-			DebugPrintf("%s", buffer);
+			DebugPrintf("%s", hs->npcSchedule.getDebugInfo().c_str());
 		}
 		if (!h)
 			DebugPrintf("The specified hotspot is not currently active\n");
 		else if (strcmp(argv[2], "paths") == 0) {
 			// List any paths for a charcter
-			h->pathFinder().list(buffer);
-			DebugPrintf("%s", buffer);
+			DebugPrintf("%s", h->pathFinder().getDebugInfo().c_str());
 		}
 		else if (strcmp(argv[2], "pixels") == 0) {
 			// List the pixel data for the hotspot
@@ -546,7 +543,7 @@ bool Debugger::cmd_showAnim(int argc, const char **argv) {
 	hotspot->setSize(width, height);
 
 	Hotspot *player = res.activateHotspot(PLAYER_ID);
-	hotspot->setColourOffset(player->resource()->colourOffset);
+	hotspot->setColorOffset(player->resource()->colorOffset);
 
 	hotspot->setAnimation(animId);
 
