@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/game.cpp $
- * $Id: game.cpp 51101 2010-07-21 20:12:35Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -228,7 +228,8 @@ void Game::execute() {
 					case Common::KEYCODE_KP_MINUS:
 						if (_debugFlag) {
 							if (roomNum == 1) roomNum = 55;
-							while (res.getRoom(--roomNum) == NULL) ;
+							while (res.getRoom(--roomNum) == NULL)
+								;
 							room.setRoomNumber(roomNum);
 						}
 						break;
