@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/hotspots.h $
- * $Id: hotspots.h 52972 2010-10-02 00:10:21Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -158,8 +158,7 @@ public:
 	void clear();
 	void reset(RoomPathsData &src);
 	PathFinderResult process();
-	void list(char *buffer);
-	void list() { list(NULL); }
+	Common::String getDebugInfo() const;
 
 	void pop() { _list.erase(_list.begin()); }
 	WalkingActionEntry &top() { return **_list.begin(); }
@@ -204,7 +203,7 @@ private:
 	Direction _direction;
 	uint8 _layer;
 	uint16 _hotspotScriptOffset;
-	uint8 _colourOffset;
+	uint8 _colorOffset;
 	bool _persistant;
 	HotspotOverrideData *_override;
 	bool _skipFlag;
@@ -325,8 +324,8 @@ public:
 	void setTickProc(uint16 newVal);
 	bool persistant() { return _persistant; }
 	void setPersistant(bool value) { _persistant = value; }
-	uint8 colourOffset() { return _colourOffset; }
-	void setColourOffset(uint8 value) { _colourOffset = value; }
+	uint8 colorOffset() { return _colorOffset; }
+	void setColorOffset(uint8 value) { _colorOffset = value; }
 	void setRoomNumber(uint16 roomNum) {
 		_roomNumber = roomNum;
 		if (_data) _data->roomNumber = roomNum;
