@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/lure.cpp $
- * $Id: lure.cpp 48935 2010-05-04 11:59:22Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -95,6 +95,10 @@ Common::Error LureEngine::init() {
 
 	_gameToLoad = -1;
 	_initialised = true;
+
+	// Setup mixer
+	syncSoundSettings();
+
 	return Common::kNoError;
 }
 
@@ -233,7 +237,8 @@ bool LureEngine::loadGame(uint8 slotNumber) {
 	}
 
 	// Read in and discard the savegame caption
-	while (f->readByte() != 0) ;
+	while (f->readByte() != 0)
+		;
 
 	// Load in the data
 	Resources::getReference().loadFromStream(f);
@@ -263,6 +268,8 @@ GUI::Debugger *LureEngine::getDebugger() {
 }
 
 void LureEngine::syncSoundSettings() {
+	Engine::syncSoundSettings();
+
 	Sound.syncSounds();
 }
 
