@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/luredefs.h $
- * $Id: luredefs.h 48661 2010-04-16 10:00:49Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -111,7 +111,7 @@ enum Action {
 // Basic game dimensions
 #define FULL_SCREEN_WIDTH 320
 #define FULL_SCREEN_HEIGHT 200
-#define GAME_COLOURS 256
+#define GAME_COLORS 256
 #define SCREEN_SIZE (FULL_SCREEN_HEIGHT * FULL_SCREEN_WIDTH)
 
 // Some resources include multiple packed palettes of 64 entries each
@@ -120,7 +120,7 @@ enum Action {
 #define RES_PALETTE_ENTRIES 220
 // Main working palette size
 #define MAIN_PALETTE_SIZE 228
-// Palette colour increment amouns for palette fade in/outs
+// Palette color increment amouns for palette fade in/outs
 #define PALETTE_FADE_INC_SIZE 4
 
 // EGA constants
@@ -189,11 +189,11 @@ enum CursorType {CURSOR_ARROW = 0, CURSOR_DISK = 1, CURSOR_TIME_START = 2,
 #define POPMENU_CHANGE_SENSITIVITY 5
 
 // Dialog related defines
-#define EGA_DIALOG_TEXT_COLOUR 6
-#define EGA_DIALOG_WHITE_COLOUR 2
-#define	VGA_DIALOG_TEXT_COLOUR 0xe2
-#define VGA_DIALOG_WHITE_COLOUR 0xe3
-#define EGA_DIALOG_BG_COLOUR 13
+#define EGA_DIALOG_TEXT_COLOR 6
+#define EGA_DIALOG_WHITE_COLOR 2
+#define	VGA_DIALOG_TEXT_COLOR 0xe2
+#define VGA_DIALOG_WHITE_COLOR 0xe3
+#define EGA_DIALOG_BG_COLOR 13
 #define INFO_DIALOG_X 69
 #define INFO_DIALOG_Y 61
 #define INFO_DIALOG_WIDTH 191
