@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/res_struct.h $
- * $Id: res_struct.h 54668 2010-11-30 09:00:20Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,9 +27,11 @@
 #define LURE_RESSTRUCT_H
 
 #include "lure/luredefs.h"
+#include "common/rect.h"
 #include "common/list.h"
 #include "common/file.h"
 #include "common/ptr.h"
+#include "common/textconsole.h"
 
 namespace Lure {
 
@@ -88,7 +90,7 @@ struct HotspotResource {
 	uint16 walkY;
 	int8 talkX;
 	int8 talkY;
-	uint16 colourOffset;
+	uint16 colorOffset;
 	uint16 animRecordId;
 	uint16 hotspotScriptOffset;
 	uint16 talkScriptOffset;
@@ -468,7 +470,7 @@ private:
 public:
 	CurrentActionStack() { _actions.clear(); }
 
-	bool isEmpty() { return _actions.begin() == _actions.end(); }
+	bool isEmpty() const { return _actions.begin() == _actions.end(); }
 	void clear() { _actions.clear(); }
 	CurrentActionEntry &top() { return **_actions.begin(); }
 	CurrentActionEntry &bottom() { 
@@ -478,9 +480,8 @@ public:
 	}
 	CurrentAction action() { return isEmpty() ? NO_ACTION : top().action(); }
 	void pop() { _actions.erase(_actions.begin()); }
-	int size() { return _actions.size(); }
-	void list(char *buffer);
-	void list() { list(NULL); }
+	int size() const { return _actions.size(); }
+	Common::String getDebugInfo() const;
 
 	void addBack(CurrentAction newAction, uint16 roomNum) {
 		_actions.push_back(ActionsList::value_type(new CurrentActionEntry(newAction, roomNum)));
@@ -539,7 +540,7 @@ public:
 	uint16 walkY;
 	int8 talkX;
 	int8 talkY;
-	uint16 colourOffset;
+	uint16 colorOffset;
 	uint16 animRecordId;
 	uint16 hotspotScriptOffset;
 	uint16 talkScriptOffset;
