@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/animation.cpp $
- * $Id: animation.cpp 51200 2010-07-23 09:49:40Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/assets.h"
 #include "m4/animation.h"
 #include "m4/compression.h"
@@ -426,7 +428,7 @@ void MadsAnimation::update() {
 			// Start displaying the message
 			AnimMessage &me = _messages[idx];
 
-			// The colour index to use is dependant on how many messages are currently on-screen
+			// The color index to use is dependant on how many messages are currently on-screen
 			uint8 colIndex;
 			switch (_messageCtr) {
 			case 1:
