@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/console.cpp $
- * $Id: console.cpp 51235 2010-07-24 05:56:06Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/m4.h"
 #include "m4/console.h"
 #include "m4/dialogs.h"
@@ -61,8 +63,10 @@ static int strToInt(const char *s) {
 		return atoi(s);
 
 	// Hexadecimal string
-	uint tmp;
-	sscanf(s, "%xh", &tmp);
+	uint tmp = 0;
+	int read = sscanf(s, "%xh", &tmp);
+	if (read < 1)
+		error("strToInt failed on string \"%s\"", s);
 	return (int)tmp;
 }
 
@@ -121,7 +125,7 @@ bool Console::cmdPlaySound(int argc, const char **argv) {
 bool Console::cmdPlayDSRSound(int argc, const char **argv) {
 	if (argc != 2 && argc != 3) {
 		DebugPrintf("Usage: %s <sound index> <DSR file>\n", argv[0]);
-		DebugPrintf("The DSR file parameter is optional, and specifies which DSR to load\n", argv[0]);
+		DebugPrintf("The DSR file parameter is optional, and specifies which DSR to load\n");
 	} else {
 		if (argc == 3)
 			_vm->_sound->loadDSRFile(argv[2]);
@@ -319,17 +323,25 @@ bool MadsConsole::cmdMessage(int argc, const char **argv) {
 		DebugPrintf("message 'objnum'\n");
 	} else if (!strcmp(argv[1], "list_quotes")) {
 		// Dump the quotes list
+#if 0
+		// FIXME: The following code is not portable and hence has been disabled.
+		// Try replacing FILE by Common::DumpFile.
 		FILE *destFile = fopen("mads_quotes.txt", "wb");
 		for (uint i = 0; i < _vm->globals()->getQuotesSize(); ++i)
 			fprintf(destFile, "%.3d - %s\n", i, _vm->globals()->getQuote(i));
 		fclose(destFile);
+#endif
 
 	} else if (!strcmp(argv[1], "list_vocab")) {
 		// Dump the vocab list
+#if 0
+		// FIXME: The following code is not portable and hence has been disabled.
+		// Try replacing FILE by Common::DumpFile.
 		FILE *destFile = fopen("mads_vocab.txt", "wb");
 		for (uint i = 1; i <= _vm->globals()->getVocabSize(); ++i)
 			fprintf(destFile, "%.3d/%.3x - %s\n", i, i, _vm->globals()->getVocab(i));
 		fclose(destFile);
+#endif
 
 	} else {
 		int messageIdx = strToInt(argv[1]);
