@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/converse.h $
- * $Id: converse.h 48172 2010-03-07 05:06:58Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -191,7 +191,7 @@ private:
 
 	void loadConversation(const char *convName);
 	void loadConversationMads(const char *convName);
-	void readConvEntryActions(Common::SubReadStream *convS, ConvEntry *curEntry);
+	void readConvEntryActions(Common::ReadStream *convS, ConvEntry *curEntry);
 	void setEntryInfo(int32 offset, EntryType type, int32 nodeIndex, int32 entryIndex);
 };
 
