@@ -18,16 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/graphics.cpp $
- * $Id: graphics.cpp 51239 2010-07-24 08:08:19Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/file.h"
-#include "common/endian.h"
 #include "common/system.h"
 #include "common/util.h"
 #include "common/ptr.h"
+#include "common/textconsole.h"
+
+#include "graphics/palette.h"
 
 #include "m4/globals.h"
 #include "m4/graphics.h"
@@ -213,8 +214,8 @@ void M4Surface::drawSprite(int x, int y, SpriteInfo &info, const Common::Rect &c
 	int scaledHeight = scaleValue(info.height, info.scaleY, errY);
 
 	/*
-	printf("M4Surface::drawSprite() info.width = %d; info.scaleX = %d; info.height = %d; info.scaleY = %d; scaledWidth = %d; scaledHeight = %d\n",
-		info.width, info.scaleX, info.height, info.scaleY, scaledWidth, scaledHeight); fflush(stdout);
+	debugCN(kDebugGraphics, "M4Surface::drawSprite() info.width = %d; info.scaleX = %d; info.height = %d; info.scaleY = %d; scaledWidth = %d; scaledHeight = %d\n",
+		info.width, info.scaleX, info.height, info.scaleY, scaledWidth, scaledHeight);
 	*/
 
 	int clipX = 0, clipY = 0;
@@ -233,7 +234,7 @@ void M4Surface::drawSprite(int x, int y, SpriteInfo &info, const Common::Rect &c
 		scaledHeight = y + scaledHeight;
 	}
 
-	//printf("M4Surface::drawSprite() width = %d; height = %d; scaledWidth = %d; scaledHeight = %d\n", info.width, info.height, scaledWidth, scaledHeight); fflush(stdout);
+	//debugCN(kDebugGraphics, "M4Surface::drawSprite() width = %d; height = %d; scaledWidth = %d; scaledHeight = %d\n", info.width, info.height, scaledWidth, scaledHeight);
 
 	// Check if sprite is inside the screen. If it's not, there's no need to draw it
 	if (scaledWidth + x <= 0 || scaledHeight + y <= 0)	// check left and top (in case x,y are negative)
@@ -300,7 +301,7 @@ void M4Surface::drawSprite(int x, int y, SpriteInfo &info, const Common::Rect &c
 							r = CLIP((info.palette[destPixel].r * pixel) >> 10, 0, 31);
 							g = CLIP((info.palette[destPixel].g * pixel) >> 10, 0, 31);
 							b = CLIP((info.palette[destPixel].b * pixel) >> 10, 0, 31);
-							pixel = info.inverseColourTable[(b << 10) | (g << 5) | r];
+							pixel = info.inverseColorTable[(b << 10) | (g << 5) | r];
 						}
 					}
 
@@ -361,7 +362,7 @@ void M4Surface::fillRect(const Common::Rect &r, uint8 color) {
 }
 
 void M4Surface::copyFrom(M4Surface *src, const Common::Rect &srcBounds, int destX, int destY,
-						 int transparentColour) {
+						 int transparentColor) {
 	// Validation of the rectangle and position
 	if ((destX >= w) || (destY >= h))
 		return;
@@ -390,13 +391,13 @@ void M4Surface::copyFrom(M4Surface *src, const Common::Rect &srcBounds, int dest
 	byte *destPtr = (byte *)pixels + (destY * width()) + destX;
 
 	for (int rowCtr = 0; rowCtr < copyRect.height(); ++rowCtr) {
-		if (transparentColour == -1)
+		if (transparentColor == -1)
 			// No transparency, so copy line over
 			Common::copy(srcPtr, srcPtr + copyRect.width(), destPtr);
 		else {
 			// Copy each byte one at a time checking for the transparency color
 			for (int xCtr = 0; xCtr < copyRect.width(); ++xCtr)
-				if (srcPtr[xCtr] != transparentColour) destPtr[xCtr] = srcPtr[xCtr];
+				if (srcPtr[xCtr] != transparentColor) destPtr[xCtr] = srcPtr[xCtr];
 		}
 
 		srcPtr += src->width();
@@ -411,7 +412,7 @@ void M4Surface::copyFrom(M4Surface *src, const Common::Rect &srcBounds, int dest
  * the specified depth requirement on a secondary surface contain depth information
  */
 void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth, 
-						 M4Surface *depthsSurface, int scale, int transparentColour) {
+						 M4Surface *depthsSurface, int scale, int transparentColor) {
 
 	if (scale == 100) {
 		// Copy the specified area
@@ -443,7 +444,7 @@ void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 		for (int rowCtr = 0; rowCtr < copyRect.height(); ++rowCtr) {
 			// Copy each byte one at a time checking against the depth
 			for (int xCtr = 0; xCtr < copyRect.width(); ++xCtr) {
-				if ((depth <= (depthsPtr[xCtr] & 0x7f)) && (srcPtr[xCtr] != transparentColour))
+				if ((depth <= (depthsPtr[xCtr] & 0x7f)) && (srcPtr[xCtr] != transparentColor))
 					destPtr[xCtr] = srcPtr[xCtr];
 			}
 
@@ -557,7 +558,7 @@ void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 				// Not a display pixel
 				continue;
 
-			if ((*srcP != transparentColour) && (depth <= (*depthP & 0x7f)))
+			if ((*srcP != transparentColor) && (depth <= (*depthP & 0x7f)))
 				*destP = *srcP;
 
 			++destP;
@@ -703,7 +704,7 @@ void M4Surface::madsLoadBackground(int roomNumber, RGBList **palData) {
 		else
 			compressedTileDataSize = tileDataUncomp->readUint32LE() - tileOfs;
 
-		//printf("Tile: %i, compressed size: %i\n", i, compressedTileDataSize);
+		//debugCN(kDebugGraphics, "Tile: %i, compressed size: %i\n", i, compressedTileDataSize);
 
 		newTile->clear();
 
@@ -740,7 +741,7 @@ void M4Surface::madsLoadBackground(int roomNumber, RGBList **palData) {
 
 void M4Surface::rexLoadBackground(Common::SeekableReadStream *source, RGBList **palData) {
 	MadsPack packData(source);
-	Common::MemoryReadStream *sourceUnc = packData.getItemStream(0);
+	Common::SeekableReadStream *sourceUnc = packData.getItemStream(0);
 
 	int sceneWidth = sourceUnc->readUint16LE();
 	int sceneHeight = sourceUnc->readUint16LE();
@@ -787,7 +788,7 @@ void M4Surface::m4LoadBackground(Common::SeekableReadStream *source) {
 	uint8 blackIndex = 0;
 
 	// Debug
-	//printf("loadBackground(): %dx%d picture (%d bytes) - %dx%d tiles of size %dx%d\n",
+	//debugCN(kDebugGraphics, "loadBackground(): %dx%d picture (%d bytes) - %dx%d tiles of size %dx%d\n",
 	//	   widthVal, heightVal, size, tilesX, tilesY, tileWidth, tileHeight);
 
 	// BGR data, which is converted to RGB8
@@ -795,7 +796,11 @@ void M4Surface::m4LoadBackground(Common::SeekableReadStream *source) {
 		palette[i].b = source->readByte() << 2;
 		palette[i].g = source->readByte() << 2;
 		palette[i].r = source->readByte() << 2;
-		palette[i].u = source->readByte() << 2;
+		// FIXME - Removed u field from RGB8 as the OSystem palette is now RGB.
+		//         If this is needed, then the system setPalette() call will need changing to skip this.
+		uint8 u = source->readByte() << 2;
+		if (u != 0)
+			debugC(1, kDebugGraphics, "Unused u field in Palette data non-zero: %d", u);
 
 		if ((blackIndex == 0) && !palette[i].r && !palette[i].g && !palette[i].b)
 			blackIndex = i;
@@ -807,7 +812,7 @@ void M4Surface::m4LoadBackground(Common::SeekableReadStream *source) {
 	// note that the height of the scene in game scenes is smaller than 480, as the bottom part of the
 	// screen is the inventory
 	assert(width() == (int)widthVal);
-	//printf("width(): %d, widthVal: %d, height(): %d, heightVal: %d\n", width(), widthVal, height(), heightVal);
+	//debugCN(kDebugGraphics, "width(): %d, widthVal: %d, height(): %d, heightVal: %d\n", width(), widthVal, height(), heightVal);
 
 	tileBuffer->create(tileWidth, tileHeight, 1);
 
@@ -929,7 +934,7 @@ void M4Surface::translate(RGBList *list, bool isTransparent) {
 	byte *palIndexes = list->palIndexes();
 
 	for (int i = 0; i < width() * height(); ++i, ++p) {
-		if (!isTransparent || (*p != TRANSPARENT_COLOUR_INDEX)) {
+		if (!isTransparent || (*p != TRANSPARENT_COLOR_INDEX)) {
 			if (*p < list->size())
 				*p = palIndexes[*p];
 			else
@@ -1031,18 +1036,17 @@ Palette::Palette(MadsM4Engine *vm) : _vm(vm) {
 }
 
 void Palette::setPalette(const byte *colors, uint start, uint num) {
-	g_system->setPalette(colors, start, num);
+	g_system->getPaletteManager()->setPalette(colors, start, num);
 	reset();
 }
 
 void Palette::setPalette(const RGB8 *colors, uint start, uint num) {
-	g_system->setPalette((const byte *)colors, start, num);
+	g_system->getPaletteManager()->setPalette((const byte *)colors, start, num);
 	reset();
 }
 
 void Palette::grabPalette(byte *colors, uint start, uint num) {
-	g_system->grabPalette(colors, start, num);
-	reset();
+	g_system->getPaletteManager()->grabPalette(colors, start, num);
 }
 
 void Palette::setEntry(uint index, uint8 r, uint8 g, uint8 b) {
@@ -1050,8 +1054,7 @@ void Palette::setEntry(uint index, uint8 r, uint8 g, uint8 b) {
 	c.r = r;
 	c.g = g;
 	c.b = b;
-	c.u = 255;
-	g_system->setPalette((const byte *)&c, index, 1);
+	g_system->getPaletteManager()->setPalette((const byte *)&c, index, 1);
 }
 
 uint8 Palette::palIndexFromRgb(byte r, byte g, byte b, RGB8 *paletteData) {
@@ -1061,7 +1064,7 @@ uint8 Palette::palIndexFromRgb(byte r, byte g, byte b, RGB8 *paletteData) {
 	int Rdiff, Gdiff, Bdiff;
 
 	if (paletteData == NULL) {
-		g_system->grabPalette((byte *)palData, 0, 256);
+		g_system->getPaletteManager()->grabPalette((byte *)palData, 0, 256);
 		paletteData = &palData[0];
 	}
 
@@ -1081,7 +1084,7 @@ uint8 Palette::palIndexFromRgb(byte r, byte g, byte b, RGB8 *paletteData) {
 
 void Palette::reset() {
 	RGB8 palData[256];
-	g_system->grabPalette((byte *)palData, 0, 256);
+	g_system->getPaletteManager()->grabPalette((byte *)palData, 0, 256);
 
 	BLACK = palIndexFromRgb(0, 0, 0, palData);
 	BLUE = palIndexFromRgb(0, 0, 255, palData);
@@ -1261,7 +1264,7 @@ void Palette::addRange(RGBList *list) {
 	RGB8 *data = list->data();
 	byte *palIndexes = list->palIndexes();
 	RGB8 palData[256];
-	g_system->grabPalette((byte *)&palData[0], 0, 256);
+	g_system->getPaletteManager()->grabPalette((byte *)&palData[0], 0, 256);
 	bool paletteChanged = false;
 
 	for (int colIndex = 0; colIndex < list->size(); ++colIndex) {
@@ -1301,7 +1304,7 @@ void Palette::addRange(RGBList *list) {
 	}
 
 	if (paletteChanged) {
-		g_system->setPalette((byte *)&palData[0], 0, 256);
+		g_system->getPaletteManager()->setPalette((byte *)&palData[0], 0, 256);
 		reset();
 	}
 }
