@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/m4_scene.cpp $
- * $Id: m4_scene.cpp 51235 2010-07-24 05:56:06Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "m4/m4_scene.h"
 #include "m4/dialogs.h"
@@ -41,7 +42,7 @@ namespace M4 {
 M4Scene::M4Scene(M4Engine *vm): _sceneResources(), Scene(vm, &_sceneResources) {
 	_vm = vm;
 	_sceneSprites = NULL;
-	_inverseColourTable = NULL;
+	_inverseColorTable = NULL;
 
 	_sceneResources.hotspots = new HotSpotList();
 	_sceneResources.parallax = new HotSpotList();
@@ -61,7 +62,7 @@ void M4Scene::loadSceneSprites(int sceneNumber) {
 	_sceneSprites = new SpriteAsset(_vm, sceneS, sceneS->size(), filename);
 	_vm->res()->toss(filename);
 
-	printf("Scene has %d sprites, each one having %d colors\n", _sceneSprites->getCount(), _sceneSprites->getColorCount());
+	debugCN(kDebugGraphics, "Scene has %d sprites, each one having %d colors\n", _sceneSprites->getCount(), _sceneSprites->getColorCount());
 }
 
 void M4Scene::loadSceneResources(int sceneNumber) {
@@ -110,15 +111,15 @@ void M4Scene::loadSceneResources(int sceneNumber) {
 	}
 }
 
-void M4Scene::loadSceneInverseColourTable(int sceneNumber) {
+void M4Scene::loadSceneInverseColorTable(int sceneNumber) {
 	char filename[kM4MaxFilenameSize];
 	Common::SeekableReadStream *iplS;
 
 	sprintf(filename, "%i.ipl", sceneNumber);
 	iplS = _vm->res()->openFile(filename);
-	delete[] _inverseColourTable;
-	_inverseColourTable = new byte[iplS->size()];
-	iplS->read(_inverseColourTable, iplS->size());
+	delete[] _inverseColorTable;
+	_inverseColorTable = new byte[iplS->size()];
+	iplS->read(_inverseColorTable, iplS->size());
 	_vm->res()->toss(filename);
 }
 
@@ -136,7 +137,7 @@ void M4Scene::loadSceneSpriteCodes(int sceneNumber) {
 //			RGB8* spritePalette = _sceneSpriteCodes->getPalette();
 		//_vm->_palette->setPalette(spritePalette, 0, colorCount);
 
-		printf("Scene has %d sprite codes, each one having %d colors\n", _sceneSpriteCodes->getCount(), colorCount);
+		debugCN(kDebugGraphics, "Scene has %d sprite codes, each one having %d colors\n", _sceneSpriteCodes->getCount(), colorCount);
 
 		// Note that toss() deletes the MemoryReadStream
 		_vm->res()->toss(filename);
@@ -163,7 +164,7 @@ void M4Scene::loadScene(int sceneNumber) {
 	loadSceneCodes(sceneNumber);
 
 	// Load inverse color table file (*.IPL)
-	loadSceneInverseColourTable(sceneNumber);
+	loadSceneInverseColorTable(sceneNumber);
 
 	if (_vm->getGameType() != GType_Burger) {
 		// Load scene sprites file (*.SSB)
@@ -202,7 +203,7 @@ void M4Scene::leaveScene() {
 	_sceneResources.parallax->clear();
 
 	delete _sceneResources.parallax;
-	delete[] _inverseColourTable;
+	delete[] _inverseColorTable;
 
 	Scene::leaveScene();
 }
@@ -252,7 +253,7 @@ void M4Scene::leftClick(int x, int y) {
 			*/
 
 			// Player said.... (for scene scripts)
-			printf("Player said: %s %s\n", currentHotSpot->getVerb(), currentHotSpot->getVocab());
+			debugCN(kDebugGraphics, "Player said: %s %s\n", currentHotSpot->getVerb(), currentHotSpot->getVocab());
 
 			// FIXME: This should be moved somewhere else, and is incomplete
 			if (_m4Vm->scene()->getInterface()->_inventory.getSelectedIndex() == -1) {
@@ -268,7 +269,7 @@ void M4Scene::leftClick(int x, int y) {
 			strcpy(_vm->_player->object, "");
 			_vm->_player->commandReady = true;
 
-			printf("## Player said: %s %s\n", _vm->_player->verb, _vm->_player->noun);
+			debugCN(kDebugGraphics, "## Player said: %s %s\n", _vm->_player->verb, _vm->_player->noun);
 
 		}
 	}
