@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/m4_views.h $
- * $Id: m4_views.h 47733 2010-01-31 00:47:29Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -42,7 +42,7 @@ public:
 	int iconIndex;
 
 	GUIInventoryItem(const char *_name, const char *_verb, M4Surface *_icon, int _iconIndex) {
-		name = _name; _verb = verb; icon = _icon; iconIndex = _iconIndex;
+		name = _name; verb = _verb; icon = _icon; iconIndex = _iconIndex;
 	}
 };
 
