@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/mads_logic.cpp $
- * $Id: mads_logic.cpp 52388 2010-08-25 13:31:14Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/m4.h"
 #include "m4/dialogs.h"
 #include "m4/mads_logic.h"
@@ -182,7 +184,9 @@ void MadsSceneLogic::initialiseDataMap() {
 	MAP_DATA(&_madsVm->_player._playerPos.y);
 	MAP_DATA(&_madsVm->_player._direction);
 	MAP_DATA(&_madsVm->_player._visible);
-	MAP_DATA(&_madsVm->scene()->_animActive);
+	MAP_DATA(&getActiveAnimationBool);
+	MAP_DATA(&getAnimationCurrentFrame);
+
 }
 
 DataMap &MadsSceneLogic::dataMap() {
@@ -658,12 +662,12 @@ void MadsSceneLogic::execute(uint32 subOffset) {
 
 		case OP_NOT:			// logical nots top item on stack
 			param = stack.pop().get();
-			stack.push(ScriptVar((uint32)!param & 0xffff));
+			stack.push(ScriptVar((uint32)(!param) & 0xffff));
 			break;
 
 		case OP_COMP:			// complements top item on stack
 			param = stack.pop().get();
-			stack.push(ScriptVar(~param & 0xffff));
+			stack.push(ScriptVar((~param) & 0xffff));
 			break;
 
 		case OP_NEG:			// negates top item on stack
