@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/mads_menus.cpp $
- * $Id: mads_menus.cpp 51235 2010-07-24 05:56:06Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/mads_menus.h"
 #include "m4/m4.h"
 
@@ -546,7 +548,7 @@ int DragonMainMenuView::getHighlightedItem(int x, int y) {
 		M4Sprite *spr = _menuItem->getFrame(0);
 
 		if ((x >= pt.x - 25) && (y >= pt.y - spr->height()) && (x < (pt.x - 25 + spr->width())) && (y < (pt.y)))  {
-			printf("x = %d, y = %d, index = %d\n", x, y, index);
+			debugCN(kDebugGraphics, "x = %d, y = %d, index = %d\n", x, y, index);
 			return index;
 		}
 	}
@@ -668,8 +670,10 @@ void RexDialogView::loadBackground() {
 		break;
 	case 8:
 		screenId = 924;
+		break;
 	case 9:
 		screenId = 920;
+		break;
 	default:
 		error("Unknown scene number");
 	}
@@ -693,11 +697,11 @@ void RexDialogView::updateState() {
 void RexDialogView::onRefresh(RectList *rects, M4Surface *destSurface) {
 	// Draw the framed base area
 	fillRect(this->bounds(), _madsVm->_palette->BLACK);
-	setColour(2);
+	setColor(2);
 	hLine(0, width(), MADS_Y_OFFSET - 2);
 	hLine(0, width(), MADS_Y_OFFSET + MADS_SURFACE_HEIGHT + 2);
 
-	// Add in the loaded background vertically centred
+	// Add in the loaded background vertically centered
 	_backgroundSurface->copyTo(this, 0, (height() - MADS_SURFACE_HEIGHT) / 2);
 
 	// Check whether any of the dialog text entries need to be refreshed
@@ -941,20 +945,20 @@ void RexDialogView::refreshText() {
 		if (!_dialogText[i].in_use)
 			continue;
 
-		// Get the item's colours
-		uint colour;
+		// Get the item's colors
+		uint color;
 		if (_dialogText[i].state == STATE_DESELECTED)
-			colour = 0xB0A;
+			color = 0xB0A;
 		else if (_dialogText[i].state == STATE_SELECTED)
-			colour = 0xD0C;
+			color = 0xD0C;
 		else
-			colour = 0xF0E;
+			color = 0xF0E;
 
-		// If there's an associated text display entry, check to see if it's colour needs to change
+		// If there's an associated text display entry, check to see if it's color needs to change
 		if (_dialogText[i].textDisplay_index >= 0) {
 			MadsTextDisplayEntry &tdEntry = _textDisplay[_dialogText[i].textDisplay_index];
 
-			if ((tdEntry.colour1 == (colour & 0xff)) && (tdEntry.colour2 == (colour >> 8)))
+			if ((tdEntry.color1 == (color & 0xff)) && (tdEntry.color2 == (color >> 8)))
 				// It's still the same, so no further action needed
 				continue;
 
@@ -965,7 +969,7 @@ void RexDialogView::refreshText() {
 
 		// Create a new text display entry for the dialog text line
 		_dialogText[i].textDisplay_index = _textDisplay.add(_dialogText[i].pos.x, _dialogText[i].pos.y,
-			colour, _dialogText[i].widthAdjust, _dialogText[i].text, _dialogText[i].font);
+			color, _dialogText[i].widthAdjust, _dialogText[i].text, _dialogText[i].font);
 	}
 }
 
