@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/mads_scene.h $
- * $Id: mads_scene.h 52365 2010-08-25 06:55:11Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -108,7 +108,6 @@ public:
 	Common::Point _destPos;
 	int _destFacing;
 	Common::Point _customDest;
-	bool _animActive;
 public:
 	MadsScene(MadsEngine *vm);
 	virtual ~MadsScene();
@@ -192,6 +191,9 @@ public:
 	bool onEvent(M4EventType eventType, int32 param1, int x, int y, bool &captureEvents);
 };
 
+extern int getActiveAnimationBool();
+extern int getAnimationCurrentFrame();
+
 } // End of namespace M4
 
 #endif
