@@ -18,13 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/woodscript.cpp $
- * $Id: woodscript.cpp 47705 2010-01-30 09:21:07Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "m4/woodscript.h"
 
+#include "common/memstream.h"
+#include "graphics/palette.h"
+
 namespace M4 {
 
 // FIXME: Put in Engine/WoodScript class
@@ -46,7 +49,7 @@ Bytecode::~Bytecode() {
 
 int Bytecode::loadInstruction(Instruction &instruction) {
 
-	//printf("Bytecode::loadInstruction() ip = %08X\n", _code->pos());
+	//debugCN(kDebugScript, "Bytecode::loadInstruction() ip = %08X\n", _code->pos());
 
 	int32 format, data;
 	uint32 code, code2;
@@ -90,7 +93,7 @@ int Bytecode::loadInstruction(Instruction &instruction) {
 
 void Bytecode::jumpAbsolute(int32 ofs) {
 	_code->seek(ofs * 4);
-	//printf("Bytecode::jumpAbsolute() ofs = %08X\n", _code->pos());
+	//debugCN(kDebugScript, "Bytecode::jumpAbsolute() ofs = %08X\n", _code->pos());
 }
 
 void Bytecode::jumpRelative(int32 ofs) {
@@ -162,7 +165,7 @@ WoodScript::WoodScript(MadsM4Engine *vm) {
 
 	_backgroundSurface = NULL;
 
-	Common::Rect viewBounds = Common::Rect(0, 0, 640, 480);
+	//Common::Rect viewBounds = Common::Rect(0, 0, 640, 480);
 	//_surfaceView = new View(viewBounds);
 }
 
@@ -200,7 +203,7 @@ void WoodScript::runTimerSequenceRequests() {
 Machine *WoodScript::createMachine(int32 machineHash, Sequence *parentSeq,
 	int32 dataHash, int32 dataRowIndex, int callbackHandler, const char *machineName) {
 
-	//printf("WoodScript::createMachine(%d)\n", machineHash); fflush(stdout);
+	//debugCN(kDebugScript, "WoodScript::createMachine(%d)\n", machineHash);
 
 	Machine *machine = new Machine(this, machineHash, parentSeq, dataHash, dataRowIndex, callbackHandler, machineName, _machineId);
 	_machineId++;
@@ -228,7 +231,7 @@ Machine *WoodScript::playSeries(const char *seriesName, long layer, uint32 flags
 	int32 frameRate, int32 loopCount, int32 s, int32 x, int32 y,
 	int32 firstFrame, int32 lastFrame) {
 
-	//printf("WoodScript::playSeries(%s)\n", seriesName);
+	//debugCN(kDebugScript, "WoodScript::playSeries(%s)\n", seriesName);
 
 	RGB8 *palette = NULL;
 	if (flags & SERIES_LOAD_PALETTE)
@@ -282,7 +285,7 @@ Machine *WoodScript::showSeries(const char *seriesName, long layer, uint32 flags
 }
 
 Machine *WoodScript::streamSeries(const char *seriesName, int32 frameRate, long layer, int32 triggerNum) {
-	//printf("WoodScript::streamSeries(%s)\n", seriesName);
+	//debugCN(kDebugScript, "WoodScript::streamSeries(%s)\n", seriesName);
 	_globals[kGlobTemp1] = frameRate << 16;
 	/* FIXME: Single frames from a stream series will be decompressed on-the-fly, contrary to
 			  "normal" sprite series, to save some memory, and since no random access to single
@@ -319,12 +322,12 @@ void WoodScript::update() {
 
 	{
 		// FIXME: This should be done when a new palette is set
-		byte palette[1024];
-		g_system->grabPalette(palette, 0, 256);
+		byte palette[768];
+		g_system->getPaletteManager()->grabPalette(palette, 0, 256);
 		for (int i = 0; i < 256; i++) {
-			_mainPalette[i].r = palette[i * 4 + 0];
-			_mainPalette[i].g = palette[i * 4 + 1];
-			_mainPalette[i].b = palette[i * 4 + 2];
+			_mainPalette[i].r = palette[i * 3 + 0];
+			_mainPalette[i].g = palette[i * 3 + 1];
+			_mainPalette[i].b = palette[i * 3 + 2];
 		}
 	}
 
