@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/woodscript.h $
- * $Id: woodscript.h 48256 2010-03-14 05:39:47Z dreammaster $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -77,7 +77,7 @@ public:
 	uint32 pos() const { return _code->pos() / 4; }
 protected:
 	WoodScript *_ws;
-	Common::MemoryReadStream *_code;
+	Common::SeekableReadStream *_code;
 	Sequence *_sequence;
 	static int32 _dataFormats[];
 	bool decodeArgument(int32 format, int32 data, long *&arg, long &value);
@@ -319,8 +319,8 @@ public:
 
 	RGB8 *getMainPalette() const;
 
-	void setInverseColourTable(byte *inverseColourTable) { _inverseColourTable = inverseColourTable; }
-	byte *getInverseColourTable() const { return _inverseColourTable; }
+	void setInverseColorTable(byte *inverseColorTable) { _inverseColorTable = inverseColorTable; }
+	byte *getInverseColorTable() const { return _inverseColorTable; }
 
 protected:
 	MadsM4Engine *_vm;
@@ -338,7 +338,7 @@ protected:
 
 	/* Misc */
 	int16 *_depthTable;
-	byte *_inverseColourTable;
+	byte *_inverseColorTable;
 	M4Surface *_backgroundSurface;
 	View *_surfaceView;
 
