@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/redreader.h $
- * $Id: redreader.h 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,8 +34,8 @@ namespace Made {
 
 class RedReader {
 public:
-	Common::MemoryReadStream *load(const char *redFilename, const char *filename);
-	static Common::MemoryReadStream *loadFromRed(const char *redFilename, const char *filename);
+	Common::SeekableReadStream *load(const char *redFilename, const char *filename);
+	static Common::SeekableReadStream *loadFromRed(const char *redFilename, const char *filename);
 private:
 	struct FileEntry {
 		uint32 compSize, origSize;
