@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/resource.cpp $
- * $Id: resource.cpp 50950 2010-07-16 23:10:41Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/debug.h"
 #include "common/endian.h"
-#include "sound/mixer.h"
-#include "sound/decoders/raw.h"
+#include "common/memstream.h"
+#include "audio/mixer.h"
+#include "audio/decoders/raw.h"
 
 #include "made/resource.h"
 #include "made/graphics.h"
@@ -56,7 +58,7 @@ PictureResource::~PictureResource() {
 }
 
 void PictureResource::load(byte *source, int size) {
-	if (READ_BE_UINT32(source) == MKID_BE('Flex')) {
+	if (READ_BE_UINT32(source) == MKTAG('F','l','e','x')) {
 		loadChunked(source, size);
 	} else {
 		loadRaw(source, size);
@@ -125,13 +127,13 @@ void PictureResource::loadChunked(byte *source, int size) {
 
 		debug(0, "chunkType = %08X; chunkSize = %d", chunkType, chunkSize);
 
-		if (chunkType == MKID_BE('Rect')) {
+		if (chunkType == MKTAG('R','e','c','t')) {
 			debug(0, "Rect");
 			sourceS->skip(4);
 			height = sourceS->readUint16BE();
 			width = sourceS->readUint16BE();
 			debug(0, "width = %d; height = %d", width, height);
-		} else if (chunkType == MKID_BE('fMap')) {
+		} else if (chunkType == MKTAG('f','M','a','p')) {
 			debug(0, "fMap");
 			lineSize = sourceS->readUint16BE();
 			sourceS->skip(11);
@@ -139,21 +141,21 @@ void PictureResource::loadChunked(byte *source, int size) {
 			cmdOffs = sourceS->pos();
 			sourceS->skip(chunkSize - 14);
 			debug(0, "lineSize = %d; cmdFlags = %d; cmdOffs = %04X", lineSize, cmdFlags, cmdOffs);
-		} else if (chunkType == MKID_BE('fLCo')) {
+		} else if (chunkType == MKTAG('f','L','C','o')) {
 			debug(0, "fLCo");
 			sourceS->skip(9);
 			pixelFlags = sourceS->readByte();
 			pixelOffs = sourceS->pos();
 			sourceS->skip(chunkSize - 10);
 			debug(0, "pixelFlags = %d; pixelOffs = %04X", pixelFlags, pixelOffs);
-		} else if (chunkType == MKID_BE('fPix')) {
+		} else if (chunkType == MKTAG('f','P','i','x')) {
 			debug(0, "fPix");
 			sourceS->skip(9);
 			maskFlags = sourceS->readByte();
 			maskOffs = sourceS->pos();
 			sourceS->skip(chunkSize - 10);
 			debug(0, "maskFlags = %d; maskOffs = %04X", maskFlags, maskOffs);
-		} else if (chunkType == MKID_BE('fGCo')) {
+		} else if (chunkType == MKTAG('f','G','C','o')) {
 			debug(0, "fGCo");
 			_hasPalette = true;
 			_paletteColorCount = chunkSize / 3;
@@ -295,7 +297,6 @@ void MenuResource::load(byte *source, int size) {
 		_strings.push_back(string);
 		debug(2, "%02d: %s\n", i, string);
 	}
-	fflush(stdout);
 	delete sourceS;
 }
 
