@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/resource.h $
- * $Id: resource.h 44589 2009-10-04 09:31:37Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,8 +30,9 @@
 #include "common/file.h"
 #include "common/stream.h"
 #include "common/hashmap.h"
+#include "common/textconsole.h"
 #include "graphics/surface.h"
-#include "sound/audiostream.h"
+#include "audio/audiostream.h"
 
 #include "made/sound.h"
 
@@ -49,16 +50,16 @@ const int kMaxResourceCacheSize = 400 * 1024;
 
 
 enum ResourceType {
-	kResARCH = MKID_BE('ARCH'),
-	kResFREE = MKID_BE('FREE'),
-	kResOMNI = MKID_BE('OMNI'),
-	kResFLEX = MKID_BE('FLEX'),
-	kResSNDS = MKID_BE('SNDS'),
-	kResANIM = MKID_BE('ANIM'),
-	kResMENU = MKID_BE('MENU'),
-	kResFONT = MKID_BE('FONT'),
-	kResXMID = MKID_BE('XMID'),
-	kResMIDI = MKID_BE('MIDI')
+	kResARCH = MKTAG('A','R','C','H'),
+	kResFREE = MKTAG('F','R','E','E'),
+	kResOMNI = MKTAG('O','M','N','I'),
+	kResFLEX = MKTAG('F','L','E','X'),
+	kResSNDS = MKTAG('S','N','D','S'),
+	kResANIM = MKTAG('A','N','I','M'),
+	kResMENU = MKTAG('M','E','N','U'),
+	kResFONT = MKTAG('F','O','N','T'),
+	kResXMID = MKTAG('X','M','I','D'),
+	kResMIDI = MKTAG('M','I','D','I')
 };
 
 struct ResourceSlot;
