@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/screen.h $
- * $Id: screen.h 46245 2009-12-03 19:18:47Z john_doe $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -200,7 +200,6 @@ protected:
 	bool _screenLock;
 	bool _paletteLock;
 
-	byte *_screenPalette;
 	byte *_palette, *_newPalette;
 	int _paletteColorCount, _oldPaletteColorCount;
 	bool _paletteInitialized, _needPalette;
