@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/metaengine.h $
- * $Id: metaengine.h 48359 2010-03-22 20:28:08Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef ENGINES_METAENGINE_H
@@ -37,8 +37,8 @@ class Engine;
 class OSystem;
 
 namespace Common {
-	class FSList;
-	class String;
+class FSList;
+class String;
 }
 
 /**
@@ -231,6 +231,7 @@ private:
 	friend class Common::Singleton<SingletonBaseType>;
 
 public:
+	GameDescriptor findGameInLoadedPlugins(const Common::String &gameName, const EnginePlugin **plugin = NULL) const;
 	GameDescriptor findGame(const Common::String &gameName, const EnginePlugin **plugin = NULL) const;
 	GameList detectGames(const Common::FSList &fslist) const;
 	const EnginePlugin::List &getPlugins() const;
