@@ -18,23 +18,39 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/console.cpp $
- * $Id: console.cpp 52631 2010-09-07 20:18:30Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "mohawk/console.h"
-#include "mohawk/myst.h"
-#include "mohawk/myst_scripts.h"
 #include "mohawk/graphics.h"
-#include "mohawk/riven.h"
-#include "mohawk/riven_external.h"
 #include "mohawk/livingbooks.h"
 #include "mohawk/sound.h"
 #include "mohawk/video.h"
 
+#include "common/system.h"
+#include "common/textconsole.h"
+
+#ifdef ENABLE_CSTIME
+#include "mohawk/cstime.h"
+#endif
+
+#ifdef ENABLE_MYST
+#include "mohawk/myst.h"
+#include "mohawk/myst_areas.h"
+#include "mohawk/myst_scripts.h"
+#endif
+
+#ifdef ENABLE_RIVEN
+#include "mohawk/riven.h"
+#include "mohawk/riven_external.h"
+#endif
+
 namespace Mohawk {
 
+#ifdef ENABLE_MYST
+
 MystConsole::MystConsole(MohawkEngine_Myst *vm) : GUI::Debugger(), _vm(vm) {
 	DCmd_Register("changeCard",			WRAP_METHOD(MystConsole, Cmd_ChangeCard));
 	DCmd_Register("curCard",			WRAP_METHOD(MystConsole, Cmd_CurCard));
@@ -49,19 +65,12 @@ MystConsole::MystConsole(MohawkEngine_Myst *vm) : GUI::Debugger(), _vm(vm) {
 	DCmd_Register("playMovie",			WRAP_METHOD(MystConsole, Cmd_PlayMovie));
 	DCmd_Register("disableInitOpcodes",	WRAP_METHOD(MystConsole, Cmd_DisableInitOpcodes));
 	DCmd_Register("cache",				WRAP_METHOD(MystConsole, Cmd_Cache));
+	DCmd_Register("resources",			WRAP_METHOD(MystConsole, Cmd_Resources));
 }
 
 MystConsole::~MystConsole() {
 }
 
-void MystConsole::preEnter() {
-	_vm->_sound->pauseSound();
-}
-
-void MystConsole::postEnter() {
-	_vm->_sound->resumeSound();
-}
-
 bool MystConsole::Cmd_ChangeCard(int argc, const char **argv) {
 	if (argc < 2) {
 		DebugPrintf("Usage: changeCard <card>\n");
@@ -69,7 +78,7 @@ bool MystConsole::Cmd_ChangeCard(int argc, const char **argv) {
 	}
 
 	_vm->_sound->stopSound();
-	_vm->changeToCard((uint16)atoi(argv[1]));
+	_vm->changeToCard((uint16)atoi(argv[1]), true);
 
 	return false;
 }
@@ -86,9 +95,9 @@ bool MystConsole::Cmd_Var(int argc, const char **argv) {
 	}
 
 	if (argc > 2)
-		_vm->_varStore->setVar((uint16)atoi(argv[1]), (uint32)atoi(argv[2]));
+		_vm->_scriptParser->setVarValue((uint16)atoi(argv[1]), (uint16)atoi(argv[2]));
 
-	DebugPrintf("%d = %d\n", (uint16)atoi(argv[1]), _vm->_varStore->getVar((uint16)atoi(argv[1])));
+	DebugPrintf("%d = %d\n", (uint16)atoi(argv[1]), _vm->_scriptParser->getVar((uint16)atoi(argv[1])));
 
 	return true;
 }
@@ -158,12 +167,13 @@ bool MystConsole::Cmd_ChangeStack(int argc, const char **argv) {
 	// as the next card could continue playing it if it.
 	_vm->_sound->stopSound();
 
-	_vm->changeToStack(stackNum - 1);
-
+	uint16 card = 0;
 	if (argc == 3)
-		_vm->changeToCard((uint16)atoi(argv[2]));
+		card = (uint16)atoi(argv[2]);
 	else
-		_vm->changeToCard(default_start_card[stackNum - 1]);
+		card = default_start_card[stackNum - 1];
+
+	_vm->changeToStack(stackNum - 1, card, 0, 0);
 
 	return false;
 }
@@ -182,16 +192,25 @@ bool MystConsole::Cmd_DrawImage(int argc, const char **argv) {
 		rect = Common::Rect((uint16)atoi(argv[2]), (uint16)atoi(argv[3]), (uint16)atoi(argv[4]), (uint16)atoi(argv[5]));
 
 	_vm->_gfx->copyImageToScreen((uint16)atoi(argv[1]), rect);
+	_vm->_system->updateScreen();
 	return false;
 }
 
 bool MystConsole::Cmd_DrawRect(int argc, const char **argv) {
-	if (argc < 5) {
+	if (argc != 5 && argc != 2) {
 		DebugPrintf("Usage: drawRect <left> <top> <right> <bottom>\n");
+		DebugPrintf("Usage: drawRect <resource id>\n");
 		return true;
 	}
 
-	_vm->_gfx->drawRect(Common::Rect((uint16)atoi(argv[1]), (uint16)atoi(argv[2]), (uint16)atoi(argv[3]), (uint16)atoi(argv[4])), true);
+	if (argc == 5) {
+		_vm->_gfx->drawRect(Common::Rect((uint16)atoi(argv[1]), (uint16)atoi(argv[2]), (uint16)atoi(argv[3]), (uint16)atoi(argv[4])), kRectEnabled);
+	} else if (argc == 2) {
+		uint16 resourceId = (uint16)atoi(argv[1]);
+		if (resourceId < _vm->_resources.size())
+			_vm->_resources[resourceId]->drawBoundingRect();
+	}
+
 	return false;
 }
 
@@ -212,8 +231,7 @@ bool MystConsole::Cmd_PlaySound(int argc, const char **argv) {
 		return true;
 	}
 
-	_vm->_sound->stopSound();
-	_vm->_sound->playSound((uint16)atoi(argv[1]));
+	_vm->_sound->replaceSoundMyst((uint16)atoi(argv[1]));
 
 	return false;
 }
@@ -249,13 +267,13 @@ bool MystConsole::Cmd_PlayMovie(int argc, const char **argv) {
 	}
 
 	if (argc == 2)
-		_vm->_video->playBackgroundMovie(argv[1], 0, 0);
+		_vm->_video->playMovie(argv[1], 0, 0);
 	else if (argc == 3)
-		_vm->_video->playBackgroundMovie(_vm->wrapMovieFilename(argv[1], stackNum - 1), 0, 0);
+		_vm->_video->playMovie(_vm->wrapMovieFilename(argv[1], stackNum - 1), 0, 0);
 	else if (argc == 4)
-		_vm->_video->playBackgroundMovie(argv[1], atoi(argv[2]), atoi(argv[3]));
+		_vm->_video->playMovie(argv[1], atoi(argv[2]), atoi(argv[3]));
 	else
-		_vm->_video->playBackgroundMovie(_vm->wrapMovieFilename(argv[1], stackNum - 1), atoi(argv[3]), atoi(argv[4]));
+		_vm->_video->playMovie(_vm->wrapMovieFilename(argv[1], stackNum - 1), atoi(argv[3]), atoi(argv[4]));
 
 	return false;
 }
@@ -267,7 +285,7 @@ bool MystConsole::Cmd_DisableInitOpcodes(int argc, const char **argv) {
 		return true;
 	}
 
-	_vm->_scriptParser->disableInitOpcodes();
+	_vm->_scriptParser->disablePersistentScripts();
 
 	return true;
 }
@@ -293,6 +311,20 @@ bool MystConsole::Cmd_Cache(int argc, const char **argv) {
 	return true;
 }
 
+bool MystConsole::Cmd_Resources(int argc, const char **argv) {
+	DebugPrintf("Resources in card %d:\n", _vm->getCurCard());
+
+	for (uint i = 0; i < _vm->_resources.size(); i++) {
+		DebugPrintf("#%2d %s\n", i, _vm->_resources[i]->describe().c_str());
+	}
+
+	return true;
+}
+
+#endif // ENABLE_MYST
+
+#ifdef ENABLE_RIVEN
+
 RivenConsole::RivenConsole(MohawkEngine_Riven *vm) : GUI::Debugger(), _vm(vm) {
 	DCmd_Register("changeCard",		WRAP_METHOD(RivenConsole, Cmd_ChangeCard));
 	DCmd_Register("curCard",		WRAP_METHOD(RivenConsole, Cmd_CurCard));
@@ -302,7 +334,6 @@ RivenConsole::RivenConsole(MohawkEngine_Riven *vm) : GUI::Debugger(), _vm(vm) {
 	DCmd_Register("stopSound",		WRAP_METHOD(RivenConsole, Cmd_StopSound));
 	DCmd_Register("curStack",		WRAP_METHOD(RivenConsole, Cmd_CurStack));
 	DCmd_Register("changeStack",	WRAP_METHOD(RivenConsole, Cmd_ChangeStack));
-	DCmd_Register("restart",		WRAP_METHOD(RivenConsole, Cmd_Restart));
 	DCmd_Register("hotspots",		WRAP_METHOD(RivenConsole, Cmd_Hotspots));
 	DCmd_Register("zipMode",		WRAP_METHOD(RivenConsole, Cmd_ZipMode));
 	DCmd_Register("dumpScript",     WRAP_METHOD(RivenConsole, Cmd_DumpScript));
@@ -315,15 +346,6 @@ RivenConsole::RivenConsole(MohawkEngine_Riven *vm) : GUI::Debugger(), _vm(vm) {
 RivenConsole::~RivenConsole() {
 }
 
-void RivenConsole::preEnter() {
-	_vm->_sound->pauseSound();
-	_vm->_sound->pauseSLST();
-}
-
-void RivenConsole::postEnter() {
-	_vm->_sound->resumeSound();
-	_vm->_sound->resumeSLST();
-}
 
 bool RivenConsole::Cmd_ChangeCard(int argc, const char **argv) {
 	if (argc < 2) {
@@ -350,18 +372,17 @@ bool RivenConsole::Cmd_Var(int argc, const char **argv) {
 		return true;
 	}
 
-	uint32 *globalVar = _vm->getVar(argv[1]);
-
-	if (!globalVar) {
-		DebugPrintf("Unknown variable \'%s\'\n", argv[1]);
+	if (!_vm->_vars.contains(argv[1])) {
+		DebugPrintf("Unknown variable '%s'\n", argv[1]);
 		return true;
 	}
 
+	uint32 &var = _vm->_vars[argv[1]];
+
 	if (argc > 2)
-		*globalVar = (uint32)atoi(argv[2]);
-
-	DebugPrintf("%s = %d\n", argv[1], *globalVar);
+		var = (uint32)atoi(argv[2]);
 
+	DebugPrintf("%s = %d\n", argv[1], var);
 	return true;
 }
 
@@ -441,14 +462,6 @@ bool RivenConsole::Cmd_ChangeStack(int argc, const char **argv) {
 	return false;
 }
 
-bool RivenConsole::Cmd_Restart(int argc, const char **argv) {
-	_vm->initVars();
-	_vm->changeToStack(aspit);
-	_vm->changeToCard(1);
-
-	return false;
-}
-
 bool RivenConsole::Cmd_Hotspots(int argc, const char **argv) {
 	DebugPrintf("Current card (%d) has %d hotspots:\n", _vm->getCurCard(), _vm->getHotspotCount());
 
@@ -468,11 +481,11 @@ bool RivenConsole::Cmd_Hotspots(int argc, const char **argv) {
 }
 
 bool RivenConsole::Cmd_ZipMode(int argc, const char **argv) {
-	uint32 *zipModeActive = _vm->getVar("azip");
-	*zipModeActive = !(*zipModeActive);
+	uint32 &zipModeActive = _vm->_vars["azip"];
+	zipModeActive = !zipModeActive;
 
 	DebugPrintf("Zip Mode is ");
-	DebugPrintf((*zipModeActive) ? "Enabled" : "Disabled");
+	DebugPrintf(zipModeActive ? "Enabled" : "Disabled");
 	DebugPrintf("\n");
 	return true;
 }
@@ -502,7 +515,7 @@ bool RivenConsole::Cmd_DumpScript(int argc, const char **argv) {
 	_vm->changeToStack(newStack);
 
 	// Load in Variable Names
-	Common::SeekableReadStream *nameStream = _vm->getRawData(ID_NAME, VariableNames);
+	Common::SeekableReadStream *nameStream = _vm->getResource(ID_NAME, VariableNames);
 	Common::StringArray varNames;
 
 	uint16 namesCount = nameStream->readUint16BE();
@@ -523,7 +536,7 @@ bool RivenConsole::Cmd_DumpScript(int argc, const char **argv) {
 	delete nameStream;
 
 	// Load in External Command Names
-	nameStream = _vm->getRawData(ID_NAME, ExternalCommandNames);
+	nameStream = _vm->getResource(ID_NAME, ExternalCommandNames);
 	Common::StringArray xNames;
 
 	namesCount = nameStream->readUint16BE();
@@ -545,9 +558,15 @@ bool RivenConsole::Cmd_DumpScript(int argc, const char **argv) {
 
 	// Get CARD/HSPT data and dump their scripts
 	if (!scumm_stricmp(argv[2], "CARD")) {
-		printf ("\n\nDumping scripts for %s\'s card %d!\n", argv[1], (uint16)atoi(argv[3]));
-		printf ("==================================\n\n");
-		Common::SeekableReadStream *cardStream = _vm->getRawData(MKID_BE('CARD'), (uint16)atoi(argv[3]));
+		// Use debugN to print these because the scripts can get very large and would
+		// really be useless if the the text console is not used. A DumpFile could also
+		// theoretically be used, but I (clone2727) typically use this dynamically and
+		// don't want countless files laying around without game context. If one would
+		// want a file of a script they could just redirect stdout to a file or use
+		// deriven.
+		debugN("\n\nDumping scripts for %s\'s card %d!\n", argv[1], (uint16)atoi(argv[3]));
+		debugN("==================================\n\n");
+		Common::SeekableReadStream *cardStream = _vm->getResource(MKTAG('C','A','R','D'), (uint16)atoi(argv[3]));
 		cardStream->seek(4);
 		RivenScriptList scriptList = _vm->_scriptMan->readScripts(cardStream, false);
 		for (uint32 i = 0; i < scriptList.size(); i++) {
@@ -556,15 +575,16 @@ bool RivenConsole::Cmd_DumpScript(int argc, const char **argv) {
 		}
 		delete cardStream;
 	} else if (!scumm_stricmp(argv[2], "HSPT")) {
-		printf ("\n\nDumping scripts for %s\'s card %d hotspots!\n", argv[1], (uint16)atoi(argv[3]));
-		printf ("===========================================\n\n");
+		// See above for why this is printed via debugN
+		debugN("\n\nDumping scripts for %s\'s card %d hotspots!\n", argv[1], (uint16)atoi(argv[3]));
+		debugN("===========================================\n\n");
 
-		Common::SeekableReadStream *hsptStream = _vm->getRawData(MKID_BE('HSPT'), (uint16)atoi(argv[3]));
+		Common::SeekableReadStream *hsptStream = _vm->getResource(MKTAG('H','S','P','T'), (uint16)atoi(argv[3]));
 
 		uint16 hotspotCount = hsptStream->readUint16BE();
 
 		for (uint16 i = 0; i < hotspotCount; i++) {
-			printf ("Hotspot %d:\n", i);
+			debugN("Hotspot %d:\n", i);
 			hsptStream->seek(22, SEEK_CUR);	// Skip non-script related stuff
 			RivenScriptList scriptList = _vm->_scriptMan->readScripts(hsptStream, false);
 			for (uint32 j = 0; j < scriptList.size(); j++) {
@@ -578,7 +598,8 @@ bool RivenConsole::Cmd_DumpScript(int argc, const char **argv) {
 		DebugPrintf("%s doesn't have any scripts!\n", argv[2]);
 	}
 
-	printf("\n\n");
+	// See above for why this is printed via debugN
+	debugN("\n\n");
 
 	_vm->changeToStack(oldStack);
 
@@ -611,9 +632,9 @@ bool RivenConsole::Cmd_Combos(int argc, const char **argv) {
 	// You'll need to look up the Rebel Tunnel puzzle on your own; the
 	// solution is constant.
 
-	uint32 teleCombo = *_vm->getVar("tcorrectorder");
-	uint32 prisonCombo = *_vm->getVar("pcorrectorder");
-	uint32 domeCombo = *_vm->getVar("adomecombo");
+	uint32 teleCombo = _vm->_vars["tcorrectorder"];
+	uint32 prisonCombo = _vm->_vars["pcorrectorder"];
+	uint32 domeCombo = _vm->_vars["adomecombo"];
 	
 	DebugPrintf("Telescope Combo:\n  ");
 	for (int i = 0; i < 5; i++)
@@ -640,33 +661,26 @@ bool RivenConsole::Cmd_SliderState(int argc, const char **argv) {
 	return true;
 }
 
+#endif // ENABLE_RIVEN
+
 LivingBooksConsole::LivingBooksConsole(MohawkEngine_LivingBooks *vm) : GUI::Debugger(), _vm(vm) {
 	DCmd_Register("playSound",			WRAP_METHOD(LivingBooksConsole, Cmd_PlaySound));
 	DCmd_Register("stopSound",			WRAP_METHOD(LivingBooksConsole, Cmd_StopSound));
 	DCmd_Register("drawImage",			WRAP_METHOD(LivingBooksConsole, Cmd_DrawImage));
+	DCmd_Register("changePage",			WRAP_METHOD(LivingBooksConsole, Cmd_ChangePage));
 }
 
 LivingBooksConsole::~LivingBooksConsole() {
 }
 
-void LivingBooksConsole::preEnter() {
-	_vm->_sound->pauseSound();
-}
-
-void LivingBooksConsole::postEnter() {
-	_vm->_sound->resumeSound();
-}
-
 bool LivingBooksConsole::Cmd_PlaySound(int argc, const char **argv) {
 	if (argc == 1) {
 		DebugPrintf("Usage: playSound <value>\n");
-
 		return true;
 	}
 
 	_vm->_sound->stopSound();
 	_vm->_sound->playSound((uint16)atoi(argv[1]));
-
 	return false;
 }
 
@@ -674,7 +688,6 @@ bool LivingBooksConsole::Cmd_StopSound(int argc, const char **argv) {
 	DebugPrintf("Stopping Sound\n");
 
 	_vm->_sound->stopSound();
-
 	return true;
 }
 
@@ -684,11 +697,127 @@ bool LivingBooksConsole::Cmd_DrawImage(int argc, const char **argv) {
 		return true;
 	}
 
-	if (_vm->getGameType() == GType_LIVINGBOOKSV1)
-		DebugPrintf("This isn't supported in the old Living Books games (yet)!\n");
-
-	_vm->_gfx->copyImageToScreen((uint16)atoi(argv[1]));
-	return _vm->getGameType() != GType_LIVINGBOOKSV1;
+	_vm->_gfx->copyAnimImageToScreen((uint16)atoi(argv[1]));
+	_vm->_system->updateScreen();
+	return false;
 }
 
+bool LivingBooksConsole::Cmd_ChangePage(int argc, const char **argv) {
+	if (argc == 1) {
+		DebugPrintf("Usage: changePage <page> [<mode>]\n");
+		return true;
+	}
+
+	if (_vm->tryLoadPageStart(argc == 2 ? _vm->getCurMode() : (LBMode)atoi(argv[2]), atoi(argv[1])))
+		return false;
+	DebugPrintf("no such page %d\n", atoi(argv[1]));
+	return true;
+}
+
+#ifdef ENABLE_CSTIME
+
+CSTimeConsole::CSTimeConsole(MohawkEngine_CSTime *vm) : GUI::Debugger(), _vm(vm) {
+	DCmd_Register("playSound",			WRAP_METHOD(CSTimeConsole, Cmd_PlaySound));
+	DCmd_Register("stopSound",			WRAP_METHOD(CSTimeConsole, Cmd_StopSound));
+	DCmd_Register("drawImage",			WRAP_METHOD(CSTimeConsole, Cmd_DrawImage));
+	DCmd_Register("drawSubimage",			WRAP_METHOD(CSTimeConsole, Cmd_DrawSubimage));
+	DCmd_Register("changeCase",			WRAP_METHOD(CSTimeConsole, Cmd_ChangeCase));
+	DCmd_Register("changeScene",			WRAP_METHOD(CSTimeConsole, Cmd_ChangeScene));
+	DCmd_Register("caseVariable",			WRAP_METHOD(CSTimeConsole, Cmd_CaseVariable));
+	DCmd_Register("invItem",			WRAP_METHOD(CSTimeConsole, Cmd_InvItem));
+}
+
+CSTimeConsole::~CSTimeConsole() {
+}
+
+bool CSTimeConsole::Cmd_PlaySound(int argc, const char **argv) {
+	if (argc == 1) {
+		DebugPrintf("Usage: playSound <value>\n");
+		return true;
+	}
+
+	_vm->_sound->stopSound();
+	_vm->_sound->playSound((uint16)atoi(argv[1]));
+	return false;
+}
+
+bool CSTimeConsole::Cmd_StopSound(int argc, const char **argv) {
+	DebugPrintf("Stopping Sound\n");
+
+	_vm->_sound->stopSound();
+	return true;
+}
+
+bool CSTimeConsole::Cmd_DrawImage(int argc, const char **argv) {
+	if (argc == 1) {
+		DebugPrintf("Usage: drawImage <value>\n");
+		return true;
+	}
+
+	_vm->_gfx->copyAnimImageToScreen((uint16)atoi(argv[1]));
+	_vm->_system->updateScreen();
+	return false;
+}
+
+bool CSTimeConsole::Cmd_DrawSubimage(int argc, const char **argv) {
+	if (argc < 3) {
+		DebugPrintf("Usage: drawSubimage <value> <subimage>\n");
+		return true;
+	}
+
+	_vm->_gfx->copyAnimSubImageToScreen((uint16)atoi(argv[1]), (uint16)atoi(argv[2]));
+	_vm->_system->updateScreen();
+	return false;
+}
+
+bool CSTimeConsole::Cmd_ChangeCase(int argc, const char **argv) {
+	if (argc < 2) {
+		DebugPrintf("Usage: changeCase <value>\n");
+		return true;
+	}
+
+	error("Can't change case yet"); // FIXME
+	return false;
+}
+
+bool CSTimeConsole::Cmd_ChangeScene(int argc, const char **argv) {
+	if (argc < 2) {
+		DebugPrintf("Usage: changeScene <value>\n");
+		return true;
+	}
+
+	_vm->addEvent(CSTimeEvent(kCSTimeEventNewScene, 0xffff, atoi(argv[1])));
+	return false;
+}
+
+bool CSTimeConsole::Cmd_CaseVariable(int argc, const char **argv) {
+	if (argc < 2) {
+		DebugPrintf("Usage: caseVariable <id> [<value>]\n");
+		return true;
+	}
+
+	if (argc == 2) {
+		DebugPrintf("case variable %d has value %d\n", atoi(argv[1]), _vm->_caseVariable[atoi(argv[1])]);
+	} else {
+		_vm->_caseVariable[atoi(argv[1])] = atoi(argv[2]);
+	}
+	return true;
+}
+
+bool CSTimeConsole::Cmd_InvItem(int argc, const char **argv) {
+	if (argc < 3) {
+		DebugPrintf("Usage: invItem <id> <0 or 1>\n");
+		return true;
+	}
+
+	if (atoi(argv[2])) {
+		_vm->addEvent(CSTimeEvent(kCSTimeEventDropItemInInventory, 0xffff, atoi(argv[1])));
+	} else {
+		_vm->addEvent(CSTimeEvent(kCSTimeEventRemoveItemFromInventory, 0xffff, atoi(argv[1])));
+	}
+	return false;
+}
+
+#endif // ENABLE_CSTIME
+
 } // End of namespace Mohawk
