@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/console.h $
- * $Id: console.h 52292 2010-08-23 04:14:30Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,19 +30,17 @@
 
 namespace Mohawk {
 
-class MohawkEngine_Myst;
-class MohawkEngine_Riven;
 class MohawkEngine_LivingBooks;
 
+#ifdef ENABLE_MYST
+
+class MohawkEngine_Myst;
+
 class MystConsole : public GUI::Debugger {
 public:
 	MystConsole(MohawkEngine_Myst *vm);
 	virtual ~MystConsole(void);
 
-protected:
-	virtual void preEnter();
-	virtual void postEnter();
-
 private:
 	MohawkEngine_Myst *_vm;
 
@@ -59,17 +57,20 @@ private:
 	bool Cmd_PlayMovie(int argc, const char **argv);
 	bool Cmd_DisableInitOpcodes(int argc, const char **argv);
 	bool Cmd_Cache(int argc, const char **argv);
+	bool Cmd_Resources(int argc, const char **argv);
 };
 
+#endif
+
+#ifdef ENABLE_RIVEN
+
+class MohawkEngine_Riven;
+
 class RivenConsole : public GUI::Debugger {
 public:
 	RivenConsole(MohawkEngine_Riven *vm);
 	virtual ~RivenConsole(void);
 
-protected:
-	virtual void preEnter();
-	virtual void postEnter();
-
 private:
 	MohawkEngine_Riven *_vm;
 
@@ -81,7 +82,6 @@ private:
 	bool Cmd_StopSound(int argc, const char **argv);
 	bool Cmd_CurStack(int argc, const char **argv);
 	bool Cmd_ChangeStack(int argc, const char **argv);
-	bool Cmd_Restart(int argc, const char **argv);
 	bool Cmd_Hotspots(int argc, const char **argv);
 	bool Cmd_ZipMode(int argc, const char **argv);
 	bool Cmd_RunAllBlocks(int argc, const char **argv);
@@ -92,23 +92,46 @@ private:
 	bool Cmd_SliderState(int argc, const char **argv);
 };
 
+#endif
+
 class LivingBooksConsole : public GUI::Debugger {
 public:
 	LivingBooksConsole(MohawkEngine_LivingBooks *vm);
 	virtual ~LivingBooksConsole(void);
 
-protected:
-	virtual void preEnter();
-	virtual void postEnter();
-
 private:
 	MohawkEngine_LivingBooks *_vm;
 
 	bool Cmd_PlaySound(int argc, const char **argv);
 	bool Cmd_StopSound(int argc, const char **argv);
 	bool Cmd_DrawImage(int argc, const char **argv);
+	bool Cmd_ChangePage(int argc, const char **argv);
 };
 
+#ifdef ENABLE_CSTIME
+
+class MohawkEngine_CSTime;
+
+class CSTimeConsole : public GUI::Debugger {
+public:
+	CSTimeConsole(MohawkEngine_CSTime *vm);
+	virtual ~CSTimeConsole(void);
+
+private:
+	MohawkEngine_CSTime *_vm;
+
+	bool Cmd_PlaySound(int argc, const char **argv);
+	bool Cmd_StopSound(int argc, const char **argv);
+	bool Cmd_DrawImage(int argc, const char **argv);
+	bool Cmd_DrawSubimage(int argc, const char **argv);
+	bool Cmd_ChangeCase(int argc, const char **argv);
+	bool Cmd_ChangeScene(int argc, const char **argv);
+	bool Cmd_CaseVariable(int argc, const char **argv);
+	bool Cmd_InvItem(int argc, const char **argv);
+};
+
+#endif
+
 } // End of namespace Mohawk
 
 #endif
