@@ -18,24 +18,31 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/detection.cpp $
- * $Id: detection.cpp 50776 2010-07-09 22:10:22Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "base/plugins.h"
 
 #include "engines/advancedDetector.h"
-#include "common/config-manager.h"
-#include "common/file.h"
 #include "common/savefile.h"
+#include "common/system.h"
+#include "common/textconsole.h"
 
-#include "mohawk/myst.h"
-#include "mohawk/riven.h"
 #include "mohawk/livingbooks.h"
 
-// Define this to enable detection of other Broderbund titles which use Mohawk (besides Myst/Riven)
-#define DETECT_BRODERBUND_TITLES
+#ifdef ENABLE_CSTIME
+#include "mohawk/cstime.h"
+#endif
+
+#ifdef ENABLE_MYST
+#include "mohawk/myst.h"
+#endif
+
+#ifdef ENABLE_RIVEN
+#include "mohawk/riven.h"
+#endif
 
 namespace Mohawk {
 
@@ -44,7 +51,7 @@ struct MohawkGameDescription {
 
 	uint8 gameType;
 	uint32 features;
-	uint16 version;
+	const char *appName;
 };
 
 const char* MohawkEngine::getGameId() const {
@@ -59,8 +66,8 @@ Common::Platform MohawkEngine::getPlatform() const {
 	return _gameDescription->desc.platform;
 }
 
-uint16 MohawkEngine::getVersion() const {
-	return _gameDescription->version;
+const char *MohawkEngine::getAppName() const {
+	return _gameDescription->appName;
 }
 
 uint8 MohawkEngine::getGameType() const {
@@ -80,6 +87,8 @@ bool MohawkEngine::hasFeature(EngineFeature f) const {
 		(f == kSupportsRTL);
 }
 
+#ifdef ENABLE_MYST
+
 bool MohawkEngine_Myst::hasFeature(EngineFeature f) const {
 	return
 		MohawkEngine::hasFeature(f)
@@ -87,6 +96,10 @@ bool MohawkEngine_Myst::hasFeature(EngineFeature f) const {
 		|| (f == kSupportsSavingDuringRuntime);
 }
 
+#endif
+
+#ifdef ENABLE_RIVEN
+
 bool MohawkEngine_Riven::hasFeature(EngineFeature f) const {
 	return
 		MohawkEngine::hasFeature(f)
@@ -94,6 +107,8 @@ bool MohawkEngine_Riven::hasFeature(EngineFeature f) const {
 		|| (f == kSupportsSavingDuringRuntime);
 }
 
+#endif
+
 } // End of Namespace Mohawk
 
 static const PlainGameDescriptor mohawkGames[] = {
@@ -101,25 +116,36 @@ static const PlainGameDescriptor mohawkGames[] = {
 	{"myst", "Myst"},
 	{"MakingOfMyst", "The Making of Myst"},
 	{"riven", "Riven: The Sequel to Myst"},
-#ifdef DETECT_BRODERBUND_TITLES
-	{"zoombini", "Logical Journey of the Zoombinis Deluxe"},
+	{"zoombini", "Logical Journey of the Zoombinis"},
+	{"cstime", "Where in Time is Carmen Sandiego?"},
 	{"csworld", "Where in the World is Carmen Sandiego?"},
 	{"csamtrak", "Where in America is Carmen Sandiego? (The Great Amtrak Train Adventure)"},
-	{"maggiess", "Maggie's Farmyard Adventure"},
+	{"carmentq", "Carmen Sandiego's ThinkQuick Challenge"},
+	{"carmentqc", "Carmen Sandiego's ThinkQuick Challenge Custom Question Creator"},
+	{"maggiesfa", "Maggie's Farmyard Adventure"},
 	{"jamesmath", "James Discovers/Explores Math"},
 	{"treehouse", "The Treehouse"},
 	{"greeneggs", "Green Eggs and Ham"},
+	{"seussabc", "Dr Seuss's ABC"},
 	{"1stdegree", "In the 1st Degree"},
 	{"csusa", "Where in the USA is Carmen Sandiego?"},
 	{"tortoise", "Aesop's Fables: The Tortoise and the Hare"},
-	{"arthur", "Arthur's Teacher Troubles"},
+	{"arthur", "Arthur's Teacher Trouble"},
 	{"grandma", "Just Grandma and Me"},
 	{"ruff", "Ruff's Bone"},
 	{"newkid", "The New Kid on the Block"},
 	{"arthurrace", "Arthur's Reading Race"},
 	{"arthurbday", "Arthur's Birthday"},
 	{"lilmonster", "Little Monster at School"},
-#endif
+	{"catinthehat", "The Cat in the Hat"},
+	{"rugrats", "Rugrats Adventure Game"},
+	{"lbsampler", "Living Books Sampler"},
+	{"bearfight", "The Berenstain Bears Get in a Fight"},
+	{"beardark", "The Berenstain Bears In The Dark"},
+	{"arthurcomp", "Arthur's Computer Adventure"},
+	{"harryhh","Harry and the Haunted House"},
+	{"stellaluna", "Stellaluna"},
+	{"sheila", "Sheila Rae, the Brave"},
 	{0, 0}
 };
 
@@ -129,6 +155,9 @@ static const char *directoryGlobs[] = {
 	"all",
 	"assets1",
 	"data",
+	"program",
+	"95instal",
+	"Rugrats Adventure Game",
 	0
 };
 
@@ -221,27 +250,47 @@ bool MohawkMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGa
 		switch (gd->gameType) {
 		case Mohawk::GType_MYST:
 		case Mohawk::GType_MAKINGOF:
+#ifdef ENABLE_MYST
 			*engine = new Mohawk::MohawkEngine_Myst(syst, gd);
 			break;
+#else
+			warning("Myst support not compiled in");
+			return false;
+#endif
 		case Mohawk::GType_RIVEN:
+#ifdef ENABLE_RIVEN
 			*engine = new Mohawk::MohawkEngine_Riven(syst, gd);
 			break;
+#else
+			warning("Riven support not compiled in");
+			return false;
+#endif
 		case Mohawk::GType_LIVINGBOOKSV1:
+		case Mohawk::GType_LIVINGBOOKSV2:
 		case Mohawk::GType_LIVINGBOOKSV3:
+		case Mohawk::GType_LIVINGBOOKSV4:
+		case Mohawk::GType_LIVINGBOOKSV5:
 			*engine = new Mohawk::MohawkEngine_LivingBooks(syst, gd);
 			break;
+		case Mohawk::GType_CSTIME:
+#ifdef ENABLE_CSTIME
+			*engine = new Mohawk::MohawkEngine_CSTime(syst, gd);
+			break;
+#else
+			warning("CSTime support not compiled in");
+			return false;
+#endif
 		case Mohawk::GType_ZOOMBINI:
 		case Mohawk::GType_CSWORLD:
 		case Mohawk::GType_CSAMTRAK:
-		case Mohawk::GType_MAGGIESS:
 		case Mohawk::GType_JAMESMATH:
 		case Mohawk::GType_TREEHOUSE:
 		case Mohawk::GType_1STDEGREE:
 		case Mohawk::GType_CSUSA:
-			error ("Unsupported Mohawk Engine");
-			break;
+			warning("Unsupported Mohawk Engine");
+			return false;
 		default:
-			error ("Unknown Mohawk Engine");
+			error("Unknown Mohawk Engine");
 		}
 	}
 
