@@ -18,30 +18,38 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/dialogs.cpp $
- * $Id: dialogs.cpp 52538 2010-09-05 00:48:38Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "mohawk/mohawk.h"
-#include "mohawk/myst.h"
-#include "mohawk/riven.h"
 #include "mohawk/dialogs.h"
 
-#include "gui/GuiManager.h"
-#include "common/savefile.h"
+#include "gui/gui-manager.h"
+#include "gui/ThemeEngine.h"
+#include "gui/widget.h"
+#include "common/system.h"
 #include "common/translation.h"
 
+#ifdef ENABLE_MYST
+#include "mohawk/myst.h"
+#endif
+
+#ifdef ENABLE_RIVEN
+#include "mohawk/riven.h"
+#endif
+
 namespace Mohawk {
 
 // This used to have GUI::Dialog("MohawkDummyDialog"), but that doesn't work with the gui branch merge :P (Sorry, Tanoku!)
-InfoDialog::InfoDialog(MohawkEngine *vm, Common::String message) : _vm(vm), GUI::Dialog(0, 0, 1, 1), _message(message) {
+InfoDialog::InfoDialog(MohawkEngine *vm, const Common::String &message) : _vm(vm), GUI::Dialog(0, 0, 1, 1), _message(message) {
 	_backgroundType = GUI::ThemeEngine::kDialogBackgroundSpecial;
 
-	_text = new GUI::StaticTextWidget(this, 4, 4, 10, 10, _message, Graphics::kTextAlignCenter);
+	_text = new GUI::StaticTextWidget(this, 0, 0, 10, 10, _message, Graphics::kTextAlignCenter);
 }
 
-void InfoDialog::setInfoText(Common::String message) {
+void InfoDialog::setInfoText(const Common::String &message) {
 	_message = message;
 	_text->setLabel(_message);
 }
@@ -58,10 +66,10 @@ void InfoDialog::reflowLayout() {
 	_x = (screenW - width) / 2;
 	_y = (screenH - height) / 2;
 
-	_text->setSize(_w - 8, _h);
+	_text->setSize(_w, _h);
 }
 
-PauseDialog::PauseDialog(MohawkEngine *vm, Common::String message) : InfoDialog(vm, message) {
+PauseDialog::PauseDialog(MohawkEngine *vm, const Common::String &message) : InfoDialog(vm, message) {
 }
 
 void PauseDialog::handleKeyDown(Common::KeyState state) {
@@ -77,6 +85,8 @@ enum {
 	kWaterCmd = 'WATR'
 };
 
+#ifdef ENABLE_MYST
+
 MystOptionsDialog::MystOptionsDialog(MohawkEngine_Myst* vm) : GUI::OptionsDialog("", 120, 120, 360, 200), _vm(vm) {
 	_zipModeCheckbox = new GUI::CheckboxWidget(this, 15, 10, 300, 15, _("~Z~ip Mode Activated"), 0, kZipCmd);
 	_transitionsCheckbox = new GUI::CheckboxWidget(this, 15, 30, 300, 15, _("~T~ransitions Enabled"), 0, kTransCmd);
@@ -91,17 +101,17 @@ MystOptionsDialog::~MystOptionsDialog() {
 void MystOptionsDialog::open() {
 	Dialog::open();
 
-	_zipModeCheckbox->setState(_vm->_zipMode);
-	_transitionsCheckbox->setState(_vm->_transitionsEnabled);
+	_zipModeCheckbox->setState(_vm->_gameState->_globals.zipMode);
+	_transitionsCheckbox->setState(_vm->_gameState->_globals.transitions);
 }
 
 void MystOptionsDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32 data) {
 	switch (cmd) {
 	case kZipCmd:
-		_vm->_zipMode = _zipModeCheckbox->getState();
+		_vm->_gameState->_globals.zipMode = _zipModeCheckbox->getState();
 		break;
 	case kTransCmd:
-		_vm->_transitionsEnabled = _transitionsCheckbox->getState();
+		_vm->_gameState->_globals.transitions = _transitionsCheckbox->getState();
 		break;
 	case GUI::kCloseCmd:
 		close();
@@ -111,6 +121,10 @@ void MystOptionsDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, ui
 	}
 }
 
+#endif
+
+#ifdef ENABLE_RIVEN
+
 RivenOptionsDialog::RivenOptionsDialog(MohawkEngine_Riven* vm) : GUI::OptionsDialog("", 120, 120, 360, 200), _vm(vm) {
 	_zipModeCheckbox = new GUI::CheckboxWidget(this, 15, 10, 300, 15, _("~Z~ip Mode Activated"), 0, kZipCmd);
 	_waterEffectCheckbox = new GUI::CheckboxWidget(this, 15, 30, 300, 15, _("~W~ater Effect Enabled"), 0, kWaterCmd);
@@ -125,17 +139,17 @@ RivenOptionsDialog::~RivenOptionsDialog() {
 void RivenOptionsDialog::open() {
 	Dialog::open();
 
-	_zipModeCheckbox->setState(*_vm->getVar("azip") != 0);
-	_waterEffectCheckbox->setState(*_vm->getVar("waterenabled") != 0);
+	_zipModeCheckbox->setState(_vm->_vars["azip"] != 0);
+	_waterEffectCheckbox->setState(_vm->_vars["waterenabled"] != 0);
 }
 
 void RivenOptionsDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32 data) {
 	switch (cmd) {
 	case kZipCmd:
-		*_vm->getVar("azip") = _zipModeCheckbox->getState() ? 1 : 0;
+		_vm->_vars["azip"] = _zipModeCheckbox->getState() ? 1 : 0;
 		break;
 	case kWaterCmd:
-		*_vm->getVar("waterenabled") = _waterEffectCheckbox->getState() ? 1 : 0;
+		_vm->_vars["waterenabled"] = _waterEffectCheckbox->getState() ? 1 : 0;
 		break;
 	case GUI::kCloseCmd:
 		close();
@@ -145,4 +159,6 @@ void RivenOptionsDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, u
 	}
 }
 
+#endif
+
 } // End of namespace Mohawk
