@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/resource_cache.h $
- * $Id: resource_cache.h 48579 2010-04-06 23:38:43Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -51,7 +51,7 @@ private:
 		Common::SeekableReadStream *data;
 	};
 
-	Common::Array<DataObject> store;
+	Common::Array<DataObject> _store;
 };
 
 } // End of namespace Mohawk
