@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven.cpp $
- * $Id: riven.cpp 52692 2010-09-12 21:35:49Z criezy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,13 +29,17 @@
 #include "common/keyboard.h"
 #include "common/translation.h"
 
+#include "mohawk/cursors.h"
 #include "mohawk/graphics.h"
+#include "mohawk/installer_archive.h"
 #include "mohawk/resource.h"
 #include "mohawk/riven.h"
 #include "mohawk/riven_external.h"
 #include "mohawk/riven_saveload.h"
 #include "mohawk/dialogs.h"
+#include "mohawk/sound.h"
 #include "mohawk/video.h"
+#include "mohawk/console.h"
 
 namespace Mohawk {
 
@@ -53,9 +57,10 @@ MohawkEngine_Riven::MohawkEngine_Riven(OSystem *syst, const MohawkGameDescriptio
 	_gameOver = false;
 	_activatedSLST = false;
 	_ignoreNextMouseUp = false;
-	_extrasFile = NULL;
+	_extrasFile = 0;
 	_curStack = aspit;
-	_hotspots = NULL;
+	_hotspots = 0;
+	removeTimer();
 
 	// NOTE: We can never really support CD swapping. All of the music files
 	// (*_Sounds.mhk) are stored on disc 1. They are copied to the hard drive
@@ -85,7 +90,6 @@ MohawkEngine_Riven::~MohawkEngine_Riven() {
 	delete _extrasFile;
 	delete _saveLoad;
 	delete _scriptMan;
-	delete[] _vars;
 	delete _optionsDialog;
 	delete _rnd;
 	delete[] _hotspots;
@@ -105,6 +109,11 @@ GUI::Debugger *MohawkEngine_Riven::getDebugger() {
 Common::Error MohawkEngine_Riven::run() {
 	MohawkEngine::run();
 
+	// Let's try to open the installer file (it holds extras.mhk)
+	// Though, we set a low priority to prefer the extracted version
+	if (_installerArchive.open("arcriven.z"))
+		SearchMan.add("arcriven.z", &_installerArchive, 0, false);
+
 	_gfx = new RivenGraphics(this);
 	_console = new RivenConsole(this);
 	_saveLoad = new RivenSaveLoad(this, _saveFileMan);
@@ -115,14 +124,40 @@ Common::Error MohawkEngine_Riven::run() {
 	_rnd = new Common::RandomSource();
 	g_eventRec.registerRandomSource(*_rnd, "riven");
 
+	// Create the cursor manager
+	if (Common::File::exists("rivendmo.exe"))
+		_cursor = new PECursorManager("rivendmo.exe");
+	else if (Common::File::exists("riven.exe"))
+		_cursor = new PECursorManager("riven.exe");
+	else // last resort: try the Mac executable
+		_cursor = new MacCursorManager("Riven");
+
 	initVars();
 
+	// We need to have a cursor source, or the game won't work
+	if (!_cursor->hasSource()) {
+		Common::String message = "You're missing a Riven executable. The Windows executable is 'riven.exe' or 'rivendmo.exe'. ";
+		message += "Using the 'arcriven.z' installer file also works. In addition, you can use the Mac 'Riven' executable.";
+		GUIErrorMessage(message);
+		warning("%s", message.c_str());
+		return Common::kNoGameDataFoundError;
+	}
+
 	// Open extras.mhk for common images
 	_extrasFile = new MohawkArchive();
-	_extrasFile->open("extras.mhk");
+
+	// We need extras.mhk for inventory images, marble images, and credits images
+	if (!_extrasFile->open("extras.mhk")) {
+		Common::String message = "You're missing 'extras.mhk'. Using the 'arcriven.z' installer file also works.";
+		GUIErrorMessage(message);
+		warning("%s", message.c_str());
+		return Common::kNoGameDataFoundError;
+	}
 
 	// Start at main cursor
-	_gfx->changeCursor(kRivenMainCursor);
+	_cursor->setCursor(kRivenMainCursor);
+	_cursor->showCursor();
+	_system->updateScreen();
 
 	// Let's begin, shall we?
 	if (getFeatures() & GF_DEMO) {
@@ -135,7 +170,12 @@ Common::Error MohawkEngine_Riven::run() {
 		Common::StringArray savedGamesList = _saveLoad->generateSaveGameList();
 		if (gameToLoad > savedGamesList.size())
 			error ("Could not find saved game");
-		_saveLoad->loadGame(savedGamesList[gameToLoad]);
+
+		// Attempt to load the game. On failure, just send us to the main menu.
+		if (!_saveLoad->loadGame(savedGamesList[gameToLoad])) {
+			changeToStack(aspit);
+			changeToCard(1);
+		}
 	} else {
 		// Otherwise, start us off at aspit's card 1 (the main menu)
         changeToStack(aspit);
@@ -150,11 +190,12 @@ Common::Error MohawkEngine_Riven::run() {
 }
 
 void MohawkEngine_Riven::handleEvents() {
-	Common::Event event;
-
-	// Update background videos and the water effect
+	// Update background running things
+	checkTimer();
 	bool needsUpdate = _gfx->runScheduledWaterEffects();
-	needsUpdate |= _video->updateBackgroundMovies();
+	needsUpdate |= _video->updateMovies();
+
+	Common::Event event;
 
 	while (_eventMan->pollEvent(event)) {
 		switch (event.type) {
@@ -264,6 +305,9 @@ void MohawkEngine_Riven::changeToStack(uint16 n) {
 	_video->stopVideos();
 	_video->clearMLST();
 
+	// Clear the graphics cache; images aren't used across stack boundaries
+	_gfx->clearCache();
+
 	// Clear the old stack files out
 	for (uint32 i = 0; i < _mhk.size(); i++)
 		delete _mhk[i];
@@ -275,11 +319,12 @@ void MohawkEngine_Riven::changeToStack(uint16 n) {
 	// Load any file that fits the patterns
 	for (int i = 0; i < ARRAYSIZE(endings); i++) {
 		Common::String filename = Common::String(prefix) + endings[i];
-		if (Common::File::exists(filename)) {
-			MohawkArchive *mhk = new MohawkArchive();
-			mhk->open(filename);
+
+		MohawkArchive *mhk = new MohawkArchive();
+		if (mhk->open(filename))
 			_mhk.push_back(mhk);
-		}
+		else
+			delete mhk;
 	}
 
 	// Make sure we have loaded files
@@ -317,6 +362,10 @@ void MohawkEngine_Riven::changeToCard(uint16 dest) {
 	_curCard = dest;
 	debug (1, "Changing to card %d", _curCard);
 
+	// Clear the graphics cache (images typically aren't used
+	// on different cards).
+	_gfx->clearCache();
+
 	if (!(getFeatures() & GF_DEMO)) {
 		for (byte i = 0; i < 13; i++)
 			if (_curStack == rivenSpecialChange[i].startStack && _curCard == matchRMAPToCard(rivenSpecialChange[i].startCardRMAP)) {
@@ -333,6 +382,9 @@ void MohawkEngine_Riven::changeToCard(uint16 dest) {
 }
 
 void MohawkEngine_Riven::refreshCard() {
+	// Clear any timer still floating around
+	removeTimer();
+
 	loadHotspots(_curCard);
 
 	_gfx->_updatesEnabled = true;
@@ -350,20 +402,21 @@ void MohawkEngine_Riven::refreshCard() {
 	if (!_activatedSLST)
 		_sound->playSLST(1, _curCard);
 
-	if (_showHotspots) {
+	if (_showHotspots)
 		for (uint16 i = 0; i < _hotspotCount; i++)
 			_gfx->drawRect(_hotspots[i].rect, _hotspots[i].enabled);
-	}
 
 	// Now we need to redraw the cursor if necessary and handle mouse over scripts
-	_curHotspot = -1;
-	checkHotspotChange();
+	updateCurrentHotspot();
+
+	// Finally, install any hardcoded timer
+	installCardTimer();
 }
 
 void MohawkEngine_Riven::loadCard(uint16 id) {
 	// NOTE: The card scripts are cleared by the RivenScriptManager automatically.
 
-	Common::SeekableReadStream* inStream = getRawData(ID_CARD, id);
+	Common::SeekableReadStream* inStream = getResource(ID_CARD, id);
 
 	_cardData.name = inStream->readSint16BE();
 	_cardData.zipModePlace = inStream->readUint16BE();
@@ -390,7 +443,7 @@ void MohawkEngine_Riven::loadHotspots(uint16 id) {
 	
 	// NOTE: The hotspot scripts are cleared by the RivenScriptManager automatically.
 
-	Common::SeekableReadStream *inStream = getRawData(ID_HSPT, id);
+	Common::SeekableReadStream *inStream = getResource(ID_HSPT, id);
 
 	_hotspotCount = inStream->readUint16BE();
 	_hotspots = new RivenHotspot[_hotspotCount];
@@ -436,7 +489,7 @@ void MohawkEngine_Riven::updateZipMode() {
 
 	for (uint32 i = 0; i < _hotspotCount; i++) {
 		if (_hotspots[i].zipModeHotspot) {
-			if (*getVar("azip") != 0) {
+			if (_vars["azip"] != 0) {
 				// Check if a zip mode hotspot is enabled by checking the name/id against the ZIPS records.
 				Common::String hotspotName = getName(HotspotNames, _hotspots[i].name_resource);
 
@@ -468,14 +521,21 @@ void MohawkEngine_Riven::checkHotspotChange() {
 	if (foundHotspot) {
 		if (_curHotspot != hotspotIndex) {
 			_curHotspot = hotspotIndex;
-			_gfx->changeCursor(_hotspots[_curHotspot].mouse_cursor);
+			_cursor->setCursor(_hotspots[_curHotspot].mouse_cursor);
+			_system->updateScreen();
 		}
 	} else {
 		_curHotspot = -1;
-		_gfx->changeCursor(kRivenMainCursor);
+		_cursor->setCursor(kRivenMainCursor);
+		_system->updateScreen();
 	}
 }
 
+void MohawkEngine_Riven::updateCurrentHotspot() {
+	_curHotspot = -1;
+	checkHotspotChange();
+}
+
 Common::String MohawkEngine_Riven::getHotspotName(uint16 hotspot) {
 	assert(hotspot < _hotspotCount);
 
@@ -516,13 +576,13 @@ void MohawkEngine_Riven::checkInventoryClick() {
 		return;
 
 	// Set the return stack/card id's.
-	*getVar("returnstackid") = _curStack;
-	*getVar("returncardid") = _curCard;
+	_vars["returnstackid"] = _curStack;
+	_vars["returncardid"] = _curCard;
 
 	// See RivenGraphics::showInventory() for an explanation
 	// of the variables' meanings.
-	bool hasCathBook = *getVar("acathbook") != 0;
-	bool hasTrapBook = *getVar("atrapbook") != 0;
+	bool hasCathBook = _vars["acathbook"] != 0;
+	bool hasTrapBook = _vars["atrapbook"] != 0;
 
 	// Go to the book if a hotspot contains the mouse
 	if (!hasCathBook) {
@@ -559,11 +619,11 @@ void MohawkEngine_Riven::checkInventoryClick() {
 }
 
 Common::SeekableReadStream *MohawkEngine_Riven::getExtrasResource(uint32 tag, uint16 id) {
-	return _extrasFile->getRawData(tag, id);
+	return _extrasFile->getResource(tag, id);
 }
 
 Common::String MohawkEngine_Riven::getName(uint16 nameResource, uint16 nameID) {
-	Common::SeekableReadStream* nameStream = getRawData(ID_NAME, nameResource);
+	Common::SeekableReadStream* nameStream = getResource(ID_NAME, nameResource);
 	uint16 fieldCount = nameStream->readUint16BE();
 	uint16* stringOffsets = new uint16[fieldCount];
 	Common::String name;
@@ -591,7 +651,7 @@ Common::String MohawkEngine_Riven::getName(uint16 nameResource, uint16 nameID) {
 
 uint16 MohawkEngine_Riven::matchRMAPToCard(uint32 rmapCode) {
 	uint16 index = 0;
-	Common::SeekableReadStream *rmapStream = getRawData(ID_RMAP, 1);
+	Common::SeekableReadStream *rmapStream = getResource(ID_RMAP, 1);
 
 	for (uint16 i = 1; rmapStream->pos() < rmapStream->size(); i++) {
 		uint32 code = rmapStream->readUint32BE();
@@ -608,7 +668,7 @@ uint16 MohawkEngine_Riven::matchRMAPToCard(uint32 rmapCode) {
 }
 
 uint32 MohawkEngine_Riven::getCurCardRMAP() {
-	Common::SeekableReadStream *rmapStream = getRawData(ID_RMAP, 1);
+	Common::SeekableReadStream *rmapStream = getResource(ID_RMAP, 1);
 	rmapStream->seek(_curCard * 4);
 	uint32 rmapCode = rmapStream->readUint32BE();
 	delete rmapStream;
@@ -638,7 +698,7 @@ void MohawkEngine_Riven::delayAndUpdate(uint32 ms) {
 
 	while (_system->getMillis() < startTime + ms && !shouldQuit()) {
 		bool needsUpdate = _gfx->runScheduledWaterEffects();
-		needsUpdate |= _video->updateBackgroundMovies();
+		needsUpdate |= _video->updateMovies();
 
 		Common::Event event;
 		while (_system->getEventManager()->pollEvent(event))
@@ -660,7 +720,7 @@ void MohawkEngine_Riven::runLoadDialog() {
 	const EnginePlugin *plugin = 0;
 	EngineMan.findGame(gameId, &plugin);
 
-	int slot = slc.runModal(plugin, ConfMan.getActiveDomainName());
+	int slot = slc.runModalWithPluginAndTarget(plugin, ConfMan.getActiveDomainName());
 	if (slot >= 0)
 		loadGameState(slot);
 
@@ -695,6 +755,88 @@ Common::String MohawkEngine_Riven::getStackName(uint16 stack) const {
 	return rivenStackNames[stack];
 }
 
+void MohawkEngine_Riven::installTimer(TimerProc proc, uint32 time) {
+	removeTimer();
+	_timerProc = proc;
+	_timerTime = time + getTotalPlayTime();
+}
+
+void MohawkEngine_Riven::checkTimer() {
+	if (!_timerProc)
+		return;
+
+	// NOTE: If the specified timer function is called, it is its job to remove the timer!
+	if (getTotalPlayTime() >= _timerTime) {
+		TimerProc proc = _timerProc;
+		proc(this);
+	}
+}
+
+void MohawkEngine_Riven::removeTimer() {
+	_timerProc = 0;
+	_timerTime = 0;
+}
+
+static void catherineIdleTimer(MohawkEngine_Riven *vm) {
+	uint32 &cathCheck = vm->_vars["pcathcheck"];
+	uint32 &cathState = vm->_vars["acathstate"];
+	uint16 movie;
+
+	// Choose a random movie based on where Catherine is
+	if (cathCheck == 0) {
+		static const int movieList[] = { 5, 6, 7, 8 };
+		cathCheck = 1;
+		movie = movieList[vm->_rnd->getRandomNumber(3)];
+	} else if (cathState == 1) {
+		static const int movieList[] = { 11, 14 };
+		movie = movieList[vm->_rnd->getRandomBit()];
+	} else {
+		static const int movieList[] = { 9, 10, 12, 13 };
+		movie = movieList[vm->_rnd->getRandomNumber(3)];
+	}
+
+	// Update her state if she moves from left/right or right/left, resp.
+	if (movie == 5 || movie == 7 || movie == 11 || movie == 14)
+		cathState = 2;
+	else
+		cathState = 1;
+
+	// Play the movie, blocking
+	vm->_video->activateMLST(movie, vm->getCurCard());
+	vm->_cursor->hideCursor();
+	vm->_video->playMovieBlockingRiven(movie);
+	vm->_cursor->showCursor();
+	vm->_system->updateScreen();
+
+	// Install the next timer for the next video
+	uint32 timeUntilNextMovie = vm->_rnd->getRandomNumber(120) * 1000;
+
+	vm->_vars["pcathtime"] = timeUntilNextMovie + vm->getTotalPlayTime();
+
+	vm->installTimer(&catherineIdleTimer, timeUntilNextMovie);
+}
+
+void MohawkEngine_Riven::installCardTimer() {
+	switch (getCurCardRMAP()) {
+	case 0x3a85: // Top of elevator on prison island
+		// Handle Catherine hardcoded videos
+		installTimer(&catherineIdleTimer, _rnd->getRandomNumberRng(1, 33) * 1000);
+		break;
+	case 0x77d6: // Sunners, top of stairs
+		// TODO: Background Sunner videos
+		break;
+	case 0x79bd: // Sunners, middle of stairs
+		// TODO: Background Sunner videos
+		break;
+	case 0x7beb: // Sunners, bottom of stairs
+		// TODO: Background Sunner videos
+		break;
+	case 0xb6ca: // Sunners, shoreline
+		// TODO: Background Sunner videos
+		break;
+	}
+}
+
 bool ZipMode::operator== (const ZipMode &z) const {
 	return z.name == name && z.id == id;
 }
