@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven_external.h $
- * $Id: riven_external.h 52735 2010-09-15 20:28:42Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -41,6 +41,7 @@ public:
 	uint16 getComboDigit(uint32 correctCombo, uint32 digit);
 	uint32 getDomeSliderState() { return _sliderState; }
 	void setDomeSliderState(uint32 state) { _sliderState = state; }
+	void checkYtramCatch(bool playSound);
 
 private:
 	MohawkEngine_Riven *_vm;
@@ -61,17 +62,19 @@ private:
 	// Supplementary Functions
 	int jspitElevatorLoop();
 	void runDemoBoundaryDialog();
-	void runEndGame(uint16 video);
-	void runCredits(uint16 video);
+	void runEndGame(uint16 video, uint32 delay);
+	void runCredits(uint16 video, uint32 delay);
 	void runDomeCheck();
 	void runDomeButtonMovie();
-	void resetDomeSliders(uint16 bitmapId, uint16 soundId, uint16 startHotspot);
+	void resetDomeSliders(uint16 soundId, uint16 startHotspot);
 	void checkDomeSliders(uint16 resetSlidersHotspot, uint16 openDomeHotspot);
 	void checkSliderCursorChange(uint16 startHotspot);
-	void dragDomeSlider(uint16 bitmapId, uint16 soundId, uint16 resetSlidersHotspot, uint16 openDomeHotspot, uint16 startHotspot);
-	void drawDomeSliders(uint16 bitmapId, uint16 startHotspot);
+	void dragDomeSlider(uint16 soundId, uint16 resetSlidersHotspot, uint16 openDomeHotspot, uint16 startHotspot);
+	void drawDomeSliders(uint16 startHotspot);
 	void drawMarbles();
 	void setMarbleHotspots();
+	void redrawWharkNumberPuzzle(uint16 overlay, uint16 number);
+	void lowerPins();
 
 	// -----------------------------------------------------
 	// aspit (Main Menu, Books, Setup) external commands
@@ -100,6 +103,8 @@ private:
 	void xalaunchbrowser(uint16 argc, uint16 *argv);
 	void xadisablemenuintro(uint16 argc, uint16 *argv);
 	void xaenablemenuintro(uint16 argc, uint16 *argv);
+	void xademoquit(uint16 argc, uint16 *argv);
+	void xaexittomain(uint16 argc, uint16 *argv);
 
 	// -----------------------------------------------------
 	// bspit (Boiler Island) external commands
@@ -192,6 +197,8 @@ private:
 	void xjlagoon1500_alert(uint16 argc, uint16 *argv);
 	// Play the Whark Game
 	void xschool280_playwhark(uint16 argc, uint16 *argv);
+	void xjschool280_resetleft(uint16 argc, uint16 *argv); // DVD only
+	void xjschool280_resetright(uint16 argc, uint16 *argv); // DVD only
 	// jspit Demo-specific commands
 	void xjatboundary(uint16 argc, uint16 *argv);
 
