@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven_saveload.cpp $
- * $Id: riven_saveload.cpp 52538 2010-09-05 00:48:38Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -102,21 +102,26 @@ bool RivenSaveLoad::loadGame(Common::String filename) {
 	debug(0, "Loading game from \'%s\'", filename.c_str());
 
 	MohawkArchive *mhk = new MohawkArchive();
-	mhk->open(loadFile);
+
+	if (!mhk->open(loadFile)) {
+		warning("Save file is not a Mohawk archive");
+		delete mhk;
+		return false;
+	}
 
 	// First, let's make sure we're using a saved game file from this version of Riven by checking the VERS resource
-	Common::SeekableReadStream *vers = mhk->getRawData(ID_VERS, 1);
+	Common::SeekableReadStream *vers = mhk->getResource(ID_VERS, 1);
 	uint32 saveGameVersion = vers->readUint32BE();
 	delete vers;
 	if ((saveGameVersion == kCDSaveGameVersion && (_vm->getFeatures() & GF_DVD))
 		|| (saveGameVersion == kDVDSaveGameVersion && !(_vm->getFeatures() & GF_DVD))) {
-		warning("Incompatible saved game versions. No support for this yet.");
+		warning("Incompatible saved game versions. No support for this yet");
 		delete mhk;
 		return false;
 	}
 
 	// Now, we'll read in the variable values.
-	Common::SeekableReadStream *vars = mhk->getRawData(ID_VARS, 1);
+	Common::SeekableReadStream *vars = mhk->getResource(ID_VARS, 1);
 	Common::Array<uint32> rawVariables;
 
 	while (!vars->eos()) {
@@ -129,7 +134,7 @@ bool RivenSaveLoad::loadGame(Common::String filename) {
 
 	// Next, we set the variables based on the name found by the index in the VARS resource.
 	// TODO: Merge with code in mohawk.cpp for loading names?
-	Common::SeekableReadStream *names = mhk->getRawData(ID_NAME, 1);
+	Common::SeekableReadStream *names = mhk->getResource(ID_NAME, 1);
 
 	uint16 namesCount = names->readUint16BE();
 	uint16 *stringOffsets = new uint16[namesCount];
@@ -142,7 +147,7 @@ bool RivenSaveLoad::loadGame(Common::String filename) {
 	uint16 stackID = 0;
 	uint16 cardID = 0;
 
-	for (uint32 i = 0; i < rawVariables.size() && i < namesCount && !names->eos(); i++) {
+	for (uint32 i = 0; i < namesCount && !names->eos(); i++) {
 		names->seek(curNamesPos);
 		names->seek(stringOffsets[i], SEEK_CUR);
 
@@ -154,23 +159,30 @@ bool RivenSaveLoad::loadGame(Common::String filename) {
 			c = (char)names->readByte();
 		}
 
-		// TODO: Some versions have two extra variables. However, the saves are
-		// still compatible with other saves of the same version (they come from DVD v1.1).
-		// There are used in the whark number puzzle. I thought jleftpos and jrightpos were
-		// for this purpose.
+		// These are timing variables used with the DVD version of Riven for the whark
+		// puzzle and are not needed at all. See xjschool280_resetleft() and
+		// xjschool280_resetright.
 		if (name == "dropLeftStart" || name == "dropRightStart")
 			continue;
 
-		uint32 *var = _vm->getVar(name);
+		uint32 &var = _vm->_vars[name];
+		name.toLowercase();
 
-		*var = rawVariables[i];
-
-		if (name.equalsIgnoreCase("CurrentStackID"))
+		// Handle any special variables here
+		// WORKAROUND: time variables are reset here for one main reason:
+		// The save does not store any start point for the time, so we don't know the real time.
+		// Because of this, in many cases, the original would just give a 'free' Ytram upon saving
+		// since the time would be used in a new (improper) time frame.
+		if (name.equalsIgnoreCase("CurrentStackID"))                  // Remap to our definitions, store for later
 			stackID = mapOldStackIDToNew(rawVariables[i]);
-		else if (name.equalsIgnoreCase("CurrentCardID"))
+		else if (name.equalsIgnoreCase("CurrentCardID"))              // Store for later
 			cardID = rawVariables[i];
-		else if (name.equalsIgnoreCase("ReturnStackID"))
-			*var = mapOldStackIDToNew(rawVariables[i]);
+		else if (name.equalsIgnoreCase("ReturnStackID") && var != 0) // if 0, the game did not use the variable yet
+			var = mapOldStackIDToNew(rawVariables[i]);
+		else if (name.contains("time"))                               // WORKAROUND: See above
+			var = 0;
+		else                                                          // Otherwise, just store it
+			var = rawVariables[i];
 	}
 
 	_vm->changeToStack(stackID);
@@ -183,7 +195,7 @@ bool RivenSaveLoad::loadGame(Common::String filename) {
 	_vm->_zipModeData.clear();
 
 	// Finally, we load in zip mode data.
-	Common::SeekableReadStream *zips = mhk->getRawData(ID_ZIPS, 1);
+	Common::SeekableReadStream *zips = mhk->getResource(ID_ZIPS, 1);
 	uint16 zipsRecordCount = zips->readUint16BE();
 	for (uint16 i = 0; i < zipsRecordCount; i++) {
 		ZipMode zip;
@@ -212,14 +224,14 @@ Common::MemoryWriteStreamDynamic *RivenSaveLoad::genVERSSection() {
 Common::MemoryWriteStreamDynamic *RivenSaveLoad::genVARSSection() {
 	Common::MemoryWriteStreamDynamic *stream = new Common::MemoryWriteStreamDynamic();
 
-	for (uint32 i = 0; i < _vm->getVarCount(); i++) {
+	for (RivenVariableMap::const_iterator it = _vm->_vars.begin(); it != _vm->_vars.end(); it++) {
 		stream->writeUint32BE(0); // Unknown
 		stream->writeUint32BE(0); // Unknown
 
 		// Remap returnstackid here because we don't actually want to change
 		// our internal returnstackid.
-		uint32 variable = _vm->getGlobalVar(i);
-		if (_vm->getGlobalVarName(i) == "returnstackid")
+		uint32 variable = it->_value;
+		if (it->_key == "returnstackid")
 			variable = mapNewStackIDToOld(variable);
 
 		stream->writeUint32BE(variable);
@@ -231,19 +243,19 @@ Common::MemoryWriteStreamDynamic *RivenSaveLoad::genVARSSection() {
 Common::MemoryWriteStreamDynamic *RivenSaveLoad::genNAMESection() {
 	Common::MemoryWriteStreamDynamic *stream = new Common::MemoryWriteStreamDynamic();
 
-	stream->writeUint16BE((uint16)_vm->getVarCount());
+	stream->writeUint16BE(_vm->_vars.size());
 
 	uint16 curPos = 0;
-	for (uint16 i = 0; i < _vm->getVarCount(); i++) {
+	for (RivenVariableMap::const_iterator it = _vm->_vars.begin(); it != _vm->_vars.end(); it++) {
 		stream->writeUint16BE(curPos);
-		curPos += _vm->getGlobalVarName(i).size() + 1;
+		curPos += it->_key.size() + 1;
 	}
 
-	for (uint16 i = 0; i < _vm->getVarCount(); i++)
+	for (uint16 i = 0; i < _vm->_vars.size(); i++)
 		stream->writeUint16BE(i);
 
-	for (uint16 i = 0; i < _vm->getVarCount(); i++) {
-		stream->write(_vm->getGlobalVarName(i).c_str(), _vm->getGlobalVarName(i).size());
+	for (RivenVariableMap::const_iterator it = _vm->_vars.begin(); it != _vm->_vars.end(); it++) {
+		stream->write(it->_key.c_str(), it->_key.size());
 		stream->writeByte(0);
 	}
 
@@ -272,8 +284,8 @@ bool RivenSaveLoad::saveGame(Common::String filename) {
 		filename += ".rvn";
 
 	// Convert class variables to variable numbers
-	*_vm->getVar("currentstackid") = mapNewStackIDToOld(_vm->getCurStack());
-	*_vm->getVar("currentcardid") = _vm->getCurCard();
+	_vm->_vars["currentstackid"] = mapNewStackIDToOld(_vm->getCurStack());
+	_vm->_vars["currentcardid"] = _vm->getCurCard();
 
 	Common::OutSaveFile *saveFile = _saveFileMan->openForSaving(filename);
 	if (!saveFile)
