@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven_saveload.h $
- * $Id: riven_saveload.h 50333 2010-06-26 17:21:50Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "common/savefile.h"
 #include "common/str.h"
+#include "common/memstream.h"
 
 namespace Mohawk {
 
