@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven_scripts.h $
- * $Id: riven_scripts.h 52482 2010-09-01 13:28:12Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,12 +28,14 @@
 
 #include "common/str-array.h"
 #include "common/ptr.h"
+#include "common/textconsole.h"
 
 class MohawkEngine_Riven;
 
 #define DECLARE_OPCODE(x) void x(uint16 op, uint16 argc, uint16 *argv)
 
 namespace Mohawk {
+
 // Script Types
 enum {
 	kMouseDownScript = 0,
@@ -46,7 +48,9 @@ enum {
 	kCardLoadScript = 6,
 	kCardLeaveScript = 7,
 	kCardOpenScript = 9,
-	kCardUpdateScript = 10
+	kCardUpdateScript = 10,
+
+	kStoredOpcodeScript // This is ScummVM-only to denote the script from a storeMovieOpcode() call
 };
 
 class RivenScript;
@@ -57,7 +61,7 @@ public:
 	~RivenScript();
 
 	void runScript();
-	void dumpScript(Common::StringArray varNames, Common::StringArray xNames, byte tabs);
+	void dumpScript(const Common::StringArray &varNames, const Common::StringArray &xNames, byte tabs);
 	uint16 getScriptType() { return _scriptType; }
 	uint16 getParentStack() { return _parentStack; }
 	uint16 getParentCard() { return _parentCard; }
@@ -80,7 +84,7 @@ private:
 	uint16 _scriptType, _parentStack, _parentCard;
 	bool _isRunning, _continueRunning;
 
-	void dumpCommands(Common::StringArray varNames, Common::StringArray xNames, byte tabs);
+	void dumpCommands(const Common::StringArray &varNames, const Common::StringArray &xNames, byte tabs);
 	void processCommands(bool runCommands);
 
 	static uint32 calculateCommandSize(Common::SeekableReadStream *script);
@@ -96,7 +100,7 @@ private:
 	DECLARE_OPCODE(mohawkSwitch);
 	DECLARE_OPCODE(enableHotspot);
 	DECLARE_OPCODE(disableHotspot);
-	DECLARE_OPCODE(clearSLST);
+	DECLARE_OPCODE(stopSound);
 	DECLARE_OPCODE(changeCursor);
 	DECLARE_OPCODE(delay);
 	DECLARE_OPCODE(runExternalCommand);
@@ -109,12 +113,12 @@ private:
 	DECLARE_OPCODE(disableMovie);
 	DECLARE_OPCODE(disableAllMovies);
 	DECLARE_OPCODE(enableMovie);
+	DECLARE_OPCODE(playMovieBlocking);
 	DECLARE_OPCODE(playMovie);
-	DECLARE_OPCODE(playMovieBg);
 	DECLARE_OPCODE(stopMovie);
 	DECLARE_OPCODE(unk_36);
 	DECLARE_OPCODE(fadeAmbientSounds);
-	DECLARE_OPCODE(complexPlayMovie);
+	DECLARE_OPCODE(storeMovieOpcode);
 	DECLARE_OPCODE(activatePLST);
 	DECLARE_OPCODE(activateSLST);
 	DECLARE_OPCODE(activateMLSTAndPlay);
@@ -134,10 +138,22 @@ public:
 	RivenScriptList readScripts(Common::SeekableReadStream *stream, bool garbageCollect = true);
 	void stopAllScripts();
 
+	struct StoredMovieOpcode {
+		RivenScript *script;
+		uint32 time;
+		uint16 id;
+	};
+
+	void setStoredMovieOpcode(const StoredMovieOpcode &op);
+	void runStoredMovieOpcode(uint16 id);
+	void clearStoredMovieOpcode();
+
 private:
 	void unloadUnusedScripts();
 	RivenScriptList _currentScripts;
 	MohawkEngine_Riven *_vm;
+
+	StoredMovieOpcode _storedMovieOpcode;
 };
 
 } // End of namespace Mohawk
