@@ -18,48 +18,51 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/sound.cpp $
- * $Id: sound.cpp 52643 2010-09-08 20:50:56Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "mohawk/sound.h"
 
+#include "common/debug.h"
+#include "common/system.h"
 #include "common/util.h"
+#include "common/textconsole.h"
 
-#include "sound/musicplugin.h"
-#include "sound/audiostream.h"
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/wave.h"
+#include "audio/musicplugin.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/wave.h"
 
 namespace Mohawk {
 
 Sound::Sound(MohawkEngine* vm) : _vm(vm) {
 	_midiDriver = NULL;
 	_midiParser = NULL;
-
-	for (uint32 i = 0; i < _handles.size(); i++) {
-		_handles[i].handle = Audio::SoundHandle();
-		_handles[i].type = kFreeHandle;
-	}
-
+	_midiData = NULL;
+	_mystBackgroundSound.type = kFreeHandle;
 	initMidi();
 }
 
 Sound::~Sound() {
 	stopSound();
 	stopAllSLST();
+	stopBackgroundMyst();
+
+	if (_midiParser) {
+		_midiParser->unloadMusic();
+		delete _midiParser;
+	}
 
 	if (_midiDriver) {
 		_midiDriver->close();
 		delete _midiDriver;
 	}
 
-	if (_midiParser) {
-		_midiParser->unloadMusic();
-		delete _midiParser;
-	}
+	if (_midiData)
+		delete[] _midiData;
 }
 
 void Sound::initMidi() {
@@ -76,43 +79,46 @@ void Sound::initMidi() {
 	_midiParser->setTimerRate(_midiDriver->getBaseTempo());
 }
 
-Audio::SoundHandle *Sound::playSound(uint16 id, byte volume, bool loop) {
-	debug (0, "Playing sound %d", id);
-
-	SndHandle *handle = getHandle();
-	handle->type = kUsedHandle;
-
+Audio::AudioStream *Sound::makeAudioStream(uint16 id, CueList *cueList) {
 	Audio::AudioStream *audStream = NULL;
 
 	switch (_vm->getGameType()) {
 	case GType_MYST:
-		if (_vm->getFeatures() & GF_ME) {
-			// Myst ME is a bit more efficient with sound storage than Myst
-			// Myst has lots of sounds repeated. To overcome this, Myst ME
-			// has MJMP resources which provide a link to the actual MSND
-			// resource we're looking for. This saves a lot of space from
-			// repeated data.
-			if (_vm->hasResource(ID_MJMP, id)) {
-				Common::SeekableReadStream *mjmpStream = _vm->getRawData(ID_MJMP, id);
-				id = mjmpStream->readUint16LE();
-				delete mjmpStream;
-			}
-
-			audStream = Audio::makeWAVStream(_vm->getRawData(ID_MSND, id), DisposeAfterUse::YES);
-		} else
-			audStream = makeMohawkWaveStream(_vm->getRawData(ID_MSND, id));
+		if (_vm->getFeatures() & GF_ME)
+			audStream = Audio::makeWAVStream(_vm->getResource(ID_MSND, convertMystID(id)), DisposeAfterUse::YES);
+		else
+			audStream = makeMohawkWaveStream(_vm->getResource(ID_MSND, id));
 		break;
 	case GType_ZOOMBINI:
-		audStream = makeMohawkWaveStream(_vm->getRawData(ID_SND, id));
+		audStream = makeMohawkWaveStream(_vm->getResource(ID_SND, id));
 		break;
 	case GType_LIVINGBOOKSV1:
-		audStream = makeOldMohawkWaveStream(_vm->getRawData(ID_WAV, id));
+		audStream = makeLivingBooksWaveStream_v1(_vm->getResource(ID_WAV, id));
 		break;
+	case GType_LIVINGBOOKSV2:
+		if (_vm->getPlatform() == Common::kPlatformMacintosh) {
+			audStream = makeLivingBooksWaveStream_v1(_vm->getResource(ID_WAV, id));
+			break;
+		}
+		// fall through
 	default:
-		audStream = makeMohawkWaveStream(_vm->getRawData(ID_TWAV, id));
+		audStream = makeMohawkWaveStream(_vm->getResource(ID_TWAV, id), cueList);
 	}
 
+	return audStream;
+}
+
+Audio::SoundHandle *Sound::playSound(uint16 id, byte volume, bool loop, CueList *cueList) {
+	debug (0, "Playing sound %d", id);
+
+	Audio::AudioStream *audStream = makeAudioStream(id, cueList);
+
 	if (audStream) {
+		SndHandle *handle = getHandle();
+		handle->type = kUsedHandle;
+		handle->id = id;
+		handle->samplesPerSecond = audStream->getRate();
+
 		// Set the stream to loop here if it's requested
 		if (loop)
 			audStream = Audio::makeLoopingAudioStream((Audio::RewindableAudioStream *)audStream, 0);
@@ -124,6 +130,24 @@ Audio::SoundHandle *Sound::playSound(uint16 id, byte volume, bool loop) {
 	return NULL;
 }
 
+Audio::SoundHandle *Sound::replaceSoundMyst(uint16 id, byte volume, bool loop) {
+	debug (0, "Replacing sound %d", id);
+
+	// TODO: The original engine does fading
+
+	Common::String name = _vm->getResourceName(ID_MSND, convertMystID(id));
+
+	// Check if sound is already playing
+	for (uint32 i = 0; i < _handles.size(); i++)
+		if (_handles[i].type == kUsedHandle
+				&& _vm->_mixer->isSoundHandleActive(_handles[i].handle)
+				&& name.equals(_vm->getResourceName(ID_MSND, convertMystID(_handles[i].id))))
+			return &_handles[i].handle;
+
+	stopSound();
+	return playSound(id, volume, loop);
+}
+
 void Sound::playSoundBlocking(uint16 id, byte volume) {
 	Audio::SoundHandle *handle = playSound(id, volume);
 
@@ -141,7 +165,10 @@ void Sound::playMidi(uint16 id) {
 	assert(_midiDriver && _midiParser);
 
 	_midiParser->unloadMusic();
-	Common::SeekableReadStream *midi = _vm->getRawData(ID_TMID, id);
+	if (_midiData)
+		delete[] _midiData;
+
+	Common::SeekableReadStream *midi = _vm->getResource(ID_TMID, id);
 
 	idTag = midi->readUint32BE();
 	assert(idTag == ID_MHWK);
@@ -149,10 +176,10 @@ void Sound::playMidi(uint16 id) {
 	idTag = midi->readUint32BE();
 	assert(idTag == ID_MIDI);
 
-	byte *midiData = (byte *)malloc(midi->size() - 12); // Enough to cover MThd/Prg#/MTrk
+	_midiData = new byte[midi->size() - 12]; // Enough to cover MThd/Prg#/MTrk
 
 	// Read the MThd Data
-	midi->read(midiData, 14);
+	midi->read(_midiData, 14);
 
 	// TODO: Load patches from the Prg# section... skip it for now.
 	idTag = midi->readUint32BE();
@@ -161,23 +188,27 @@ void Sound::playMidi(uint16 id) {
 
 	// Read the MTrk Data
 	uint32 mtrkSize = midi->size() - midi->pos();
-	midi->read(midiData + 14, mtrkSize);
+	midi->read(_midiData + 14, mtrkSize);
 
 	delete midi;
 
 	// Now, play it :)
-	if (!_midiParser->loadMusic(midiData, 14 + mtrkSize))
+	if (!_midiParser->loadMusic(_midiData, 14 + mtrkSize))
 		error ("Could not play MIDI music from tMID %04x\n", id);
 
 	_midiDriver->setTimerCallback(_midiParser, MidiParser::timerCallback);
 }
 
+void Sound::stopMidi() {
+	_midiParser->unloadMusic();
+}
+
 byte Sound::convertRivenVolume(uint16 volume) {
 	return (volume == 256) ? 255 : volume;
 }
 
 void Sound::playSLST(uint16 index, uint16 card) {
-	Common::SeekableReadStream *slstStream = _vm->getRawData(ID_SLST, card);
+	Common::SeekableReadStream *slstStream = _vm->getResource(ID_SLST, card);
 	SLSTRecord slstRecord;
 	uint16 recordCount = slstStream->readUint16BE();
 
@@ -237,8 +268,8 @@ void Sound::playSLST(uint16 index, uint16 card) {
 
 	delete slstStream;
 
-	// No matching records, assume we need to stop all SLST's
-	stopAllSLST();
+	// If we have no matching entries, we do nothing and just let
+	// the previous ambient sounds continue.
 }
 
 void Sound::playSLST(SLSTRecord slstRecord) {
@@ -269,8 +300,9 @@ void Sound::playSLST(SLSTRecord slstRecord) {
 	}
 }
 
-void Sound::stopAllSLST() {
+void Sound::stopAllSLST(bool fade) {
 	for (uint16 i = 0; i < _currentSLSTSounds.size(); i++) {
+		// TODO: Fade out, if requested
 		_vm->_mixer->stopHandle(*_currentSLSTSounds[i].handle);
 		delete _currentSLSTSounds[i].handle;
 	}
@@ -292,7 +324,7 @@ void Sound::playSLSTSound(uint16 id, bool fade, bool loop, uint16 volume, int16
 	sndHandle.id = id;
 	_currentSLSTSounds.push_back(sndHandle);
 
-	Audio::AudioStream *audStream = makeMohawkWaveStream(_vm->getRawData(ID_TWAV, id));
+	Audio::AudioStream *audStream = makeMohawkWaveStream(_vm->getResource(ID_TWAV, id));
 
 	// Loop here if necessary
 	if (loop)
@@ -304,7 +336,7 @@ void Sound::playSLSTSound(uint16 id, bool fade, bool loop, uint16 volume, int16
 }
 
 void Sound::stopSLSTSound(uint16 index, bool fade) {
-	// TODO: Fade out, mixer needs to be extended to get volume on a handle
+	// TODO: Fade out, if requested
 	_vm->_mixer->stopHandle(*_currentSLSTSounds[index].handle);
 	delete _currentSLSTSounds[index].handle;
 	_currentSLSTSounds.remove_at(index);
@@ -320,83 +352,92 @@ void Sound::resumeSLST() {
 		_vm->_mixer->pauseHandle(*_currentSLSTSounds[i].handle, false);
 }
 
-Audio::AudioStream *Sound::makeMohawkWaveStream(Common::SeekableReadStream *stream) {
+Audio::AudioStream *Sound::makeMohawkWaveStream(Common::SeekableReadStream *stream, CueList *cueList) {
 	uint32 tag = 0;
-	ADPC_Chunk adpc;
-	Cue_Chunk cue;
-	Data_Chunk data_chunk;
+	ADPCMStatus adpcmStatus;
+	DataChunk dataChunk;
 	uint32 dataSize = 0;
 
-	memset(&data_chunk, 0, sizeof(Data_Chunk));
+	memset(&dataChunk, 0, sizeof(DataChunk));
 
 	if (stream->readUint32BE() != ID_MHWK) // MHWK tag again
-		error ("Could not find tag \'MHWK\'");
+		error ("Could not find tag 'MHWK'");
 
 	stream->readUint32BE(); // Skip size
 
 	if (stream->readUint32BE() != ID_WAVE)
-		error ("Could not find tag \'WAVE\'");
+		error ("Could not find tag 'WAVE'");
 
-	while (!data_chunk.audio_data) {
+	while (!dataChunk.audioData) {
 		tag = stream->readUint32BE();
 
 		switch (tag) {
 		case ID_ADPC:
 			debug(2, "Found Tag ADPC");
-			// Riven ADPCM Sound Only
-			// NOTE: We completely ignore the contents of this chunk on purpose. In the original
-			// engine this held the status for the ADPCM decoder, while in ScummVM we store this data
-			// in the ADPCM decoder itself. The code is here for reference only.
+			// ADPCM Sound Only
+			//
+			// This is useful for seeking in the stream, and is actually quite brilliant
+			// considering some of the other things Broderbund did with the engine.
+			// Only Riven and CSTime are known to use ADPCM audio and only CSTime
+			// actually requires this for seeking. On the other hand, it may be interesting
+			// to look at that one Riven sample that uses the cue points.
+			//
+			// Basically, the sample frame from the cue list is looked up here and then
+			// sets the starting sample and step index at the point specified. Quite
+			// an elegant/efficient system, really.
 
-			adpc.size = stream->readUint32BE();
-			adpc.itemCount = stream->readUint16BE();
-			adpc.channels = stream->readUint16BE();
-			adpc.statusItems = new ADPC_Chunk::StatusItem[adpc.itemCount];
+			adpcmStatus.size = stream->readUint32BE();
+			adpcmStatus.itemCount = stream->readUint16BE();
+			adpcmStatus.channels = stream->readUint16BE();
+			adpcmStatus.statusItems = new ADPCMStatus::StatusItem[adpcmStatus.itemCount];
 
-			assert(adpc.channels <= 2);
+			assert(adpcmStatus.channels <= 2);
 
-			for (uint16 i = 0; i < adpc.itemCount; i++) {
-				adpc.statusItems[i].sampleFrame = stream->readUint32BE();
+			for (uint16 i = 0; i < adpcmStatus.itemCount; i++) {
+				adpcmStatus.statusItems[i].sampleFrame = stream->readUint32BE();
 
-				for (uint16 j = 0; j < adpc.channels; j++)
-					adpc.statusItems[i].channelStatus[j] = stream->readUint32BE();
+				for (uint16 j = 0; j < adpcmStatus.channels; j++) {
+					adpcmStatus.statusItems[i].channelStatus[j].last = stream->readSint16BE();
+					adpcmStatus.statusItems[i].channelStatus[j].stepIndex = stream->readUint16BE();
+				}
 			}
 
-			delete[] adpc.statusItems;
+			// TODO: Actually use this chunk. For now, just delete the status items...
+			delete[] adpcmStatus.statusItems;
 			break;
 		case ID_CUE:
 			debug(2, "Found Tag Cue#");
-			// I have not tested this with Myst, but the one Riven test-case,
-			// pspit tWAV 3, has two cue points: "Beg Loop" and "End Loop".
-			// So, my guess is that a cue chunk just holds where to loop the
-			// sound. Some cue chunks even have no point count (such as
-			// Myst's intro.dat MSND 2. So, my theory is that a cue chunk
-			// always represents a loop, and if there is a point count, that
-			// represents the points from which to loop.
-			//
-			// This theory is probably not entirely true anymore. I've found
-			// that the values (which were previously unknown) in the DATA
-			// chunk are for looping. Since it was only used in Myst, it was
-			// always 10 0's, Tito just thought it was useless. I'm still not
-			// sure what purpose this has.
+			// Cues are used for animation sync. There are a couple in Myst and
+			// Riven but are not used there at all.
 
-			cue.size = stream->readUint32BE();
-			cue.point_count = stream->readUint16BE();
+			if (!cueList) {
+				uint32 size = stream->readUint32BE();
+				stream->skip(size);
+				break;
+			}
 
-			if (cue.point_count == 0)
-				debug (2, "Cue# chunk found with no points!");
+			cueList->size = stream->readUint32BE();
+			cueList->pointCount = stream->readUint16BE();
+
+			if (cueList->pointCount == 0)
+				debug(2, "Cue# chunk found with no points!");
 			else
-				debug (2, "Cue# chunk found with %d point(s)!", cue.point_count);
+				debug(2, "Cue# chunk found with %d point(s)!", cueList->pointCount);
 
-			for (uint16 i = 0; i < cue.point_count; i++) {
-				cue.cueList[i].position = stream->readUint32BE();
-				cue.cueList[i].length = stream->readByte();
-				for (byte j = 0; j < cue.cueList[i].length; j++)
-					cue.cueList[i].name += stream->readByte();
-				// Realign to uint16 boundaries...
-				if (!(cue.cueList[i].length & 1))
+			cueList->points.resize(cueList->pointCount);
+			for (uint16 i = 0; i < cueList->pointCount; i++) {
+				cueList->points[i].sampleFrame = stream->readUint32BE();
+
+				byte nameLength = stream->readByte();
+				cueList->points[i].name.clear();
+				for (byte j = 0; j < nameLength; j++)
+					cueList->points[i].name += stream->readByte();
+
+				// Realign to an even boundary
+				if (!(nameLength & 1))
 					stream->readByte();
-				debug (3, "Cue# chunk point %d: %s", i, cue.cueList[i].name.c_str());
+
+				debug (3, "Cue# chunk point %d (frame %d): %s", i, cueList->points[i].sampleFrame, cueList->points[i].name.c_str());
 			}
 			break;
 		case ID_DATA:
@@ -404,25 +445,25 @@ Audio::AudioStream *Sound::makeMohawkWaveStream(Common::SeekableReadStream *stre
 			// We subtract 20 from the actual chunk size, which is the total size
 			// of the chunk's header
 			dataSize = stream->readUint32BE() - 20;
-			data_chunk.sample_rate = stream->readUint16BE();
-			data_chunk.sample_count = stream->readUint32BE();
-			data_chunk.bitsPerSample = stream->readByte();
-			data_chunk.channels = stream->readByte();
-			data_chunk.encoding = stream->readUint16BE();
-			data_chunk.loop = stream->readUint16BE();
-			data_chunk.loopStart = stream->readUint32BE();
-			data_chunk.loopEnd = stream->readUint32BE();
+			dataChunk.sampleRate = stream->readUint16BE();
+			dataChunk.sampleCount = stream->readUint32BE();
+			dataChunk.bitsPerSample = stream->readByte();
+			dataChunk.channels = stream->readByte();
+			dataChunk.encoding = stream->readUint16BE();
+			dataChunk.loopCount = stream->readUint16BE();
+			dataChunk.loopStart = stream->readUint32BE();
+			dataChunk.loopEnd = stream->readUint32BE();
 
-			// NOTE: We currently ignore all of the loop parameters here. Myst uses the loop
-			// variable but the loopStart and loopEnd are always 0 and the size of the sample.
-			// Myst ME doesn't use the Mohawk Sound format and just standard WAVE files and
-			// therefore does not contain any of this metadata and we have to specify whether
-			// or not to loop elsewhere.
+			// NOTE: We currently ignore all of the loop parameters here. Myst uses the
+			// loopCount variable but the loopStart and loopEnd are always 0 and the size of
+			// the sample. Myst ME doesn't use the Mohawk Sound format and just standard WAVE
+			// files and therefore does not contain any of this metadata and we have to specify
+			// whether or not to loop elsewhere.
 
-			data_chunk.audio_data = stream->readStream(dataSize);
+			dataChunk.audioData = stream->readStream(dataSize);
 			break;
 		default:
-			error ("Unknown tag found in 'tWAV' chunk -- \'%s\'", tag2str(tag));
+			error ("Unknown tag found in 'tWAV' chunk -- '%s'", tag2str(tag));
 		}
 	}
 
@@ -432,41 +473,42 @@ Audio::AudioStream *Sound::makeMohawkWaveStream(Common::SeekableReadStream *stre
 	// The sound in Myst uses raw unsigned 8-bit data
 	// The sound in the CD version of Riven is encoded in Intel DVI ADPCM
 	// The sound in the DVD version of Riven is encoded in MPEG-2 Layer II or Intel DVI ADPCM
-	if (data_chunk.encoding == kCodecRaw) {
+	if (dataChunk.encoding == kCodecRaw) {
 		byte flags = Audio::FLAG_UNSIGNED;
 
-		if (data_chunk.channels == 2)
+		if (dataChunk.channels == 2)
 			flags |= Audio::FLAG_STEREO;
 
-		return Audio::makeRawStream(data_chunk.audio_data, data_chunk.sample_rate, flags);
-	} else if (data_chunk.encoding == kCodecADPCM) {
-		uint32 blockAlign = data_chunk.channels * data_chunk.bitsPerSample / 8;
-		return Audio::makeADPCMStream(data_chunk.audio_data, DisposeAfterUse::YES, dataSize, Audio::kADPCMIma, data_chunk.sample_rate, data_chunk.channels, blockAlign);
-	} else if (data_chunk.encoding == kCodecMPEG2) {
+		return Audio::makeRawStream(dataChunk.audioData, dataChunk.sampleRate, flags);
+	} else if (dataChunk.encoding == kCodecADPCM) {
+		uint32 blockAlign = dataChunk.channels * dataChunk.bitsPerSample / 8;
+		return Audio::makeADPCMStream(dataChunk.audioData, DisposeAfterUse::YES, dataSize, Audio::kADPCMDVI, dataChunk.sampleRate, dataChunk.channels, blockAlign);
+	} else if (dataChunk.encoding == kCodecMPEG2) {
 #ifdef USE_MAD
-		return Audio::makeMP3Stream(data_chunk.audio_data, DisposeAfterUse::YES);
+		return Audio::makeMP3Stream(dataChunk.audioData, DisposeAfterUse::YES);
 #else
 		warning ("MAD library not included - unable to play MP2 audio");
 #endif
 	} else {
-		error ("Unknown Mohawk WAVE encoding %d", data_chunk.encoding);
+		error ("Unknown Mohawk WAVE encoding %d", dataChunk.encoding);
 	}
 
 	return NULL;
 }
 
-Audio::AudioStream *Sound::makeOldMohawkWaveStream(Common::SeekableReadStream *stream) {
+Audio::AudioStream *Sound::makeLivingBooksWaveStream_v1(Common::SeekableReadStream *stream) {
 	uint16 header = stream->readUint16BE();
 	uint16 rate = 0;
 	uint32 size = 0;
 
 	if (header == 'Wv') { // Big Endian
 		rate = stream->readUint16BE();
-		stream->skip(10); // Loop chunk, like the newer format?
+		stream->skip(10); // Unknown
 		size = stream->readUint32BE();
 	} else if (header == 'vW') { // Little Endian
+		stream->readUint16LE(); // Unknown
 		rate = stream->readUint16LE();
-		stream->skip(10); // Loop chunk, like the newer format?
+		stream->skip(8); // Unknown
 		size = stream->readUint32LE();
 	} else
 		error("Could not find Old Mohawk Sound header");
@@ -484,6 +526,7 @@ SndHandle *Sound::getHandle() {
 
 		if (!_vm->_mixer->isSoundHandleActive(_handles[i].handle)) {
 			_handles[i].type = kFreeHandle;
+			_handles[i].id = 0;
 			return &_handles[i];
 		}
 	}
@@ -492,6 +535,7 @@ SndHandle *Sound::getHandle() {
 	SndHandle handle;
 	handle.handle = Audio::SoundHandle();
 	handle.type = kFreeHandle;
+	handle.id = 0;
 	_handles.push_back(handle);
 
 	return &_handles[_handles.size() - 1];
@@ -502,6 +546,16 @@ void Sound::stopSound() {
 		if (_handles[i].type == kUsedHandle) {
 			_vm->_mixer->stopHandle(_handles[i].handle);
 			_handles[i].type = kFreeHandle;
+			_handles[i].id = 0;
+		}
+}
+
+void Sound::stopSound(uint16 id) {
+	for (uint32 i = 0; i < _handles.size(); i++)
+		if (_handles[i].type == kUsedHandle && _handles[i].id == id) {
+			_vm->_mixer->stopHandle(_handles[i].handle);
+			_handles[i].type = kFreeHandle;
+			_handles[i].id = 0;
 		}
 }
 
@@ -517,4 +571,101 @@ void Sound::resumeSound() {
 			_vm->_mixer->pauseHandle(_handles[i].handle, false);
 }
 
+bool Sound::isPlaying(uint16 id) {
+	for (uint32 i = 0; i < _handles.size(); i++)
+		if (_handles[i].type == kUsedHandle && _handles[i].id == id)
+			return _vm->_mixer->isSoundHandleActive(_handles[i].handle);
+
+	return false;
+}
+
+bool Sound::isPlaying() {
+	for (uint32 i = 0; i < _handles.size(); i++)
+		if (_handles[i].type == kUsedHandle)
+			if (_vm->_mixer->isSoundHandleActive(_handles[i].handle))
+				return true;
+
+	return false;
+}
+
+uint Sound::getNumSamplesPlayed(uint16 id) {
+	for (uint32 i = 0; i < _handles.size(); i++)
+		if (_handles[i].type == kUsedHandle && _handles[i].id == id) {
+			return (_vm->_mixer->getSoundElapsedTime(_handles[i].handle) * _handles[i].samplesPerSecond) / 1000;
+		}
+
+	return 0;
+}
+
+uint16 Sound::convertMystID(uint16 id) {
+	// Myst ME is a bit more efficient with sound storage than Myst
+	// Myst has lots of sounds repeated. To overcome this, Myst ME
+	// has MJMP resources which provide a link to the actual MSND
+	// resource we're looking for. This saves a lot of space from
+	// repeated data.
+	if (_vm->hasResource(ID_MJMP, id)) {
+		Common::SeekableReadStream *mjmpStream = _vm->getResource(ID_MJMP, id);
+		id = mjmpStream->readUint16LE();
+		delete mjmpStream;
+	}
+
+	return id;
+}
+
+Audio::SoundHandle *Sound::replaceBackgroundMyst(uint16 id, uint16 volume) {
+	debug(0, "Replacing background sound with %d", id);
+
+	// TODO: The original engine does fading
+
+	Common::String name = _vm->getResourceName(ID_MSND, convertMystID(id));
+
+	// Check if sound is already playing
+	if (_mystBackgroundSound.type == kUsedHandle && _vm->_mixer->isSoundHandleActive(_mystBackgroundSound.handle)
+			&& name.equals(_vm->getResourceName(ID_MSND, convertMystID(_mystBackgroundSound.id))))
+		return &_mystBackgroundSound.handle;
+
+	// Stop old background sound
+	stopBackgroundMyst();
+
+	// Play new sound
+	Audio::AudioStream *audStream = makeAudioStream(id);
+
+	if (audStream) {
+		_mystBackgroundSound.type = kUsedHandle;
+		_mystBackgroundSound.id = id;
+		_mystBackgroundSound.samplesPerSecond = audStream->getRate();
+
+		// Set the stream to loop
+		audStream = Audio::makeLoopingAudioStream((Audio::RewindableAudioStream *)audStream, 0);
+
+		_vm->_mixer->playStream(Audio::Mixer::kPlainSoundType, &_mystBackgroundSound.handle, audStream, -1, volume >> 8);
+		return &_mystBackgroundSound.handle;
+	}
+
+	return NULL;
+}
+
+void Sound::stopBackgroundMyst() {
+	if (_mystBackgroundSound.type == kUsedHandle) {
+		_vm->_mixer->stopHandle(_mystBackgroundSound.handle);
+		_mystBackgroundSound.type = kFreeHandle;
+		_mystBackgroundSound.id = 0;
+	}
+}
+
+void Sound::pauseBackgroundMyst() {
+	if (_mystBackgroundSound.type == kUsedHandle)
+		_vm->_mixer->pauseHandle(_mystBackgroundSound.handle, true);
+}
+
+void Sound::resumeBackgroundMyst() {
+	if (_mystBackgroundSound.type == kUsedHandle)
+		_vm->_mixer->pauseHandle(_mystBackgroundSound.handle, false);
+}
+
+void Sound::changeBackgroundVolumeMyst(uint16 vol) {
+	if (_mystBackgroundSound.type == kUsedHandle)
+		_vm->_mixer->setChannelVolume(_mystBackgroundSound.handle, vol >> 8);
+}
+
 } // End of namespace Mohawk
