@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/debug.cpp $
- * $Id: debug.cpp 49141 2010-05-22 15:56:27Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -47,16 +47,18 @@ Debugger::Debugger(Parallaction *vm)
 	DCmd_Register("locations",	WRAP_METHOD(Debugger, Cmd_Locations));
 	DCmd_Register("gfxobjects",	WRAP_METHOD(Debugger, Cmd_GfxObjects));
 	DCmd_Register("programs",	WRAP_METHOD(Debugger, Cmd_Programs));
-
+	DCmd_Register("showmouse",	WRAP_METHOD(Debugger, Cmd_ShowMouse));
 }
 
 
 void Debugger::preEnter() {
 	_mouseState = _vm->_input->getMouseState();
+	_vm->pauseEngine(true);
 }
 
 
 void Debugger::postEnter() {
+	_vm->pauseEngine(false);
 	_vm->_input->setMouseState(_mouseState);
 	_vm->_input->setArrowCursor();	// unselects the active item, if any
 }
@@ -320,4 +322,9 @@ bool Debugger::Cmd_Programs(int argc, const char** argv) {
 	return true;
 }
 
+bool Debugger::Cmd_ShowMouse(int argc, const char** argv) {
+	_mouseState = MOUSE_ENABLED_SHOW;
+	return true;
+}
+
 } // namespace Parallaction
