@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/detection.cpp $
- * $Id: detection.cpp 49788 2010-06-15 10:59:23Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "common/config-manager.h"
 #include "engines/advancedDetector.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "parallaction/parallaction.h"
 
@@ -325,7 +326,7 @@ int ParallactionMetaEngine::getMaximumSaveSlot() const { return 99; }
 
 void ParallactionMetaEngine::removeSaveState(const char *target, int slot) const {
 	Common::String filename = ConfMan.getDomain(target)->getVal("gameid");
-	filename += Common::String::printf(".0%02d", slot);
+	filename += Common::String::format(".0%02d", slot);
 
 	g_system->getSavefileManager()->removeSavefile(filename);
 }
