@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/disk.h $
- * $Id: disk.h 48936 2010-05-04 12:00:16Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,14 +29,20 @@
 #define PATH_LEN 200
 
 #include "common/archive.h"
+#include "common/str.h"
 
-#include "graphics/surface.h"
 #include "graphics/iff.h"
 
 namespace Common {
-	class FSDirectory;
+class FSDirectory;
+class ReadStream;
+class SeekableReadStream;
+struct IFFChunk;
 }
 
+namespace Graphics {
+struct Surface;
+}
 
 namespace Parallaction {
 
@@ -185,8 +191,8 @@ protected:
 	void unpackBitmap(byte *dst, byte *src, uint16 numFrames, uint16 bytesPerPlane, uint16 height);
 	Common::SeekableReadStream *tryOpenFile(const char* name);
 	Font *createFont(const char *name, Common::SeekableReadStream &stream);
-	void loadMask(BackgroundInfo& info, const char *name);
-	void loadPath(BackgroundInfo& info, const char *name);
+	void loadMask_internal(BackgroundInfo& info, const char *name);
+	void loadPath_internal(BackgroundInfo& info, const char *name);
 	void loadBackground(BackgroundInfo& info, const char *name);
 	void buildMask(byte* buf);
 
