@@ -18,13 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/disk_ns.cpp $
- * $Id: disk_ns.cpp 48936 2010-05-04 12:00:16Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/config-manager.h"
 #include "common/fs.h"
+#include "common/memstream.h"
+#include "common/substream.h"
+#include "common/textconsole.h"
 #include "parallaction/parser.h"
 #include "parallaction/parallaction.h"
 
@@ -89,7 +92,7 @@ NSArchive::NSArchive(Common::SeekableReadStream *stream, Common::Platform platfo
 		if (features & GF_DEMO) {
 			isSmallArchive = stream->size() == SIZEOF_SMALL_ARCHIVE;
 		} else if (features & GF_LANG_MULT) {
-			isSmallArchive = (stream->readUint32BE() != MKID_BE('NDOS'));
+			isSmallArchive = (stream->readUint32BE() != MKTAG('N','D','O','S'));
 		}
 	}
 
@@ -799,7 +802,7 @@ void AmigaDisk_ns::unpackBitmap(byte *dst, byte *src, uint16 numFrames, uint16 b
 	uint16 planeSize = bytesPerPlane * height;
 
 	for (uint32 i = 0; i < numFrames; i++) {
-		if (READ_BE_UINT32(src) == MKID_BE('DLTA')) {
+		if (READ_BE_UINT32(src) == MKTAG('D','L','T','A')) {
 
 			uint size = READ_BE_UINT32(src + 4);
 
@@ -852,6 +855,7 @@ GfxObj* AmigaDisk_ns::loadStatic(const char* name) {
 Common::SeekableReadStream *AmigaDisk_ns::tryOpenFile(const char* name) {
 	debugC(3, kDebugDisk, "AmigaDisk_ns::tryOpenFile(%s)", name);
 
+	PowerPackerStream *ret;
 	Common::SeekableReadStream *stream = _sset.createReadStreamForMember(name);
 	if (stream)
 		return stream;
@@ -859,13 +863,19 @@ Common::SeekableReadStream *AmigaDisk_ns::tryOpenFile(const char* name) {
 	char path[PATH_LEN];
 	sprintf(path, "%s.pp", name);
 	stream = _sset.createReadStreamForMember(path);
-	if (stream)
-		return new PowerPackerStream(*stream);
+	if (stream) {
+		ret = new PowerPackerStream(*stream);
+		delete stream;
+		return ret;
+	}
 
 	sprintf(path, "%s.dd", name);
 	stream = _sset.createReadStreamForMember(path);
-	if (stream)
-		return new PowerPackerStream(*stream);
+	if (stream) {
+		ret = new PowerPackerStream(*stream);
+		delete stream;
+		return ret;
+	}
 
 	return 0;
 }
@@ -926,8 +936,8 @@ void AmigaDisk_ns::loadBackground(BackgroundInfo& info, const char *name) {
 	}
 }
 
-void AmigaDisk_ns::loadMask(BackgroundInfo& info, const char *name) {
-	debugC(5, kDebugDisk, "AmigaDisk_ns::loadMask(%s)", name);
+void AmigaDisk_ns::loadMask_internal(BackgroundInfo& info, const char *name) {
+	debugC(5, kDebugDisk, "AmigaDisk_ns::loadMask_internal(%s)", name);
 
 	char path[PATH_LEN];
 	sprintf(path, "%s.mask", name);
@@ -953,7 +963,7 @@ void AmigaDisk_ns::loadMask(BackgroundInfo& info, const char *name) {
 	info._mask = loader._maskBuffer;
 }
 
-void AmigaDisk_ns::loadPath(BackgroundInfo& info, const char *name) {
+void AmigaDisk_ns::loadPath_internal(BackgroundInfo& info, const char *name) {
 
 	char path[PATH_LEN];
 	sprintf(path, "%s.path", name);
@@ -978,11 +988,11 @@ void AmigaDisk_ns::loadScenery(BackgroundInfo& info, const char* background, con
 	loadBackground(info, filename);
 
 	if (mask == 0) {
-		loadMask(info, background);
-		loadPath(info, background);
+		loadMask_internal(info, background);
+		loadPath_internal(info, background);
 	} else {
-		loadMask(info, mask);
-		loadPath(info, mask);
+		loadMask_internal(info, mask);
+		loadPath_internal(info, mask);
 	}
 
 	return;
@@ -1087,4 +1097,4 @@ Common::SeekableReadStream* AmigaDisk_ns::loadSound(const char* name) {
 	return tryOpenFile(path);
 }
 
-} // namespace Parallaction
+} // End of namespace Parallaction
