@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/exec_br.cpp $
- * $Id: exec_br.cpp 50363 2010-06-27 04:58:48Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,8 @@
 #include "parallaction/input.h"
 #include "parallaction/parallaction.h"
 
+#include "common/textconsole.h"
+
 namespace Parallaction {
 
 #define INST_ON			1
@@ -107,10 +109,14 @@ void Parallaction_br::clearSubtitles() {
 	if (_subtitle[0]) {
 		_gfx->hideLabel(_subtitle[0]);
 	}
+	delete _subtitle[0];
+	_subtitle[0] = 0;
 
 	if (_subtitle[1]) {
 		_gfx->hideLabel(_subtitle[1]);
 	}
+	delete _subtitle[1];
+	_subtitle[1] = 0;
 }
 
 
