@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/exec_ns.cpp $
- * $Id: exec_ns.cpp 39732 2009-03-29 10:18:09Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "parallaction/parallaction.h"
 #include "parallaction/sound.h"
 
+#include "common/textconsole.h"
 
 namespace Parallaction {
 
