@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/font.cpp $
- * $Id: font.cpp 47180 2010-01-08 22:07:35Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
-#include "common/stream.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 #include "parallaction/parallaction.h"
 
@@ -574,7 +575,7 @@ void AmigaFont::blitData(byte c) {
 }
 
 uint16 AmigaFont::width(byte c) {
-//	printf("kern(%i) = %i, space(%i) = %i\t", c, getKerning(c), c, getSpacing(c));
+//	debug("kern(%i) = %i, space(%i) = %i\t", c, getKerning(c), c, getSpacing(c));
 	return getKerning(c) + getSpacing(c);
 }
 
@@ -642,7 +643,7 @@ Font *AmigaDisk_ns::createFont(const char *name, Common::SeekableReadStream &str
 }
 
 Font *DosDisk_br::createFont(const char *name, Common::ReadStream &stream) {
-//	printf("DosDisk_br::createFont(%s)\n", name);
+//	debug("DosDisk_br::createFont(%s)", name);
 	Font *font;
 
 	if (_vm->getFeatures() & GF_DEMO) {
@@ -670,7 +671,6 @@ GfxObj* DosDisk_br::createInventoryObjects(Common::SeekableReadStream &stream) {
 
 
 void Parallaction_ns::initFonts() {
-
 	if (getPlatform() == Common::kPlatformPC) {
 		_dialogueFont = _disk->loadFont("comic");
 		_labelFont = _disk->loadFont("topaz");
@@ -683,7 +683,6 @@ void Parallaction_ns::initFonts() {
 		_menuFont = _disk->loadFont("slide");
 		_introFont = _disk->loadFont("intro");
 	}
-
 }
 
 void Parallaction_br::initFonts() {
@@ -701,4 +700,4 @@ void Parallaction_br::initFonts() {
 	}
 }
 
-}
+} // End of namespace Parallaction
