@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/gfxbase.cpp $
- * $Id: gfxbase.cpp 49621 2010-06-13 06:56:13Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "disk.h"
 
 #include "common/algorithm.h"
+#include "common/textconsole.h"
 #include "parallaction/parallaction.h"
 
 namespace Parallaction {
@@ -322,7 +323,7 @@ void Gfx::bltMaskScale(const Common::Rect& r, byte *data, Graphics::Surface *sur
 	uint line = 0, col = 0;
 
 	uint xAccum = 0, yAccum = 0;
-    uint inc = width * (100 - scale);
+	uint inc = width * (100 - scale);
 	uint thr = width * 100;
 
 	for (uint16 i = 0; i < srcRect.height(); i++) {
