@@ -19,13 +19,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/graphics.cpp $
- * $Id: graphics.cpp 49620 2010-06-13 06:55:58Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/system.h"
 #include "common/file.h"
+#include "common/textconsole.h"
+#include "graphics/palette.h"
 #include "graphics/primitives.h"
 #include "engines/util.h"
 
@@ -152,34 +154,32 @@ void Palette::fadeTo(const Palette& target, uint step) {
 		if (_data[i] == target._data[i]) continue;
 
 		if (_data[i] < target._data[i])
-			_data[i] = CLIP(_data[i] + step, (uint)0, (uint)target._data[i]);
+			_data[i] = CLIP(_data[i] + (int)step, (int)0, (int)target._data[i]);
 		else
-			_data[i] = CLIP(_data[i] - step, (uint)target._data[i], (uint)255);
+			_data[i] = CLIP(_data[i] - (int)step, (int)target._data[i], (int)255);
 	}
 
 	return;
 }
 
-uint Palette::fillRGBA(byte *rgba) {
+uint Palette::fillRGB(byte *rgb) {
 
 	byte r, g, b;
-	byte *hbPal = rgba + _colors * 4;
+	byte *hbPal = rgb + _colors * 3;
 
 	for (uint32 i = 0; i < _colors; i++) {
 		r = (_data[i*3]   << 2) | (_data[i*3]   >> 4);
 		g = (_data[i*3+1] << 2) | (_data[i*3+1] >> 4);
 		b = (_data[i*3+2] << 2) | (_data[i*3+2] >> 4);
 
-		rgba[i*4]   = r;
-		rgba[i*4+1] = g;
-		rgba[i*4+2] = b;
-		rgba[i*4+3] = 0;
+		rgb[i*3]   = r;
+		rgb[i*3+1] = g;
+		rgb[i*3+2] = b;
 
 		if (_hb) {
-			hbPal[i*4]   = r >> 1;
-			hbPal[i*4+1] = g >> 1;
-			hbPal[i*4+2] = b >> 1;
-			hbPal[i*4+3] = 0;
+			hbPal[i*3]   = r >> 1;
+			hbPal[i*3+1] = g >> 1;
+			hbPal[i*3+2] = b >> 1;
 		}
 
 	}
@@ -222,10 +222,10 @@ void Palette::rotate(uint first, uint last, bool forward) {
 
 
 void Gfx::setPalette(Palette pal) {
-	byte sysPal[256*4];
+	byte sysPal[256*3];
 
-	uint n = pal.fillRGBA(sysPal);
-	_vm->_system->setPalette(sysPal, 0, n);
+	uint n = pal.fillRGB(sysPal);
+	_vm->_system->getPaletteManager()->setPalette(sysPal, 0, n);
 }
 
 void Gfx::setBlackPalette() {
@@ -1110,7 +1110,15 @@ void PathBuffer::free() {
 }
 
 byte PathBuffer::getValue(uint16 x, uint16 y) const {
-	byte m = data[(x >> 3) + y * internalWidth];
+	byte m = 0;
+	if (data) {
+		uint index = (x >> 3) + y * internalWidth;
+		if (index < size)
+			m = data[index];
+		else
+			warning("PathBuffer::getValue(x: %d, y: %d) outside of data buffer of size %d", x, y, size);
+	} else
+		warning("PathBuffer::getValue() attempted to use NULL data buffer");
 	uint bit = bigEndian ? (x & 7) : (7 - (x & 7));
 	return ((1 << bit) & m) >> bit;
 }
