@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/graphics.h $
- * $Id: graphics.h 48811 2010-04-27 08:59:13Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -250,7 +250,7 @@ public:
 	void setEntry(uint index, int red, int green, int blue);
 	void makeGrayscale();
 	void fadeTo(const Palette& target, uint step);
-	uint fillRGBA(byte *rgba);
+	uint fillRGB(byte *rgb);
 
 	void rotate(uint first, uint last, bool forward);
 };
@@ -409,10 +409,10 @@ public:
 	virtual ~BalloonManager() { }
 
 	virtual void reset() = 0;
-	virtual int setLocationBalloon(const char *text, bool endGame) = 0;
-	virtual int setDialogueBalloon(const char *text, uint16 winding, TextColor textColor) = 0;
-	virtual int setSingleBalloon(const char *text, uint16 x, uint16 y, uint16 winding, TextColor textColor) = 0;
-	virtual void setBalloonText(uint id, const char *text, TextColor textColor) = 0;
+	virtual int setLocationBalloon(const Common::String &text, bool endGame) = 0;
+	virtual int setDialogueBalloon(const Common::String &text, uint16 winding, TextColor textColor) = 0;
+	virtual int setSingleBalloon(const Common::String &text, uint16 x, uint16 y, uint16 winding, TextColor textColor) = 0;
+	virtual void setBalloonText(uint id, const Common::String &text, TextColor textColor) = 0;
 	virtual int hitTestDialogueBalloon(int x, int y) = 0;
 };
 
