@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/gui.cpp $
- * $Id: gui.cpp 46941 2010-01-03 19:37:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "parallaction/gui.h"
 
 namespace Parallaction {
