@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/inventory.cpp $
- * $Id: inventory.cpp 45140 2009-10-16 00:08:18Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "parallaction/input.h"
 #include "parallaction/parallaction.h"
 
-
+#include "common/textconsole.h"
 
 namespace Parallaction {
 
