@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/objects.h $
- * $Id: objects.h 49136 2010-05-22 12:36:36Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -163,6 +163,8 @@ struct Answer {
 	int	_counterOp;
 
 	Answer();
+	bool textIsNull();
+	int speakerMood();
 };
 
 struct Question {
@@ -173,6 +175,9 @@ struct Question {
 
 	Question(const Common::String &name);
 	~Question();
+	bool textIsNull();
+	int speakerMood();
+	int balloonWinding();
 };
 
 struct Dialogue {
