@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/parallaction.h $
- * $Id: parallaction.h 50039 2010-06-19 04:50:44Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,6 +32,7 @@
 #include "common/func.h"
 #include "common/random.h"
 #include "common/savefile.h"
+#include "common/textconsole.h"
 
 #include "engines/engine.h"
 
@@ -48,8 +49,9 @@
  *
  * Status of this engine: ???
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Nippon Safes Inc. (complete)
+ * - The Big Red Adventure (work in progress)
  */
 namespace Parallaction {
 
@@ -267,7 +269,7 @@ public:
 	virtual Common::Error run() {
 		Common::Error err;
 		err = init();
-		if (err != Common::kNoError)
+		if (err.getCode() != Common::kNoError)
 			return err;
 		return go();
 	}
@@ -605,7 +607,7 @@ private:
 extern Parallaction *_vm;
 
 
-} // namespace Parallaction
+} // End of namespace Parallaction
 
 
 #endif
