@@ -18,11 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/parser.cpp $
- * $Id: parser.cpp 49127 2010-05-21 11:05:18Z peres001 $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
+
 #include "parallaction/parallaction.h"
 #include "parallaction/parser.h"
 
@@ -257,5 +259,4 @@ void Parser::parseStatement() {
 	(*(*_currentOpcodes)[_lookup])();
 }
 
-
-} // namespace Parallaction
+} // End of namespace Parallaction
