@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/sound.h $
- * $Id: sound.h 47579 2010-01-26 22:48:45Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,10 +29,10 @@
 #include "common/util.h"
 #include "common/mutex.h"
 
-#include "sound/audiostream.h"
-#include "sound/decoders/iff_sound.h"
-#include "sound/mixer.h"
-#include "sound/mididrv.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/iff_sound.h"
+#include "audio/mixer.h"
+#include "audio/mididrv.h"
 
 #define PATH_LEN 200
 
@@ -133,12 +133,14 @@ public:
 class DosSoundMan_ns : public SoundMan_ns {
 
 	MidiPlayer	*_midiPlayer;
-	int			_musicData1;
-
+	bool		_playing;
+	
 	bool isLocationSilent(const char *locationName);
+	bool locationHasOwnSoftMusic(const char *locationName);
 
+	
 public:
-	DosSoundMan_ns(Parallaction_ns *vm, MidiDriver *midiDriver);
+	DosSoundMan_ns(Parallaction_ns *vm);
 	~DosSoundMan_ns();
 	void playMusic();
 	void stopMusic();
@@ -226,7 +228,7 @@ class DosSoundMan_br : public SoundMan_br {
 	Audio::AudioStream *loadChannelData(const char *filename, Channel *ch, bool looping);
 
 public:
-	DosSoundMan_br(Parallaction_br *vm, MidiDriver *midiDriver);
+	DosSoundMan_br(Parallaction_br *vm);
 	~DosSoundMan_br();
 
 	void playMusic();
