@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/walk.h $
- * $Id: walk.h 48477 2010-04-02 22:14:18Z wjpalenstijn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -31,12 +31,10 @@
 
 #include "parallaction/objects.h"
 
-
 namespace Parallaction {
 
 struct Character;
 
-
 class PathWalker_NS {
 	AnimationPtr _a;
 	PointList	_walkPath;
@@ -61,14 +59,13 @@ public:
 	void walk();
 };
 
-
 class PathWalker_BR {
 
 	struct State {
 		bool			_active;
 		AnimationPtr	_a;
 		int				_walkDelay;
-		int				_fieldC;
+		bool			_stillWalkingTowardsNode;
 		Common::Point	_startFoot;
 		bool			_first;
 		int				_step;
