@@ -18,14 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/command.cpp $
- * $Id: command.cpp 48800 2010-04-25 21:53:09Z cyx $
+ * $URL$
+ * $Id$
  *
  */
 
 
-#include "common/events.h"
-#include "common/system.h"
 #include "queen/command.h"
 
 #include "queen/display.h"
@@ -367,6 +365,17 @@ void Command::readCommandsFrom(byte *&ptr) {
 		memset(&_cmdObject[0], 0, sizeof(CmdObject));
 		for (i = 1; i <= _numCmdObject; i++) {
 			_cmdObject[i].readFromBE(ptr);
+
+			// WORKAROUND bug #1858081: Fix an off by one error in the object
+			// command 175. Object 309 should be copied to 308 (disabled).
+			//
+			// _objectData[307].name = -195
+			// _objectData[308].name = 50
+			// _objectData[309].name = -50
+
+			if (i == 175 && _cmdObject[i].id == 320 && _cmdObject[i].dstObj == 307 && _cmdObject[i].srcObj == 309) {
+				_cmdObject[i].dstObj = 308;
+			}
 		}
 	}
 
