@@ -18,11 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/cutaway.cpp $
- * $Id: cutaway.cpp 48800 2010-04-25 21:53:09Z cyx $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
 
 #include "queen/cutaway.h"
 
@@ -283,7 +284,7 @@ void Cutaway::limitBob(CutawayObject &object) {
 		}
 
 		BobSlot *bob =
-			_vm->graphics()->bob( _vm->logic()->findBob(object.objectNumber) );
+			_vm->graphics()->bob(_vm->logic()->findBob(object.objectNumber));
 
 		if (!bob) {
 			warning("Failed to find bob");
@@ -667,7 +668,7 @@ const byte *Cutaway::handleAnimation(const byte *ptr, CutawayObject &object) {
 
 				// Only flip if we are not moving or it is not a person object
 				if (!(objAnim[i].object > 0 && objAnim[i].object < 4) ||
-						!(objAnim[i].mx || objAnim[i].my) )
+						!(objAnim[i].mx || objAnim[i].my))
 					bob->xflip = objAnim[i].flip;
 
 				// Add frame alteration
@@ -1235,7 +1236,7 @@ void Cutaway::handleText(
 	}
 
 	BobSlot *bob =
-		_vm->graphics()->bob( _vm->logic()->findBob(ABS(object.objectNumber)) );
+		_vm->graphics()->bob(_vm->logic()->findBob(ABS(object.objectNumber)));
 
 	_vm->graphics()->setBobText(bob, sentence, x, object.bobStartY, object.specialMove, flags);
 
