@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/input.cpp $
- * $Id: input.cpp 48645 2010-04-12 21:21:06Z salty-horse $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/events.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "queen/queen.h"
 #include "queen/input.h"
