@@ -18,15 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/logic.cpp $
- * $Id: logic.cpp 34700 2008-09-30 12:27:38Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/config-manager.h"
-#include "common/events.h"
-#include "common/system.h"
+#include "common/textconsole.h"
 
 #include "queen/logic.h"
 
@@ -1550,7 +1549,7 @@ void Logic::asmEndGame() {
 	while (n--) {
 		_vm->update();
 	}
-//	printf("Game completed.");
+//	debug("Game completed.");
 	_vm->quitGame();
 }
 
@@ -2004,7 +2003,7 @@ void Logic::asmPanLeftToBomb() {
 }
 
 void Logic::asmEndDemo() {
-//	printf("Flight of the Amazon Queen, released January 95.");
+//	debug("Flight of the Amazon Queen, released January 95.");
 	_vm->quitGame();
 }
 
@@ -2049,7 +2048,7 @@ void Logic::asmInterviewIntro() {
 }
 
 void Logic::asmEndInterview() {
-//	printf("Interactive Interview copyright (c) 1995, IBI.");
+//	debug("Interactive Interview copyright (c) 1995, IBI.");
 	_vm->quitGame();
 }
 
