@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/queen.cpp $
- * $Id: queen.cpp 51566 2010-08-01 07:02:05Z Bluddy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,6 +32,7 @@
 #include "common/system.h"
 #include "common/events.h"
 #include "common/EventRecorder.h"
+#include "common/textconsole.h"
 
 #include "engines/util.h"
 
@@ -240,14 +241,20 @@ void QueenEngine::checkOptionSettings() {
 }
 
 void QueenEngine::syncSoundSettings() {
+	Engine::syncSoundSettings();
+
 	readOptionSettings();
 }
 
 void QueenEngine::readOptionSettings() {
+	bool mute = false;
+	if (ConfMan.hasKey("mute"))
+		mute = ConfMan.getBool("mute");
+
 	_sound->setVolume(ConfMan.getInt("music_volume"));
-	_sound->musicToggle(!ConfMan.getBool("music_mute"));
-	_sound->sfxToggle(!ConfMan.getBool("sfx_mute"));
-	_sound->speechToggle(!ConfMan.getBool("speech_mute"));
+	_sound->musicToggle(!(mute || ConfMan.getBool("music_mute")));
+	_sound->sfxToggle(!(mute || ConfMan.getBool("sfx_mute")));
+	_sound->speechToggle(!(mute || ConfMan.getBool("speech_mute")));
 	_talkSpeed = (ConfMan.getInt("talkspeed") * (MAX_TEXT_SPEED - MIN_TEXT_SPEED) + 255 / 2) / 255 + MIN_TEXT_SPEED;
 	_subtitles = ConfMan.getBool("subtitles");
 	checkOptionSettings();
@@ -397,7 +404,7 @@ Common::InSaveFile *QueenEngine::readGameStateHeader(int slot, GameStateHeader *
 	char name[20];
 	makeGameStateName(slot, name);
 	Common::InSaveFile *file = _saveFileMan->openForLoading(name);
-	if (file && file->readUint32BE() == MKID_BE('SCVM')) {
+	if (file && file->readUint32BE() == MKTAG('S','C','V','M')) {
 		gsh->version = file->readUint32BE();
 		gsh->flags = file->readUint32BE();
 		gsh->dataSize = file->readUint32BE();
@@ -470,11 +477,14 @@ Common::Error QueenEngine::run() {
 	}
 
 	_sound = Sound::makeSoundInstance(_mixer, this, _resource->getCompression());
+
 	_walk = new Walk(this);
 	//_talkspeedScale = (MAX_TEXT_SPEED - MIN_TEXT_SPEED) / 255.0;
 
 	registerDefaultSettings();
-	readOptionSettings();
+
+	// Setup mixer
+	syncSoundSettings();
 
 	_logic->start();
 	if (ConfMan.hasKey("save_slot") && canLoadOrSave()) {
