@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/resource.cpp $
- * $Id: resource.cpp 50964 2010-07-17 18:41:38Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/debug.h"
 #include "common/endian.h"
 #include "common/config-manager.h"
+#include "common/substream.h"
+#include "common/textconsole.h"
 #include "queen/resource.h"
 
 namespace Queen {
@@ -131,7 +133,7 @@ void Resource::loadTextFile(const char *filename, Common::StringArray &stringLis
 bool Resource::detectVersion(DetectedGameVersion *ver, Common::File *f) {
 	memset(ver, 0, sizeof(DetectedGameVersion));
 
-	if (f->readUint32BE() == MKID_BE('QTBL')) {
+	if (f->readUint32BE() == MKTAG('Q','T','B','L')) {
 		f->read(ver->str, 6);
 		f->skip(2);
 		ver->compression = f->readByte();
@@ -268,7 +270,7 @@ void Resource::seekResourceFile(int num, uint32 offset) {
 void Resource::readTableFile(uint8 version, uint32 offset) {
 	Common::File tableFile;
 	tableFile.open(_tableFilename);
-	if (tableFile.isOpen() && tableFile.readUint32BE() == MKID_BE('QTBL')) {
+	if (tableFile.isOpen() && tableFile.readUint32BE() == MKTAG('Q','T','B','L')) {
 		uint32 tableVersion = tableFile.readUint32BE();
 		if (version > tableVersion) {
 			error("The game you are trying to play requires version %d of queen.tbl, "
