@@ -18,15 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/talk.cpp $
- * $Id: talk.cpp 48645 2010-04-12 21:21:06Z salty-horse $
+ * $URL$
+ * $Id$
  *
  */
 
 
-#include "common/events.h"
-#include "common/system.h"
 #include "common/rect.h"
+#include "common/textconsole.h"
 
 #include "queen/talk.h"
 
@@ -551,11 +550,11 @@ bool Talk::speak(const char *sentence, Person *person, const char *voiceFilePref
 		return personWalking;
 	}
 
-	if (0 == strcmp(person->name, "FAYE-H" ) ||
+	if (0 == strcmp(person->name, "FAYE-H") ||
 		0 == strcmp(person->name, "FRANK-H") ||
 		0 == strcmp(person->name, "AZURA-H") ||
 		0 == strcmp(person->name, "X3_RITA") ||
-		(0 == strcmp(person->name, "JOE") && _vm->logic()->currentRoom() == FAYE_HEAD ) ||
+		(0 == strcmp(person->name, "JOE") && _vm->logic()->currentRoom() == FAYE_HEAD) ||
 		(0 == strcmp(person->name, "JOE") && _vm->logic()->currentRoom() == AZURA_HEAD) ||
 		(0 == strcmp(person->name, "JOE") && _vm->logic()->currentRoom() == FRANK_HEAD))
 		_talkHead = true;
@@ -777,7 +776,7 @@ void Talk::defaultAnimation(
 	}
 
 	// Make sure that Person closes their mouth
-	if (!isJoe && parameters->ff > 0)
+	if (!isJoe && parameters && parameters->ff > 0)
 		_vm->bankMan()->overpack(parameters->ff, startFrame, bankNum);
 }
 
