@@ -18,11 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/walk.cpp $
- * $Id: walk.cpp 30667 2008-01-28 00:14:17Z jvprat $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/textconsole.h"
 
 #include "queen/walk.h"
 
