@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/animation.cpp $
- * $Id: animation.cpp 49047 2010-05-16 10:36:21Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -42,8 +42,6 @@ namespace Saga {
 Anim::Anim(SagaEngine *vm) : _vm(vm) {
 	uint16 i;
 
-	_cutawayList = NULL;
-	_cutawayListLength = 0;
 	_cutawayActive = false;
 
 	for (i = 0; i < MAX_ANIMATIONS; i++)
@@ -55,21 +53,16 @@ Anim::Anim(SagaEngine *vm) : _vm(vm) {
 
 Anim::~Anim() {
 	reset();
-#ifdef ENABLE_IHNM
-	freeCutawayList();
-#endif
 }
 
 #ifdef ENABLE_IHNM
 
-void Anim::loadCutawayList(const byte *resourcePointer, size_t resourceLength) {
-	free(_cutawayList);
-	_cutawayListLength = resourceLength / 8;
-	_cutawayList = (Cutaway *)malloc(_cutawayListLength * sizeof(Cutaway));
+void Anim::loadCutawayList(const ByteArray &resourceData) {
+	_cutawayList.resize(resourceData.size() / 8);
 
-	MemoryReadStream cutawayS(resourcePointer, resourceLength);
+	ByteArrayReadStreamEndian cutawayS(resourceData);
 
-	for (int i = 0; i < _cutawayListLength; i++) {
+	for (uint i = 0; i < _cutawayList.size(); i++) {
 		_cutawayList[i].backgroundResourceId = cutawayS.readUint16LE();
 		_cutawayList[i].animResourceId = cutawayS.readUint16LE();
 		_cutawayList[i].cycles = cutawayS.readSint16LE();
@@ -77,20 +70,16 @@ void Anim::loadCutawayList(const byte *resourcePointer, size_t resourceLength) {
 	}
 }
 
-void Anim::freeCutawayList() {
-	free(_cutawayList);
-	_cutawayList = NULL;
-	_cutawayListLength = 0;
+void Anim::clearCutawayList() {
+	_cutawayList.clear();
 }
 
 int Anim::playCutaway(int cut, bool fade) {
 	debug(0, "playCutaway(%d, %d)", cut, fade);
 
 	Event event;
-	Event *q_event = NULL;
+	EventColumns *eventColumns = NULL;
 	bool startImmediately = false;
-	byte *resourceData;
-	size_t resourceDataLength;
 	ResourceContext *context = _vm->_resource->getContext(GAME_RESOURCEFILE);
 
 	_cutAwayFade = fade;
@@ -111,7 +100,7 @@ int Anim::playCutaway(int cut, bool fade) {
 		event.time = 0;
 		event.duration = kNormalFadeDuration;
 		event.data = cur_pal;
-		q_event = _vm->_events->queue(&event);
+		eventColumns = _vm->_events->queue(event);
 
 		// set fade mode
 		event.type = kEvTImmediate;
@@ -120,7 +109,7 @@ int Anim::playCutaway(int cut, bool fade) {
 		event.param = kNoFade;
 		event.time = 0;
 		event.duration = 0;
-		q_event = _vm->_events->chain(q_event, &event);
+		_vm->_events->chain(eventColumns, event);
 	}
 
 	// Prepare cutaway
@@ -148,7 +137,7 @@ int Anim::playCutaway(int cut, bool fade) {
 		event.time = 0;
 		event.duration = 0;
 		event.param = _cutawayList[cut].backgroundResourceId;
-		q_event = _vm->_events->chain(q_event, &event);
+		eventColumns = _vm->_events->chain(eventColumns, event);
 	} else {
 		showCutawayBg(_cutawayList[cut].backgroundResourceId);
 	}
@@ -180,9 +169,10 @@ int Anim::playCutaway(int cut, bool fade) {
 	// for the second from the left monitor in Ellen's chapter etc
 	// Therefore, skip the animation bit if animResourceId is 0 and only show the background
 	if (_cutawayList[cut].animResourceId != 0) {
-		_vm->_resource->loadResource(context, _cutawayList[cut].animResourceId, resourceData, resourceDataLength);
-		load(MAX_ANIMATIONS + cutawaySlot, resourceData, resourceDataLength);
-		free(resourceData);
+		ByteArray resourceData;
+		_vm->_resource->loadResource(context, _cutawayList[cut].animResourceId, resourceData);
+		load(MAX_ANIMATIONS + cutawaySlot, resourceData);
+		
 
 		setCycles(MAX_ANIMATIONS + cutawaySlot, _cutawayList[cut].cycles);
 		setFrameTime(MAX_ANIMATIONS + cutawaySlot, 1000 / _cutawayList[cut].frameRate);
@@ -198,9 +188,9 @@ int Anim::playCutaway(int cut, bool fade) {
 		event.time = (40 / 3) * 1000 / _cutawayList[cut].frameRate;
 
 		if (fade)
-			q_event = _vm->_events->chain(q_event, &event);
+			eventColumns = _vm->_events->chain(eventColumns, event);
 		else
-			_vm->_events->queue(&event);
+			_vm->_events->queue(event);
 	}
 
 	return MAX_ANIMATIONS + cutawaySlot;
@@ -222,7 +212,7 @@ void Anim::returnFromCutaway() {
 
 	if (_cutawayActive) {
 		Event event;
-		Event *q_event = NULL;
+		EventColumns *eventColumns = NULL;
 
 		if (_cutAwayFade) {
 			static PalEntry cur_pal[PAL_ENTRIES];
@@ -237,7 +227,7 @@ void Anim::returnFromCutaway() {
 			event.time = 0;
 			event.duration = kNormalFadeDuration;
 			event.data = cur_pal;
-			q_event = _vm->_events->queue(&event);
+			eventColumns = _vm->_events->queue(event);
 
 			// set fade mode
 			event.type = kEvTImmediate;
@@ -246,7 +236,7 @@ void Anim::returnFromCutaway() {
 			event.param = kNoFade;
 			event.time = 0;
 			event.duration = 0;
-			q_event = _vm->_events->chain(q_event, &event);
+			_vm->_events->chain(eventColumns, event);
 		}
 
 		// Clear the cutaway. Note that this sets _cutawayActive to false
@@ -257,9 +247,9 @@ void Anim::returnFromCutaway() {
 		event.duration = 0;
 
 		if (_cutAwayFade)
-			q_event = _vm->_events->chain(q_event, &event);		// chain with the other events
+			eventColumns = _vm->_events->chain(eventColumns, event);		// chain with the other events
 		else
-			q_event = _vm->_events->queue(&event);
+			eventColumns = _vm->_events->queue(event);
 
 		_vm->_scene->restoreScene();
 
@@ -279,7 +269,7 @@ void Anim::returnFromCutaway() {
 		event.op = kEventResumeAll;
 		event.time = 0;
 		event.duration = 0;
-		q_event = _vm->_events->chain(q_event, &event);		// chain with the other events
+		_vm->_events->chain(eventColumns, event);		// chain with the other events
 
 		// Draw the scene
 		event.type = kEvTImmediate;
@@ -287,7 +277,7 @@ void Anim::returnFromCutaway() {
 		event.op = kEventDraw;
 		event.time = 0;
 		event.duration = 0;
-		q_event = _vm->_events->chain(q_event, &event);		// chain with the other events
+		_vm->_events->chain(eventColumns, event);		// chain with the other events
 
 		// Handle fade up, if we previously faded down
 		if (_cutAwayFade) {
@@ -297,14 +287,14 @@ void Anim::returnFromCutaway() {
 			event.time = 0;
 			event.duration = kNormalFadeDuration;
 			event.data = saved_pal;
-			q_event = _vm->_events->chain(q_event, &event);
+			_vm->_events->chain(eventColumns, event);
 		}
 
 		event.type = kEvTOneshot;
 		event.code = kScriptEvent;
 		event.op = kEventThreadWake;
 		event.param = kWaitTypeWakeUp;
-		q_event = _vm->_events->chain(q_event, &event);
+		_vm->_events->chain(eventColumns, event);
 	}
 }
 
@@ -338,22 +328,20 @@ void Anim::clearCutaway() {
 void Anim::showCutawayBg(int bg) {
 	ResourceContext *context = _vm->_resource->getContext(GAME_RESOURCEFILE);
 
-	byte *resourceData;
-	size_t resourceDataLength;
-	byte *buf;
-	size_t buflen;
+	ByteArray resourceData;
+	ByteArray image;
 	int width;
 	int height;
 	Event event;
 	static PalEntry pal[PAL_ENTRIES];
 
-	_vm->_resource->loadResource(context, bg, resourceData, resourceDataLength);
-	_vm->decodeBGImage(resourceData, resourceDataLength, &buf, &buflen, &width, &height);
+	_vm->_resource->loadResource(context, bg, resourceData);
+	_vm->decodeBGImage(resourceData, image, &width, &height);
 
-	const byte *palPointer = _vm->getImagePal(resourceData, resourceDataLength);
+	const byte *palPointer = _vm->getImagePal(resourceData);
 	memcpy(pal, palPointer, sizeof(pal));
 	const Rect rect(width, height);
-	_vm->_render->getBackGroundSurface()->blit(rect, buf);
+	_vm->_render->getBackGroundSurface()->blit(rect, image.getBuffer());
 	_vm->_render->setFullRefresh(true);
 	_vm->_frameCount++;
 
@@ -365,13 +353,10 @@ void Anim::showCutawayBg(int bg) {
 		event.time = 0;
 		event.duration = kNormalFadeDuration;
 		event.data = pal;
-		_vm->_events->queue(&event);
+		_vm->_events->queue(event);
 	} else {
 		_vm->_gfx->setPalette(pal);
 	}
-
-	free(buf);
-	free(resourceData);
 }
 
 void Anim::startVideo(int vid, bool fade) {
@@ -397,18 +382,18 @@ void Anim::returnFromVideo() {
 
 #endif
 
-void Anim::load(uint16 animId, const byte *animResourceData, size_t animResourceLength) {
+void Anim::load(uint16 animId, const ByteArray &resourceData) {
 	AnimationData *anim;
 	uint16 temp;
 
 	if (animId >= MAX_ANIMATIONS) {
 		if (animId >= MAX_ANIMATIONS + ARRAYSIZE(_cutawayAnimations))
 			error("Anim::load could not find unused animation slot");
-		anim = _cutawayAnimations[animId - MAX_ANIMATIONS] = new AnimationData(animResourceData, animResourceLength);
+		anim = _cutawayAnimations[animId - MAX_ANIMATIONS] = new AnimationData();
 	} else
-		anim = _animations[animId] = new AnimationData(animResourceData, animResourceLength);
+		anim = _animations[animId] = new AnimationData();
 
-	MemoryReadStreamEndian headerReadS(anim->resourceData, anim->resourceLength, _vm->isBigEndian());
+	ByteArrayReadStreamEndian headerReadS(resourceData, _vm->isBigEndian());
 	anim->magic = headerReadS.readUint16LE(); // cause ALWAYS LE
 	anim->screenWidth = headerReadS.readUint16();
 	anim->screenHeight = headerReadS.readUint16();
@@ -418,23 +403,30 @@ void Anim::load(uint16 animId, const byte *animResourceData, size_t animResource
 	anim->maxFrame = headerReadS.readByte() - 1;
 	anim->loopFrame = headerReadS.readByte() - 1;
 	temp = headerReadS.readUint16BE();
-	anim->start = headerReadS.pos();
+	size_t start;
+
+	start = headerReadS.pos();
 	if (temp == (uint16)(-1)) {
 		temp = 0;
 	}
-	anim->start += temp;
+	start += temp;
 
+	size_t dataOffset = headerReadS.pos();
+	if (dataOffset != start) {
+		warning("Anim::load animId=%d start != dataOffset 0x%X 0x%X", animId, uint(start), uint(dataOffset));
+	}
+
+	anim->resourceData.resize(resourceData.size() - dataOffset);
+	
+	memcpy(anim->resourceData.getBuffer(), resourceData.getBuffer() + dataOffset, anim->resourceData.size());
 	// Cache frame offsets
 
 	// WORKAROUND: Cutaway with background resource ID 37 (loaded as cutaway #4) is ending credits.
 	// For some reason it has wrong number of frames specified in its header. So we calculate it here:
-	if (animId > MAX_ANIMATIONS && _cutawayListLength > 4 && _cutawayList[4].backgroundResourceId == 37 && anim->maxFrame == 143)
+	if (animId > MAX_ANIMATIONS && _cutawayList.size() > 4 && _cutawayList[4].backgroundResourceId == 37 && anim->maxFrame == 143)
 		anim->maxFrame = fillFrameOffsets(anim, false);
 
-	anim->frameOffsets = (size_t *)malloc((anim->maxFrame + 1) * sizeof(*anim->frameOffsets));
-	if (anim->frameOffsets == NULL) {
-		memoryError("Anim::load");
-	}
+	anim->frameOffsets.resize(anim->maxFrame + 1);
 
 	fillFrameOffsets(anim);
 
@@ -504,7 +496,7 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
 		event.op = kEventFrame;
 		event.param = animId;
 		event.time = 10;
-		_vm->_events->queue(&event);
+		_vm->_events->queue(event);
 
 		// Nothing to render here (apart from the background, which is already rendered),
 		// so return
@@ -534,7 +526,7 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
 		event.op = kEventFrame;
 		event.param = animId;
 		event.time = 0;
-		_vm->_events->queue(&event);
+		_vm->_events->queue(event);
 
 		return;
 	}
@@ -575,7 +567,7 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
 				event.code = kSceneEvent;
 				event.op = kEventEnd;
 				event.time = anim->frameTime + vectorTime;
-				_vm->_events->queue(&event);
+				_vm->_events->queue(event);
 			}
 			return;
 		} else {
@@ -601,7 +593,7 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
 	event.op = kEventFrame;
 	event.param = animId;
 	event.time = frameTime;
-	_vm->_events->queue(&event);
+	_vm->_events->queue(event);
 }
 
 void Anim::stop(uint16 animId) {
@@ -688,7 +680,7 @@ void Anim::decodeFrame(AnimationData *anim, size_t frameOffset, byte *buf, size_
 		error("decodeFrame() Buffer size inadequate");
 	}
 
-	MemoryReadStream readS(anim->resourceData + frameOffset, anim->resourceLength - frameOffset);
+	Common::MemoryReadStream readS(&anim->resourceData[frameOffset], anim->resourceData.size() - frameOffset);
 
 // FIXME: This is thrown when the first video of the IHNM end sequence is shown (the "turn off screen"
 // video), however the video is played correctly and the rest of the end sequence continues normally
@@ -825,9 +817,7 @@ int Anim::fillFrameOffsets(AnimationData *anim, bool reallyFill) {
 	int i;
 	bool longData = isLongData();
 
-	MemoryReadStreamEndian readS(anim->resourceData, anim->resourceLength, !_vm->isBigEndian()); // RLE has inversion BE<>LE
-
-	readS.seek(12);
+	Common::MemoryReadStreamEndian readS(&anim->resourceData.front(), anim->resourceData.size(), !_vm->isBigEndian()); // RLE has inversion BE<>LE
 
 	while (readS.pos() != readS.size()) {
 		if (reallyFill) {
@@ -843,7 +833,7 @@ int Anim::fillFrameOffsets(AnimationData *anim, bool reallyFill) {
 		// including the frame header, is in big endian format
 		do {
 			markByte = readS.readByte();
-//			debug(7, "_pos=%x currentFrame=%i markByte=%x", readS.pos(), currentFrame, markByte);
+//			debug(7, "_pos=%X currentFrame=%i markByte=%X", readS.pos(), currentFrame, markByte);
 
 			switch (markByte) {
 			case SAGA_FRAME_START: // Start of frame
@@ -942,9 +932,9 @@ void Anim::animInfo() {
 void Anim::cutawayInfo() {
 	uint16 i;
 
-	_vm->_console->DebugPrintf("There are %d cutaways loaded:\n", _cutawayListLength);
+	_vm->_console->DebugPrintf("There are %d cutaways loaded:\n", _cutawayList.size());
 
-	for (i = 0; i < _cutawayListLength; i++) {
+	for (i = 0; i < _cutawayList.size(); i++) {
 		_vm->_console->DebugPrintf("%02d: Bg res: %u Anim res: %u Cycles: %u Framerate: %u\n", i,
 			_cutawayList[i].backgroundResourceId, _cutawayList[i].animResourceId,
 			_cutawayList[i].cycles, _cutawayList[i].frameRate);
