@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/detection.cpp $
- * $Id: detection.cpp 49788 2010-06-15 10:59:23Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -56,9 +56,9 @@ struct SAGAGameDescription {
 
 bool SagaEngine::isBigEndian() const { return isMacResources() && getGameId() == GID_ITE; }
 bool SagaEngine::isMacResources() const { return (getPlatform() == Common::kPlatformMacintosh); }
-const GameResourceDescription *SagaEngine::getResourceDescription() { return _gameDescription->resourceDescription; }
+const GameResourceDescription *SagaEngine::getResourceDescription() const { return _gameDescription->resourceDescription; }
 
-const GameFontDescription *SagaEngine::getFontDescription(int index) {
+const GameFontDescription *SagaEngine::getFontDescription(int index) const {
 	assert(index < _gameDescription->fontsCount);
 	return &_gameDescription->fontDescriptions[index];
 }
@@ -259,12 +259,12 @@ SaveStateDescriptor SagaMetaEngine::querySaveMetaInfos(const char *target, int s
 			version = SWAP_BYTES_32(version);
 		}
 
-		debug(2, "Save version: %x", version);
+		debug(2, "Save version: 0x%X", version);
 
 		if (version < 4)
 			warning("This savegame is not endian-safe. There may be problems");
 
-		if (type != MKID_BE('SAGA')) {
+		if (type != MKTAG('S','A','G','A')) {
 			error("SagaEngine::load wrong save game format");
 		}
 
@@ -372,12 +372,13 @@ Common::Error SagaEngine::saveGameState(int slot, const char *desc) {
 }
 
 bool SagaEngine::canLoadGameStateCurrently() {
-	return !_scene->isInIntro();
+	return !_scene->isInIntro() &&
+		(_interface->getMode() == kPanelMain || _interface->getMode() == kPanelChapterSelection);
 }
 
 bool SagaEngine::canSaveGameStateCurrently() {
 	return !_scene->isInIntro() &&
-		   (_interface->getMode() == kPanelMain || _interface->getMode() == kPanelChapterSelection);
+		(_interface->getMode() == kPanelMain || _interface->getMode() == kPanelChapterSelection);
 }
 
 } // End of namespace Saga
