@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/font.cpp $
- * $Id: font.cpp 52800 2010-09-19 08:18:52Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -41,37 +41,39 @@ Font::Font(SagaEngine *vm) : _vm(vm) {
 
 	assert(_vm->getFontsCount() > 0);
 
-	_fonts = (FontData **)calloc(_vm->getFontsCount(), sizeof(*_fonts));
-	_loadedFonts = 0;
-
+	_fonts.resize(_vm->getFontsCount());
 	for (i = 0; i < _vm->getFontsCount(); i++) {
-		loadFont(_vm->getFontDescription(i)->fontResourceId);
+#ifdef __DS__
+		_fonts[i].outline.font = NULL;
+		_fonts[i].normal.font = NULL;
+#endif
+		loadFont(&_fonts[i],	_vm->getFontDescription(i)->fontResourceId);
 	}
 
+	
+	
 	_fontMapping = 0;
 }
 
 Font::~Font() {
 	debug(8, "Font::~Font(): Freeing fonts.");
-	int i;
 
-	for (i = 0 ; i < _loadedFonts ; i++) {
-		if (_fonts[i] != NULL) {
-			free(_fonts[i]->normal.font);
-			free(_fonts[i]->outline.font);
+#ifdef __DS__
+	for (int i = 0; i < _vm->getFontsCount(); i++) {
+		if (_fonts[i].outline.font) {
+			free(_fonts[i].outline.font);
 		}
-
-		free(_fonts[i]);
-	}
-
-	free(_fonts);
+		
+		if (_fonts[i].normal.font) {
+			free(_fonts[i].normal.font);
+		}
+	}	
+#endif
 }
 
 
-void Font::loadFont(uint32 fontResourceId) {
-	FontData *font;
-	byte *fontResourcePointer;
-	size_t fontResourceLength;
+void Font::loadFont(FontData *font, uint32 fontResourceId) {
+	ByteArray fontResourceData;
 	int numBits;
 	int c;
 	ResourceContext *fontContext;
@@ -84,16 +86,13 @@ void Font::loadFont(uint32 fontResourceId) {
 	}
 
 	// Load font resource
-	_vm->_resource->loadResource(fontContext, fontResourceId, fontResourcePointer, fontResourceLength);
+	_vm->_resource->loadResource(fontContext, fontResourceId, fontResourceData);
 
-	if (fontResourceLength < FONT_DESCSIZE) {
-		error("Font::loadFont() Invalid font length (%i < %i)", (int)fontResourceLength, FONT_DESCSIZE);
+	if (fontResourceData.size() < FONT_DESCSIZE) {
+		error("Font::loadFont() Invalid font length (%i < %i)", (int)fontResourceData.size(), FONT_DESCSIZE);
 	}
 
-	MemoryReadStreamEndian readS(fontResourcePointer, fontResourceLength, fontContext->isBigEndian());
-
-	// Create new font structure
-	font = (FontData *)malloc(sizeof(*font));
+	ByteArrayReadStreamEndian readS(fontResourceData, fontContext->isBigEndian());
 
 	// Read font header
 	font->normal.header.charHeight = readS.readUint16();
@@ -126,17 +125,20 @@ void Font::loadFont(uint32 fontResourceId) {
 		error("Invalid font resource size");
 	}
 
-	font->normal.font = (byte*)malloc(fontResourceLength - FONT_DESCSIZE);
-	memcpy(font->normal.font, fontResourcePointer + FONT_DESCSIZE, fontResourceLength - FONT_DESCSIZE);
-
-	free(fontResourcePointer);
-
+#ifndef __DS__
+	font->normal.font.resize(fontResourceData.size() - FONT_DESCSIZE);
+	memcpy(font->normal.font.getBuffer(), fontResourceData.getBuffer() + FONT_DESCSIZE, fontResourceData.size() - FONT_DESCSIZE);
+#else
+	if (font->normal.font) {
+		free(font->normal.font);
+	}
+		
+	font->normal.font = (byte *) malloc(fontResourceData.size() - FONT_DESCSIZE);
+	memcpy(font->normal.font, fontResourceData.getBuffer() + FONT_DESCSIZE, fontResourceData.size() - FONT_DESCSIZE);
+#endif
 
 	// Create outline font style
 	createOutline(font);
-
-	// Set font data
-	_fonts[_loadedFonts++] = font;
 }
 
 void Font::createOutline(FontData *font) {
@@ -145,12 +147,12 @@ void Font::createOutline(FontData *font) {
 	int newByteWidth;
 	int newRowLength = 0;
 	int currentByte;
-	unsigned char *basePointer;
-	unsigned char *srcPointer;
-	unsigned char *destPointer1;
-	unsigned char *destPointer2;
-	unsigned char *destPointer3;
-	unsigned char charRep;
+	byte *basePointer;
+	byte *srcPointer;
+	byte *destPointer1;
+	byte *destPointer2;
+	byte *destPointer3;
+	byte charRep;
 
 	// Populate new font style character data
 	for (i = 0; i < FONT_CHARCOUNT; i++) {
@@ -177,20 +179,28 @@ void Font::createOutline(FontData *font) {
 	font->outline.header.rowLength = newRowLength;
 
 	// Allocate new font representation storage
-	font->outline.font = (unsigned char *)calloc(newRowLength, font->outline.header.charHeight);
+#ifdef __DS__
+	if (font->outline.font) {
+		free(font->outline.font);
+	}
+
+	font->outline.font = (byte *) calloc(newRowLength * font->outline.header.charHeight, 1);
+#else
+	font->outline.font.resize(newRowLength * font->outline.header.charHeight);
+#endif
 
 
 	// Generate outline font representation
 	for (i = 0; i < FONT_CHARCOUNT; i++) {
 		for (row = 0; row < font->normal.header.charHeight; row++) {
 			for (currentByte = 0; currentByte < font->outline.fontCharEntry[i].byteWidth; currentByte++) {
-				basePointer = font->outline.font + font->outline.fontCharEntry[i].index + currentByte;
+				basePointer = &font->outline.font[font->outline.fontCharEntry[i].index + currentByte];
 				destPointer1 = basePointer + newRowLength * row;
 				destPointer2 = basePointer + newRowLength * (row + 1);
 				destPointer3 = basePointer + newRowLength * (row + 2);
 				if (currentByte > 0) {
 					// Get last two columns from previous byte
-					srcPointer = font->normal.font + font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + (currentByte - 1);
+					srcPointer = &font->normal.font[font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + (currentByte - 1)];
 					charRep = *srcPointer;
 					*destPointer1 |= ((charRep << 6) | (charRep << 7));
 					*destPointer2 |= ((charRep << 6) | (charRep << 7));
@@ -198,7 +208,7 @@ void Font::createOutline(FontData *font) {
 				}
 
 				if (currentByte < font->normal.fontCharEntry[i].byteWidth) {
-					srcPointer = font->normal.font + font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + currentByte;
+					srcPointer = &font->normal.font[font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + currentByte];
 					charRep = *srcPointer;
 					*destPointer1 |= charRep | (charRep >> 1) | (charRep >> 2);
 					*destPointer2 |= charRep | (charRep >> 1) | (charRep >> 2);
@@ -210,15 +220,15 @@ void Font::createOutline(FontData *font) {
 		// "Hollow out" character to prevent overdraw
 		for (row = 0; row < font->normal.header.charHeight; row++) {
 			for (currentByte = 0; currentByte < font->outline.fontCharEntry[i].byteWidth; currentByte++) {
-				destPointer2 = font->outline.font + font->outline.header.rowLength * (row + 1) + font->outline.fontCharEntry[i].index + currentByte;
+				destPointer2 = &font->outline.font[font->outline.header.rowLength * (row + 1) + font->outline.fontCharEntry[i].index + currentByte];
 				if (currentByte > 0) {
 					// Get last two columns from previous byte
-					srcPointer = font->normal.font + font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + (currentByte - 1);
+					srcPointer = &font->normal.font[font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + (currentByte - 1)];
 					*destPointer2 &= ((*srcPointer << 7) ^ 0xFFU);
 				}
 
 				if (currentByte < font->normal.fontCharEntry[i].byteWidth) {
-					srcPointer = font->normal.font + font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + currentByte;
+					srcPointer = &font->normal.font[font->normal.header.rowLength * row + font->normal.fontCharEntry[i].index + currentByte];
 					*destPointer2 &= ((*srcPointer >> 1) ^ 0xFFU);
 				}
 			}
@@ -289,7 +299,7 @@ void Font::draw(FontId fontId, const char *text, size_t count, const Common::Poi
 
 void Font::outFont(const FontStyle &drawFont, const char *text, size_t count, const Common::Point &point, int color, FontEffectFlags flags) {
 	const byte *textPointer;
-	byte *c_dataPointer;
+	const byte *c_dataPointer;
 	int c_code;
 	int charRow = 0;
 	Point textPoint(point);
@@ -384,7 +394,7 @@ void Font::outFont(const FontStyle &drawFont, const char *text, size_t count, co
 				break;
 			}
 
-			c_dataPointer = drawFont.font + charRow * drawFont.header.rowLength + drawFont.fontCharEntry[c_code].index;
+			c_dataPointer = &drawFont.font[charRow * drawFont.header.rowLength + drawFont.fontCharEntry[c_code].index];
 
 			for (c_byte = 0; c_byte < c_byte_len; c_byte++, c_dataPointer++) {
 				// Check each bit, draw pixel if bit is set
@@ -458,7 +468,6 @@ int Font::getHeight(FontId fontId, const char *text, int width, FontEffectFlags
 	int textWidth;
 	int textLength;
 	int fitWidth;
-	const char *startPointer;
 	const char *searchPointer;
 	const char *measurePointer;
 	const char *foundPointer;
@@ -489,7 +498,6 @@ int Font::getHeight(FontId fontId, const char *text, int width, FontEffectFlags
 	len_total = 0;
 	wc = 0;
 
-	startPointer = text;
 	measurePointer = text;
 	searchPointer = text;
 	endPointer = text + textLength;
@@ -522,7 +530,6 @@ int Font::getHeight(FontId fontId, const char *text, int width, FontEffectFlags
 			len_total = 0;
 			wc = 0;
 			measurePointer = searchPointer;
-			startPointer = searchPointer;
 		} else {
 			// Word will fit ok
 			w_total += w;
