@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/isomap.h $
- * $Id: isomap.h 48232 2010-03-10 21:44:58Z h00ligan $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -95,7 +95,7 @@ enum TileMapEdgeType {
 struct IsoTileData {
 	byte height;
 	int8 attributes;
-	size_t offset;
+	byte *tilePointer;
 	uint16 terrainMask;
 	byte FGDBGDAttr;
 	int8 GetMaskRule() const {
@@ -154,14 +154,13 @@ class IsoMap {
 public:
 	IsoMap(SagaEngine *vm);
 	~IsoMap() {
-		freeMem();
 	}
-	void loadImages(const byte * resourcePointer, size_t resourceLength);
-	void loadMap(const byte * resourcePointer, size_t resourceLength);
-	void loadPlatforms(const byte * resourcePointer, size_t resourceLength);
-	void loadMetaTiles(const byte * resourcePointer, size_t resourceLength);
-	void loadMulti(const byte * resourcePointer, size_t resourceLength);
-	void freeMem();
+	void loadImages(const ByteArray &resourceData);
+	void loadMap(const ByteArray &resourceData);
+	void loadPlatforms(const ByteArray &resourceData);
+	void loadMetaTiles(const ByteArray &resourceData);
+	void loadMulti(const ByteArray &resourceData);
+	void clear();
 	void draw();
 	void drawSprite(SpriteList &spriteList, int spriteNumber, const Location &location, const Point &screenPosition, int scale);
 	void adjustScroll(bool jump);
@@ -213,16 +212,14 @@ private:
 	IsoTileData *getTile(int16 u, int16 v, int16 z);
 
 
-	byte *_tileData;
-	size_t _tileDataLength;
+	ByteArray _tileData;
 	Common::Array<IsoTileData> _tilesTable;
 
 	Common::Array<TilePlatformData> _tilePlatformList;
 	Common::Array<MetaTileData> _metaTileList;
 
 	Common::Array<MultiTileEntryData> _multiTable;
-	uint16 _multiDataCount;
-	int16 *_multiTableData;
+	Common::Array<int16> _multiTableData;
 
 	TileMapData _tileMap;
 
