@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/music.cpp $
- * $Id: music.cpp 52923 2010-09-28 04:53:51Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,12 +30,13 @@
 #include "saga/resource.h"
 #include "saga/music.h"
 
-#include "sound/audiostream.h"
-#include "sound/mididrv.h"
-#include "sound/midiparser.h"
-#include "sound/decoders/raw.h"
+#include "audio/audiostream.h"
+#include "audio/mididrv.h"
+#include "audio/midiparser.h"
+#include "audio/decoders/raw.h"
 #include "common/config-manager.h"
 #include "common/file.h"
+#include "common/substream.h"
 
 namespace Saga {
 
@@ -43,84 +44,88 @@ namespace Saga {
 #define MUSIC_SUNSPOT 26
 
 MusicDriver::MusicDriver() : _isGM(false) {
-	memset(_channel, 0, sizeof(_channel));
-	_masterVolume = 0;
-	_nativeMT32 = ConfMan.getBool("native_mt32");
+
+	MidiPlayer::createDriver();
 
 	MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_MIDI | MDT_ADLIB | MDT_PREFER_GM);
-	_driver = MidiDriver::createMidi(dev);
 	_driverType = MidiDriver::getMusicType(dev);
-	if (isMT32())
-		_driver->property(MidiDriver::PROP_CHANNEL_MASK, 0x03FE);
 
-	this->open();
-}
-
-MusicDriver::~MusicDriver() {
-	this->close();
-	delete _driver;
-}
-
-int MusicDriver::open() {
 	int retValue = _driver->open();
-	if (retValue)
-		return retValue;
+	if (retValue == 0) {
+		if (_nativeMT32)
+			_driver->sendMT32Reset();
+		else
+			_driver->sendGMReset();
 
-	if (_nativeMT32)
-		_driver->sendMT32Reset();
-	else
-		_driver->sendGMReset();
-
-	return 0;
-}
-
-void MusicDriver::setVolume(int volume) {
-	volume = CLIP(volume, 0, 255);
-
-	if (_masterVolume == volume)
-		return;
-
-	_masterVolume = volume;
-
-	Common::StackLock lock(_mutex);
-
-	for (int i = 0; i < 16; ++i) {
-		if (_channel[i]) {
-			_channel[i]->volume(_channelVolume[i] * _masterVolume / 255);
-		}
+		_driver->setTimerCallback(this, &timerCallback);
 	}
 }
 
 void MusicDriver::send(uint32 b) {
-	byte channel = (byte)(b & 0x0F);
-	if ((b & 0xFFF0) == 0x07B0) {
-		// Adjust volume changes by master volume
-		byte volume = (byte)((b >> 16) & 0x7F);
-		_channelVolume[channel] = volume;
-		volume = volume * _masterVolume / 255;
-		b = (b & 0xFF00FFFF) | (volume << 16);
-	} else if ((b & 0xF0) == 0xC0 && !_isGM && !isMT32()) {
+	if ((b & 0xF0) == 0xC0 && !_isGM && !_nativeMT32) {
 		// Remap MT32 instruments to General Midi
 		b = (b & 0xFFFF00FF) | MidiDriver::_mt32ToGm[(b >> 8) & 0xFF] << 8;
-	} else if ((b & 0xFFF0) == 0x007BB0) {
-		// Only respond to All Notes Off if this channel
-		// has currently been allocated
-		if (!_channel[channel])
-			return;
+	}
+	Audio::MidiPlayer::send(b);
+}
+
+void MusicDriver::metaEvent(byte type, byte *data, uint16 length) {
+	// TODO: Seems SAGA does not want / need to handle end-of-track events?
+}
+
+void MusicDriver::play(SagaEngine *vm, ByteArray *buffer, bool loop) {
+	if (buffer->size() < 4) {
+		error("Music::play() wrong music resource size");
 	}
 
-	if (!_channel[channel])
-		_channel[channel] = (channel == 9) ? _driver->getPercussionChannel() : _driver->allocateChannel();
-	else
-		_channel[channel]->send(b);
+	// Check if the game is using XMIDI or SMF music
+	if (vm->getGameId() == GID_IHNM && vm->isMacResources()) {
+		// Just set an XMIDI parser for Mac IHNM for now
+		_parser = MidiParser::createParser_XMIDI();
+	} else {
+		if (!memcmp(buffer->getBuffer(), "FORM", 4)) {
+			_parser = MidiParser::createParser_XMIDI();
+			// ITE had MT32 mapped instruments
+			_isGM = (vm->getGameId() != GID_ITE);
+		} else {
+			_parser = MidiParser::createParser_SMF();
+			// ITE with standalone MIDI files is General MIDI
+			_isGM = (vm->getGameId() == GID_ITE);
+		}
+	}
+
+	if (!_parser->loadMusic(buffer->getBuffer(), buffer->size()))
+		error("Music::play() wrong music resource");
+
+	_parser->setTrack(0);
+	_parser->setMidiDriver(this);
+	_parser->setTimerRate(_driver->getBaseTempo());
+	_parser->property(MidiParser::mpCenterPitchWheelOnUnload, 1);
+	_parser->property(MidiParser::mpSendSustainOffOnNotesOff, 1);
+
+	// Handle music looping
+	_parser->property(MidiParser::mpAutoLoop, loop);
+//	_isLooping = loop;
+
+	_isPlaying = true;
 }
 
+void MusicDriver::pause() {
+	_isPlaying = false;
+}
+
+void MusicDriver::resume() {
+	_isPlaying = true;
+}
+
+
 Music::Music(SagaEngine *vm, Audio::Mixer *mixer) : _vm(vm), _mixer(mixer) {
 	_currentVolume = 0;
-	_driver = new MusicDriver();
+	_currentMusicBuffer = NULL;
+	_player = new MusicDriver();
 
 	_digitalMusicContext = _vm->_resource->getContext(GAME_DIGITALMUSICFILE);
-	if (!_driver->isAdlib())
+	if (!_player->isAdlib())
 		_musicContext = _vm->_resource->getContext(GAME_MUSICFILE_GM);
 	else
 		_musicContext = _vm->_resource->getContext(GAME_MUSICFILE_FM);
@@ -157,60 +162,19 @@ Music::Music(SagaEngine *vm, Audio::Mixer *mixer) : _vm(vm), _mixer(mixer) {
 		}
 	}
 
-	// Check if the game is using XMIDI or SMF music
-	if (_vm->getGameId() == GID_IHNM && _vm->isMacResources()) {
-		// Just set an XMIDI parser for Mac IHNM for now
-		_parser = MidiParser::createParser_XMIDI();
-	} else {
-		byte *resourceData;
-		size_t resourceSize;
-		int resourceId = (_vm->getGameId() == GID_ITE ? 9 : 0);
-		_vm->_resource->loadResource(_musicContext, resourceId, resourceData, resourceSize);
-		if (!memcmp(resourceData, "FORM", 4)) {
-			_parser = MidiParser::createParser_XMIDI();
-			// ITE had MT32 mapped instruments
-			_driver->setGM(_vm->getGameId() != GID_ITE);
-		} else {
-			_parser = MidiParser::createParser_SMF();
-			// ITE with standalone MIDI files is General MIDI
-			_driver->setGM(_vm->getGameId() == GID_ITE);
-		}
-		free(resourceData);
-	}
-
-	_parser->setMidiDriver(_driver);
-	_parser->setTimerRate(_driver->getBaseTempo());
-	_parser->property(MidiParser::mpCenterPitchWheelOnUnload, 1);
-
-	_songTableLen = 0;
-	_songTable = 0;
-
-	_midiMusicData = NULL;
 	_digitalMusic = false;
 }
 
 Music::~Music() {
 	_vm->getTimerManager()->removeTimerProc(&musicVolumeGaugeCallback);
 	_mixer->stopHandle(_musicHandle);
-	_driver->setTimerCallback(NULL, NULL);
-	delete _driver;
-	_parser->setMidiDriver(NULL);
-	delete _parser;
-
-	free(_songTable);
-	free(_midiMusicData);
+	delete _player;
 }
 
 void Music::musicVolumeGaugeCallback(void *refCon) {
 	((Music *)refCon)->musicVolumeGauge();
 }
 
-void Music::onTimer(void *refCon) {
-	Music *music = (Music *)refCon;
-	Common::StackLock lock(music->_driver->_mutex);
-	music->_parser->onTimer();
-}
-
 void Music::musicVolumeGauge() {
 	int volume;
 
@@ -226,7 +190,7 @@ void Music::musicVolumeGauge() {
 		volume = 1;
 
 	_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, volume);
-	_driver->setVolume(volume);
+	_player->setVolume(volume);
 
 	if (_currentVolumePercent == 100) {
 		_vm->getTimerManager()->removeTimerProc(&musicVolumeGaugeCallback);
@@ -242,8 +206,11 @@ void Music::setVolume(int volume, int time) {
 		volume = 255;
 
 	if (time == 1) {
+		if (ConfMan.hasKey("mute") && ConfMan.getBool("mute"))
+			volume = 0;
+
 		_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, volume);
-		_driver->setVolume(volume);
+		_player->setVolume(volume);
 		_vm->getTimerManager()->removeTimerProc(&musicVolumeGaugeCallback);
 		_currentVolume = volume;
 		return;
@@ -253,14 +220,12 @@ void Music::setVolume(int volume, int time) {
 }
 
 bool Music::isPlaying() {
-	return _mixer->isSoundHandleActive(_musicHandle) || _parser->isPlaying();
+	return _mixer->isSoundHandleActive(_musicHandle) || _player->isPlaying();
 }
 
 void Music::play(uint32 resourceId, MusicFlags flags) {
 	Audio::SeekableAudioStream *audioStream = NULL;
-	byte *resourceData;
-	size_t resourceSize;
-	uint32 loopStart;
+	uint32 loopStart = 0;
 
 	debug(2, "Music::play %d, %d", resourceId, flags);
 
@@ -270,7 +235,7 @@ void Music::play(uint32 resourceId, MusicFlags flags) {
 
 	_trackNumber = resourceId;
 	_mixer->stopHandle(_musicHandle);
-	_parser->unloadMusic();
+	_player->stop();
 
 	int realTrackNumber;
 
@@ -392,39 +357,28 @@ void Music::play(uint32 resourceId, MusicFlags flags) {
 #endif
 		return;
 	} else {
-		_vm->_resource->loadResource(_musicContext, resourceId, resourceData, resourceSize);
+		if (_currentMusicBuffer == &_musicBuffer[1]) {
+			_currentMusicBuffer = &_musicBuffer[0];
+		} else {
+			_currentMusicBuffer = &_musicBuffer[1];
+		}
+		_vm->_resource->loadResource(_musicContext, resourceId, *_currentMusicBuffer);
 	}
 
-	if (resourceSize < 4) {
-		error("Music::play() wrong music resource size");
-	}
-
-	if (!_parser->loadMusic(resourceData, resourceSize))
-		error("Music::play() wrong music resource");
-
-	_parser->setTrack(0);
-	_driver->setTimerCallback(this, &onTimer);
-
+	_player->play(_vm, _currentMusicBuffer, (flags & MUSIC_LOOP));
 	setVolume(_vm->_musicVolume);
-
-	// Handle music looping
-	_parser->property(MidiParser::mpAutoLoop, (flags & MUSIC_LOOP) ? 1 : 0);
-
-	free(_midiMusicData);
-	_midiMusicData = resourceData;
 }
 
 void Music::pause() {
-	_driver->setTimerCallback(NULL, NULL);
+	_player->pause();
 }
 
 void Music::resume() {
-	_driver->setTimerCallback(this, &onTimer);
+	_player->resume();
 }
 
 void Music::stop() {
-	_driver->setTimerCallback(NULL, NULL);
-	_parser->unloadMusic();
+	_player->stop();
 }
 
 } // End of namespace Saga
