@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/music.h $
- * $Id: music.h 52736 2010-09-15 22:00:20Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,12 +28,12 @@
 #ifndef SAGA_MUSIC_H
 #define SAGA_MUSIC_H
 
-#include "sound/audiocd.h"
-#include "sound/mididrv.h"
-#include "sound/midiparser.h"
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/flac.h"
+#include "audio/midiplayer.h"
+#include "audio/midiparser.h"
+#include "audio/mixer.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/flac.h"
 #include "common/mutex.h"
 
 namespace Saga {
@@ -44,50 +44,26 @@ enum MusicFlags {
 	MUSIC_DEFAULT = 0xffff
 };
 
-class MusicDriver : public MidiDriver {
+class MusicDriver : public Audio::MidiPlayer {
 public:
 	MusicDriver();
-	~MusicDriver();
 
-	void setVolume(int volume);
-	int getVolume() { return _masterVolume; }
+	void play(SagaEngine *vm, ByteArray *buffer, bool loop);
+	virtual void pause();
+	virtual void resume();
 
-	bool isAdlib() { return _driverType == MT_ADLIB; }
-	bool isMT32() { return _driverType == MT_MT32 || _nativeMT32; }
-	void setGM(bool isGM) { _isGM = isGM; }
+	bool isAdlib() const { return _driverType == MT_ADLIB; }
 
-	//MidiDriver interface implementation
-	int open();
-	void close() { _driver->close(); }
-	void send(uint32 b);
+	// FIXME
+	bool isPlaying() const { return _parser && _parser->isPlaying(); }
 
-	void metaEvent(byte type, byte *data, uint16 length) {}
-
-	void setTimerCallback(void *timerParam, void (*timerProc)(void *)) { _driver->setTimerCallback(timerParam, timerProc); }
-	uint32 getBaseTempo()	{ return _driver->getBaseTempo(); }
-
-	//Channel allocation functions
-	MidiChannel *allocateChannel()		{ return 0; }
-	MidiChannel *getPercussionChannel()	{ return 0; }
-
-	Common::Mutex _mutex;
+	// MidiDriver_BASE interface implementation
+	virtual void send(uint32 b);
+	virtual void metaEvent(byte type, byte *data, uint16 length);
 
 protected:
-
-	static void onTimer(void *data);
-
-	MidiChannel *_channel[16];
-	MidiDriver *_driver;
 	MusicType _driverType;
-	byte _channelVolume[16];
 	bool _isGM;
-	bool _nativeMT32;
-
-	byte _masterVolume;
-
-	byte *_musicData;
-	uint16 *_buf;
-	size_t _musicDataSize;
 };
 
 class Music {
@@ -106,14 +82,13 @@ public:
 	void setVolume(int volume, int time = 1);
 	int getVolume() { return _currentVolume; }
 
-	int32 *_songTable;
-	int _songTableLen;
+	Common::Array<int32> _songTable;
 
 private:
 	SagaEngine *_vm;
 	Audio::Mixer *_mixer;
 
-	MusicDriver *_driver;
+	MusicDriver *_player;
 	Audio::SoundHandle _musicHandle;
 	uint32 _trackNumber;
 
@@ -124,13 +99,13 @@ private:
 
 	ResourceContext *_musicContext;
 	ResourceContext *_digitalMusicContext;
-	MidiParser *_parser;
 
-	byte *_midiMusicData;
 
 	static void musicVolumeGaugeCallback(void *refCon);
 	static void onTimer(void *refCon);
 	void musicVolumeGauge();
+	ByteArray *_currentMusicBuffer;
+	ByteArray _musicBuffer[2];
 };
 
 } // End of namespace Saga
