@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/resource.h $
- * $Id: resource.h 49046 2010-05-16 10:23:44Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #ifndef SAGA_RESOURCE_H
 #define SAGA_RESOURCE_H
 
+#include "common/array.h"
 #include "common/file.h"
 #include "common/list.h"
 
@@ -39,6 +40,9 @@ namespace Saga {
 
 #define RSC_MIN_FILESIZE (RSC_TABLEINFO_SIZE + RSC_TABLEENTRY_SIZE + 1)
 
+class SagaEngine;
+class ByteArray;
+
 struct PatchData {
 	Common::File *_patchFile;
 	const char *_fileName;
@@ -79,27 +83,10 @@ struct ResourceData {
 	}
 };
 
-class ResourceDataArray : public Common::Array<ResourceData> {
-};
+typedef Common::Array<ResourceData> ResourceDataArray;
 
 class ResourceContext {
 friend class Resource;
-protected:
-	const char *_fileName;
-	uint16 _fileType;
-	bool _isCompressed;
-	int _serial;					// IHNM speech files
-
-	bool _isBigEndian;
-	ResourceDataArray _table;
-	Common::File _file;
-	int32 _fileSize;
-
-	bool load(SagaEngine *_vm, Resource *resource);
-	bool loadResV1(uint32 contextOffset, uint32 contextSize);
-
-	virtual bool loadMac() = 0;
-	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) = 0;
 public:
 
 	ResourceContext():
@@ -108,32 +95,14 @@ public:
 		_fileSize(0) {
 	}
 
-	virtual ~ResourceContext() {
-	}
+	virtual ~ResourceContext() { }
 
-	bool isCompressed() const {
-		return _isCompressed;
-	}
-
-	uint16 fileType() const {
-		return _fileType;
-	}
-
-	int32 fileSize() const {
-		return _fileSize;
-	}
-
-	int serial() const {
-		return _serial;
-	}
-
-	bool isBigEndian() const {
-		return _isBigEndian;
-	}
-
-	const char * fileName() const {
-		return _fileName;
-	}
+	bool isCompressed() const {	return _isCompressed; }
+	uint16 fileType() const { return _fileType; }
+	int32 fileSize() const { return _fileSize; }
+	int serial() const { return _serial; }
+	bool isBigEndian() const { return _isBigEndian; }
+	const char * fileName() const {	return _fileName; }
 
 	Common::File *getFile(ResourceData *resourceData) {
 		Common::File *file;
@@ -172,10 +141,26 @@ public:
 		}
 		return -1;
 	}
+protected:
+	const char *_fileName;
+	uint16 _fileType;
+	bool _isCompressed;
+	int _serial;					// IHNM speech files
+
+	bool _isBigEndian;
+	ResourceDataArray _table;
+	Common::File _file;
+	int32 _fileSize;
+
+	bool load(SagaEngine *_vm, Resource *resource);
+	bool loadResV1(uint32 contextOffset, uint32 contextSize);
+
+	virtual bool loadMacMIDI() { return false; }
+	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) = 0;
+	virtual void processPatches(Resource *resource, const GamePatchDescription *patchFiles) { }
 };
 
-class ResourceContextList : public Common::List<ResourceContext*> {
-};
+typedef Common::List<ResourceContext*> ResourceContextList;
 
 struct MetaResource {
 	int16 sceneIndex;
@@ -206,12 +191,13 @@ public:
 	virtual ~Resource();
 	bool createContexts();
 	void clearContexts();
-	void loadResource(ResourceContext *context, uint32 resourceId, byte*&resourceBuffer, size_t &resourceSize);
+	void loadResource(ResourceContext *context, uint32 resourceId, ByteArray &resourceBuffer);
 
 	virtual uint32 convertResourceId(uint32 resourceId) = 0;
 	virtual void loadGlobalResources(int chapter, int actorsEntrance) = 0;
 
 	ResourceContext *getContext(uint16 fileType, int serial = 0);
+	virtual MetaResource* getMetaResource() = 0;
 protected:
 	SagaEngine *_vm;
 	ResourceContextList _contexts;
@@ -221,23 +207,24 @@ protected:
 
 	void addContext(const char *fileName, uint16 fileType, bool isCompressed = false, int serial = 0);
 	virtual ResourceContext *createContext() = 0;
-public:
-	virtual MetaResource* getMetaResource() = 0;
 };
 
 // ITE
 class ResourceContext_RSC: public ResourceContext {
 protected:
-	virtual bool loadMac();
+	virtual bool loadMacMIDI();
 	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) {
 		return loadResV1(contextOffset, contextSize);
 	}
+	virtual void processPatches(Resource *resource, const GamePatchDescription *patchFiles);
 };
 
 class Resource_RSC : public Resource {
 public:
 	Resource_RSC(SagaEngine *vm) : Resource(vm) {}
-	virtual uint32 convertResourceId(uint32 resourceId);
+	virtual uint32 convertResourceId(uint32 resourceId) {
+		return _vm->isMacResources() ? resourceId - 2 : resourceId;
+	}
 	virtual void loadGlobalResources(int chapter, int actorsEntrance) {}
 	virtual MetaResource* getMetaResource() {
 		MetaResource *dummy = 0;
@@ -253,20 +240,16 @@ protected:
 // IHNM
 class ResourceContext_RES: public ResourceContext {
 protected:
-	virtual bool loadMac() {
-		return false;
-	}
 	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) {
 		return loadResV1(0, contextSize);
 	}
+
+	virtual void processPatches(Resource *resource, const GamePatchDescription *patchFiles);
 };
 
-//TODO: move load routines from sndres
+// TODO: move load routines from sndres
 class VoiceResourceContext_RES: public ResourceContext {
 protected:
-	virtual bool loadMac() {
-		return false;
-	}
 	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) {
 		return false;
 	}
@@ -298,9 +281,6 @@ class ResourceContext_HRS: public ResourceContext {
 protected:
 	ResourceDataArray _categories;
 
-	virtual bool loadMac() {
-		return false;
-	}
 	virtual bool loadRes(uint32 contextOffset, uint32 contextSize) {
 		return loadResV2(contextSize);
 	}
