@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/resource_hrs.cpp $
- * $Id: resource_hrs.cpp 46254 2009-12-04 17:52:42Z h00ligan $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -62,7 +62,7 @@ bool ResourceContext_HRS::loadResV2(uint32 contextSize) {
 	readElement(_file, origin);
 
 	// Check if the file is valid
-	if (origin.id != MKID_BE('HRES')) {	// header
+	if (origin.id != MKTAG('H','R','E','S')) {	// header
 		return false;
 	}
 
