@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/scene.h $
- * $Id: scene.h 49079 2010-05-18 14:17:24Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,6 +32,7 @@
 #include "saga/actor.h"
 #include "saga/interface.h"
 #include "saga/puzzle.h"
+#include "saga/events.h"
 
 namespace Saga {
 
@@ -55,8 +56,6 @@ namespace Saga {
 
 class ObjectMap;
 
-struct Event;
-
 enum SceneFlags {
 	kSceneFlagISO        = 1,
 	kSceneFlagShowCursor = 2
@@ -74,7 +73,6 @@ enum FTA2Endings {
 struct BGInfo {
 	Rect bounds;
 	byte *buffer;
-	size_t bufferLength;
 };
 
 typedef int (SceneProc) (int, void *);
@@ -112,11 +110,14 @@ enum SAGAResourceTypes {
 struct SceneResourceData {
 	uint32 resourceId;
 	int resourceType;
-	byte *buffer;
-	size_t size;
 	bool invalid;
+
+	SceneResourceData() : resourceId(0), resourceType(0),  invalid(false) {
+	}
 };
 
+typedef Common::Array<SceneResourceData> SceneResourceDataArray;
+
 #define SAGA_SCENE_DESC_LEN 16
 
 struct SceneDescription {
@@ -128,47 +129,30 @@ struct SceneDescription {
 	uint16 sceneScriptEntrypointNumber;
 	uint16 startScriptEntrypointNumber;
 	int16 musicResourceId;
-	SceneResourceData *resourceList;
-	size_t resourceListCount;
+	
+	void reset()  {
+		flags = resourceListResourceId = endSlope = beginSlope = scriptModuleNumber = sceneScriptEntrypointNumber = startScriptEntrypointNumber = musicResourceId = 0;
+	}
 };
 
 struct SceneEntry {
 	Location location;
-	int facing;
+	uint16 facing;
 };
 
-struct SceneEntryList {
-	SceneEntry *entryList;
-	int entryListCount;
-
-	const SceneEntry * getEntry(int index) {
-		if ((index < 0) || (index >= entryListCount)) {
-			error("SceneEntryList::getEntry wrong index (%d)", index);
-		}
-		return &entryList[index];
-	}
-	void freeMem() {
-		free(entryList);
-		memset(this, 0, sizeof(*this));
-	}
-	SceneEntryList() {
-		memset(this, 0, sizeof(*this));
-	}
-	~SceneEntryList() {
-		freeMem();
-	}
-};
+typedef Common::Array<SceneEntry> SceneEntryList;
 
 struct SceneImage {
-	int loaded;
+	bool loaded;
 	int w;
 	int h;
 	int p;
-	byte *buf;
-	size_t buf_len;
-	byte *res_buf;
-	size_t res_len;
+	ByteArray buffer;
 	PalEntry pal[256];
+
+	SceneImage() : loaded(false), w(0), h(0), p(0) {
+		memset(pal, 0, sizeof(pal));
+	}
 };
 
 
@@ -179,14 +163,12 @@ enum SceneTransitionType {
 
 enum SceneLoadFlags {
 	kLoadByResourceId,
-	kLoadBySceneNumber,
-	kLoadByDescription
+	kLoadBySceneNumber
 };
 
 struct LoadSceneParams {
 	int32 sceneDescriptor;
 	SceneLoadFlags loadFlag;
-	SceneDescription* sceneDescription;
 	SceneProc *sceneProc;
 	bool sceneSkipTarget;
 	SceneTransitionType transitionType;
@@ -248,8 +230,8 @@ class Scene {
 	void skipScene();
 	void endScene();
 	void restoreScene();
-	void queueScene(LoadSceneParams *sceneQueue) {
-		_sceneQueue.push_back(*sceneQueue);
+	void queueScene(const LoadSceneParams &sceneQueue) {
+		_sceneQueue.push_back(sceneQueue);
 	}
 
 	void draw();
@@ -258,7 +240,7 @@ class Scene {
 	bool isInIntro() { return !_inGame; }
 	const Rect& getSceneClip() const { return _sceneClip; }
 
-	void getBGMaskInfo(int &width, int &height, byte *&buffer, size_t &bufferLength);
+	void getBGMaskInfo(int &width, int &height, byte *&buffer);
 	int isBGMaskPresent() { return _bgMask.loaded; }
 
 	int getBGMaskType(const Point &testPoint) {
@@ -274,7 +256,7 @@ class Scene {
 		}
 		#endif
 
-		return (_bgMask.buf[offset] >> 4) & 0x0f;
+		return (_bgMask.buffer[offset] >> 4) & 0x0f;
 	}
 
 	bool validBGMaskPoint(const Point &testPoint) {
@@ -325,7 +307,7 @@ class Scene {
 
 	bool isSceneLoaded() const { return _sceneLoaded; }
 
-	int getSceneResourceId(int sceneNumber) {
+	uint16 getSceneResourceId(int sceneNumber) {
 	#ifdef SCENE_DEBUG
 		if ((sceneNumber < 0) || (sceneNumber >= _sceneCount)) {
 			error("getSceneResourceId: wrong sceneNumber %i", sceneNumber);
@@ -376,17 +358,16 @@ class Scene {
  private:
 	void loadScene(LoadSceneParams &loadSceneParams);
 	void loadSceneDescriptor(uint32 resourceId);
-	void loadSceneResourceList(uint32 resourceId);
-	void loadSceneEntryList(const byte* resourcePointer, size_t resourceLength);
-	void processSceneResources();
+	void loadSceneResourceList(uint32 resourceId, SceneResourceDataArray &resourceList);
+	void loadSceneEntryList(const ByteArray &resourceData);
+	void processSceneResources(SceneResourceDataArray &resourceList);
 	void getResourceTypes(SAGAResourceTypes *&types, int &typesCount);
 
 
 	SagaEngine *_vm;
 
 	ResourceContext *_sceneContext;
-	int *_sceneLUT;
-	int _sceneCount;
+	Common::Array<uint16> _sceneLUT;
 	SceneQueueList _sceneQueue;
 	bool _sceneLoaded;
 	int _currentProtag;
@@ -398,10 +379,7 @@ class Scene {
 	int _currentMusicRepeat;
 	bool _chapterPointsChanged;
 	bool _inGame;
-	bool _loadDescription;
 	SceneDescription _sceneDescription;
-	size_t _resourceListCount;
-	SceneResourceData *_resourceList;
 	SceneProc *_sceneProc;
 	SceneImage _bg;
 	SceneImage _bgMask;
@@ -456,8 +434,8 @@ class Scene {
 	static int SC_ITEIntroFaireTentProc(int param, void *refCon);
 
  private:
-	Event *ITEQueueDialogue(Event *q_event, int n_dialogues, const IntroDialogue dialogue[]);
-	Event *ITEQueueCredits(int delta_time, int duration, int n_credits, const IntroCredit credits[]);
+	EventColumns *ITEQueueDialogue(EventColumns *eventColumns, int n_dialogues, const IntroDialogue dialogue[]);
+	EventColumns *ITEQueueCredits(int delta_time, int duration, int n_credits, const IntroCredit credits[]);
 	int ITEIntroAnimProc(int param);
 	int ITEIntroCave1Proc(int param);
 	int ITEIntroCave2Proc(int param);
