@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/sndres.cpp $
- * $Id: sndres.cpp 52976 2010-10-02 09:19:28Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,12 +34,12 @@
 
 #include "common/file.h"
 
-#include "sound/audiostream.h"
-#include "sound/decoders/adpcm.h"
-#include "sound/decoders/aiff.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/voc.h"
-#include "sound/decoders/wave.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/adpcm.h"
+#include "audio/decoders/aiff.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/voc.h"
+#include "audio/decoders/wave.h"
 #ifdef ENABLE_SAGA2
 #include "saga/shorten.h"
 #endif
@@ -60,8 +60,11 @@ SndRes::SndRes(SagaEngine *vm) : _vm(vm), _sfxContext(NULL), _voiceContext(NULL)
 	setVoiceBank(0);
 
 	if (_vm->getGameId() == GID_ITE) {
-		_fxTable = ITE_SfxTable;
-		_fxTableLen = ITE_SFXCOUNT;
+		_fxTable.resize(ITE_SFXCOUNT);
+		for (uint i = 0; i < _fxTable.size(); i++) {
+			_fxTable[i].res = ITE_SfxTable[i].res;
+			_fxTable[i].vol = ITE_SfxTable[i].vol;
+		}
 #ifdef ENABLE_IHNM
 	} else if (_vm->getGameId() == GID_IHNM) {
 		ResourceContext *resourceContext;
@@ -71,32 +74,24 @@ SndRes::SndRes(SagaEngine *vm) : _vm(vm), _sfxContext(NULL), _voiceContext(NULL)
 			error("Resource::loadGlobalResources() resource context not found");
 		}
 
-		byte *resourcePointer;
-		size_t resourceLength;
+		ByteArray resourceData;
 
 		if (_vm->isIHNMDemo()) {
-			_vm->_resource->loadResource(resourceContext, RID_IHNMDEMO_SFX_LUT,
-									 resourcePointer, resourceLength);
+			_vm->_resource->loadResource(resourceContext, RID_IHNMDEMO_SFX_LUT, resourceData);
 		} else {
-			_vm->_resource->loadResource(resourceContext, RID_IHNM_SFX_LUT,
-									 resourcePointer, resourceLength);
+			_vm->_resource->loadResource(resourceContext, RID_IHNM_SFX_LUT, resourceData);
 		}
 
-		if (resourceLength == 0) {
+		if (resourceData.empty()) {
 			error("Sndres::SndRes can't read SfxIDs table");
 		}
 
-		_fxTableIDsLen = resourceLength / 2;
-		_fxTableIDs = (int16 *)malloc(_fxTableIDsLen * sizeof(int16));
+		_fxTableIDs.resize(resourceData.size() / 2);
 
-		MemoryReadStream metaS(resourcePointer, resourceLength);
-		for (int i = 0; i < _fxTableIDsLen; i++)
+		ByteArrayReadStreamEndian metaS(resourceData);
+		for (uint i = 0; i < _fxTableIDs.size(); i++) {
 			_fxTableIDs[i] = metaS.readSint16LE();
-
-		free(resourcePointer);
-
-		_fxTable = 0;
-		_fxTableLen = 0;
+		}
 #endif
 #ifdef ENABLE_SAGA2
 	} else if (_vm->getGameId() == GID_DINO) {
@@ -108,12 +103,6 @@ SndRes::SndRes(SagaEngine *vm) : _vm(vm), _sfxContext(NULL), _voiceContext(NULL)
 }
 
 SndRes::~SndRes() {
-#ifdef ENABLE_IHNM
-	if (_vm->getGameId() == GID_IHNM) {
-		free(_fxTable);
-		free(_fxTableIDs);
-	}
-#endif
 }
 
 void SndRes::setVoiceBank(int serial) {
@@ -327,7 +316,7 @@ bool SndRes::load(ResourceContext *context, uint32 resourceId, SoundBuffer &buff
 #endif
 		} else if (resourceType == kSoundVOC) {
 			data = Audio::loadVOCFromStream(readS, size, rate);
-			result = (data != 0);
+			result = (data != NULL);
 			if (onlyHeader)
 				free(data);
 			buffer.flags |= Audio::FLAG_UNSIGNED;
@@ -339,11 +328,13 @@ bool SndRes::load(ResourceContext *context, uint32 resourceId, SoundBuffer &buff
 			buffer.frequency = rate;
 			buffer.size = size;
 
-			if (!onlyHeader && resourceType != kSoundVOC) {
-				buffer.buffer = (byte *)malloc(size);
-				readS.read(buffer.buffer, size);
-			} else if (!onlyHeader && resourceType == kSoundVOC) {
-				buffer.buffer = data;
+			if (!onlyHeader) {
+				if (resourceType == kSoundVOC) {
+					buffer.buffer = data;
+				} else {
+					buffer.buffer = (byte *)malloc(size);
+					readS.read(buffer.buffer, size);
+				}
 			}
 		}
 		break;
