@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/sound.cpp $
- * $Id: sound.cpp 49725 2010-06-15 10:25:34Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,15 +28,15 @@
 #include "saga/saga.h"
 #include "saga/sound.h"
 
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
-#include "sound/decoders/adpcm.h"
-#include "sound/decoders/raw.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/decoders/adpcm.h"
+#include "audio/decoders/raw.h"
 
 namespace Saga {
 
 Sound::Sound(SagaEngine *vm, Audio::Mixer *mixer) :
-	_vm(vm), _mixer(mixer), _voxStream(0) {
+	_vm(vm), _mixer(mixer) {
 
 	for (int i = 0; i < SOUND_HANDLES; i++)
 		_handles[i].type = kFreeHandle;
@@ -45,7 +45,6 @@ Sound::Sound(SagaEngine *vm, Audio::Mixer *mixer) :
 }
 
 Sound::~Sound() {
-	delete _voxStream;
 }
 
 SndHandle *Sound::getHandle() {
@@ -176,8 +175,12 @@ void Sound::stopAll() {
 }
 
 void Sound::setVolume() {
-	_vm->_soundVolume = ConfMan.getInt("sfx_volume");
-	_vm->_speechVolume = ConfMan.getInt("speech_volume");
+	bool mute = false;
+	if (ConfMan.hasKey("mute"))
+		mute = ConfMan.getBool("mute");
+
+	_vm->_soundVolume = mute ? 0 : ConfMan.getInt("sfx_volume");
+	_vm->_speechVolume = mute ? 0 : ConfMan.getInt("speech_volume");
 	_mixer->setVolumeForSoundType(Audio::Mixer::kSFXSoundType, _vm->_soundVolume);
 	_mixer->setVolumeForSoundType(Audio::Mixer::kSpeechSoundType, _vm->_speechVolume);
 }
