@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/sound.h $
- * $Id: sound.h 49725 2010-06-15 10:25:34Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,10 +29,10 @@
 #define SAGA_SOUND_H
 
 #include "common/file.h"
-#include "sound/mixer.h"
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/flac.h"
+#include "audio/mixer.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/flac.h"
 
 namespace Saga {
 
@@ -95,7 +95,6 @@ public:
 
 	SagaEngine *_vm;
 	Audio::Mixer *_mixer;
-	MemoryReadStream *_voxStream;
 
 	SndHandle _handles[SOUND_HANDLES];
 };
