@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/console.h $
- * $Id: console.h 53821 2010-10-25 11:32:23Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -36,17 +36,20 @@ namespace Sci {
 class SciEngine;
 struct List;
 
-reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecode);
+reg_t disassemble(EngineState *s, reg_t pos, bool printBWTag, bool printBytecode);
+bool isJumpOpcode(EngineState *s, reg_t pos, reg_t& jumpOffset);
 
 class Console : public GUI::Debugger {
 public:
 	Console(SciEngine *engine);
 	virtual ~Console();
-	void preEnter();
-	void postEnter();
 
 	int printObject(reg_t pos);
 
+private:
+	virtual void preEnter();
+	virtual void postEnter();
+
 private:
 	// General
 	bool cmdHelp(int argc, const char **argv);
@@ -75,7 +78,6 @@ private:
 	bool cmdList(int argc, const char **argv);
 	bool cmdHexgrep(int argc, const char **argv);
 	bool cmdVerifyScripts(int argc, const char **argv);
-	bool cmdShowInstruments(int argc, const char **argv);
 	// Game
 	bool cmdSaveGame(int argc, const char **argv);
 	bool cmdRestoreGame(int argc, const char **argv);
@@ -90,12 +92,11 @@ private:
 	bool cmdSetPalette(int argc, const char **argv);
 	bool cmdDrawPic(int argc, const char **argv);
 	bool cmdDrawCel(int argc, const char **argv);
-#ifdef ENABLE_SCI32
-	bool cmdDrawRobot(int argc, const char **argv);
-#endif
 	bool cmdUndither(int argc, const char **argv);
 	bool cmdPicVisualize(int argc, const char **argv);
 	bool cmdPlayVideo(int argc, const char **argv);
+	bool cmdAnimateList(int argc, const char **argv);
+	bool cmdWindowList(int argc, const char **argv);
 	// Segments
 	bool cmdPrintSegmentTable(int argc, const char **argv);
 	bool cmdSegmentInfo(int argc, const char **argv);
@@ -115,6 +116,8 @@ private:
 	bool cmdStopAllSounds(int argc, const char **argv);
 	bool cmdSfx01Header(int argc, const char **argv);
 	bool cmdSfx01Track(int argc, const char **argv);
+	bool cmdShowInstruments(int argc, const char **argv);
+	bool cmdMapInstrument(int argc, const char **argv);
 	// Script
 	bool cmdAddresses(int argc, const char **argv);
 	bool cmdRegisters(int argc, const char **argv);
@@ -162,12 +165,18 @@ private:
 	void hexDumpReg(const reg_t *data, int len, int regsPerLine = 4, int startOffset = 0, bool isArray = false);
 
 private:
+	/**
+	 * Prints all the scripts calling the specified kernel function.
+	 * NOTE: The results produced by this aren't 100% correct, as it
+	 * does not dissect script exports
+	 */
+	void printKernelCallsFound(int kernelFuncNum, bool showFoundScripts);
+
 	SciEngine *_engine;
 	DebugState &_debugState;
 	bool _mouseVisible;
 	Common::String _videoFile;
 	int _videoFrameDelay;
-	uint32 _enterTime;
 };
 
 } // End of namespace Sci
