@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/debug.h $
- * $Id: debug.h 52490 2010-09-02 09:05:08Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,18 +34,18 @@ namespace Sci {
 // These types are used both as identifiers and as elements of bitfields
 enum BreakpointType {
 	/**
-	 * Break when selector is executed. data contains (char *) selector name
+	 * Break when a selector is executed. Data contains (char *) selector name
 	 * (in the format Object::Method)
 	 */
-	BREAK_SELECTOREXEC = 1 << 0, // break when selector gets executed
-	BREAK_SELECTORREAD = 1 << 1, // break when selector gets executed
-	BREAK_SELECTORWRITE = 1 << 2, // break when selector gets executed
+	BREAK_SELECTOREXEC  = 1 << 0, // break when a function selector is executed
+	BREAK_SELECTORREAD  = 1 << 1, // break when a variable selector is read
+	BREAK_SELECTORWRITE = 1 << 2, // break when a variable selector is written
 
 	/**
-	 * Break when an exported function is called. data contains
+	 * Break when an exported function is called. Data contains
 	 * script_no << 16 | export_no.
 	 */
-	BREAK_EXPORT = 1 << 3
+	BREAK_EXPORT        = 1 << 3
 };
 
 struct Breakpoint {
