@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/kfile.cpp $
- * $Id: kfile.cpp 52694 2010-09-12 21:56:37Z criezy $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "common/file.h"
 #include "common/str.h"
 #include "common/savefile.h"
+#include "common/system.h"
 #include "common/translation.h"
 
 #include "gui/saveload.h"
@@ -132,17 +133,17 @@ reg_t file_open(EngineState *s, const char *filename, int mode, bool unwrapFilen
 		}
 
 		if (!inFile)
-			debugC(2, kDebugLevelFile, "  -> file_open(_K_FILE_MODE_OPEN_OR_FAIL): failed to open file '%s'", englishName.c_str());
+			debugC(kDebugLevelFile, "  -> file_open(_K_FILE_MODE_OPEN_OR_FAIL): failed to open file '%s'", englishName.c_str());
 	} else if (mode == _K_FILE_MODE_CREATE) {
 		// Create the file, destroying any content it might have had
 		outFile = saveFileMan->openForSaving(wrappedName);
 		if (!outFile)
-			debugC(2, kDebugLevelFile, "  -> file_open(_K_FILE_MODE_CREATE): failed to create file '%s'", englishName.c_str());
+			debugC(kDebugLevelFile, "  -> file_open(_K_FILE_MODE_CREATE): failed to create file '%s'", englishName.c_str());
 	} else if (mode == _K_FILE_MODE_OPEN_OR_CREATE) {
 		// Try to open file, create it if it doesn't exist
 		outFile = saveFileMan->openForSaving(wrappedName);
 		if (!outFile)
-			debugC(2, kDebugLevelFile, "  -> file_open(_K_FILE_MODE_CREATE): failed to create file '%s'", englishName.c_str());
+			debugC(kDebugLevelFile, "  -> file_open(_K_FILE_MODE_CREATE): failed to create file '%s'", englishName.c_str());
 		// QfG1 opens the character export file with _K_FILE_MODE_CREATE first,
 		// closes it immediately and opens it again with this here. Perhaps
 		// other games use this for read access as well. I guess changing this
@@ -153,7 +154,7 @@ reg_t file_open(EngineState *s, const char *filename, int mode, bool unwrapFilen
 	}
 
 	if (!inFile && !outFile) { // Failed
-		debugC(2, kDebugLevelFile, "  -> file_open() failed");
+		debugC(kDebugLevelFile, "  -> file_open() failed");
 		return SIGNAL_REG;
 	}
 
@@ -171,7 +172,7 @@ reg_t file_open(EngineState *s, const char *filename, int mode, bool unwrapFilen
 	s->_fileHandles[handle]._out = outFile;
 	s->_fileHandles[handle]._name = englishName;
 
-	debugC(2, kDebugLevelFile, "  -> opened file '%s' with handle %d", englishName.c_str(), handle);
+	debugC(kDebugLevelFile, "  -> opened file '%s' with handle %d", englishName.c_str(), handle);
 	return make_reg(0, handle);
 }
 
@@ -179,7 +180,7 @@ reg_t kFOpen(EngineState *s, int argc, reg_t *argv) {
 	Common::String name = s->_segMan->getString(argv[0]);
 	int mode = argv[1].toUint16();
 
-	debugC(2, kDebugLevelFile, "kFOpen(%s,0x%x)", name.c_str(), mode);
+	debugC(kDebugLevelFile, "kFOpen(%s,0x%x)", name.c_str(), mode);
 	return file_open(s, name.c_str(), mode, true);
 }
 
@@ -198,7 +199,7 @@ static FileHandle *getFileFromHandle(EngineState *s, uint handle) {
 }
 
 reg_t kFClose(EngineState *s, int argc, reg_t *argv) {
-	debugC(2, kDebugLevelFile, "kFClose(%d)", argv[0].toUint16());
+	debugC(kDebugLevelFile, "kFClose(%d)", argv[0].toUint16());
 	if (argv[0] != SIGNAL_REG) {
 		FileHandle *f = getFileFromHandle(s, argv[0].toUint16());
 		if (f)
@@ -241,7 +242,7 @@ static int fgets_wrapper(EngineState *s, char *dest, int maxsize, int handle) {
 		*dest = 0;
 	}
 
-	debugC(2, kDebugLevelFile, "  -> FGets'ed \"%s\"", dest);
+	debugC(kDebugLevelFile, "  -> FGets'ed \"%s\"", dest);
 	return readBytes;
 }
 
@@ -250,9 +251,10 @@ reg_t kFGets(EngineState *s, int argc, reg_t *argv) {
 	char *buf = new char[maxsize];
 	int handle = argv[2].toUint16();
 
-	debugC(2, kDebugLevelFile, "kFGets(%d, %d)", handle, maxsize);
+	debugC(kDebugLevelFile, "kFGets(%d, %d)", handle, maxsize);
 	int readBytes = fgets_wrapper(s, buf, maxsize, handle);
 	s->_segMan->memcpy(argv[0], (const byte*)buf, maxsize);
+	delete[] buf;
 	return readBytes ? argv[0] : NULL_REG;
 }
 
@@ -265,7 +267,7 @@ reg_t kGetCWD(EngineState *s, int argc, reg_t *argv) {
 	// TODO/FIXME: Is "/" a good value? Maybe "" or "." or "C:\" are better?
 	s->_segMan->strcpy(argv[0], "/");
 
-	debugC(2, kDebugLevelFile, "kGetCWD() -> %s", "/");
+	debugC(kDebugLevelFile, "kGetCWD() -> %s", "/");
 
 	return argv[0];
 }
@@ -370,8 +372,7 @@ reg_t kGetSaveDir(EngineState *s, int argc, reg_t *argv) {
 	if (argc > 0)
 		warning("kGetSaveDir called with %d parameter(s): %04x:%04x", argc, PRINT_REG(argv[0]));
 #endif
-
-	return make_reg(s->_segMan->getSysStringsSegment(), SYS_STRING_SAVEDIR);
+		return s->_segMan->getSaveDirPtr();
 }
 
 reg_t kCheckFreeSpace(EngineState *s, int argc, reg_t *argv) {
@@ -422,7 +423,7 @@ static void listSavegames(Common::Array<SavegameDesc> &saves) {
 		Common::SeekableReadStream *in;
 		if ((in = saveFileMan->openForLoading(filename))) {
 			SavegameMetadata meta;
-			if (!get_savegame_metadata(in, &meta) || meta.savegame_name.empty()) {
+			if (!get_savegame_metadata(in, &meta) || meta.name.empty()) {
 				// invalid
 				delete in;
 				continue;
@@ -431,17 +432,17 @@ static void listSavegames(Common::Array<SavegameDesc> &saves) {
 
 			SavegameDesc desc;
 			desc.id = strtol(filename.end() - 3, NULL, 10);
-			desc.date = meta.savegame_date;
+			desc.date = meta.saveDate;
 			// We need to fix date in here, because we save DDMMYYYY instead of
 			// YYYYMMDD, so sorting wouldn't work
 			desc.date = ((desc.date & 0xFFFF) << 16) | ((desc.date & 0xFF0000) >> 8) | ((desc.date & 0xFF000000) >> 24);
-			desc.time = meta.savegame_time;
-			desc.version = meta.savegame_version;
+			desc.time = meta.saveTime;
+			desc.version = meta.version;
 
-			if (meta.savegame_name.lastChar() == '\n')
-				meta.savegame_name.deleteLastChar();
+			if (meta.name.lastChar() == '\n')
+				meta.name.deleteLastChar();
 
-			Common::strlcpy(desc.name, meta.savegame_name.c_str(), SCI_MAX_SAVENAME_LENGTH);
+			Common::strlcpy(desc.name, meta.name.c_str(), SCI_MAX_SAVENAME_LENGTH);
 
 			debug(3, "Savegame in file %s ok, id %d", filename.c_str(), desc.id);
 
@@ -496,7 +497,7 @@ reg_t kCheckSaveGame(EngineState *s, int argc, reg_t *argv) {
 
 	// Find saved-game
 	if ((virtualId < SAVEGAMEID_OFFICIALRANGE_START) || (virtualId > SAVEGAMEID_OFFICIALRANGE_END))
-		error("kCheckSaveGame: called with invalid savegameId!");
+		error("kCheckSaveGame: called with invalid savegameId");
 	uint savegameId = virtualId - SAVEGAMEID_OFFICIALRANGE_START;
 	int savegameNr = findSavegame(saves, savegameId);
 	if (savegameNr == -1)
@@ -576,7 +577,7 @@ reg_t kSaveGame(EngineState *s, int argc, reg_t *argv) {
 		EngineMan.findGame(g_sci->getGameIdStr(), &plugin);
 		GUI::SaveLoadChooser *dialog = new GUI::SaveLoadChooser(_("Save game:"), _("Save"));
 		dialog->setSaveMode(true);
-		savegameId = dialog->runModal(plugin, ConfMan.getActiveDomainName());
+		savegameId = dialog->runModalWithPluginAndTarget(plugin, ConfMan.getActiveDomainName());
 		game_description = dialog->getResultString();
 		if (game_description.empty()) {
 			// create our own description for the saved game, the user didnt enter it
@@ -584,7 +585,7 @@ reg_t kSaveGame(EngineState *s, int argc, reg_t *argv) {
 			g_system->getTimeAndDate(curTime);
 			curTime.tm_year += 1900; // fixup year
 			curTime.tm_mon++; // fixup month
-			game_description = Common::String::printf("%02d.%02d.%04d / %02d:%02d:%02d", curTime.tm_mday, curTime.tm_mon, curTime.tm_year, curTime.tm_hour, curTime.tm_min, curTime.tm_sec);
+			game_description = Common::String::format("%02d.%02d.%04d / %02d:%02d:%02d", curTime.tm_mday, curTime.tm_mon, curTime.tm_year, curTime.tm_hour, curTime.tm_min, curTime.tm_sec);
 		}
 		delete dialog;
 		g_sci->_soundCmd->pauseAll(false); // unpause music ( we can't have it paused during save)
@@ -641,20 +642,23 @@ reg_t kSaveGame(EngineState *s, int argc, reg_t *argv) {
 	Common::String filename = g_sci->getSavegameName(savegameId);
 	Common::SaveFileManager *saveFileMan = g_engine->getSaveFileManager();
 	Common::OutSaveFile *out;
-	if (!(out = saveFileMan->openForSaving(filename))) {
+
+	out = saveFileMan->openForSaving(filename);
+	if (!out) {
 		warning("Error opening savegame \"%s\" for writing", filename.c_str());
 	} else {
 		if (!gamestate_save(s, out, game_description.c_str(), version.c_str())) {
-			warning("Saving the game failed.");
+			warning("Saving the game failed");
 		} else {
-			out->finalize();
-			if (out->err()) {
-				warning("Writing the savegame failed.");
-			} else {
-				s->r_acc = TRUE_REG; // success
-			}
-			delete out;
+			s->r_acc = TRUE_REG; // save successful
 		}
+
+		out->finalize();
+		if (out->err()) {
+			warning("Writing the savegame failed");
+			s->r_acc = NULL_REG; // write failure
+		}
+		delete out;
 	}
 
 	return s->r_acc;
@@ -676,7 +680,7 @@ reg_t kRestoreGame(EngineState *s, int argc, reg_t *argv) {
 			EngineMan.findGame(g_sci->getGameIdStr(), &plugin);
 			GUI::SaveLoadChooser *dialog = new GUI::SaveLoadChooser(_("Restore game:"), _("Restore"));
 			dialog->setSaveMode(false);
-			savegameId = dialog->runModal(plugin, ConfMan.getActiveDomainName());
+			savegameId = dialog->runModalWithPluginAndTarget(plugin, ConfMan.getActiveDomainName());
 			delete dialog;
 			if (savegameId < 0) {
 				g_sci->_soundCmd->pauseAll(false); // unpause music
@@ -707,7 +711,9 @@ reg_t kRestoreGame(EngineState *s, int argc, reg_t *argv) {
 		Common::SaveFileManager *saveFileMan = g_engine->getSaveFileManager();
 		Common::String filename = g_sci->getSavegameName(savegameId);
 		Common::SeekableReadStream *in;
-		if ((in = saveFileMan->openForLoading(filename))) {
+
+		in = saveFileMan->openForLoading(filename);
+		if (in) {
 			// found a savegame file
 
 			gamestate_restore(s, in);
@@ -765,25 +771,26 @@ reg_t kFileIOOpen(EngineState *s, int argc, reg_t *argv) {
 	}
 
 	// SQ4 floppy attempts to update the savegame index file sq4sg.dir when
-	// deleting saved games. We don't use an index file for saving or
-	// loading, so just stop the game from modifying the file here in order
-	// to avoid having it saved in the ScummVM save directory.
+	// deleting saved games. We don't use an index file for saving or loading,
+	// so just stop the game from modifying the file here in order to avoid
+	// having it saved in the ScummVM save directory.
 	if (name == "sq4sg.dir") {
-		debugC(2, kDebugLevelFile, "Not opening unused file sq4sg.dir");
+		debugC(kDebugLevelFile, "Not opening unused file sq4sg.dir");
 		return SIGNAL_REG;
 	}
 
 	if (name.empty()) {
 		// Happens many times during KQ1 (e.g. when typing something)
-		debugC(2, kDebugLevelFile, "Attempted to open a file with an empty filename");
+		debugC(kDebugLevelFile, "Attempted to open a file with an empty filename");
 		return SIGNAL_REG;
 	}
-	debugC(2, kDebugLevelFile, "kFileIO(open): %s, 0x%x", name.c_str(), mode);
+	debugC(kDebugLevelFile, "kFileIO(open): %s, 0x%x", name.c_str(), mode);
 
 	// QFG import rooms get a virtual filelisting instead of an actual one
 	if (g_sci->inQfGImportRoom()) {
-		// we need to find out what the user actually selected, "savedHeroes" is already destroyed
-		//  when we get here. That's why we need to remember selection via kDrawControl
+		// We need to find out what the user actually selected, "savedHeroes" is
+		// already destroyed when we get here. That's why we need to remember
+		// selection via kDrawControl.
 		name = s->_dirseeker.getVirtualFilename(s->_chosenQfGImportItem);
 		unwrapFilename = false;
 	}
@@ -792,7 +799,7 @@ reg_t kFileIOOpen(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kFileIOClose(EngineState *s, int argc, reg_t *argv) {
-	debugC(2, kDebugLevelFile, "kFileIO(close): %d", argv[0].toUint16());
+	debugC(kDebugLevelFile, "kFileIO(close): %d", argv[0].toUint16());
 
 	FileHandle *f = getFileFromHandle(s, argv[0].toUint16());
 	if (f) {
@@ -807,7 +814,7 @@ reg_t kFileIOReadRaw(EngineState *s, int argc, reg_t *argv) {
 	int size = argv[2].toUint16();
 	int bytesRead = 0;
 	char *buf = new char[size];
-	debugC(2, kDebugLevelFile, "kFileIO(readRaw): %d, %d", handle, size);
+	debugC(kDebugLevelFile, "kFileIO(readRaw): %d, %d", handle, size);
 		
 	FileHandle *f = getFileFromHandle(s, handle);
 	if (f) {
@@ -825,7 +832,7 @@ reg_t kFileIOWriteRaw(EngineState *s, int argc, reg_t *argv) {
 	char *buf = new char[size];
 	bool success = false;
 	s->_segMan->memcpy((byte*)buf, argv[1], size);
-	debugC(2, kDebugLevelFile, "kFileIO(writeRaw): %d, %d", handle, size);
+	debugC(kDebugLevelFile, "kFileIO(writeRaw): %d, %d", handle, size);
 
 	FileHandle *f = getFileFromHandle(s, handle);
 	if (f) {
@@ -868,7 +875,7 @@ reg_t kFileIOUnlink(EngineState *s, int argc, reg_t *argv) {
 		result = saveFileMan->removeSavefile(wrappedName);
 	}
 
-	debugC(2, kDebugLevelFile, "kFileIO(unlink): %s", name.c_str());
+	debugC(kDebugLevelFile, "kFileIO(unlink): %s", name.c_str());
 	if (result)
 		return NULL_REG;
 	return make_reg(0, 2); // DOS - file not found error code
@@ -878,7 +885,7 @@ reg_t kFileIOReadString(EngineState *s, int argc, reg_t *argv) {
 	int size = argv[1].toUint16();
 	char *buf = new char[size];
 	int handle = argv[2].toUint16();
-	debugC(2, kDebugLevelFile, "kFileIO(readString): %d, %d", handle, size);
+	debugC(kDebugLevelFile, "kFileIO(readString): %d, %d", handle, size);
 
 	int readBytes = fgets_wrapper(s, buf, size, handle);
 	s->_segMan->memcpy(argv[0], (const byte*)buf, size);
@@ -889,7 +896,7 @@ reg_t kFileIOReadString(EngineState *s, int argc, reg_t *argv) {
 reg_t kFileIOWriteString(EngineState *s, int argc, reg_t *argv) {
 	int handle = argv[0].toUint16();
 	Common::String str = s->_segMan->getString(argv[1]);
-	debugC(2, kDebugLevelFile, "kFileIO(writeString): %d", handle);
+	debugC(kDebugLevelFile, "kFileIO(writeString): %d", handle);
 
 	FileHandle *f = getFileFromHandle(s, handle);
 
@@ -905,7 +912,7 @@ reg_t kFileIOSeek(EngineState *s, int argc, reg_t *argv) {
 	int handle = argv[0].toUint16();
 	int offset = argv[1].toUint16();
 	int whence = argv[2].toUint16();
-	debugC(2, kDebugLevelFile, "kFileIO(seek): %d, %d, %d", handle, offset, whence);
+	debugC(kDebugLevelFile, "kFileIO(seek): %d, %d, %d", handle, offset, whence);
 		
 	FileHandle *f = getFileFromHandle(s, handle);
 
@@ -1017,7 +1024,7 @@ reg_t kFileIOFindFirst(EngineState *s, int argc, reg_t *argv) {
 	Common::String mask = s->_segMan->getString(argv[0]);
 	reg_t buf = argv[1];
 	int attr = argv[2].toUint16(); // We won't use this, Win32 might, though...
-	debugC(2, kDebugLevelFile, "kFileIO(findFirst): %s, 0x%x", mask.c_str(), attr);
+	debugC(kDebugLevelFile, "kFileIO(findFirst): %s, 0x%x", mask.c_str(), attr);
 
 	// We remove ".*". mask will get prefixed, so we will return all additional files for that gameid
 	if (mask == "*.*")
@@ -1026,26 +1033,27 @@ reg_t kFileIOFindFirst(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kFileIOFindNext(EngineState *s, int argc, reg_t *argv) {
-	debugC(2, kDebugLevelFile, "kFileIO(findNext)");
+	debugC(kDebugLevelFile, "kFileIO(findNext)");
 	return s->_dirseeker.nextFile(s->_segMan);
 }
 
 reg_t kFileIOExists(EngineState *s, int argc, reg_t *argv) {
 	Common::String name = s->_segMan->getString(argv[0]);
 
-	// Check for regular file
-	bool exists = Common::File::exists(name);
-	Common::SaveFileManager *saveFileMan = g_engine->getSaveFileManager();
-	const Common::String wrappedName = g_sci->wrapFilename(name);
+	bool exists = false;
 
+	// Check for regular file
+	exists = Common::File::exists(name);
+
+	// Check for a savegame with the name
+	Common::SaveFileManager *saveFileMan = g_engine->getSaveFileManager();
 	if (!exists)
 		exists = !saveFileMan->listSavefiles(name).empty();
 
+	// Try searching for the file prepending "target-"
+	const Common::String wrappedName = g_sci->wrapFilename(name);
 	if (!exists) {
-		// Try searching for the file prepending target-
-		Common::SeekableReadStream *inFile = saveFileMan->openForLoading(wrappedName);
-		exists = (inFile != 0);
-		delete inFile;
+		exists = !saveFileMan->listSavefiles(wrappedName).empty();
 	}
 
 	// Special case for non-English versions of LSL5: The English version of
@@ -1064,11 +1072,11 @@ reg_t kFileIOExists(EngineState *s, int argc, reg_t *argv) {
 		for (int i = 0; i < 10; i++)
 			outFile->writeByte(defaultContent[i]);
 		outFile->finalize();
+		exists = !outFile->err();	// check whether we managed to create the file.
 		delete outFile;
-		exists = true;
 	}
 
-	debugC(2, kDebugLevelFile, "kFileIO(fileExists) %s -> %d", name.c_str(), exists);
+	debugC(kDebugLevelFile, "kFileIO(fileExists) %s -> %d", name.c_str(), exists);
 	return make_reg(0, exists);
 }
 
@@ -1114,6 +1122,26 @@ reg_t kFileIOWriteWord(EngineState *s, int argc, reg_t *argv) {
 	return s->r_acc; // FIXME: does this really not return anything?
 }
 
+reg_t kFileIOCreateSaveSlot(EngineState *s, int argc, reg_t *argv) {
+	// Used in Shivers when the user enters his name on the guest book
+	// in the beginning to start the game.
+
+	// Creates a new save slot, and returns if the operation was successful
+
+	// Argument 0 denotes the save slot as a negative integer, 2 means "0"
+	// Argument 1 is a string, with the file name, obtained from kSave(5).
+	// The interpreter checks if it can be written to (by checking for free
+	// disk space and write permissions)
+
+	// We don't really use or need any of this...
+
+	uint16 saveSlot = argv[0].toUint16();
+	char* fileName = s->_segMan->lookupString(argv[1])->getRawData();
+	warning("kFileIOCreateSaveSlot(%d, '%s')", saveSlot, fileName);
+
+	return TRUE_REG;	// slot creation was successful
+}
+
 reg_t kCD(EngineState *s, int argc, reg_t *argv) {
 	// TODO: Stub
 	switch (argv[0].toUint16()) {
@@ -1129,13 +1157,21 @@ reg_t kCD(EngineState *s, int argc, reg_t *argv) {
 
 reg_t kSave(EngineState *s, int argc, reg_t *argv) {
 	switch (argv[0].toUint16()) {
-	case 0: // Called by kq7 when starting chapters
-		return SIGNAL_REG;
-	case 2: // GetSaveDir
-		// Yay! Reusing the old kernel function!
+	case 0:
+		return kSaveGame(s, argc - 1,argv + 1);
+	case 1:
+		return kRestoreGame(s, argc - 1,argv + 1);
+	case 2:
 		return kGetSaveDir(s, argc - 1, argv + 1);
+	case 5:
+		return kGetSaveFiles(s, argc - 1, argv + 1);
 	case 8:
 		// TODO
+		// This is a timer callback, with 1 parameter: the timer object
+		// (e.g. "timers").
+		// It's used for auto-saving (i.e. save every X minutes, by checking
+		// the elapsed time from the timer object)
+
 		// This function has to return something other than 0 to proceed
 		return s->r_acc;
 	default:
