@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/kgraphics.cpp $
- * $Id: kgraphics.cpp 53816 2010-10-25 10:57:59Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -33,6 +33,7 @@
 
 #include "sci/sci.h"
 #include "sci/debug.h"	// for g_debug_sleeptime_factor
+#include "sci/event.h"
 #include "sci/resource.h"
 #include "sci/engine/features.h"
 #include "sci/engine/state.h"
@@ -47,16 +48,27 @@
 #include "sci/graphics/paint16.h"
 #include "sci/graphics/picture.h"
 #include "sci/graphics/ports.h"
-#include "sci/graphics/robot.h"
 #include "sci/graphics/screen.h"
 #include "sci/graphics/text16.h"
 #include "sci/graphics/view.h"
 #ifdef ENABLE_SCI32
 #include "sci/graphics/frameout.h"
+#include "sci/video/robot_decoder.h"
 #endif
 
 namespace Sci {
 
+static int16 adjustGraphColor(int16 color) {
+	// WORKAROUND: SCI1 EGA and Amiga games can set invalid colors (above 0 - 15).
+	// Colors above 15 are all white in SCI1 EGA games, which is why this was never
+	// observed. We clip them all to (0, 15) instead, as colors above 15 are used
+	// for the undithering algorithm in EGA games - bug #3048908.
+	if (getSciVersion() >= SCI_VERSION_1_EARLY && g_sci->getResMan()->getViewType() == kViewEga)
+		return color & 0x0F;	// 0 - 15
+	else
+		return color;
+}
+
 void showScummVMDialog(const Common::String &message) {
 	GUI::MessageDialog dialog(message, "OK");
 	dialog.runModal();
@@ -129,8 +141,7 @@ static reg_t kSetCursorSci11(EngineState *s, int argc, reg_t *argv) {
 			g_sci->_gfxCursor->kernelHide();
 			break;
 		case -1:
-			// TODO: Special case at least in kq6, check disassembly
-			//  Does something with magCursor, which is set on argc = 10, which we don't support
+			g_sci->_gfxCursor->kernelClearZoomZone();
 			break;
 		case -2:
 			g_sci->_gfxCursor->kernelResetMoveZone();
@@ -184,15 +195,10 @@ static reg_t kSetCursorSci11(EngineState *s, int argc, reg_t *argv) {
 		break;
 	case 10:
 		// Freddy pharkas, when using the whiskey glass to read the prescription (bug #3034973)
-		// magnifier support, disabled using argc == 1, argv == -1
-		warning("kSetCursor: unsupported magnifier");
-		// we just set the view cursor currently
-		g_sci->_gfxCursor->kernelSetView(argv[5].toUint16(), argv[6].toUint16(), argv[7].toUint16(), hotspot);
-		// argv[0] -> 1, 2, 4 -> maybe magnification multiplier
-		// argv[1-4] -> rect for magnification
-		// argv[5, 6, 7] -> view resource for cursor
-		// argv[8] -> picture resource for mag
-		// argv[9] -> color for magnifier replacement
+		g_sci->_gfxCursor->kernelSetZoomZone(argv[0].toUint16(), 
+			Common::Rect(argv[1].toUint16(), argv[2].toUint16(), argv[3].toUint16(), argv[4].toUint16()),
+			argv[5].toUint16(), argv[6].toUint16(), argv[7].toUint16(),
+			argv[8].toUint16(), argv[9].toUint16());
 		break;
 	default :
 		error("kSetCursor: Unhandled case: %d arguments given", argc);
@@ -214,12 +220,7 @@ reg_t kSetCursor(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kMoveCursor(EngineState *s, int argc, reg_t *argv) {
-	Common::Point pos;
-	if (argc == 2) {
-		pos.y = argv[1].toSint16();
-		pos.x = argv[0].toSint16();
-		g_sci->_gfxCursor->kernelSetPos(pos);
-	}
+	g_sci->_gfxCursor->kernelSetPos(Common::Point(argv[0].toSint16(), argv[1].toSint16()));
 	return s->r_acc;
 }
 
@@ -252,22 +253,14 @@ reg_t kGraph(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kGraphGetColorCount(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isAmiga32color())
-		return make_reg(0, 32);
-	return make_reg(0, !g_sci->getResMan()->isVGA() ? 16 : 256);
+	return make_reg(0, g_sci->_gfxPalette->getTotalColorCount());
 }
 
 reg_t kGraphDrawLine(EngineState *s, int argc, reg_t *argv) {
-	int16 color = argv[4].toSint16();
+	int16 color = adjustGraphColor(argv[4].toSint16());
 	int16 priority = (argc > 5) ? argv[5].toSint16() : -1;
 	int16 control = (argc > 6) ? argv[6].toSint16() : -1;
 
-	// TODO: Find out why we get > 15 for color in EGA
-	// FIXME: EGA? Which EGA? SCI0 or SCI1? Check the
-	// workarounds inside kGraphFillBoxAny and kNewWindow
-	if (!g_sci->getResMan()->isVGA() && !g_sci->getResMan()->isAmiga32color())
-		color &= 0x0F;
-
 	g_sci->_gfxPaint16->kernelGraphDrawLine(getGraphPoint(argv), getGraphPoint(argv + 2), color, priority, control);
 	return s->r_acc;
 }
@@ -299,17 +292,10 @@ reg_t kGraphFillBoxForeground(EngineState *s, int argc, reg_t *argv) {
 reg_t kGraphFillBoxAny(EngineState *s, int argc, reg_t *argv) {
 	Common::Rect rect = getGraphRect(argv);
 	int16 colorMask = argv[4].toUint16();
-	int16 color = argv[5].toSint16();
+	int16 color = adjustGraphColor(argv[5].toSint16());
 	int16 priority = argv[6].toSint16(); // yes, we may read from stack sometimes here
 	int16 control = argv[7].toSint16(); // sierra did the same
 
-	// WORKAROUND: PQ3 EGA is setting invalid colors (above 0 - 15).
-	// Colors above 15 are all white in SCI1 EGA games, which is why this was never
-	// observed. We clip them all to (0, 15) instead, as colors above 15 are used
-	// for the undithering algorithm in EGA games - bug #3048908.
-	if (g_sci->getResMan()->getViewType() == kViewEga && getSciVersion() >= SCI_VERSION_1_EARLY)
-		color &= 0x0F;
-
 	g_sci->_gfxPaint16->kernelGraphFillBox(rect, colorMask, color, priority, control);
 	return s->r_acc;
 }
@@ -348,7 +334,7 @@ reg_t kTextSize(EngineState *s, int argc, reg_t *argv) {
 	int font_nr = argv[2].toUint16();
 
 	if (!dest) {
-		debugC(2, kDebugLevelStrings, "GetTextSize: Empty destination");
+		debugC(kDebugLevelStrings, "GetTextSize: Empty destination");
 		return s->r_acc;
 	}
 
@@ -363,7 +349,7 @@ reg_t kTextSize(EngineState *s, int argc, reg_t *argv) {
 
 	if (text.empty()) { // Empty text
 		dest[2] = dest[3] = make_reg(0, 0);
-		debugC(2, kDebugLevelStrings, "GetTextSize: Empty string");
+		debugC(kDebugLevelStrings, "GetTextSize: Empty string");
 		return s->r_acc;
 	}
 
@@ -373,11 +359,12 @@ reg_t kTextSize(EngineState *s, int argc, reg_t *argv) {
 	if (!g_sci->_gfxText16) {
 		// TODO: Implement this
 		textWidth = 0; textHeight = 0;
+		warning("TODO: implement kTextSize for SCI32");
 	} else
 #endif
 		g_sci->_gfxText16->kernelTextSize(g_sci->strSplit(text.c_str(), sep).c_str(), font_nr, maxwidth, &textWidth, &textHeight);
 	
-	debugC(2, kDebugLevelStrings, "GetTextSize '%s' -> %dx%d", text.c_str(), textWidth, textHeight);
+	debugC(kDebugLevelStrings, "GetTextSize '%s' -> %dx%d", text.c_str(), textWidth, textHeight);
 	dest[2] = make_reg(0, textHeight);
 	dest[3] = make_reg(0, textWidth);
 	return s->r_acc;
@@ -473,7 +460,7 @@ reg_t kNumLoops(EngineState *s, int argc, reg_t *argv) {
 
 	loopCount = g_sci->_gfxCache->kernelViewGetLoopCount(viewId);
 
-	debugC(2, kDebugLevelGraphics, "NumLoops(view.%d) = %d", viewId, loopCount);
+	debugC(kDebugLevelGraphics, "NumLoops(view.%d) = %d", viewId, loopCount);
 
 	return make_reg(0, loopCount);
 }
@@ -486,7 +473,7 @@ reg_t kNumCels(EngineState *s, int argc, reg_t *argv) {
 
 	celCount = g_sci->_gfxCache->kernelViewGetCelCount(viewId, loopNo);
 
-	debugC(2, kDebugLevelGraphics, "NumCels(view.%d, %d) = %d", viewId, loopNo, celCount);
+	debugC(kDebugLevelGraphics, "NumCels(view.%d, %d) = %d", viewId, loopNo, celCount);
 
 	return make_reg(0, celCount);
 }
@@ -562,8 +549,6 @@ reg_t kSetNowSeen(EngineState *s, int argc, reg_t *argv) {
 	return s->r_acc;
 }
 
-// we are called on EGA/amiga games as well, this doesnt make sense.
-//  doing this would actually break the system EGA/amiga palette
 reg_t kPalette(EngineState *s, int argc, reg_t *argv) {
 	if (!s)
 		return make_reg(0, getSciVersion());
@@ -571,86 +556,85 @@ reg_t kPalette(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kPaletteSetFromResource(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		GuiResourceId resourceId = argv[0].toUint16();
-		bool force = false;
-		if (argc == 2)
-			force = argv[1].toUint16() == 2 ? true : false;
-		g_sci->_gfxPalette->kernelSetFromResource(resourceId, force);
-	}
+	GuiResourceId resourceId = argv[0].toUint16();
+	bool force = false;
+	if (argc == 2)
+		force = argv[1].toUint16() == 2 ? true : false;
+
+	// Non-VGA games don't use palette resources.
+	// This has been changed to 64 colors because Longbow Amiga does have
+	// one palette (palette 999).
+	if (g_sci->_gfxPalette->getTotalColorCount() < 64)
+		return s->r_acc;
+
+	g_sci->_gfxPalette->kernelSetFromResource(resourceId, force);
 	return s->r_acc;
 }
 
 reg_t kPaletteSetFlag(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
-		uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
-		uint16 flags = argv[2].toUint16();
-		g_sci->_gfxPalette->kernelSetFlag(fromColor, toColor, flags);
-	}
+	uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
+	uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
+	uint16 flags = argv[2].toUint16();
+	g_sci->_gfxPalette->kernelSetFlag(fromColor, toColor, flags);
 	return s->r_acc;
 }
 
 reg_t kPaletteUnsetFlag(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
-		uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
-		uint16 flags = argv[2].toUint16();
-		g_sci->_gfxPalette->kernelUnsetFlag(fromColor, toColor, flags);
-	}
+	uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
+	uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
+	uint16 flags = argv[2].toUint16();
+	g_sci->_gfxPalette->kernelUnsetFlag(fromColor, toColor, flags);
 	return s->r_acc;
 }
 
 reg_t kPaletteSetIntensity(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
-		uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
-		uint16 intensity = argv[2].toUint16();
-		bool setPalette = (argc < 4) ? true : (argv[3].isNull()) ? true : false;
+	uint16 fromColor = CLIP<uint16>(argv[0].toUint16(), 1, 255);
+	uint16 toColor = CLIP<uint16>(argv[1].toUint16(), 1, 255);
+	uint16 intensity = argv[2].toUint16();
+	bool setPalette = (argc < 4) ? true : (argv[3].isNull()) ? true : false;
 
-		g_sci->_gfxPalette->kernelSetIntensity(fromColor, toColor, intensity, setPalette);
-	}
+	// Palette intensity in non-VGA SCI1 games has been removed
+	if (g_sci->_gfxPalette->getTotalColorCount() < 256)
+		return s->r_acc;
+
+	g_sci->_gfxPalette->kernelSetIntensity(fromColor, toColor, intensity, setPalette);
 	return s->r_acc;
 }
 
 reg_t kPaletteFindColor(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		uint16 r = argv[0].toUint16();
-		uint16 g = argv[1].toUint16();
-		uint16 b = argv[2].toUint16();
-		return make_reg(0, g_sci->_gfxPalette->kernelFindColor(r, g, b));
-	}
-	return NULL_REG;
+	uint16 r = argv[0].toUint16();
+	uint16 g = argv[1].toUint16();
+	uint16 b = argv[2].toUint16();
+	return make_reg(0, g_sci->_gfxPalette->kernelFindColor(r, g, b));
 }
 
 reg_t kPaletteAnimate(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		int16 argNr;
-		bool paletteChanged = false;
-		for (argNr = 0; argNr < argc; argNr += 3) {
-			uint16 fromColor = argv[argNr].toUint16();
-			uint16 toColor = argv[argNr + 1].toUint16();
-			int16 speed = argv[argNr + 2].toSint16();
-			if (g_sci->_gfxPalette->kernelAnimate(fromColor, toColor, speed))
-				paletteChanged = true;
-		}
-		if (paletteChanged)
-			g_sci->_gfxPalette->kernelAnimateSet();
+	int16 argNr;
+	bool paletteChanged = false;
+
+	// Palette animation in non-VGA SCI1 games has been removed
+	if (g_sci->_gfxPalette->getTotalColorCount() < 256)
+		return s->r_acc;
+
+	for (argNr = 0; argNr < argc; argNr += 3) {
+		uint16 fromColor = argv[argNr].toUint16();
+		uint16 toColor = argv[argNr + 1].toUint16();
+		int16 speed = argv[argNr + 2].toSint16();
+		if (g_sci->_gfxPalette->kernelAnimate(fromColor, toColor, speed))
+			paletteChanged = true;
 	}
+	if (paletteChanged)
+		g_sci->_gfxPalette->kernelAnimateSet();
+
 	return s->r_acc;
 }
 
 reg_t kPaletteSave(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		return g_sci->_gfxPalette->kernelSave();
-	}
-	return NULL_REG;
+	return g_sci->_gfxPalette->kernelSave();
 }
 
 reg_t kPaletteRestore(EngineState *s, int argc, reg_t *argv) {
-	if (g_sci->getResMan()->isVGA()) {
-		g_sci->_gfxPalette->kernelRestore(argv[0]);
-	}
+	g_sci->_gfxPalette->kernelRestore(argv[0]);
 	return argv[0];
 }
 
@@ -805,13 +789,13 @@ void _k_GenericDrawControl(EngineState *s, reg_t controlObject, bool hilite) {
 
 	switch (type) {
 	case SCI_CONTROLS_TYPE_BUTTON:
-		debugC(2, kDebugLevelGraphics, "drawing button %04x:%04x to %d,%d", PRINT_REG(controlObject), x, y);
+		debugC(kDebugLevelGraphics, "drawing button %04x:%04x to %d,%d", PRINT_REG(controlObject), x, y);
 		g_sci->_gfxControls->kernelDrawButton(rect, controlObject, g_sci->strSplit(text.c_str(), NULL).c_str(), fontId, style, hilite);
 		return;
 
 	case SCI_CONTROLS_TYPE_TEXT:
 		alignment = readSelectorValue(s->_segMan, controlObject, SELECTOR(mode));
-		debugC(2, kDebugLevelGraphics, "drawing text %04x:%04x ('%s') to %d,%d, mode=%d", PRINT_REG(controlObject), text.c_str(), x, y, alignment);
+		debugC(kDebugLevelGraphics, "drawing text %04x:%04x ('%s') to %d,%d, mode=%d", PRINT_REG(controlObject), text.c_str(), x, y, alignment);
 		g_sci->_gfxControls->kernelDrawText(rect, controlObject, g_sci->strSplit(text.c_str()).c_str(), fontId, alignment, style, hilite);
 		s->r_acc = g_sci->_gfxText16->allocAndFillReferenceRectArray();
 		return;
@@ -825,7 +809,7 @@ void _k_GenericDrawControl(EngineState *s, reg_t controlObject, bool hilite) {
 			cursorPos = text.size();
 			writeSelectorValue(s->_segMan, controlObject, SELECTOR(cursor), cursorPos);
 		}
-		debugC(2, kDebugLevelGraphics, "drawing edit control %04x:%04x (text %04x:%04x, '%s') to %d,%d", PRINT_REG(controlObject), PRINT_REG(textReference), text.c_str(), x, y);
+		debugC(kDebugLevelGraphics, "drawing edit control %04x:%04x (text %04x:%04x, '%s') to %d,%d", PRINT_REG(controlObject), PRINT_REG(textReference), text.c_str(), x, y);
 		g_sci->_gfxControls->kernelDrawTextEdit(rect, controlObject, g_sci->strSplit(text.c_str(), NULL).c_str(), fontId, mode, style, cursorPos, maxChars, hilite);
 		return;
 
@@ -842,7 +826,7 @@ void _k_GenericDrawControl(EngineState *s, reg_t controlObject, bool hilite) {
 			else
 				priority = -1;
 		}
-		debugC(2, kDebugLevelGraphics, "drawing icon control %04x:%04x to %d,%d", PRINT_REG(controlObject), x, y - 1);
+		debugC(kDebugLevelGraphics, "drawing icon control %04x:%04x to %d,%d", PRINT_REG(controlObject), x, y - 1);
 		g_sci->_gfxControls->kernelDrawIcon(rect, controlObject, viewId, loopNo, celNo, priority, style, hilite);
 		return;
 
@@ -890,7 +874,7 @@ void _k_GenericDrawControl(EngineState *s, reg_t controlObject, bool hilite) {
 			}
 		}
 
-		debugC(2, kDebugLevelGraphics, "drawing list control %04x:%04x to %d,%d, diff %d", PRINT_REG(controlObject), x, y, SCI_MAX_SAVENAME_LENGTH);
+		debugC(kDebugLevelGraphics, "drawing list control %04x:%04x to %d,%d, diff %d", PRINT_REG(controlObject), x, y, SCI_MAX_SAVENAME_LENGTH);
 		g_sci->_gfxControls->kernelDrawList(rect, controlObject, maxChars, listCount, listEntries, fontId, style, upperPos, cursorPos, isAlias, hilite);
 		free(listEntries);
 		delete[] listStrings;
@@ -1091,22 +1075,11 @@ reg_t kNewWindow(EngineState *s, int argc, reg_t *argv) {
 	int argextra = argc >= 13 ? 4 : 0; // Triggers in PQ3 and SCI1.1 games, argc 13 for DOS argc 15 for mac
 	int	style = argv[5 + argextra].toSint16();
 	int	priority = (argc > 6 + argextra) ? argv[6 + argextra].toSint16() : -1;
-	int colorPen = (argc > 7 + argextra) ? argv[7 + argextra].toSint16() : 0;
-	int colorBack = (argc > 8 + argextra) ? argv[8 + argextra].toSint16() : 255;
+	int colorPen = adjustGraphColor((argc > 7 + argextra) ? argv[7 + argextra].toSint16() : 0);
+	int colorBack = adjustGraphColor((argc > 8 + argextra) ? argv[8 + argextra].toSint16() : 255);
 
-	// WORKAROUND: PQ3 EGA is setting invalid colors (above 0 - 15).
-	// Colors above 15 are all white in SCI1 EGA games, which is why this was never
-	// observed. We clip them all to (0, 15) instead, as colors above 15 are used
-	// for the undithering algorithm in EGA games - bug #3048908.
-	if (g_sci->getResMan()->getViewType() == kViewEga && getSciVersion() >= SCI_VERSION_1_EARLY) {
-		colorPen &= 0x0F;
-		colorBack &= 0x0F;
-	}
-
-	//	const char *title = argv[4 + argextra].segment ? kernel_dereference_char_pointer(s, argv[4 + argextra], 0) : NULL;
-	if (argc>=13) {
+	if (argc >= 13)
 		rect2 = Common::Rect (argv[5].toSint16(), argv[4].toSint16(), argv[7].toSint16(), argv[6].toSint16());
-	}
 
 	Common::String title;
 	if (argv[4 + argextra].segment) {
@@ -1123,6 +1096,14 @@ reg_t kAnimate(EngineState *s, int argc, reg_t *argv) {
 
 	g_sci->_gfxAnimate->kernelAnimate(castListReference, cycle, argc, argv);
 
+	// WORKAROUND: At the end of Ecoquest 1, during the credits, the game
+	// doesn't call kGetEvent(), so no events are processed (e.g. window
+	// focusing, window moving etc). We poll events for that scene, to
+	// keep ScummVM responsive. Fixes ScummVM "freezing" during the credits,
+	// bug #3101846
+	if (g_sci->getGameId() == GID_ECOQUEST && s->currentRoomNumber() == 680)
+		g_sci->getEventManager()->getSciEvent(SCI_EVENT_PEEK);
+
 	return s->r_acc;
 }
 
@@ -1202,14 +1183,12 @@ reg_t kShow(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kRemapColors(EngineState *s, int argc, reg_t *argv) {
-	// TODO: This is all a stub/skeleton, thus we're invoking kStub() for now
-	kStub(s, argc, argv);
-
 	uint16 operation = argv[0].toUint16();
 
 	switch (operation) {
-	case 0:	{ // Initialize remapping to base. 0 turns remapping off.
-		//int16 unk1 = (argc >= 2) ? argv[1].toSint16() : 0;
+	case 0:	{ // Set remapping to base. 0 turns remapping off.
+		int16 base = (argc >= 2) ? argv[1].toSint16() : 0;
+		warning("kRemapColors: Set remapping to base %d", base);
 		}
 		break;
 	case 1:	{ // unknown
@@ -1219,18 +1198,32 @@ reg_t kRemapColors(EngineState *s, int argc, reg_t *argv) {
 		//int16 unk3 = argv[3].toSint16();
 		//uint16 unk4 = argv[4].toUint16();
 		//uint16 unk5 = (argc >= 6) ? argv[5].toUint16() : 0;
+		kStub(s, argc, argv);
 		}
 		break;
 	case 2:	{ // remap by percent
-		//int16 unk1 = argv[1].toSint16();
-		//uint16 percent = argv[2].toUint16();
-		//uint16 unk3 = (argc >= 4) ? argv[3].toUint16() : 0;
+		// This adjusts the alpha value of a specific color, and it operates on
+		// an RGBA palette. Since we're operating on an RGB palette, we just
+		// modify the color intensity instead
+		// TODO: From what I understand, palette remapping should be placed
+		// separately, so that it can be reset by case 0 above. Thus, we
+		// should adjust the functionality of the Palette class accordingly.
+		int16 color = argv[1].toSint16();
+		if (color >= 10)
+			color -= 10;
+		uint16 percent = argv[2].toUint16(); // 0 - 100
+		if (argc >= 4)
+			warning("RemapByPercent called with 4 parameters, unknown parameter is %d", argv[3].toUint16());
+		g_sci->_gfxPalette->kernelSetIntensity(color, 255, percent, false);
 		}
 		break;
 	case 3:	{ // remap to gray
-		//int16 unk1 = argv[1].toSint16();
-		//int16 percent = argv[2].toSint16();	// 0 - 100
-		//uint16 unk3 = (argc >= 4) ? argv[3].toUint16() : 0;
+		// NOTE: This adjusts the alpha value of a specific color, and it operates on
+		// an RGBA palette
+		int16 color = argv[1].toSint16();	// this is subtracted from a maximum color value, and can be offset by 10
+		int16 percent = argv[2].toSint16(); // 0 - 100
+		uint16 unk3 = (argc >= 4) ? argv[3].toUint16() : 0;
+		warning("kRemapColors: RemapToGray color %d by %d percent (unk3 = %d)", color, percent, unk3);
 		}
 		break;
 	case 4:	{ // unknown
@@ -1238,11 +1231,13 @@ reg_t kRemapColors(EngineState *s, int argc, reg_t *argv) {
 		//uint16 unk2 = argv[2].toUint16();
 		//uint16 unk3 = argv[3].toUint16();
 		//uint16 unk4 = (argc >= 5) ? argv[4].toUint16() : 0;
+		kStub(s, argc, argv);
 		}
 		break;
 	case 5:	{ // increment color
 		//int16 unk1 = argv[1].toSint16();
 		//uint16 unk2 = argv[2].toUint16();
+		kStub(s, argc, argv);
 		}
 		break;
 	default:
@@ -1265,6 +1260,7 @@ reg_t kIsHiRes(EngineState *s, int argc, reg_t *argv) {
 
 // SCI32 variant, can't work like sci16 variants
 reg_t kCantBeHere32(EngineState *s, int argc, reg_t *argv) {
+	// TODO
 //	reg_t curObject = argv[0];
 //	reg_t listReference = (argc > 1) ? argv[1] : NULL_REG;
 	
@@ -1272,69 +1268,38 @@ reg_t kCantBeHere32(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kAddScreenItem(EngineState *s, int argc, reg_t *argv) {
-	reg_t viewObj = argv[0];
-
-	g_sci->_gfxFrameout->kernelAddScreenItem(viewObj);
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelAddScreenItem(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kUpdateScreenItem(EngineState *s, int argc, reg_t *argv) {
-	//reg_t viewObj = argv[0];
-
-	//warning("kUpdateScreenItem, object %04x:%04x, view %d, loop %d, cel %d, pri %d", PRINT_REG(viewObj), viewId, loopNo, celNo, priority);
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelUpdateScreenItem(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kDeleteScreenItem(EngineState *s, int argc, reg_t *argv) {
-	reg_t viewObj = argv[0];
-
-	g_sci->_gfxFrameout->kernelDeleteScreenItem(viewObj);
-
-	/*
-	reg_t viewObj = argv[0];
-	uint16 viewId = readSelectorValue(s->_segMan, viewObj, SELECTOR(view));
-	int16 loopNo = readSelectorValue(s->_segMan, viewObj, SELECTOR(loop));
-	int16 celNo = readSelectorValue(s->_segMan, viewObj, SELECTOR(cel));
-	//int16 leftPos = 0;
-	//int16 topPos = 0;
-	int16 priority = readSelectorValue(s->_segMan, viewObj, SELECTOR(priority));
-	//int16 control = 0;
-	*/
-
-	// TODO
-
-	//warning("kDeleteScreenItem, view %d, loop %d, cel %d, pri %d", viewId, loopNo, celNo, priority);
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelDeleteScreenItem(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kAddPlane(EngineState *s, int argc, reg_t *argv) {
-	reg_t planeObj = argv[0];
-
-	g_sci->_gfxFrameout->kernelAddPlane(planeObj);
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelAddPlane(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kDeletePlane(EngineState *s, int argc, reg_t *argv) {
-	reg_t planeObj = argv[0];
-
-	g_sci->_gfxFrameout->kernelDeletePlane(planeObj);
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelDeletePlane(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kUpdatePlane(EngineState *s, int argc, reg_t *argv) {
-	reg_t planeObj = argv[0];
-
-	g_sci->_gfxFrameout->kernelUpdatePlane(planeObj);
+	g_sci->_gfxFrameout->kernelUpdatePlane(argv[0]);
 	return s->r_acc;
 }
 
 reg_t kRepaintPlane(EngineState *s, int argc, reg_t *argv) {
-	reg_t picObj = argv[0];
-
-	// TODO
-
-	warning("kRepaintPlane object %04x:%04x", PRINT_REG(picObj));
-	return NULL_REG;
+	g_sci->_gfxFrameout->kernelRepaintPlane(argv[0]);
+	return s->r_acc;
 }
 
 reg_t kAddPicAt(EngineState *s, int argc, reg_t *argv) {
@@ -1406,8 +1371,17 @@ reg_t kCreateTextBitmap(EngineState *s, int argc, reg_t *argv) {
 			warning("kCreateTextBitmap(0): expected 4 arguments, got %i", argc);
 			return NULL_REG;
 		}
-		reg_t object = argv[3];
-		Common::String text = s->_segMan->getString(readSelector(s->_segMan, object, SELECTOR(text)));
+		//reg_t object = argv[3];
+		//Common::String text = s->_segMan->getString(readSelector(s->_segMan, object, SELECTOR(text)));
+		break;
+	}
+	case 1: {
+		if (argc != 2) {
+			warning("kCreateTextBitmap(0): expected 2 arguments, got %i", argc);
+			return NULL_REG;
+		}
+		//reg_t object = argv[1];
+		//Common::String text = s->_segMan->getString(readSelector(s->_segMan, object, SELECTOR(text)));
 		break;
 	}
 	default:
@@ -1429,22 +1403,29 @@ reg_t kRobot(EngineState *s, int argc, reg_t *argv) {
 			int16 x = argv[4].toUint16();
 			int16 y = argv[5].toUint16();
 			warning("kRobot(init), id %d, obj %04x:%04x, flag %d, x=%d, y=%d", id, PRINT_REG(obj), flag, x, y);
-			GfxRobot *test = new GfxRobot(g_sci->getResMan(), g_sci->_gfxScreen, id);
-			test->draw();
-			delete test;
-
+			g_sci->_robotDecoder->load(id);
+			g_sci->_robotDecoder->setPos(x, y);
 			}
 			break;
 		case 1:	// LSL6 hires (startup)
 			// TODO
 			return NULL_REG;	// an integer is expected
-		case 4: {	// start
-				int id = argv[1].toUint16();
-				warning("kRobot(start), id %d", id);
+		case 4: {	// start - we don't really have a use for this one
+				//int id = argv[1].toUint16();
+				//warning("kRobot(start), id %d", id);
 			}
 			break;
+		case 7:	// unknown, called e.g. by Phantasmagoria
+			warning("kRobot(%d)", subop);
+			break;
 		case 8: // sync
-			//warning("kRobot(sync), obj %04x:%04x", PRINT_REG(argv[1]));
+			if ((uint32)g_sci->_robotDecoder->getCurFrame() !=  g_sci->_robotDecoder->getFrameCount() - 1) {
+				writeSelector(s->_segMan, argv[1], SELECTOR(signal), NULL_REG);
+			} else {
+				g_sci->_robotDecoder->close();
+				// Signal the engine scripts that the video is done
+				writeSelector(s->_segMan, argv[1], SELECTOR(signal), SIGNAL_REG);
+			}
 			break;
 		default:
 			warning("kRobot(%d)", subop);
@@ -1490,22 +1471,183 @@ reg_t kSetShowStyle(EngineState *s, int argc, reg_t *argv) {
 	// TODO: This is all a stub/skeleton, thus we're invoking kStub() for now
 	kStub(s, argc, argv);
 
+	// Can be called with 7 or 8 parameters
 	// showStyle matches the style selector of the associated plane object
 	uint16 showStyle = argv[0].toUint16();	// 0 - 15
 	reg_t planeObj = argv[1];
-	//argv[2]
-	//int16 priority = argv[3].toSint16();
-	//argv[4]
-	//argv[5]
-	//argv[6]
-	//argv[7]
-	//int16 unk8 = (argc >= 9) ? argv[8].toSint16() : 0;
+	//argv[2]	// seconds
+	//argv[3]	// back
+	//int16 priority = argv[4].toSint16();
+	//argv[5]	// animate
+	//argv[6]	// refFrame
+	//int16 unk7 = (argc >= 8) ? argv[7].toSint16() : 0;	// divisions
 
 	if (showStyle > 15) {
 		warning("kSetShowStyle: Illegal style %d for plane %04x:%04x", showStyle, PRINT_REG(planeObj));
 		return s->r_acc;
 	}
 
+	// TODO: Check if the plane is in the list of planes to draw
+
+	return s->r_acc;
+}
+
+reg_t kCelInfo(EngineState *s, int argc, reg_t *argv) {
+	// TODO: This is all a stub/skeleton, thus we're invoking kStub() for now
+	kStub(s, argc, argv);
+
+	// Used by Shivers 1, room 23601
+
+	// 6 arguments, all integers:
+	// argv[0] - subop (0 - 4). It's constantly called with 4 in Shivers 1
+	// argv[1] - view (used with view 23602 in Shivers 1)
+	// argv[2] - loop
+	// argv[3] - cel
+	// argv[4] - unknown (row?)
+	// argv[5] - unknown (column?)
+
+	// Subops:
+	// 0 - return the view
+	// 1 - return the loop
+	// 2, 3 - nop
+	// 4 - returns some kind of hash (?) based on the view and the two last params
+
+	// This seems to be a debug function, but it could be used to check if
+	// the jigsaw pieces "stick" together (they currently don't, unless I'm missing
+	// something)
+
+	return s->r_acc;
+}
+
+reg_t kScrollWindow(EngineState *s, int argc, reg_t *argv) {
+	// Used by Phantasmagoria 1 and SQ6. In SQ6, it is used for the messages
+	// shown in the scroll window at the bottom of the screen.
+
+	// TODO: This is all a stub/skeleton, thus we're invoking kStub() for now
+	kStub(s, argc, argv);
+
+	switch (argv[0].toUint16()) {
+	case 0:	// Init
+		// 2 parameters
+		// argv[1] points to the scroll object (e.g. textScroller in SQ6)
+		// argv[2] is an integer (e.g. 0x32)
+		break;
+	case 1: // Show message
+		// 5 or 6 parameters
+		// Seems to be called with 5 parameters when the narrator speaks, and
+		// with 6 when Roger speaks
+		// argv[1] unknown (usually 0)
+		// argv[2] the text to show
+		// argv[3] a small integer (e.g. 0x32)
+		// argv[4] a small integer (e.g. 0x54)
+		// argv[5] optional, unknown (usually 0)
+		warning("kScrollWindow: '%s'", s->_segMan->getString(argv[2]).c_str());
+		break;
+	case 2: // Clear
+		// 2 parameters
+		// TODO
+		break;
+	case 3: // Page up
+		// 2 parameters
+		// TODO
+		break;
+	case 4: // Page down
+		// 2 parameters
+		// TODO
+		break;
+	case 5: // Up arrow
+		// 2 parameters
+		// TODO
+		break;
+	case 6: // Down arrow
+		// 2 parameters
+		// TODO
+		break;
+	case 7: // Home
+		// 2 parameters
+		// TODO
+		break;
+	case 8: // End
+		// 2 parameters
+		// TODO
+		break;
+	case 9: // Resize
+		// 3 parameters
+		// TODO
+		break;
+	case 10: // Where
+		// 3 parameters
+		// TODO
+		break;
+	case 11: // Go
+		// 4 parameters
+		// TODO
+		break;
+	case 12: // Insert
+		// 7 parameters
+		// TODO
+		break;
+	case 13: // Delete
+		// 3 parameters
+		// TODO
+		break;
+	case 14: // Modify
+		// 7 or 8 parameters
+		// TODO
+		break;
+	case 15: // Hide
+		// 2 parameters
+		// TODO
+		break;
+	case 16: // Show
+		// 2 parameters
+		// TODO
+		break;
+	case 17: // Destroy
+		// 2 parameters
+		// TODO
+		break;
+	case 18: // Text
+		// 2 parameters
+		// TODO
+		break;
+	case 19: // Reconstruct
+		// 3 parameters
+		// TODO
+		break;
+	default:
+		error("kScrollWindow: unknown subop %d", argv[0].toUint16());
+		break;
+	}
+
+	return s->r_acc;
+}
+
+reg_t kSetFontRes(EngineState *s, int argc, reg_t *argv) {
+	// TODO: This defines the resolution that the fonts are supposed to be displayed
+	// in. Currently, this is only used for showing high-res fonts in GK1 Mac, but
+	// should be extended to handle other font resolutions such as those 
+	
+	int xResolution = argv[0].toUint16();
+	//int yResolution = argv[1].toUint16();
+
+	g_sci->_gfxScreen->setFontIsUpscaled(xResolution == 640 &&
+			g_sci->_gfxScreen->getUpscaledHires() != GFX_SCREEN_UPSCALED_DISABLED);
+
+	return s->r_acc;
+}
+
+reg_t kFont(EngineState *s, int argc, reg_t *argv) {
+	// Handle font settings for SCI2.1
+
+	switch (argv[0].toUint16()) {
+	case 1:
+		// Set font resolution
+		return kSetFontRes(s, argc - 1, argv + 1);
+	default:
+		warning("kFont: unknown subop %d", argv[0].toUint16());
+	}
+
 	return s->r_acc;
 }
 
