@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/kparse.cpp $
- * $Id: kparse.cpp 52497 2010-09-02 13:50:49Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -62,7 +62,7 @@ reg_t kSaid(EngineState *s, int argc, reg_t *argv) {
 	}
 
 #ifdef DEBUG_PARSER
-		printf("Said block: ");
+		debugN("Said block: ");
 		g_sci->getVocabulary()->debugDecipherSaidBlock(said_block);
 #endif
 
@@ -70,11 +70,11 @@ reg_t kSaid(EngineState *s, int argc, reg_t *argv) {
 		return NULL_REG;
 	}
 
-	new_lastmatch = said(s, said_block, debug_parser);
+	new_lastmatch = said(said_block, debug_parser);
 	if (new_lastmatch  != SAID_NO_MATCH) { /* Build and possibly display a parse tree */
 
 #ifdef DEBUG_PARSER
-		printf("kSaid: Match.\n");
+		debugN("kSaid: Match.\n");
 #endif
 
 		s->r_acc = make_reg(0, 1);
@@ -93,13 +93,13 @@ reg_t kParse(EngineState *s, int argc, reg_t *argv) {
 	reg_t stringpos = argv[0];
 	Common::String string = s->_segMan->getString(stringpos);
 	char *error;
-	ResultWordList words;
 	reg_t event = argv[1];
 	g_sci->checkVocabularySwitch();
 	Vocabulary *voc = g_sci->getVocabulary();
 	voc->parser_event = event;
-	reg_t params[2] = { voc->parser_base, stringpos };
+	reg_t params[2] = { s->_segMan->getParserPtr(), stringpos };
 
+	ResultWordListList words;
 	bool res = voc->tokenizeString(words, string.c_str(), &error);
 	voc->parserIsValid = false; /* not valid */
 
@@ -109,10 +109,15 @@ reg_t kParse(EngineState *s, int argc, reg_t *argv) {
 		s->r_acc = make_reg(0, 1);
 
 #ifdef DEBUG_PARSER
-			debugC(2, kDebugLevelParser, "Parsed to the following blocks:");
+		debugC(kDebugLevelParser, "Parsed to the following blocks:");
 
-			for (ResultWordList::const_iterator i = words.begin(); i != words.end(); ++i)
-				debugC(2, kDebugLevelParser, "   Type[%04x] Group[%04x]", i->_class, i->_group);
+		for (ResultWordListList::const_iterator i = words.begin(); i != words.end(); ++i) {
+			debugCN(2, kDebugLevelParser, "   ");
+			for (ResultWordList::const_iterator j = i->begin(); j != i->end(); ++j) {
+				debugCN(2, kDebugLevelParser, "%sType[%04x] Group[%04x]", j == i->begin() ? "" : " / ", j->_class, j->_group);
+			}
+			debugCN(2, kDebugLevelParser, "\n");
+		}
 #endif
 
 		int syntax_fail = voc->parseGNF(words);
@@ -124,7 +129,7 @@ reg_t kParse(EngineState *s, int argc, reg_t *argv) {
 			invokeSelector(s, g_sci->getGameObject(), SELECTOR(syntaxFail), argc, argv, 2, params);
 			/* Issue warning */
 
-			debugC(2, kDebugLevelParser, "Tree building failed");
+			debugC(kDebugLevelParser, "Tree building failed");
 
 		} else {
 			voc->parserIsValid = true;
@@ -138,19 +143,11 @@ reg_t kParse(EngineState *s, int argc, reg_t *argv) {
 	} else {
 
 		s->r_acc = make_reg(0, 0);
-		// FIXME: When typing something wrong in the fanmade game Demo Quest,
-		// after the error dialog, the game checks for claimed to be 0 before
-		// showing a subsequent dialog. The following selector change causes
-		// it to be 1, thus causing the game to hang in an endless loop (bug
-		// #3038870. Thus, this seems to be wrong (since fanmade games use
-		// the original SCI interpreter), but we need to check against
-		// dissassembly. Since kParse is in the process of being dissassembled
-		// again, I'm leaving this FIXME in for now, so that it won't be
-		// forgotten :)
 		writeSelectorValue(segMan, event, SELECTOR(claimed), 1);
+
 		if (error) {
-			s->_segMan->strcpy(voc->parser_base, error);
-			debugC(2, kDebugLevelParser, "Word unknown: %s", error);
+			s->_segMan->strcpy(s->_segMan->getParserPtr(), error);
+			debugC(kDebugLevelParser, "Word unknown: %s", error);
 			/* Issue warning: */
 
 			invokeSelector(s, g_sci->getGameObject(), SELECTOR(wordFail), argc, argv, 2, params);
@@ -172,7 +169,7 @@ reg_t kSetSynonyms(EngineState *s, int argc, reg_t *argv) {
 	Vocabulary *voc = g_sci->getVocabulary();
 
 	// Only SCI0-SCI1 EGA games had a parser. In newer versions, this is a stub
-	if (getSciVersion() > SCI_VERSION_1_EGA)
+	if (getSciVersion() > SCI_VERSION_1_EGA_ONLY)
 		return s->r_acc;
 
 	voc->clearSynonyms();
@@ -194,7 +191,7 @@ reg_t kSetSynonyms(EngineState *s, int argc, reg_t *argv) {
 			const byte *synonyms = s->_segMan->getScript(seg)->getSynonyms();
 
 			if (synonyms) {
-				debugC(2, kDebugLevelParser, "Setting %d synonyms for script.%d",
+				debugC(kDebugLevelParser, "Setting %d synonyms for script.%d",
 				          numSynonyms, script);
 
 				if (numSynonyms > 16384) {
@@ -205,8 +202,8 @@ reg_t kSetSynonyms(EngineState *s, int argc, reg_t *argv) {
 				} else
 					for (int i = 0; i < numSynonyms; i++) {
 						synonym_t tmp;
-						tmp.replaceant = (int16)READ_LE_UINT16(synonyms + i * 4);
-						tmp.replacement = (int16)READ_LE_UINT16(synonyms + i * 4 + 2);
+						tmp.replaceant = READ_LE_UINT16(synonyms + i * 4);
+						tmp.replacement = READ_LE_UINT16(synonyms + i * 4 + 2);
 						voc->addSynonym(tmp);
 					}
 			} else
@@ -217,7 +214,7 @@ reg_t kSetSynonyms(EngineState *s, int argc, reg_t *argv) {
 		node = s->_segMan->lookupNode(node->succ);
 	}
 
-	debugC(2, kDebugLevelParser, "A total of %d synonyms are active now.", numSynonyms);
+	debugC(kDebugLevelParser, "A total of %d synonyms are active now.", numSynonyms);
 
 	return s->r_acc;
 }
