@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/kscripts.cpp $
- * $Id: kscripts.cpp 52585 2010-09-06 10:41:14Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -56,14 +56,6 @@ reg_t kUnLoad(EngineState *s, int argc, reg_t *argv) {
 		ResourceType restype = g_sci->getResMan()->convertResType(argv[0].toUint16());
 		reg_t resnr = argv[1];
 
-		// WORKAROUND for a broken script in room 320 in Castle of Dr. Brain.
-		// Script 377 tries to free the hunk memory allocated for the saved area
-		// (underbits) beneath the pop up window, which results in having the
-		// window stay on screen even when it's closed. Ignore this request here.
-		if (restype == kResourceTypeMemory && g_sci->getGameId() == GID_CASTLEBRAIN &&
-			s->currentRoomNumber() == 320)
-			return s->r_acc;
-
 		if (restype == kResourceTypeMemory)
 			s->_segMan->freeHunkEntry(resnr);
 	}
@@ -103,12 +95,12 @@ reg_t kLock(EngineState *s, int argc, reg_t *argv) {
 				g_sci->getResMan()->unlockResource(which);
 			else {
 				if (id.getType() == kResourceTypeInvalid)
-					warning("[resMan] Attempt to unlock resource %i of invalid type %i", id.getNumber(), type);
+				  warning("[resMan] Attempt to unlock resource %i of invalid type %i", id.getNumber(), argv[0].toUint16());
 				else
 					// Happens in CD games (e.g. LSL6CD) with the message
 					// resource. It isn't fatal, and it's usually caused
 					// by leftover scripts.
-					debugC(2, kDebugLevelResMan, "[resMan] Attempt to unlock non-existant resource %s", id.toString().c_str());
+					debugC(kDebugLevelResMan, "[resMan] Attempt to unlock non-existant resource %s", id.toString().c_str());
 			}
 		}
 		break;
@@ -153,9 +145,9 @@ reg_t kClone(EngineState *s, int argc, reg_t *argv) {
 		return NULL_REG;
 	}
 
-	debugC(2, kDebugLevelMemory, "Attempting to clone from %04x:%04x", PRINT_REG(parentAddr));
+	debugC(kDebugLevelMemory, "Attempting to clone from %04x:%04x", PRINT_REG(parentAddr));
 
-	uint16 infoSelector = readSelectorValue(s->_segMan, parentAddr, SELECTOR(_info_));
+	uint16 infoSelector = parentObj->getInfoSelector().offset;
 	cloneObj = s->_segMan->allocateClone(&cloneAddr);
 
 	if (!cloneObj) {
@@ -174,12 +166,12 @@ reg_t kClone(EngineState *s, int argc, reg_t *argv) {
 	// extend the internal storage size.
 	if (infoSelector & kInfoFlagClone)
 		parentObj = s->_segMan->getObject(parentAddr);
-
+	
 	*cloneObj = *parentObj;
 
 	// Mark as clone
 	infoSelector &= ~kInfoFlagClass; // remove class bit
-	writeSelectorValue(s->_segMan, cloneAddr, SELECTOR(_info_), infoSelector | kInfoFlagClone);
+	cloneObj->setInfoSelector(make_reg(0, infoSelector | kInfoFlagClone));
 
 	cloneObj->setSpeciesSelector(cloneObj->getPos());
 	if (parentObj->isClass())
@@ -206,7 +198,7 @@ reg_t kDisposeClone(EngineState *s, int argc, reg_t *argv) {
 	//  At least kq4early relies on this behaviour. The scripts clone "Sound", then set bit 1 manually
 	//  and call kDisposeClone later. In that case we may not free it, otherwise we will run into issues
 	//  later, because kIsObject would then return false and Sound object wouldn't get checked.
-	uint16 infoSelector = readSelectorValue(s->_segMan, obj, SELECTOR(_info_));
+	uint16 infoSelector = object->getInfoSelector().offset;
 	if ((infoSelector & 3) == kInfoFlagClone)
 		object->markAsFreed();
 
@@ -246,12 +238,22 @@ reg_t kScriptID(EngineState *s, int argc, reg_t *argv) {
 		return NULL_REG;
 	}
 
-	uint16 address = scr->validateExportFunc(index);
+	uint16 address = scr->validateExportFunc(index, true);
 
-	// Point to the heap for SCI1.1+ games
-	if (getSciVersion() >= SCI_VERSION_1_1)
+	// Point to the heap for SCI1.1 - SCI2.1 games
+	if (getSciVersion() >= SCI_VERSION_1_1 && getSciVersion() <= SCI_VERSION_2_1)
 		address += scr->getScriptSize();
 
+	// Bugfix for the intro speed in PQ2 version 1.002.011.
+	// This is taken from the patch by NewRisingSun(NRS) / Belzorash. Global 3
+	// is used for timing during the intro, and in the problematic version it's
+	// initialized to 0, whereas it's 6 in other versions. Thus, we assign it
+	// to 6 here, fixing the speed of the introduction. Refer to bug #3102071.
+	if (g_sci->getGameId() == GID_PQ2 && script == 200 &&
+		s->variables[VAR_GLOBAL][3].isNull()) {
+		s->variables[VAR_GLOBAL][3] = make_reg(0, 6);
+	}
+
 	return make_reg(scriptSeg, address);
 }
 
@@ -260,7 +262,7 @@ reg_t kDisposeScript(EngineState *s, int argc, reg_t *argv) {
 
 	SegmentId id = s->_segMan->getScriptSegment(script);
 	Script *scr = s->_segMan->getScriptIfLoaded(id);
-	if (scr) {
+	if (scr && !scr->isMarkedAsDeleted()) {
 		if (s->_executionStack.back().addr.pc.segment != id)
 			scr->setLockers(1);
 	}
