@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/scriptdebug.cpp $
- * $Id: scriptdebug.cpp 51243 2010-07-24 11:59:40Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,6 +34,10 @@
 
 namespace Sci {
 
+// This table is only used for debugging. Don't include it for devices
+// with not enough available memory (e.g. phones), where REDUCE_MEMORY_USAGE
+// is defined
+#ifndef REDUCE_MEMORY_USAGE
 const char *opcodeNames[] = {
 	   "bnot",       "add",      "sub",      "mul",      "div",
 		"mod",       "shr",      "shl",      "xor",      "and",
@@ -62,15 +66,16 @@ const char *opcodeNames[] = {
 	   "-agi",      "-ali",     "-ati",     "-api",     "-sgi",
 	   "-sli",      "-sti",     "-spi"
 };
+#endif	// REDUCE_MEMORY_USAGE
 
 // Disassembles one command from the heap, returns address of next command or 0 if a ret was encountered.
-reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecode) {
+reg_t disassemble(EngineState *s, reg_t pos, bool printBWTag, bool printBytecode) {
 	SegmentObj *mobj = s->_segMan->getSegment(pos.segment, SEG_TYPE_SCRIPT);
 	Script *script_entity = NULL;
 	const byte *scr;
 	int scr_size;
 	reg_t retval = make_reg(pos.segment, pos.offset + 1);
-	uint16 param_value;
+	uint16 param_value = 0xffff; // Suppress GCC warning by setting default value, chose value as invalid to getKernelName etc. 
 	int i = 0;
 	Kernel *kernel = g_sci->getKernel();
 
@@ -85,7 +90,7 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 
 	if (pos.offset >= scr_size) {
 		warning("Trying to disassemble beyond end of script");
-		return pos;
+		return NULL_REG;
 	}
 
 	int16 opparams[4];
@@ -95,25 +100,27 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 
 	opsize &= 1; // byte if true, word if false
 
-	printf("%04x:%04x: ", PRINT_REG(pos));
+	debugN("%04x:%04x: ", PRINT_REG(pos));
 
-	if (print_bytecode) {
+	if (printBytecode) {
 		if (pos.offset + bytecount > scr_size) {
 			warning("Operation arguments extend beyond end of script");
 			return retval;
 		}
 
 		for (i = 0; i < bytecount; i++)
-			printf("%02x ", scr[pos.offset + i]);
+			debugN("%02x ", scr[pos.offset + i]);
 
 		for (i = bytecount; i < 5; i++)
-			printf("   ");
+			debugN("   ");
 	}
 
-	if (print_bw_tag)
-		printf("[%c] ", opsize ? 'B' : 'W');
+	if (printBWTag)
+		debugN("[%c] ", opsize ? 'B' : 'W');
 
-	printf("%s", opcodeNames[opcode]);
+#ifndef REDUCE_MEMORY_USAGE
+	debugN("%s", opcodeNames[opcode]);
+#endif
 
 	i = 0;
 	while (g_opcode_formats[opcode][i]) {
@@ -124,12 +131,15 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 
 		case Script_SByte:
 		case Script_Byte:
-			printf(" %02x", scr[retval.offset++]);
+			param_value = scr[retval.offset];
+			debugN(" %02x", scr[retval.offset]);
+			retval.offset++;
 			break;
 
 		case Script_Word:
 		case Script_SWord:
-			printf(" %04x", READ_SCI11ENDIAN_UINT16(&scr[retval.offset]));
+			param_value = READ_SCI11ENDIAN_UINT16(&scr[retval.offset]);
+			debugN(" %04x", READ_SCI11ENDIAN_UINT16(&scr[retval.offset]));
 			retval.offset += 2;
 			break;
 
@@ -148,11 +158,11 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 			}
 
 			if (opcode == op_callk)
-				printf(" %s[%x]", (param_value < kernel->_kernelFuncs.size()) ?
+				debugN(" %s[%x]", (param_value < kernel->_kernelFuncs.size()) ?
 							((param_value < kernel->getKernelNamesSize()) ? kernel->getKernelName(param_value).c_str() : "[Unknown(postulated)]")
 							: "<invalid>", param_value);
 			else
-				printf(opsize ? " %02x" : " %04x", param_value);
+				debugN(opsize ? " %02x" : " %04x", param_value);
 
 			break;
 
@@ -163,7 +173,7 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 				param_value = READ_SCI11ENDIAN_UINT16(&scr[retval.offset]);
 				retval.offset += 2;
 			}
-			printf(opsize ? " %02x" : " %04x", param_value);
+			debugN(opsize ? " %02x" : " %04x", param_value);
 			break;
 
 		case Script_SRelative:
@@ -173,7 +183,7 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 				param_value = READ_SCI11ENDIAN_UINT16(&scr[retval.offset]);
 				retval.offset += 2;
 			}
-			printf(opsize ? " %02x  [%04x]" : " %04x  [%04x]", param_value, (0xffff) & (retval.offset + param_value));
+			debugN(opsize ? " %02x  [%04x]" : " %04x  [%04x]", param_value, (0xffff) & (retval.offset + param_value));
 			break;
 
 		case Script_End:
@@ -190,34 +200,38 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 		if ((opcode == op_pTos) || (opcode == op_sTop) || (opcode == op_pToa) || (opcode == op_aTop) ||
 		        (opcode == op_dpToa) || (opcode == op_ipToa) || (opcode == op_dpTos) || (opcode == op_ipTos)) {
 			const Object *obj = s->_segMan->getObject(s->xs->objp);
-			if (!obj)
+			if (!obj) {
 				warning("Attempted to reference on non-object at %04x:%04x", PRINT_REG(s->xs->objp));
-			else
-				printf("	(%s)", g_sci->getKernel()->getSelectorName(obj->propertyOffsetToId(s->_segMan, scr[pos.offset + 1])).c_str());
+			} else {
+				if (getSciVersion() == SCI_VERSION_3)
+					debugN("\t(%s)", g_sci->getKernel()->getSelectorName(param_value).c_str());
+				else
+					debugN("\t(%s)", g_sci->getKernel()->getSelectorName(obj->propertyOffsetToId(s->_segMan, param_value)).c_str());
+			}
 		}
 	}
 
-	printf("\n");
+	debugN("\n");
 
 	if (pos == s->xs->addr.pc) { // Extra information if debugging the current opcode
 		if (opcode == op_callk) {
-			int stackframe = (scr[pos.offset + 2] >> 1) + (s->restAdjust);
+			int stackframe = (scr[pos.offset + 2] >> 1) + (s->r_rest);
 			int argc = ((s->xs->sp)[- stackframe - 1]).offset;
 			bool oldScriptHeader = (getSciVersion() == SCI_VERSION_0_EARLY);
 
 			if (!oldScriptHeader)
-				argc += (s->restAdjust);
+				argc += (s->r_rest);
 
-			printf(" Kernel params: (");
+			debugN(" Kernel params: (");
 
 			for (int j = 0; j < argc; j++) {
-				printf("%04x:%04x", PRINT_REG((s->xs->sp)[j - stackframe]));
+				debugN("%04x:%04x", PRINT_REG((s->xs->sp)[j - stackframe]));
 				if (j + 1 < argc)
-					printf(", ");
+					debugN(", ");
 			}
-			printf(")\n");
+			debugN(")\n");
 		} else if ((opcode == op_send) || (opcode == op_self)) {
-			int restmod = s->restAdjust;
+			int restmod = s->r_rest;
 			int stackframe = (scr[pos.offset + 1] >> 1) + restmod;
 			reg_t *sb = s->xs->sp;
 			uint16 selector;
@@ -240,32 +254,32 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 				if (!name)
 					name = "<invalid>";
 
-				printf("  %s::%s[", name, g_sci->getKernel()->getSelectorName(selector).c_str());
+				debugN("  %s::%s[", name, g_sci->getKernel()->getSelectorName(selector).c_str());
 
 				switch (lookupSelector(s->_segMan, called_obj_addr, selector, 0, &fun_ref)) {
 				case kSelectorMethod:
-					printf("FUNCT");
+					debugN("FUNCT");
 					argc += restmod;
 					restmod = 0;
 					break;
 				case kSelectorVariable:
-					printf("VAR");
+					debugN("VAR");
 					break;
 				case kSelectorNone:
-					printf("INVALID");
+					debugN("INVALID");
 					break;
 				}
 
-				printf("](");
+				debugN("](");
 
 				while (argc--) {
-					printf("%04x:%04x", PRINT_REG(sb[- stackframe + 2]));
+					debugN("%04x:%04x", PRINT_REG(sb[- stackframe + 2]));
 					if (argc)
-						printf(", ");
+						debugN(", ");
 					stackframe--;
 				}
 
-				printf(")\n");
+				debugN(")\n");
 				stackframe -= 2;
 			} // while (stackframe > 0)
 		} // Send-like opcodes
@@ -274,6 +288,34 @@ reg_t disassemble(EngineState *s, reg_t pos, int print_bw_tag, int print_bytecod
 	return retval;
 }
 
+bool isJumpOpcode(EngineState *s, reg_t pos, reg_t& jumpTarget) {
+	SegmentObj *mobj = s->_segMan->getSegment(pos.segment, SEG_TYPE_SCRIPT);
+	if (!mobj)
+		return false;
+	Script *script_entity = (Script *)mobj;
+
+	const byte *scr = script_entity->getBuf();
+	int scr_size = script_entity->getBufSize();
+
+	if (pos.offset >= scr_size)
+		return false;
+
+	int16 opparams[4];
+	byte opsize;
+	int bytecount = readPMachineInstruction(scr + pos.offset, opsize, opparams);
+	const byte opcode = opsize >> 1;
+
+	switch (opcode) {
+	case op_bt:
+	case op_bnt:
+	case op_jmp:
+		jumpTarget = pos + bytecount + opparams[0];
+		return true;
+	default:
+		return false;
+	}
+}
+
 
 void SciEngine::scriptDebug() {
 	EngineState *s = _gamestate;
@@ -334,8 +376,8 @@ void SciEngine::scriptDebug() {
 		// OK, found whatever we were looking for
 	}
 
-	printf("Step #%d\n", s->scriptStepCounter);
-	disassemble(s, s->xs->addr.pc, 0, 1);
+	debugN("Step #%d\n", s->scriptStepCounter);
+	disassemble(s, s->xs->addr.pc, false, true);
 
 	if (_debugState.runningStep) {
 		_debugState.runningStep--;
@@ -354,27 +396,27 @@ void Kernel::dumpScriptObject(char *data, int seeker, int objsize) {
 	int namepos = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + 14 + seeker);
 	int i = 0;
 
-	printf("Object\n");
+	debugN("Object\n");
 
 	Common::hexdump((unsigned char *) data + seeker, objsize - 4, 16, seeker);
 	//-4 because the size includes the two-word header
 
-	printf("Name: %s\n", namepos ? ((char *)(data + namepos)) : "<unknown>");
-	printf("Superclass: %x\n", superclass);
-	printf("Species: %x\n", species);
-	printf("-info-:%x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + 12 + seeker) & 0xffff);
+	debugN("Name: %s\n", namepos ? ((char *)(data + namepos)) : "<unknown>");
+	debugN("Superclass: %x\n", superclass);
+	debugN("Species: %x\n", species);
+	debugN("-info-:%x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + 12 + seeker) & 0xffff);
 
-	printf("Function area offset: %x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + seeker + 4));
-	printf("Selectors [%x]:\n", selectors = (selectorsize = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + seeker + 6)));
+	debugN("Function area offset: %x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + seeker + 4));
+	debugN("Selectors [%x]:\n", selectors = (selectorsize = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + seeker + 6)));
 
 	seeker += 8;
 
 	while (selectors--) {
-		printf("  [#%03x] = 0x%x\n", i++, (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker) & 0xffff);
+		debugN("  [#%03x] = 0x%x\n", i++, (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker) & 0xffff);
 		seeker += 2;
 	}
 
-	printf("Overridden functions: %x\n", selectors = overloads = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker));
+	debugN("Overridden functions: %x\n", selectors = overloads = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker));
 
 	seeker += 2;
 
@@ -382,8 +424,8 @@ void Kernel::dumpScriptObject(char *data, int seeker, int objsize) {
 		while (overloads--) {
 			int selector = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + (seeker));
 
-			printf("  [%03x] %s: @", selector & 0xffff, (selector >= 0 && selector < (int)_selectorNames.size()) ? _selectorNames[selector].c_str() : "<?>");
-			printf("%04x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + selectors*2 + 2) & 0xffff);
+			debugN("  [%03x] %s: @", selector & 0xffff, (selector >= 0 && selector < (int)_selectorNames.size()) ? _selectorNames[selector].c_str() : "<?>");
+			debugN("%04x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + selectors*2 + 2) & 0xffff);
 
 			seeker += 2;
 		}
@@ -395,17 +437,17 @@ void Kernel::dumpScriptClass(char *data, int seeker, int objsize) {
 	int superclass = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + 10 + seeker);
 	int namepos = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + 14 + seeker);
 
-	printf("Class\n");
+	debugN("Class\n");
 
 	Common::hexdump((unsigned char *) data + seeker, objsize - 4, 16, seeker);
 
-	printf("Name: %s\n", namepos ? ((char *)data + namepos) : "<unknown>");
-	printf("Superclass: %x\n", superclass);
-	printf("Species: %x\n", species);
-	printf("-info-:%x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + 12 + seeker) & 0xffff);
+	debugN("Name: %s\n", namepos ? ((char *)data + namepos) : "<unknown>");
+	debugN("Superclass: %x\n", superclass);
+	debugN("Species: %x\n", species);
+	debugN("-info-:%x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + 12 + seeker) & 0xffff);
 
-	printf("Function area offset: %x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + 4));
-	printf("Selectors [%x]:\n", selectors = (selectorsize = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + 6)));
+	debugN("Function area offset: %x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + 4));
+	debugN("Selectors [%x]:\n", selectors = (selectorsize = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + 6)));
 
 	seeker += 8;
 	selectorsize <<= 1;
@@ -413,7 +455,7 @@ void Kernel::dumpScriptClass(char *data, int seeker, int objsize) {
 	while (selectors--) {
 		int selector = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *) data + (seeker) + selectorsize);
 
-		printf("  [%03x] %s = 0x%x\n", 0xffff & selector, (selector >= 0 && selector < (int)_selectorNames.size()) ? _selectorNames[selector].c_str() : "<?>",
+		debugN("  [%03x] %s = 0x%x\n", 0xffff & selector, (selector >= 0 && selector < (int)_selectorNames.size()) ? _selectorNames[selector].c_str() : "<?>",
 		          (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker) & 0xffff);
 
 		seeker += 2;
@@ -421,16 +463,16 @@ void Kernel::dumpScriptClass(char *data, int seeker, int objsize) {
 
 	seeker += selectorsize;
 
-	printf("Overloaded functions: %x\n", selectors = overloads = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker));
+	debugN("Overloaded functions: %x\n", selectors = overloads = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker));
 
 	seeker += 2;
 
 	while (overloads--) {
 		int selector = (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + (seeker));
-		fprintf(stderr, "selector=%d; selectorNames.size() =%d\n", selector, _selectorNames.size());
-		printf("  [%03x] %s: @", selector & 0xffff, (selector >= 0 && selector < (int)_selectorNames.size()) ?
+		debugN("selector=%d; selectorNames.size() =%d\n", selector, _selectorNames.size());
+		debugN("  [%03x] %s: @", selector & 0xffff, (selector >= 0 && selector < (int)_selectorNames.size()) ?
 		          _selectorNames[selector].c_str() : "<?>");
-		printf("%04x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + selectors * 2 + 2) & 0xffff);
+		debugN("%04x\n", (int16)READ_SCI11ENDIAN_UINT16((unsigned char *)data + seeker + selectors * 2 + 2) & 0xffff);
 
 		seeker += 2;
 	}
@@ -452,17 +494,17 @@ void Kernel::dissectScript(int scriptNumber, Vocabulary *vocab) {
 		unsigned int seeker = _seeker + 4;
 
 		if (!objType) {
-			printf("End of script object (#0) encountered.\n");
-			printf("Classes: %i, Objects: %i, Export: %i,\n Var: %i (all base 10)",
+			debugN("End of script object (#0) encountered.\n");
+			debugN("Classes: %i, Objects: %i, Export: %i,\n Var: %i (all base 10)",
 			          objectctr[6], objectctr[1], objectctr[7], objectctr[10]);
 			return;
 		}
 
-		printf("\n");
+		debugN("\n");
 
 		objsize = (int16)READ_SCI11ENDIAN_UINT16(script->data + _seeker + 2);
 
-		printf("Obj type #%x, size 0x%x: ", objType, objsize);
+		debugN("Obj type #%x, size 0x%x: ", objType, objsize);
 
 		_seeker += objsize;
 
@@ -474,28 +516,28 @@ void Kernel::dissectScript(int scriptNumber, Vocabulary *vocab) {
 			break;
 
 		case SCI_OBJ_CODE:
-			printf("Code\n");
+			debugN("Code\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
-		case 3:
-			printf("<unknown>\n");
+		case SCI_OBJ_SYNONYMS:
+			debugN("Synonyms\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
 		case SCI_OBJ_SAID:
-			printf("Said\n");
+			debugN("Said\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 
-			printf("%04x: ", seeker);
+			debugN("%04x: ", seeker);
 			vocab->debugDecipherSaidBlock(script->data + seeker);
-			printf("\n");
+			debugN("\n");
 			break;
 
 		case SCI_OBJ_STRINGS:
-			printf("Strings\n");
+			debugN("Strings\n");
 			while (script->data [seeker]) {
-				printf("%04x: %s\n", seeker, script->data + seeker);
+				debugN("%04x: %s\n", seeker, script->data + seeker);
 				seeker += strlen((char *)script->data + seeker) + 1;
 			}
 			seeker++; // the ending zero byte
@@ -506,33 +548,216 @@ void Kernel::dissectScript(int scriptNumber, Vocabulary *vocab) {
 			break;
 
 		case SCI_OBJ_EXPORTS:
-			printf("Exports\n");
+			debugN("Exports\n");
 			Common::hexdump((unsigned char *)script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
 		case SCI_OBJ_POINTERS:
-			printf("Pointers\n");
+			debugN("Pointers\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
 		case 9:
-			printf("<unknown>\n");
+			debugN("<unknown>\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
 		case SCI_OBJ_LOCALVARS:
-			printf("Local vars\n");
+			debugN("Local vars\n");
 			Common::hexdump(script->data + seeker, objsize - 4, 16, seeker);
 			break;
 
 		default:
-			printf("Unsupported!\n");
+			debugN("Unsupported!\n");
 			return;
 		}
 
 	}
 
-	printf("Script ends without terminator\n");
+	debugN("Script ends without terminator\n");
+}
+
+bool SciEngine::checkSelectorBreakpoint(BreakpointType breakpointType, reg_t send_obj, int selector) {
+	Common::String methodName = _gamestate->_segMan->getObjectName(send_obj);
+	methodName += ("::" + getKernel()->getSelectorName(selector));
+
+	Common::List<Breakpoint>::const_iterator bpIter;
+	for (bpIter = _debugState._breakpoints.begin(); bpIter != _debugState._breakpoints.end(); ++bpIter) {
+		if ((*bpIter).type == breakpointType && (*bpIter).name == methodName) {
+			_console->DebugPrintf("Break on %s (in [%04x:%04x])\n", methodName.c_str(), PRINT_REG(send_obj));
+			_debugState.debugging = true;
+			_debugState.breakpointWasHit = true;
+			return true;
+		}
+	}
+	return false;
+}
+
+bool SciEngine::checkExportBreakpoint(uint16 script, uint16 pubfunct) {
+	if (_debugState._activeBreakpointTypes & BREAK_EXPORT) {
+		uint32 bpaddress = (script << 16 | pubfunct);
+
+		Common::List<Breakpoint>::const_iterator bp;
+		for (bp = _debugState._breakpoints.begin(); bp != _debugState._breakpoints.end(); ++bp) {
+			if (bp->type == BREAK_EXPORT && bp->address == bpaddress) {
+				_console->DebugPrintf("Break on script %d, export %d\n", script, pubfunct);
+				_debugState.debugging = true;
+				_debugState.breakpointWasHit = true;
+				return true;
+			}
+		}
+	}
+
+	return false;
+}
+
+void debugSelectorCall(reg_t send_obj, Selector selector, int argc, StackPtr argp, ObjVarRef &varp, reg_t funcp, SegManager *segMan, SelectorType selectorType) {
+	int activeBreakpointTypes = g_sci->_debugState._activeBreakpointTypes;
+	const char *objectName = segMan->getObjectName(send_obj);
+	const char *selectorName = g_sci->getKernel()->getSelectorName(selector).c_str();
+	Console *con = g_sci->getSciDebugger();
+
+#ifdef VM_DEBUG_SEND
+		debugN("Send to %04x:%04x (%s), selector %04x (%s):", PRINT_REG(send_obj), 
+			s->_segMan->getObjectName(send_obj), selector, 
+			g_sci->getKernel()->getSelectorName(selector).c_str());
+#endif // VM_DEBUG_SEND
+
+	switch (selectorType) {
+	case kSelectorNone:
+		break;
+	case kSelectorVariable:
+#ifdef VM_DEBUG_SEND
+		if (argc)
+			debugN("Varselector: Write %04x:%04x\n", PRINT_REG(argp[1]));
+		else
+			debugN("Varselector: Read\n");
+#endif // VM_DEBUG_SEND
+
+		// argc == 0: read selector
+		// argc == 1: write selector
+		// argc can be bigger than 1 in some cases, because of a script bug.
+		// Usually, these aren't fatal.
+		if ((activeBreakpointTypes & BREAK_SELECTORREAD) ||
+			(activeBreakpointTypes & BREAK_SELECTORWRITE) ||
+			argc > 1) {
+
+			reg_t selectorValue = *varp.getPointer(segMan);
+			if (!argc && (activeBreakpointTypes & BREAK_SELECTORREAD)) {
+				if (g_sci->checkSelectorBreakpoint(BREAK_SELECTORREAD, send_obj, selector))
+					con->DebugPrintf("Read from selector (%s:%s): %04x:%04x\n", 
+							objectName, selectorName,
+							PRINT_REG(selectorValue));
+			} else if (argc && (activeBreakpointTypes & BREAK_SELECTORWRITE)) {
+				if (g_sci->checkSelectorBreakpoint(BREAK_SELECTORWRITE, send_obj, selector))
+					con->DebugPrintf("Write to selector (%s:%s): change %04x:%04x to %04x:%04x\n", 
+							objectName, selectorName,
+							PRINT_REG(selectorValue), PRINT_REG(argp[1]));
+			}
+
+			if (argc > 1)
+				debug(kDebugLevelScripts, "Write to selector (%s:%s): change %04x:%04x to %04x:%04x, argc == %d\n", 
+							objectName, selectorName,
+							PRINT_REG(selectorValue), PRINT_REG(argp[1]), argc);
+		}
+		break;
+	case kSelectorMethod:
+#ifndef VM_DEBUG_SEND
+			if (activeBreakpointTypes & BREAK_SELECTOREXEC) {
+				if (g_sci->checkSelectorBreakpoint(BREAK_SELECTOREXEC, send_obj, selector)) {
+#else
+			if (true) {
+				if (true) {
+#endif
+					con->DebugPrintf("%s::%s(", objectName, selectorName);
+					for (int i = 0; i < argc; i++) {
+						con->DebugPrintf("%04x:%04x", PRINT_REG(argp[i+1]));
+						if (i + 1 < argc)
+							con->DebugPrintf(", ");
+					}
+					con->DebugPrintf(") at %04x:%04x\n", PRINT_REG(funcp));
+				}
+			}
+		break;
+	}	// switch
+}
+
+void logKernelCall(const KernelFunction *kernelCall, const KernelSubFunction *kernelSubCall, EngineState *s, int argc, reg_t *argv, reg_t result) {
+	Kernel *kernel = g_sci->getKernel();
+	if (!kernelSubCall) {
+		debugN("k%s: ", kernelCall->name);
+	} else {
+		int callNameLen = strlen(kernelCall->name);
+		if (strncmp(kernelCall->name, kernelSubCall->name, callNameLen) == 0) {
+			const char *subCallName = kernelSubCall->name + callNameLen;
+			debugN("k%s(%s): ", kernelCall->name, subCallName);
+		} else {
+			debugN("k%s(%s): ", kernelCall->name, kernelSubCall->name);
+		}
+	}
+	for (int parmNr = 0; parmNr < argc; parmNr++) {
+		if (parmNr)
+			debugN(", ");
+		uint16 regType = kernel->findRegType(argv[parmNr]);
+		if (regType & SIG_TYPE_NULL)
+			debugN("0");
+		else if (regType & SIG_TYPE_UNINITIALIZED)
+			debugN("UNINIT");
+		else if (regType & SIG_IS_INVALID)
+			debugN("INVALID");
+		else if (regType & SIG_TYPE_INTEGER)
+			debugN("%d", argv[parmNr].offset);
+		else {
+			debugN("%04x:%04x", PRINT_REG(argv[parmNr]));
+			switch (regType) {
+			case SIG_TYPE_OBJECT:
+				debugN(" (%s)", s->_segMan->getObjectName(argv[parmNr]));
+				break;
+			case SIG_TYPE_REFERENCE:
+			{
+				SegmentObj *mobj = s->_segMan->getSegmentObj(argv[parmNr].segment);
+				switch (mobj->getType()) {
+				case SEG_TYPE_HUNK:
+				{
+					HunkTable *ht = (HunkTable*)mobj;
+					int index = argv[parmNr].offset;
+					if (ht->isValidEntry(index)) {
+						// NOTE: This ", deleted" isn't as useful as it could
+						// be because it prints the status _after_ the kernel
+						// call.
+						debugN(" ('%s' hunk%s)", ht->_table[index].type, ht->_table[index].mem ? "" : ", deleted");
+					} else
+						debugN(" (INVALID hunk ref)");
+					break;
+				}
+				default:
+					// TODO: Any other segment types which could
+					// use special handling?
+
+					if (kernelCall->function == kSaid) {
+						SegmentRef saidSpec = s->_segMan->dereference(argv[parmNr]);
+						if (saidSpec.isRaw) {
+							debugN(" ('");
+							g_sci->getVocabulary()->debugDecipherSaidBlock(saidSpec.raw);
+							debugN("')");
+						} else {
+							debugN(" (non-raw said-spec)");
+						}
+					} else {
+						debugN(" ('%s')", s->_segMan->getString(argv[parmNr]).c_str());
+					}
+					break;
+				}
+			}
+			default:
+				break;
+			}
+		}
+	}
+	if (result.isPointer())
+		debugN(" = %04x:%04x\n", PRINT_REG(result));
+	else
+		debugN(" = %d\n", result.offset);
 }
 
 } // End of namespace Sci
