@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/seg_manager.cpp $
- * $Id: seg_manager.cpp 52703 2010-09-13 13:47:56Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -63,7 +63,7 @@ void SegManager::resetSegMan() {
 	// Free memory
 	for (uint i = 0; i < _heap.size(); i++) {
 		if (_heap[i])
-			deallocate(i, false);
+			deallocate(i);
 	}
 
 	_heap.clear();
@@ -76,28 +76,30 @@ void SegManager::resetSegMan() {
 	_nodesSegId = 0;
 	_hunksSegId = 0;
 
+#ifdef ENABLE_SCI32
+	_arraysSegId = 0;
+	_stringSegId = 0;
+#endif
+
 	// Reinitialize class table
 	_classTable.clear();
 	createClassTable();
 }
 
 void SegManager::initSysStrings() {
-	_sysStrings = (SystemStrings *)allocSegment(new SystemStrings(), &_sysStringsSegId);
+	if (getSciVersion() <= SCI_VERSION_1_1) {
+		// We need to allocate system strings in one segment, for compatibility reasons
+		allocDynmem(512, "system strings", &_saveDirPtr);
+		_parserPtr = make_reg(_saveDirPtr.segment, _saveDirPtr.offset + 256);
+#ifdef ENABLE_SCI32
+	} else {
+		SciString *saveDirString = allocateString(&_saveDirPtr);
+		saveDirString->setSize(256);
+		saveDirString->setValue(0, 0);
 
-	// Allocate static buffer for savegame and CWD directories
-	SystemString *strSaveDir = getSystemString(SYS_STRING_SAVEDIR);
-	strSaveDir->_name = "savedir";
-	strSaveDir->_maxSize = MAX_SAVE_DIR_SIZE;
-	strSaveDir->_value = (char *)calloc(MAX_SAVE_DIR_SIZE, sizeof(char));
-	// Set the savegame dir (actually, we set it to a fake value,
-	// since we cannot let the game control where saves are stored)
-	::strcpy(strSaveDir->_value, "");
-
-	// Allocate static buffer for the parser base
-	SystemString *strParserBase = getSystemString(SYS_STRING_PARSER_BASE);
-	strParserBase->_name = "parser-base";
-	strParserBase->_maxSize = MAX_PARSER_BASE;
-	strParserBase->_value = (char *)calloc(MAX_PARSER_BASE, sizeof(char));
+		_parserPtr = NULL_REG;	// no SCI2 game had a parser
+#endif
+	}
 }
 
 SegmentId SegManager::findFreeSegment() const {
@@ -149,23 +151,21 @@ Script *SegManager::allocateScript(int script_nr, SegmentId *segid) {
 	return (Script *)mem;
 }
 
-int SegManager::deallocate(SegmentId seg, bool recursive) {
-	SegmentObj *mobj;
-	VERIFY(check(seg), "invalid seg id");
+void SegManager::deallocate(SegmentId seg) {
+	if (!check(seg))
+		error("SegManager::deallocate(): invalid segment ID");
 
-	mobj = _heap[seg];
+	SegmentObj *mobj = _heap[seg];
 
 	if (mobj->getType() == SEG_TYPE_SCRIPT) {
 		Script *scr = (Script *)mobj;
 		_scriptSegMap.erase(scr->getScriptNumber());
-		if (recursive && scr->_localsSegment)
-			deallocate(scr->_localsSegment, recursive);
+		if (scr->_localsSegment)
+			deallocate(scr->_localsSegment);
 	}
 
 	delete mobj;
 	_heap[seg] = NULL;
-
-	return 1;
 }
 
 bool SegManager::isHeapObject(reg_t pos) const {
@@ -177,8 +177,7 @@ bool SegManager::isHeapObject(reg_t pos) const {
 }
 
 void SegManager::deallocateScript(int script_nr) {
-	SegmentId seg = getScriptSegment(script_nr);
-	deallocate(seg, true);
+	deallocate(getScriptSegment(script_nr));
 }
 
 Script *SegManager::getScript(const SegmentId seg) {
@@ -255,7 +254,9 @@ const char *SegManager::getObjectName(reg_t pos) {
 	if (nameReg.isNull())
 		return "<no name>";
 
-	const char *name = derefString(nameReg);
+	const char *name = 0;
+	if (nameReg.segment)
+		name  = derefString(nameReg);
 	if (!name)
 		return "<invalid name>";
 
@@ -301,9 +302,9 @@ reg_t SegManager::findObjectByName(const Common::String &name, int index) {
 		return NULL_REG;
 
 	if (result.size() > 1 && index < 0) {
-		printf("Ambiguous:\n");
+		debug("findObjectByName(%s): multiple matches:", name.c_str());
 		for (i = 0; i < result.size(); i++)
-			printf("  %3x: [%04x:%04x] %s\n", i, PRINT_REG(result[i]), name.c_str());
+			debug("  %3x: [%04x:%04x]", i, PRINT_REG(result[i]));
 		return NULL_REG; // Ambiguous
 	}
 
@@ -359,9 +360,8 @@ LocalVariables *SegManager::allocLocalsSegment(Script *scr) {
 
 		if (scr->_localsSegment) {
 			locals = (LocalVariables *)_heap[scr->_localsSegment];
-			VERIFY(locals != NULL, "Re-used locals segment was NULL'd out");
-			VERIFY(locals->getType() == SEG_TYPE_LOCALS, "Re-used locals segment did not consist of local variables");
-			VERIFY(locals->script_id == scr->getScriptNumber(), "Re-used locals segment belonged to other script");
+			if (!locals || locals->getType() != SEG_TYPE_LOCALS || locals->script_id != scr->getScriptNumber())
+				error("Invalid script locals segment while allocating locals");
 		} else
 			locals = (LocalVariables *)allocSegment(new LocalVariables(), &scr->_localsSegment);
 
@@ -402,7 +402,7 @@ void SegManager::freeHunkEntry(reg_t addr) {
 		return;
 	}
 
-	ht->freeEntry(addr.offset);
+	ht->freeEntryContents(addr.offset);
 }
 
 reg_t SegManager::allocateHunkEntry(const char *hunk_type, int size) {
@@ -600,10 +600,14 @@ static inline char getChar(const SegmentRef &ref, uint offset) {
 		if (!((val.segment == 0xFFFF) && (offset > 1)))
 			warning("Attempt to read character from non-raw data");
 
-	return (offset & 1 ? val.offset >> 8 : val.offset & 0xff);
+	bool oddOffset = offset & 1;
+	if (g_sci->isBE())
+		oddOffset = !oddOffset;
+
+	return (oddOffset ? val.offset >> 8 : val.offset & 0xff);
 }
 
-static inline void setChar(const SegmentRef &ref, uint offset, char value) {
+static inline void setChar(const SegmentRef &ref, uint offset, byte value) {
 	if (ref.skipByte)
 		offset++;
 
@@ -611,7 +615,11 @@ static inline void setChar(const SegmentRef &ref, uint offset, char value) {
 
 	val->segment = 0;
 
-	if (offset & 1)
+	bool oddOffset = offset & 1;
+	if (g_sci->isBE())
+		oddOffset = !oddOffset;
+
+	if (oddOffset)
 		val->offset = (val->offset & 0x00ff) | (value << 8);
 	else
 		val->offset = (val->offset & 0xff00) | value;
@@ -855,7 +863,7 @@ bool SegManager::freeDynmem(reg_t addr) {
 	if (addr.segment < 1 || addr.segment >= _heap.size() || !_heap[addr.segment] || _heap[addr.segment]->getType() != SEG_TYPE_DYNMEM)
 		return false; // error
 
-	deallocate(addr.segment, true);
+	deallocate(addr.segment);
 
 	return true; // OK
 }
@@ -1013,7 +1021,7 @@ void SegManager::uninstantiateScript(int script_nr) {
 	SegmentId segmentId = getScriptSegment(script_nr);
 	Script *scr = getScriptIfLoaded(segmentId);
 
-	if (!scr) {   // Is it already unloaded?
+	if (!scr || scr->isMarkedAsDeleted()) {   // Is it already unloaded?
 		//warning("unloading script 0x%x requested although not loaded", script_nr);
 		// This is perfectly valid SCI behaviour
 		return;
@@ -1070,15 +1078,7 @@ void SegManager::uninstantiateScriptSci0(int script_nr) {
 					if (scr->getLockers())
 						scr->decrementLockers();  // Decrease lockers if this is us ourselves
 				} else {
-					if (g_sci->getGameId() == GID_HOYLE3 && (superclass_script == 0 || superclass_script >= 990)) {
-						// HACK for Hoyle 3: when exiting Checkers or Pachisi, scripts 0, 999 and some others
-						// are deleted but are never instantiated again. We ignore deletion of these scripts
-						// here for Hoyle 3 - bug #3038837
-						// TODO/FIXME: find out why this happens, seems like there is a problem with the object
-						// lock code
-					} else {
-						uninstantiateScript(superclass_script);
-					}
+					uninstantiateScript(superclass_script);
 				}
 				// Recurse to assure that the superclass lockers number gets decreased
 			}
