@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/state.h $
- * $Id: state.h 52474 2010-08-31 15:50:46Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,8 +32,8 @@
 #include "common/str-array.h"
 
 namespace Common {
-	class SeekableReadStream;
-	class WriteStream;
+class SeekableReadStream;
+class WriteStream;
 }
 
 #include "sci/sci.h"
@@ -78,10 +78,6 @@ private:
 	void addAsVirtualFiles(Common::String title, Common::String fileMask);
 };
 
-enum {
-	MAX_SAVE_DIR_SIZE = MAXPATHLEN
-};
-
 enum {
 	MAX_SAVEGAME_NR = 20 /**< Maximum number of savegames */
 };
@@ -113,6 +109,31 @@ public:
 	bool isOpen() const;
 };
 
+enum VideoFlags {
+	kNone            = 0,
+	kDoubled         = 1 << 0,
+	kDropFrames      = 1 << 1,
+	kBlackLines      = 1 << 2,
+	kUnkBit3         = 1 << 3,
+	kGammaBoost      = 1 << 4,
+	kHoldBlackFrame  = 1 << 5,
+	kHoldLastFrame   = 1 << 6,
+	kUnkBit7         = 1 << 7,
+	kStretch         = 1 << 8
+};
+
+struct VideoState {
+	Common::String fileName;
+	uint16 x;
+	uint16 y;
+	uint16 flags;
+
+	void reset() {
+		fileName = "";
+		x = y = flags = 0;
+	}
+};
+
 struct EngineState : public Common::Serializable {
 public:
 	EngineState(SegManager *segMan);
@@ -125,7 +146,6 @@ public:
 
 	/* Non-VM information */
 
-	uint32 gameStartTime; /**< The time at which the interpreter was started */
 	uint32 lastWaitTime; /**< The last time the game invoked Wait() */
 	uint32 _screenUpdateTime;	/**< The last time the game updated the screen */
 
@@ -135,6 +155,7 @@ public:
 	uint32 _throttleCounter; /**< total times kAnimate was invoked */
 	uint32 _throttleLastTime; /**< last time kAnimate was invoked */
 	bool _throttleTrigger;
+	bool _gameIsBenchmarking;
 
 	/* Kernel File IO stuff */
 
@@ -162,9 +183,10 @@ public:
 	int executionStackBase;
 	bool _executionStackPosChanged;   /**< Set to true if the execution stack position should be re-evaluated by the vm */
 
+	// Registers
 	reg_t r_acc; /**< Accumulator */
-	int16 restAdjust; /**< current &rest register */
 	reg_t r_prev; /**< previous comparison result */
+	int16 r_rest; /**< current &rest register */
 
 	StackPtr stack_base; /**< Pointer to the least stack element */
 	StackPtr stack_top; /**< First invalid stack element */
@@ -198,7 +220,6 @@ public:
 
 	int gcCountDown; /**< Number of kernel calls until next gc */
 
-public:
 	MessageState *_msgState;
 
 	// MemorySegment provides access to a 256-byte block of memory that remains
@@ -206,9 +227,12 @@ public:
 	enum {
 		kMemorySegmentMax = 256
 	};
-	uint _memorySegmentSize;
+	uint16 _memorySegmentSize;
 	byte _memorySegment[kMemorySegmentMax];
 
+	VideoState _videoState;
+	bool _syncedAudioOptions;
+
 	/**
 	 * Resets the engine state.
 	 */
