@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/static_selectors.cpp $
- * $Id: static_selectors.cpp 52757 2010-09-17 12:37:59Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "sci/engine/kernel.h"
 #include "sci/engine/seg_manager.h"
+#include "sci/engine/vm.h"
 
 namespace Sci {
 
@@ -64,6 +65,12 @@ static const char * const sci1Selectors[] = {
 	      "frame",        "vol",          "pri",    "perform",  "moveDone"  // 93 - 97
 };
 
+static const char * const sci11Selectors[] = {
+	  "topString",      "flags",    "quitGame",     "restart",      "hide", // 98 - 102
+	"scaleSignal",     "scaleX",      "scaleY",    "maxScale","vanishingX", // 103 - 107
+	 "vanishingY"                                                           // 108
+};
+
 #ifdef ENABLE_SCI32
 static const char * const sci2Selectors[] = {
 	    "plane",           "x",           "y",            "z",     "scaleX", //  0 -  4
@@ -108,21 +115,37 @@ static const SelectorRemap sciSelectorRemap[] = {
 	// SCI1.1
 	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,    "nodePtr",  41 },
 	{        SCI_VERSION_1_1,        SCI_VERSION_1_1, "cantBeHere",  54 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,  "topString",  98 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,      "flags",  99 },
-	// quitGame
-	// restart
-	// hide
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,"scaleSignal", 103 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,     "scaleX", 104 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,     "scaleY", 105 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1,   "maxScale", 106 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1, "vanishingX", 107 },
-	{        SCI_VERSION_1_1,        SCI_VERSION_1_1, "vanishingY", 108 },
 	{        SCI_VERSION_1_1,        SCI_VERSION_2_1,     "-info-",4103 },
 	{ SCI_VERSION_NONE,             SCI_VERSION_NONE,            0,   0 }
 };
 
+struct ClassReference {
+	int script;
+	const char *className;
+	const char *selectorName;
+	SelectorType selectorType;
+	uint selectorOffset;
+};
+
+// For variable selectors, we ignore the global selectors and start off from
+// the object's selectors (i.e. from the name selector onwards). Thus, the
+// following are not taken into consideration when calculating the indices of
+// variable selectors in this array:
+// SCI0 - SCI1: species, superClass, -info-
+// SCI1.1: -objID-, -size-, -propDict-, -methDict-, -classScript-, -script-,
+//         -super-, -info-
+static const ClassReference classReferences[] = {
+	{   0, "Character",         "say",   kSelectorMethod,  5 },	// Crazy Nick's Soft Picks
+	{ 928,  "Narrator",         "say",   kSelectorMethod,  4 },
+	{ 928,  "Narrator",   "startText",   kSelectorMethod,  5 },
+	{ 929,      "Sync",    "syncTime", kSelectorVariable,  1 },
+	{ 929,      "Sync",     "syncCue", kSelectorVariable,  2 },
+	{ 981, "SysWindow",        "open",   kSelectorMethod,  1 },
+	{ 999,    "Script",        "init",   kSelectorMethod,  0 },
+	{ 999,    "Script",     "dispose",   kSelectorMethod,  2 },
+	{ 999,    "Script", "changeState",   kSelectorMethod,  3 }
+};
+
 Common::StringArray Kernel::checkStaticSelectorNames() {
 	Common::StringArray names;
 	const int offset = (getSciVersion() < SCI_VERSION_1_1) ? 3 : 0;
@@ -132,10 +155,12 @@ Common::StringArray Kernel::checkStaticSelectorNames() {
 #else
 	const int count = ARRAYSIZE(sci0Selectors) + offset;
 #endif
+	int countSci1 = ARRAYSIZE(sci1Selectors);
+	int countSci11 = ARRAYSIZE(sci11Selectors);
 
 	// Resize the list of selector names and fill in the SCI 0 names.
 	names.resize(count);
-	if (getSciVersion() < SCI_VERSION_1_1) {
+	if (getSciVersion() <= SCI_VERSION_1_LATE) {
 		// Fill selectors 0 - 2 for SCI0 - SCI1 late
 		names[0] = "species";
 		names[1] = "superClass";
@@ -149,121 +174,20 @@ Common::StringArray Kernel::checkStaticSelectorNames() {
 
 		if (getSciVersion() > SCI_VERSION_01) {
 			// Several new selectors were added in SCI 1 and later.
-			int count2 = ARRAYSIZE(sci1Selectors);
-			names.resize(count + count2);
-			for (int i = count; i < count + count2; i++)
+			names.resize(count + countSci1);
+			for (int i = count; i < count + countSci1; i++)
 				names[i] = sci1Selectors[i - count];
 		}
 
-		// Now, we need to find out selectors which keep changing place...
-		// We do that by dissecting game objects, and looking for selectors at
-		// specified locations.
-
-		// We need to initialize script 0 here, to make sure that it's always
-		// located at segment 1.
-		_segMan->instantiateScript(0);
-
-		// The Actor class contains the init, xLast and yLast selectors, which
-		// we reference directly. It's always in script 998, so we need to
-		// explicitly load it here.
-		if (_resMan->testResource(ResourceId(kResourceTypeScript, 998))) {
-			_segMan->instantiateScript(998);
-
-			const Object *actorClass = _segMan->getObject(_segMan->findObjectByName("Actor"));
-
-			if (actorClass) {
-				// The init selector is always the first function
-				int initSelectorPos = actorClass->getFuncSelector(0);
-
-				if (names.size() < (uint32)initSelectorPos + 2)
-					names.resize((uint32)initSelectorPos + 2);
-
-				names[initSelectorPos] = "init";
-				// dispose comes right after init
-				names[initSelectorPos + 1] = "dispose";
-
-				if ((getSciVersion() >= SCI_VERSION_1_EGA)) {
-					// Find the xLast and yLast selectors, used in kDoBresen
-
-					// xLast and yLast always come between illegalBits and xStep
-					int illegalBitsSelectorPos = actorClass->locateVarSelector(_segMan, 15 + offset);	// illegalBits
-					int xStepSelectorPos = actorClass->locateVarSelector(_segMan, 51 + offset);	// xStep
-					if (xStepSelectorPos - illegalBitsSelectorPos != 3) {
-						error("illegalBits and xStep selectors aren't found in "
-							  "known locations. illegalBits = %d, xStep = %d",
-							  illegalBitsSelectorPos, xStepSelectorPos);
-					}
-
-					int xLastSelectorPos = actorClass->getVarSelector(illegalBitsSelectorPos + 1);
-					int yLastSelectorPos = actorClass->getVarSelector(illegalBitsSelectorPos + 2);
-
-					if (names.size() < (uint32)yLastSelectorPos + 1)
-						names.resize((uint32)yLastSelectorPos + 1);
-
-					names[xLastSelectorPos] = "xLast";
-					names[yLastSelectorPos] = "yLast";
-				}	// if ((getSciVersion() >= SCI_VERSION_1_EGA))
-			}	// if (actorClass)
-
-			_segMan->uninstantiateScript(998);
-		}	// if (_resMan->testResource(ResourceId(kResourceTypeScript, 998)))
-
-		if (_resMan->testResource(ResourceId(kResourceTypeScript, 981))) {
-			// The SysWindow class contains the open selectors, which we
-			// reference directly. It's always in script 981, so we need to
-			// explicitly load it here
-			_segMan->instantiateScript(981);
-
-			const Object *sysWindowClass = _segMan->getObject(_segMan->findObjectByName("SysWindow"));
-
-			if (sysWindowClass) {
-				if (sysWindowClass->getMethodCount() < 2)
-					error("The SysWindow class has less than 2 methods");
-
-				// The open selector is always the second function
-				int openSelectorPos = sysWindowClass->getFuncSelector(1);
-
-				if (names.size() < (uint32)openSelectorPos + 1)
-					names.resize((uint32)openSelectorPos + 1);
-
-				names[openSelectorPos] = "open";
-			}
-
-			_segMan->uninstantiateScript(981);
-		}	// if (_resMan->testResource(ResourceId(kResourceTypeScript, 981)))
-
-		if (g_sci->getGameId() == GID_HOYLE4) {
-			// The demo of Hoyle 4 is one of the few demos with lip syncing and no selector vocabulary.
-			// This needs two selectors, "syncTime" and "syncCue", which keep changing positions in each
-			// game. Usually, games with speech and lip sync have a selector vocabulary, so we don't need
-			// to set these two selectors, but we need for Hoyle...
-			if (names.size() < 276)
-				names.resize(276);
-
-			names[274] = "syncTime";
-			names[275] = "syncCue";
-		} else if (g_sci->getGameId() == GID_PEPPER) {
-			// Same as above for the non-interactive demo of Pepper
-			if (names.size() < 539)
-				names.resize(539);
-
-			names[263] = "syncTime";
-			names[264] = "syncCue";
-			names[538] = "startText";
-		} else if (g_sci->getGameId() == GID_LAURABOW2) {
-			// The floppy of version needs the changeState selector set to match up with the
-			// CD version's workarounds.
-			if (names.size() < 251)
-				names.resize(251);
-
-			names[144] = "changeState";
-		} else if (g_sci->getGameId() == GID_CNICK_KQ) {
-			if (names.size() < 447)
-				names.resize(447);
-
-			names[446] = "say";
+		if (getSciVersion() >= SCI_VERSION_1_1) {
+			// Several new selectors were added in SCI 1.1
+			names.resize(count + countSci1 + countSci11);
+			for (int i = count + countSci1; i < count + countSci1 + countSci11; i++)
+				names[i] = sci11Selectors[i - count - countSci1];
 		}
 
+		findSpecificSelectors(names);
+
 #ifdef ENABLE_SCI32
 	} else {
 		// SCI2+
@@ -284,4 +208,93 @@ Common::StringArray Kernel::checkStaticSelectorNames() {
 	return names;
 }
 
+void Kernel::findSpecificSelectors(Common::StringArray &selectorNames) {
+	// Now, we need to find out selectors which keep changing place...
+	// We do that by dissecting game objects, and looking for selectors at
+	// specified locations.
+
+	// We need to initialize script 0 here, to make sure that it's always
+	// located at segment 1.
+	_segMan->instantiateScript(0);
+
+	// The Actor class contains the init, xLast and yLast selectors, which
+	// we reference directly. It's always in script 998, so we need to
+	// explicitly load it here.
+	if ((getSciVersion() >= SCI_VERSION_1_EGA_ONLY)) {
+		if (_resMan->testResource(ResourceId(kResourceTypeScript, 998))) {
+			_segMan->instantiateScript(998);
+
+			const Object *actorClass = _segMan->getObject(_segMan->findObjectByName("Actor"));
+
+			if (actorClass) {
+				// Find the xLast and yLast selectors, used in kDoBresen
+
+				const int offset = (getSciVersion() < SCI_VERSION_1_1) ? 3 : 0;
+				// xLast and yLast always come between illegalBits and xStep
+				int illegalBitsSelectorPos = actorClass->locateVarSelector(_segMan, 15 + offset);	// illegalBits
+				int xStepSelectorPos = actorClass->locateVarSelector(_segMan, 51 + offset);	// xStep
+				if (xStepSelectorPos - illegalBitsSelectorPos != 3) {
+					error("illegalBits and xStep selectors aren't found in "
+							"known locations. illegalBits = %d, xStep = %d",
+							illegalBitsSelectorPos, xStepSelectorPos);
+				}
+
+				int xLastSelectorPos = actorClass->getVarSelector(illegalBitsSelectorPos + 1);
+				int yLastSelectorPos = actorClass->getVarSelector(illegalBitsSelectorPos + 2);
+
+				if (selectorNames.size() < (uint32)yLastSelectorPos + 1)
+					selectorNames.resize((uint32)yLastSelectorPos + 1);
+
+				selectorNames[xLastSelectorPos] = "xLast";
+				selectorNames[yLastSelectorPos] = "yLast";
+			}	// if (actorClass)
+
+			_segMan->uninstantiateScript(998);
+		}	// if (_resMan->testResource(ResourceId(kResourceTypeScript, 998)))
+	}	// if ((getSciVersion() >= SCI_VERSION_1_EGA_ONLY))
+
+	// Find selectors from specific classes
+
+	for (int i = 0; i < ARRAYSIZE(classReferences); i++) {
+		if (!_resMan->testResource(ResourceId(kResourceTypeScript, classReferences[i].script)))
+			continue;
+
+		_segMan->instantiateScript(classReferences[i].script);
+
+		const Object *targetClass = _segMan->getObject(_segMan->findObjectByName(classReferences[i].className));
+		int targetSelectorPos = 0;
+		uint selectorOffset = classReferences[i].selectorOffset;
+
+		if (targetClass) {
+			if (classReferences[i].selectorType == kSelectorMethod) {
+				if (targetClass->getMethodCount() < selectorOffset + 1)
+					error("The %s class has less than %d methods (%d)", 
+							classReferences[i].className, selectorOffset + 1, 
+							targetClass->getMethodCount());
+
+				targetSelectorPos = targetClass->getFuncSelector(selectorOffset);
+			} else {
+				// Add the global selectors to the selector ID
+				selectorOffset += (getSciVersion() <= SCI_VERSION_1_LATE) ? 3 : 8;
+
+				if (targetClass->getVarCount() < selectorOffset + 1)
+					error("The %s class has less than %d variables (%d)", 
+							classReferences[i].className, selectorOffset + 1,
+							targetClass->getVarCount());
+
+				targetSelectorPos = targetClass->getVarSelector(selectorOffset);
+			}
+
+			if (selectorNames.size() < (uint32)targetSelectorPos + 1)
+				selectorNames.resize((uint32)targetSelectorPos + 1);
+
+
+			selectorNames[targetSelectorPos] = classReferences[i].selectorName;
+		}
+	}
+
+	// Reset the segment manager
+	_segMan->resetSegMan();
+}
+
 } // End of namespace Sci
