@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/event.h $
- * $Id: event.h 51459 2010-07-29 10:48:54Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #define SCI_EVENT_H
 
 #include "common/list.h"
+#include "common/rect.h"
 
 namespace Sci {
 
@@ -46,6 +47,13 @@ struct SciEvent {
 	 * PC keyboard scancodes.
 	 */
 	short character;
+
+	/**
+	 * The mouse position at the time the event was created.
+	 *
+	 * These are display coordinates!
+	 */
+	Common::Point mousePos;
 };
 
 /*Values for type*/
@@ -56,11 +64,8 @@ struct SciEvent {
 #define SCI_EVENT_DIRECTION       (1<<6)
 #define SCI_EVENT_SAID            (1<<7)
 /*Fake values for other events*/
-#define SCI_EVENT_ERROR           (1<<10)
 #define SCI_EVENT_QUIT            (1<<11)
 #define SCI_EVENT_PEEK            (1<<15)
-/* The QUIT event may be used to signal an external 'quit' command being
-** issued to the gfx driver.  */
 #define SCI_EVENT_ANY             0x7fff
 
 /* Keycodes of special keys: */
@@ -116,16 +121,12 @@ public:
 
 	void updateScreen();
 	SciEvent getSciEvent(unsigned int mask);
-	bool getUsesNewKeyboardDirectionType();
 
 private:
 	SciEvent getScummVMEvent();
 
 	const bool _fontIsExtended;
-	int _modifierStates;
 	Common::List<SciEvent> _events;
-
-	bool _usesNewKeyboardDirectionType;
 };
 
 } // End of namespace Sci
