@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/cursor.cpp $
- * $Id: cursor.cpp 53015 2010-10-04 11:58:51Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
+#include "common/config-manager.h"
 #include "common/events.h"
 #include "common/macresman.h"
+#include "common/memstream.h"
 #include "common/system.h"
 #include "common/util.h"
 #include "graphics/cursorman.h"
@@ -37,6 +39,7 @@
 #include "sci/graphics/coordadjuster.h"
 #include "sci/graphics/view.h"
 #include "sci/graphics/cursor.h"
+#include "sci/graphics/maciconbar.h"
 
 namespace Sci {
 
@@ -49,10 +52,25 @@ GfxCursor::GfxCursor(ResourceManager *resMan, GfxPalette *palette, GfxScreen *sc
 	// center mouse cursor
 	setPosition(Common::Point(_screen->getWidth() / 2, _screen->getHeight() / 2));
 	_moveZoneActive = false;
+
+	_zoomZoneActive = false;
+	_zoomZone = Common::Rect();
+	_zoomCursorView = 0;
+	_zoomCursorLoop = 0;
+	_zoomCursorCel = 0;
+	_zoomPicView = 0;
+	_zoomColor = 0;
+	_zoomMultiplier = 0;
+	_cursorSurface = 0;
+	if (g_sci && g_sci->getGameId() == GID_KQ6 && g_sci->getPlatform() == Common::kPlatformWindows)
+		_useOriginalKQ6WinCursors = ConfMan.getBool("windows_cursors");
+	else
+		_useOriginalKQ6WinCursors = false;
 }
 
 GfxCursor::~GfxCursor() {
 	purgeCache();
+	kernelClearZoomZone();
 }
 
 void GfxCursor::init(GfxCoordAdjuster *coordAdjuster, EventManager *event) {
@@ -160,6 +178,10 @@ void GfxCursor::kernelSetView(GuiResourceId viewNum, int loopNum, int celNum, Co
 	if (_cachedCursors.size() >= MAX_CACHED_CURSORS)
 		purgeCache();
 
+	// Use the original Windows cursors in KQ6, if requested
+	if (_useOriginalKQ6WinCursors)
+		viewNum += 2000;		// Windows cursors
+
 	if (!_cachedCursors.contains(viewNum))
 		_cachedCursors[viewNum] = new GfxView(_resMan, _screen, _palette, viewNum);
 
@@ -184,7 +206,7 @@ void GfxCursor::kernelSetView(GuiResourceId viewNum, int loopNum, int celNum, Co
 	}
 
 	const byte *rawBitmap = cursorView->getBitmap(loopNum, celNum);
-	if (_upscaledHires) {
+	if (_upscaledHires && !_useOriginalKQ6WinCursors) {
 		// Scale cursor by 2x - note: sierra didn't do this, but it looks much better
 		width *= 2;
 		height *= 2;
@@ -203,77 +225,14 @@ void GfxCursor::kernelSetView(GuiResourceId viewNum, int loopNum, int celNum, Co
 	delete cursorHotspot;
 }
 
-void GfxCursor::kernelSetMacCursor(GuiResourceId viewNum, int loopNum, int celNum, Common::Point *hotspot) {
-	// See http://developer.apple.com/legacy/mac/library/documentation/mac/QuickDraw/QuickDraw-402.html
-	// for more information.
-
-	// View 998 seems to be a fake resource used to call for Mac cursor resources.
-	// For other resources, they're still in the views, so use them.
-	if (viewNum != 998) {
-		kernelSetView(viewNum, loopNum, celNum, hotspot);
-		return;
-	}
-
-	// TODO: What about the 2000 resources? Inventory items? How to handle?
-	// TODO: 1000 + celNum won't work for GK1
-
-	Resource *resource = _resMan->findResource(ResourceId(kResourceTypeCursor, 1000 + celNum), false);
-
-	if (!resource) {
-		warning("Mac cursor %d not found", 1000 + celNum);
-		return;
-	}
-
-	assert(resource);
-
-	if (resource->size == 32 * 2 + 4) {
-		// Mac CURS cursor
-		byte *cursorBitmap = new byte[16 * 16];
-		byte *data = resource->data;
-
-		// Get B&W data
-		for (byte i = 0; i < 32; i++) {
-			byte imageByte = *data++;
-			for (byte b = 0; b < 8; b++)
-				cursorBitmap[i * 8 + b] = (byte)((imageByte & (0x80 >> b)) > 0 ? 0x00 : 0xFF);
-		}
-
-		// Apply mask data
-		for (byte i = 0; i < 32; i++) {
-			byte imageByte = *data++;
-			for (byte b = 0; b < 8; b++)
-				if ((imageByte & (0x80 >> b)) == 0)
-					cursorBitmap[i * 8 + b] = SCI_CURSOR_SCI0_TRANSPARENCYCOLOR; // Doesn't matter, just is transparent
-		}
-
-		uint16 hotspotX = READ_BE_UINT16(data);
-		uint16 hotspotY = READ_BE_UINT16(data + 2);
-
-		CursorMan.replaceCursor(cursorBitmap, 16, 16, hotspotX, hotspotY, SCI_CURSOR_SCI0_TRANSPARENCYCOLOR);
-
-		delete[] cursorBitmap;
-	} else {
-		// Mac crsr cursor
-		byte *cursorBitmap, *palette;
-		int width, height, hotspotX, hotspotY, palSize, keycolor;
-		Common::MacResManager::convertCrsrCursor(resource->data, resource->size, &cursorBitmap, &width, &height, &hotspotX, &hotspotY, &keycolor, true, &palette, &palSize);
-		CursorMan.replaceCursor(cursorBitmap, width, height, hotspotX, hotspotY, keycolor);
-		CursorMan.replaceCursorPalette(palette, 0, palSize);
-		free(cursorBitmap);
-		free(palette);
-	}
-
-	kernelShow();
-}
-
 // this list contains all mandatory set cursor changes, that need special handling
 //  ffs. GfxCursor::setPosition (below)
 //    Game,            newPosition, validRect
 static const SciCursorSetPositionWorkarounds setPositionWorkarounds[] = {
-    { GID_ISLANDBRAIN, 84, 109,     46, 76, 174, 243 }, // island of dr. brain / game menu
-    { GID_LSL5,        23, 171,     0, 0, 26, 320 },    // larry 5 / skip forward helper
-    { GID_QFG1VGA,     64, 174,     40, 37, 74, 284 },  // Quest For Glory 1 VGA / run/walk/sleep sub-menu
-    { (SciGameId)0,    -1, -1,     -1, -1, -1, -1 }
+	{ GID_ISLANDBRAIN, 84, 109,     46, 76, 174, 243 }, // island of dr. brain / game menu
+	{ GID_LSL5,        23, 171,     0, 0, 26, 320 },    // larry 5 / skip forward helper
+	{ GID_QFG1VGA,     64, 174,     40, 37, 74, 284 },  // Quest For Glory 1 VGA / run/walk/sleep sub-menu
+	{ (SciGameId)0,    -1, -1,     -1, -1, -1, -1 }
 };
 
 void GfxCursor::setPosition(Common::Point pos) {
@@ -329,9 +288,10 @@ Common::Point GfxCursor::getPosition() {
 }
 
 void GfxCursor::refreshPosition() {
+	Common::Point mousePoint = getPosition();
+
 	if (_moveZoneActive) {
 		bool clipped = false;
-		Common::Point mousePoint = getPosition();
 
 		if (mousePoint.x < _moveZone.left) {
 			mousePoint.x = _moveZone.left;
@@ -353,6 +313,52 @@ void GfxCursor::refreshPosition() {
 		if (clipped)
 			setPosition(mousePoint);
 	}
+
+	if (_zoomZoneActive) {
+		// Cursor
+		const CelInfo *cursorCelInfo = _zoomCursorView->getCelInfo(_zoomCursorLoop, _zoomCursorCel);
+		const byte *cursorBitmap = _zoomCursorView->getBitmap(_zoomCursorLoop, _zoomCursorCel);
+		// Pic
+		const CelInfo *picCelInfo = _zoomPicView->getCelInfo(0, 0);
+		const byte *rawPicBitmap = _zoomPicView->getBitmap(0, 0);
+
+		// Compute hotspot of cursor
+		Common::Point cursorHotspot = Common::Point((cursorCelInfo->width >> 1) - cursorCelInfo->displaceX, cursorCelInfo->height - cursorCelInfo->displaceY - 1);
+
+		int16 targetX = ((mousePoint.x - _moveZone.left) * _zoomMultiplier);
+		int16 targetY = ((mousePoint.y - _moveZone.top) * _zoomMultiplier);
+		if (targetX < 0)
+			targetX = 0;
+		if (targetY < 0)
+			targetY = 0;
+
+		targetX -= cursorHotspot.x;
+		targetY -= cursorHotspot.y;
+
+		// Sierra SCI actually drew only within zoom area, thus removing the need to fill any other pixels with upmost/left
+		//  color of the picture cel. This also made the cursor not appear on top of everything. They actually drew the
+		//  cursor manually within kAnimate processing and used a hidden cursor for moving.
+		//  TODO: we should also do this
+
+		// Replace the special magnifier color with the associated magnified pixels
+		for (int x = 0; x < cursorCelInfo->width; x++) {
+			for (int y = 0; y < cursorCelInfo->height; y++) {
+				int curPos = cursorCelInfo->width * y + x;
+				if (cursorBitmap[curPos] == _zoomColor) {
+					int16 rawY = targetY + y;
+					int16 rawX = targetX + x;
+					if ((rawY >= 0) && (rawY < picCelInfo->height) && (rawX >= 0) && (rawX < picCelInfo->width)) {
+						int rawPos = picCelInfo->width * rawY + rawX;
+						_cursorSurface[curPos] = rawPicBitmap[rawPos];
+					} else {
+						_cursorSurface[curPos] = rawPicBitmap[0]; // use left and upmost pixel color
+					}
+				}
+			}
+		}
+
+		CursorMan.replaceCursor((const byte *)_cursorSurface, cursorCelInfo->width, cursorCelInfo->height, cursorHotspot.x, cursorHotspot.y, cursorCelInfo->clearKey);
+	}
 }
 
 void GfxCursor::kernelResetMoveZone() {
@@ -364,6 +370,44 @@ void GfxCursor::kernelSetMoveZone(Common::Rect zone) {
 	_moveZoneActive = true;
 }
 
+void GfxCursor::kernelClearZoomZone() {
+	kernelResetMoveZone();
+	_zoomZone = Common::Rect();
+	_zoomColor = 0;
+	_zoomMultiplier = 0;
+	_zoomZoneActive = false;
+	delete _zoomCursorView;
+	_zoomCursorView = 0;
+	delete _zoomPicView;
+	_zoomPicView = 0;
+	delete[] _cursorSurface;
+	_cursorSurface = 0;
+}
+
+void GfxCursor::kernelSetZoomZone(byte multiplier, Common::Rect zone, GuiResourceId viewNum, int loopNum, int celNum, GuiResourceId picNum, byte zoomColor) {
+	kernelClearZoomZone();
+
+	_zoomMultiplier = multiplier;
+
+	if (_zoomMultiplier != 1 && _zoomMultiplier != 2 && _zoomMultiplier != 4)
+		error("Unexpected zoom multiplier (expected 1, 2 or 4)");
+
+	_zoomCursorView = new GfxView(_resMan, _screen, _palette, viewNum);
+	_zoomCursorLoop = (byte)loopNum;
+	_zoomCursorCel = (byte)celNum;
+	_zoomPicView = new GfxView(_resMan, _screen, _palette, picNum);
+	const CelInfo *cursorCelInfo = _zoomCursorView->getCelInfo(_zoomCursorLoop, _zoomCursorCel);
+	const byte *cursorBitmap = _zoomCursorView->getBitmap(_zoomCursorLoop, _zoomCursorCel);
+	_cursorSurface = new byte[cursorCelInfo->width * cursorCelInfo->height];
+	memcpy(_cursorSurface, cursorBitmap, cursorCelInfo->width * cursorCelInfo->height);
+
+	_zoomZone = zone;
+	kernelSetMoveZone(_zoomZone);
+
+	_zoomColor = zoomColor;
+	_zoomZoneActive = true;
+}
+
 void GfxCursor::kernelSetPos(Common::Point pos) {
 	_coordAdjuster->setCursorPos(pos);
 	kernelMoveCursor(pos);
@@ -383,4 +427,101 @@ void GfxCursor::kernelMoveCursor(Common::Point pos) {
 	_event->getSciEvent(SCI_EVENT_PEEK);
 }
 
+void GfxCursor::kernelSetMacCursor(GuiResourceId viewNum, int loopNum, int celNum, Common::Point *hotspot) {
+	// Here we try to map the view number onto the cursor. What they did was keep the
+	// kSetCursor calls the same, but perform remapping on the cursors. They also took
+	// it a step further and added a new kPlatform sub-subop that handles remapping
+	// automatically. The view resources may exist, but none of the games actually
+	// use them.
+
+	if (_macCursorRemap.empty()) {
+		// QFG1/Freddy/Hoyle4 use a straight viewNum->cursor ID mapping
+		// KQ6 uses this mapping for its cursors
+		if (g_sci->getGameId() == GID_KQ6) {
+			if (viewNum == 990)      // Inventory Cursors
+				viewNum = loopNum * 16 + celNum + 2000;
+			else if (viewNum == 998) // Regular Cursors
+				viewNum = celNum + 1000;
+			else                     // Unknown cursor, ignored
+				return;
+		}
+		if (g_sci->hasMacIconBar())
+			g_sci->_gfxMacIconBar->setInventoryIcon(viewNum);
+	} else {
+		// If we do have the list, we'll be using a remap based on what the
+		// scripts have given us.
+		for (uint32 i = 0; i < _macCursorRemap.size(); i++) {
+			if (viewNum == _macCursorRemap[i]) {
+				viewNum = (i + 1) * 0x100 + loopNum * 0x10 + celNum;
+				break;
+			}
+
+			if (i == _macCursorRemap.size())
+				error("Unmatched Mac cursor %d", viewNum);
+		}
+	}
+
+	Resource *resource = _resMan->findResource(ResourceId(kResourceTypeCursor, viewNum), false);
+
+	if (!resource) {
+		// The cursor resources often don't exist, this is normal behavior
+		debug(0, "Mac cursor %d not found", viewNum);
+		return;
+	}
+
+	CursorMan.disableCursorPalette(false);
+
+	assert(resource);
+
+	if (resource->size == 32 * 2 + 4) {
+		// Mac CURS cursor
+		// See http://developer.apple.com/legacy/mac/library/documentation/mac/QuickDraw/QuickDraw-402.html
+		// for more information.
+		byte *cursorBitmap = new byte[16 * 16];
+		byte *data = resource->data;
+
+		// Get B&W data
+		for (byte i = 0; i < 32; i++) {
+			byte imageByte = *data++;
+			for (byte b = 0; b < 8; b++)
+				cursorBitmap[i * 8 + b] = (byte)((imageByte & (0x80 >> b)) > 0 ? 1 : 2);
+		}
+
+		// Apply mask data
+		for (byte i = 0; i < 32; i++) {
+			byte imageByte = *data++;
+			for (byte b = 0; b < 8; b++)
+				if ((imageByte & (0x80 >> b)) == 0)
+					cursorBitmap[i * 8 + b] = 0; // Doesn't matter, just is transparent
+		}
+
+		uint16 hotspotY = READ_BE_UINT16(data);
+		uint16 hotspotX = READ_BE_UINT16(data + 2);
+
+		static const byte cursorPalette[] = { 0x00, 0x00, 0x00, 0xff, 0xff, 0xff };
+
+		CursorMan.replaceCursor(cursorBitmap, 16, 16, hotspotX, hotspotY, 0);
+		CursorMan.replaceCursorPalette(cursorPalette, 1, 2);
+
+		delete[] cursorBitmap;
+	} else {
+		// Mac crsr cursor
+		byte *cursorBitmap, *palette;
+		int width, height, hotspotX, hotspotY, palSize, keycolor;
+		Common::MemoryReadStream resStream(resource->data, resource->size);
+		Common::MacResManager::convertCrsrCursor(&resStream, &cursorBitmap, width, height, hotspotX, hotspotY, keycolor, true, &palette, palSize);
+		CursorMan.replaceCursor(cursorBitmap, width, height, hotspotX, hotspotY, keycolor);
+		CursorMan.replaceCursorPalette(palette, 0, palSize);
+		delete[] cursorBitmap;
+		delete[] palette;
+	}
+
+	kernelShow();
+}
+
+void GfxCursor::setMacCursorRemapList(int cursorCount, reg_t *cursors) {
+	for (int i = 0; i < cursorCount; i++)
+		_macCursorRemap.push_back(cursors[i].toUint16());
+}
+
 } // End of namespace Sci
