@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/font.cpp $
- * $Id: font.cpp 53816 2010-10-25 10:57:59Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -45,12 +45,12 @@ GfxFontFromResource::GfxFontFromResource(ResourceManager *resMan, GfxScreen *scr
 	}
 	_resourceData = _resource->data;
 
-	_numChars = READ_LE_UINT16(_resourceData + 2);
-	_fontHeight = READ_LE_UINT16(_resourceData + 4);
+	_numChars = READ_SCI32ENDIAN_UINT16(_resourceData + 2);
+	_fontHeight = READ_SCI32ENDIAN_UINT16(_resourceData + 4);
 	_chars = new Charinfo[_numChars];
 	// filling info for every char
 	for (int16 i = 0; i < _numChars; i++) {
-		_chars[i].offset = READ_LE_UINT16(_resourceData + 6 + i * 2);
+		_chars[i].offset = READ_SCI32ENDIAN_UINT16(_resourceData + 6 + i * 2);
 		_chars[i].w = _resourceData[_chars[i].offset];
 		_chars[i].h = _resourceData[_chars[i].offset + 1];
 	}
@@ -79,8 +79,13 @@ byte *GfxFontFromResource::getCharData(uint16 chr) {
 }
 
 void GfxFontFromResource::draw(uint16 chr, int16 top, int16 left, byte color, bool greyedOutput) {
-	int charWidth = MIN<int>(getCharWidth(chr), _screen->getWidth() - left);
-	int charHeight = MIN<int>(getCharHeight(chr), _screen->getHeight() - top);
+	// Make sure we're comparing against the correct dimensions
+	// If the font we're drawing is already upscaled, make sure we use the full screen width/height
+	uint16 screenWidth = _screen->fontIsUpscaled() ? _screen->getDisplayWidth() : _screen->getWidth();
+	uint16 screenHeight = _screen->fontIsUpscaled() ? _screen->getDisplayHeight() : _screen->getHeight();
+
+	int charWidth = MIN<int>(getCharWidth(chr), screenWidth - left);
+	int charHeight = MIN<int>(getCharHeight(chr), screenHeight - top);
 	byte b = 0, mask = 0xFF;
 	int y = 0;
 	int16 greyedTop = top;
@@ -99,4 +104,31 @@ void GfxFontFromResource::draw(uint16 chr, int16 top, int16 left, byte color, bo
 	}
 }
 
+#ifdef ENABLE_SCI32
+
+void GfxFontFromResource::drawToBuffer(uint16 chr, int16 top, int16 left, byte color, bool greyedOutput, byte *buffer, int16 bufWidth, int16 bufHeight) {
+	int charWidth = MIN<int>(getCharWidth(chr), bufWidth - left);
+	int charHeight = MIN<int>(getCharHeight(chr), bufHeight - top);
+	byte b = 0, mask = 0xFF;
+	int y = 0;
+	int16 greyedTop = top;
+
+	byte *pIn = getCharData(chr);
+	for (int i = 0; i < charHeight; i++, y++) {
+		if (greyedOutput)
+			mask = ((greyedTop++) % 2) ? 0xAA : 0x55;
+		for (int done = 0; done < charWidth; done++) {
+			if ((done & 7) == 0) // fetching next data byte
+				b = *(pIn++) & mask;
+			if (b & 0x80) {	// if MSB is set - paint it
+				int offset = (top + y) * bufWidth + (left + done);
+				buffer[offset] = color;
+			}
+			b = b << 1;
+		}
+	}
+}
+
+#endif
+
 } // End of namespace Sci
