@@ -18,14 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/frameout.cpp $
- * $Id: frameout.cpp 51729 2010-08-04 10:11:06Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/util.h"
-#include "common/stack.h"
-#include "graphics/primitives.h"
+#include "common/algorithm.h"
+#include "common/events.h"
+#include "common/keyboard.h"
+#include "common/list_intern.h"
+#include "common/str.h"
+#include "common/system.h"
+#include "common/textconsole.h"
+#include "engines/engine.h"
+#include "graphics/surface.h"
 
 #include "sci/sci.h"
 #include "sci/engine/kernel.h"
@@ -41,9 +47,12 @@
 #include "sci/graphics/palette.h"
 #include "sci/graphics/picture.h"
 #include "sci/graphics/frameout.h"
+#include "sci/video/robot_decoder.h"
 
 namespace Sci {
 
+// TODO/FIXME: This is all guesswork
+
 GfxFrameout::GfxFrameout(SegManager *segMan, ResourceManager *resMan, GfxCoordAdjuster *coordAdjuster, GfxCache *cache, GfxScreen *screen, GfxPalette *palette, GfxPaint32 *paint32)
 	: _segMan(segMan), _resMan(resMan), _cache(cache), _screen(screen), _palette(palette), _paint32(paint32) {
 
@@ -55,21 +64,37 @@ GfxFrameout::GfxFrameout(SegManager *segMan, ResourceManager *resMan, GfxCoordAd
 GfxFrameout::~GfxFrameout() {
 }
 
+void GfxFrameout::clear() {
+	_screenItems.clear();
+	_planes.clear();
+	_planePictures.clear();
+}
+
 void GfxFrameout::kernelAddPlane(reg_t object) {
 	PlaneEntry newPlane;
 
 	if (_planes.empty()) {
 		// There has to be another way for sierra sci to do this or maybe script resolution is compiled into
 		//  interpreter (TODO)
-		scriptsRunningHeight = readSelectorValue(_segMan, object, SELECTOR(resY));
-		scriptsRunningWidth = readSelectorValue(_segMan, object, SELECTOR(resX));
+		uint16 tmpRunningWidth = readSelectorValue(_segMan, object, SELECTOR(resX));
+		uint16 tmpRunningHeight = readSelectorValue(_segMan, object, SELECTOR(resY));
+
+		// The above can be 0 in SCI3 (e.g. Phantasmagoria 2)
+		if (tmpRunningWidth > 0 && tmpRunningHeight > 0) {
+			scriptsRunningWidth = tmpRunningWidth;
+			scriptsRunningHeight = tmpRunningHeight;
+		}
+
 		_coordAdjuster->setScriptsResolution(scriptsRunningWidth, scriptsRunningHeight);
 	}
 
 	newPlane.object = object;
-	newPlane.pictureId = 0xFFFF;
 	newPlane.priority = readSelectorValue(_segMan, object, SELECTOR(priority));
 	newPlane.lastPriority = 0xFFFF; // hidden
+	newPlane.planeOffsetX = 0;
+	newPlane.pictureId = 0xFFFF;
+	newPlane.planePictureMirrored = false;
+	newPlane.planeBack = 0;
 	_planes.push_back(newPlane);
 
 	kernelUpdatePlane(object);
@@ -91,13 +116,66 @@ void GfxFrameout::kernelUpdatePlane(reg_t object) {
 						addPlanePicture(object, it->pictureId, 0);
 				}
 			}
+			it->planeRect.top = readSelectorValue(_segMan, object, SELECTOR(top));
+			it->planeRect.left = readSelectorValue(_segMan, object, SELECTOR(left));
+			it->planeRect.bottom = readSelectorValue(_segMan, object, SELECTOR(bottom)) + 1;
+			it->planeRect.right = readSelectorValue(_segMan, object, SELECTOR(right)) + 1;
+
+			Common::Rect screenRect(_screen->getWidth(), _screen->getHeight());
+			it->planeRect.top = (it->planeRect.top * screenRect.height()) / scriptsRunningHeight;
+			it->planeRect.left = (it->planeRect.left * screenRect.width()) / scriptsRunningWidth;
+			it->planeRect.bottom = (it->planeRect.bottom * screenRect.height()) / scriptsRunningHeight;
+			it->planeRect.right = (it->planeRect.right * screenRect.width()) / scriptsRunningWidth;
+
+			// We get negative left in kq7 in scrolling rooms
+			if (it->planeRect.left < 0) {
+				it->planeOffsetX = -it->planeRect.left;
+				it->planeRect.left = 0;
+			} else {
+				it->planeOffsetX = 0;
+			}
+
+			if (it->planeRect.top < 0)
+				it->planeRect.top = 0;
+			// We get bad plane-bottom in sq6
+			if (it->planeRect.right > _screen->getWidth())
+				it->planeRect.right = _screen->getWidth();
+			if (it->planeRect.bottom > _screen->getHeight())
+				it->planeRect.bottom = _screen->getHeight();
+
+			it->planeClipRect = Common::Rect(it->planeRect.width(), it->planeRect.height());
+			it->upscaledPlaneRect = it->planeRect;
+			it->upscaledPlaneClipRect = it->planeClipRect;
+			if (_screen->getUpscaledHires()) {
+				_screen->adjustToUpscaledCoordinates(it->upscaledPlaneRect.top, it->upscaledPlaneRect.left);
+				_screen->adjustToUpscaledCoordinates(it->upscaledPlaneRect.bottom, it->upscaledPlaneRect.right);
+				_screen->adjustToUpscaledCoordinates(it->upscaledPlaneClipRect.top, it->upscaledPlaneClipRect.left);
+				_screen->adjustToUpscaledCoordinates(it->upscaledPlaneClipRect.bottom, it->upscaledPlaneClipRect.right);
+			}
+
+			it->planePictureMirrored = readSelectorValue(_segMan, object, SELECTOR(mirrored));
+			it->planeBack = readSelectorValue(_segMan, object, SELECTOR(back));
+
 			sortPlanes();
+
+			// Update the items in the plane
+			for (FrameoutList::iterator listIterator = _screenItems.begin(); listIterator != _screenItems.end(); listIterator++) {
+				reg_t itemPlane = readSelector(_segMan, (*listIterator)->object, SELECTOR(plane));
+				if (object == itemPlane) {
+					kernelUpdateScreenItem((*listIterator)->object);
+				}
+			}
+
 			return;
 		}
 	}
 	error("kUpdatePlane called on plane that wasn't added before");
 }
 
+void GfxFrameout::kernelRepaintPlane(reg_t object) {
+	// TODO
+}
+
 void GfxFrameout::kernelDeletePlane(reg_t object) {
 	deletePlanePictures(object);
 	for (PlaneList::iterator it = _planes.begin(); it != _planes.end(); it++) {
@@ -144,13 +222,51 @@ void GfxFrameout::deletePlanePictures(reg_t object) {
 }
 
 void GfxFrameout::kernelAddScreenItem(reg_t object) {
-	_screenItems.push_back(object);
+	// Ignore invalid items
+	if (!_segMan->isObject(object))
+		return;
+
+	FrameoutEntry *itemEntry = new FrameoutEntry();
+	memset(itemEntry, 0, sizeof(FrameoutEntry));
+	itemEntry->object = object;
+	itemEntry->givenOrderNr = _screenItems.size();
+	_screenItems.push_back(itemEntry);
+
+	kernelUpdateScreenItem(object);
+}
+
+void GfxFrameout::kernelUpdateScreenItem(reg_t object) {
+	// Ignore invalid items
+	if (!_segMan->isObject(object))
+		return;
+
+	for (FrameoutList::iterator listIterator = _screenItems.begin(); listIterator != _screenItems.end(); listIterator++) {
+		FrameoutEntry *itemEntry = *listIterator;
+
+		if (itemEntry->object == object) {
+			itemEntry->viewId = readSelectorValue(_segMan, object, SELECTOR(view));
+			itemEntry->loopNo = readSelectorValue(_segMan, object, SELECTOR(loop));
+			itemEntry->celNo = readSelectorValue(_segMan, object, SELECTOR(cel));
+			itemEntry->x = readSelectorValue(_segMan, object, SELECTOR(x));
+			itemEntry->y = readSelectorValue(_segMan, object, SELECTOR(y));
+			itemEntry->z = readSelectorValue(_segMan, object, SELECTOR(z));
+			itemEntry->priority = readSelectorValue(_segMan, object, SELECTOR(priority));
+			if (readSelectorValue(_segMan, object, SELECTOR(fixPriority)) == 0)
+				itemEntry->priority = itemEntry->y;
+
+			itemEntry->signal = readSelectorValue(_segMan, object, SELECTOR(signal));
+			itemEntry->scaleX = readSelectorValue(_segMan, object, SELECTOR(scaleX));
+			itemEntry->scaleY = readSelectorValue(_segMan, object, SELECTOR(scaleY));
+			return;
+		}
+	}
 }
 
 void GfxFrameout::kernelDeleteScreenItem(reg_t object) {
-	for (uint32 itemNr = 0; itemNr < _screenItems.size(); itemNr++) {
-		if (_screenItems[itemNr] == object) {
-			_screenItems.remove_at(itemNr);
+	for (FrameoutList::iterator listIterator = _screenItems.begin(); listIterator != _screenItems.end(); listIterator++) {
+		FrameoutEntry *itemEntry = *listIterator;
+		if (itemEntry->object == object) {
+			_screenItems.remove(itemEntry);
 			return;
 		}
 	}
@@ -161,7 +277,7 @@ int16 GfxFrameout::kernelGetHighPlanePri() {
 	return readSelectorValue(g_sci->getEngineState()->_segMan, _planes.back().object, SELECTOR(priority));
 }
 
-// No idea yet how to implement this
+// TODO: No idea yet how to implement this
 void GfxFrameout::kernelAddPicAt(reg_t planeObj, int16 forWidth, GuiResourceId pictureId) {
 	addPlanePicture(planeObj, pictureId, forWidth);
 }
@@ -203,115 +319,111 @@ void GfxFrameout::sortPlanes() {
 	Common::sort(_planes.begin(), _planes.end(), planeSortHelper);
 }
 
-void GfxFrameout::kernelFrameout() {
-	_palette->palVaryUpdate();
+static int16 GetLongest(const char *text, int16 maxWidth, GfxFont *font) {
+	uint16 curChar = 0;
+	int16 maxChars = 0, curCharCount = 0;
+	uint16 width = 0;
 
-	// Allocate enough space for all screen items
-	FrameoutEntry *itemData = new FrameoutEntry[_screenItems.size()];
+	while (width <= maxWidth) {
+		curChar = (*(const byte *)text++);
+
+		switch (curChar) {
+		// We need to add 0xD, 0xA and 0xD 0xA to curCharCount and then exit
+		//  which means, we split text like
+		//  'Mature, experienced software analyst available.' 0xD 0xA
+		//  'Bug installation a proven speciality. "No version too clean."' (normal game text, this is from lsl2)
+		//   and 0xA '-------' 0xA (which is the official sierra subtitle separator)
+		//  Sierra did it the same way.
+		case 0xD:
+			// Check, if 0xA is following, if so include it as well
+			if ((*(const unsigned char *)text) == 0xA)
+				curCharCount++;
+			// it's meant to pass through here
+		case 0xA:
+			curCharCount++;
+			// and it's also meant to pass through here
+		case 0:
+			return curCharCount;
+		case ' ':
+			maxChars = curCharCount; // return count up to (but not including) breaking space
+			break;
+		}
+		if (width + font->getCharWidth(curChar) > maxWidth)
+			break;
+		width += font->getCharWidth(curChar);
+		curCharCount++;
+	}
+
+	return maxChars;
+}
+
+void GfxFrameout::kernelFrameout() {
+	if (g_sci->_robotDecoder->isVideoLoaded()) {
+		bool skipVideo = false;
+		RobotDecoder *videoDecoder = g_sci->_robotDecoder;
+		uint16 x = videoDecoder->getPos().x;
+		uint16 y = videoDecoder->getPos().y;
+
+		if (videoDecoder->hasDirtyPalette())
+			videoDecoder->setSystemPalette();
+
+		while (!g_engine->shouldQuit() && !videoDecoder->endOfVideo() && !skipVideo) {
+			if (videoDecoder->needsUpdate()) {
+				const Graphics::Surface *frame = videoDecoder->decodeNextFrame();
+				if (frame) {
+					g_system->copyRectToScreen((byte *)frame->pixels, frame->pitch, x, y, frame->w, frame->h);
+
+					if (videoDecoder->hasDirtyPalette())
+						videoDecoder->setSystemPalette();
+
+					g_system->updateScreen();
+				}
+			}
+
+			Common::Event event;
+			while (g_system->getEventManager()->pollEvent(event)) {
+				if ((event.type == Common::EVENT_KEYDOWN && event.kbd.keycode == Common::KEYCODE_ESCAPE) || event.type == Common::EVENT_LBUTTONUP)
+					skipVideo = true;
+			}
+
+			g_system->delayMillis(10);
+		}
+		return;
+	}
+
+	_palette->palVaryUpdate();
 
 	for (PlaneList::iterator it = _planes.begin(); it != _planes.end(); it++) {
 		reg_t planeObject = it->object;
 		uint16 planeLastPriority = it->lastPriority;
 
-		Common::Rect planeRect;
-		planeRect.top = readSelectorValue(_segMan, planeObject, SELECTOR(top));
-		planeRect.left = readSelectorValue(_segMan, planeObject, SELECTOR(left));
-		planeRect.bottom = readSelectorValue(_segMan, planeObject, SELECTOR(bottom)) + 1;
-		planeRect.right = readSelectorValue(_segMan, planeObject, SELECTOR(right)) + 1;
-
 		// Update priority here, sq6 sets it w/o UpdatePlane
 		uint16 planePriority = it->priority = readSelectorValue(_segMan, planeObject, SELECTOR(priority));
 
-		Common::Rect screenRect(_screen->getWidth(), _screen->getHeight());
-		planeRect.top = (planeRect.top * screenRect.height()) / scriptsRunningHeight;
-		planeRect.left = (planeRect.left * screenRect.width()) / scriptsRunningWidth;
-		planeRect.bottom = (planeRect.bottom * screenRect.height()) / scriptsRunningHeight;
-		planeRect.right = (planeRect.right * screenRect.width()) / scriptsRunningWidth;
-
-		int16 planeOffsetX = 0;
-
-		// We get negative left in kq7 in scrolling rooms
-		if (planeRect.left < 0) {
-			planeOffsetX = -planeRect.left;
-			planeRect.left = 0;
-		}
-		if (planeRect.top < 0)
-			planeRect.top = 0;
-		// We get bad plane-bottom in sq6
-		if (planeRect.right > _screen->getWidth())
-			planeRect.right = _screen->getWidth();
-		if (planeRect.bottom > _screen->getHeight())
-			planeRect.bottom = _screen->getHeight();
-
 		it->lastPriority = planePriority;
 		if (planePriority == 0xffff) { // Plane currently not meant to be shown
 			// If plane was shown before, delete plane rect
 			if (planePriority != planeLastPriority)
-				_paint32->fillRect(planeRect, 0);
+				_paint32->fillRect(it->planeRect, 0);
 			continue;
 		}
 
-		Common::Rect planeClipRect(planeRect.width(), planeRect.height());
-
-		Common::Rect upscaledPlaneRect = planeRect;
-		Common::Rect upscaledPlaneClipRect = planeClipRect;
-		if (_screen->getUpscaledHires()) {
-			_screen->adjustToUpscaledCoordinates(upscaledPlaneRect.top, upscaledPlaneRect.left);
-			_screen->adjustToUpscaledCoordinates(upscaledPlaneRect.bottom, upscaledPlaneRect.right);
-			_screen->adjustToUpscaledCoordinates(upscaledPlaneClipRect.top, upscaledPlaneClipRect.left);
-			_screen->adjustToUpscaledCoordinates(upscaledPlaneClipRect.bottom, upscaledPlaneClipRect.right);
-		}
-
-		byte planeBack = readSelectorValue(_segMan, planeObject, SELECTOR(back));
-		if (planeBack)
-			_paint32->fillRect(planeRect, planeBack);
+		if (it->planeBack)
+			_paint32->fillRect(it->planeRect, it->planeBack);
 
 		GuiResourceId planeMainPictureId = it->pictureId;
 
-		bool planePictureMirrored = false;
-		if (readSelectorValue(_segMan, planeObject, SELECTOR(mirrored)))
-			planePictureMirrored = true;
-
-		_coordAdjuster->pictureSetDisplayArea(planeRect);
+		_coordAdjuster->pictureSetDisplayArea(it->planeRect);
 		_palette->drewPicture(planeMainPictureId);
 
-		// Fill our itemlist for this plane
-		int16 itemCount = 0;
-		FrameoutEntry *itemEntry = itemData;
 		FrameoutList itemList;
 
-		for (uint32 itemNr = 0; itemNr < _screenItems.size(); itemNr++) {
-			reg_t itemObject = _screenItems[itemNr];
-
-			// Remove any invalid items
-			if (!_segMan->isObject(itemObject)) {
-				_screenItems.remove_at(itemNr);
-				itemNr--;
-				continue;
-			}
-
-			reg_t itemPlane = readSelector(_segMan, itemObject, SELECTOR(plane));
+		// Copy screen items of the current frame to the list of items to be drawn
+		for (FrameoutList::iterator listIterator = _screenItems.begin(); listIterator != _screenItems.end(); listIterator++) {
+			reg_t itemPlane = readSelector(_segMan, (*listIterator)->object, SELECTOR(plane));
 			if (planeObject == itemPlane) {
-				// Found an item on current plane
-				itemEntry->viewId = readSelectorValue(_segMan, itemObject, SELECTOR(view));
-				itemEntry->loopNo = readSelectorValue(_segMan, itemObject, SELECTOR(loop));
-				itemEntry->celNo = readSelectorValue(_segMan, itemObject, SELECTOR(cel));
-				itemEntry->x = readSelectorValue(_segMan, itemObject, SELECTOR(x));
-				itemEntry->y = readSelectorValue(_segMan, itemObject, SELECTOR(y));
-				itemEntry->z = readSelectorValue(_segMan, itemObject, SELECTOR(z));
-				itemEntry->priority = readSelectorValue(_segMan, itemObject, SELECTOR(priority));
-				if (readSelectorValue(_segMan, itemObject, SELECTOR(fixPriority)) == 0)
-					itemEntry->priority = itemEntry->y;
-
-				itemEntry->signal = readSelectorValue(_segMan, itemObject, SELECTOR(signal));
-				itemEntry->scaleX = readSelectorValue(_segMan, itemObject, SELECTOR(scaleX));
-				itemEntry->scaleY = readSelectorValue(_segMan, itemObject, SELECTOR(scaleY));
-				itemEntry->object = itemObject;
-				itemEntry->givenOrderNr = itemNr;
-
-				itemList.push_back(itemEntry);
-				itemEntry++;
-				itemCount++;
+				kernelUpdateScreenItem((*listIterator)->object);	// TODO: Why is this necessary?
+				itemList.push_back(*listIterator);
 			}
 		}
 
@@ -343,13 +455,10 @@ void GfxFrameout::kernelFrameout() {
 		// Now sort our itemlist
 		Common::sort(itemList.begin(), itemList.end(), sortHelper);
 
-		// Now display itemlist
-		itemEntry = itemData;
-
 //		warning("Plane %s", _segMan->getObjectName(planeObject));
 
 		for (FrameoutList::iterator listIterator = itemList.begin(); listIterator != itemList.end(); listIterator++) {
-			itemEntry = *listIterator;
+			FrameoutEntry *itemEntry = *listIterator;
 
 			if (itemEntry->object.isNull()) {
 				// Picture cel data
@@ -360,25 +469,25 @@ void GfxFrameout::kernelFrameout() {
 				// Out of view
 				int16 pictureCelStartX = itemEntry->picStartX + itemEntry->x;
 				int16 pictureCelEndX = pictureCelStartX + itemEntry->picture->getSci32celWidth(itemEntry->celNo);
-				int16 planeStartX = planeOffsetX;
-				int16 planeEndX = planeStartX + planeRect.width();
+				int16 planeStartX = it->planeOffsetX;
+				int16 planeEndX = planeStartX + it->planeRect.width();
 				if (pictureCelEndX < planeStartX)
 					continue;
 				if (pictureCelStartX > planeEndX)
 					continue;
 
-				int16 pictureOffsetX = planeOffsetX;
+				int16 pictureOffsetX = it->planeOffsetX;
 				int16 pictureX = itemEntry->x;
-				if ((planeOffsetX) || (itemEntry->picStartX)) {
-					if (planeOffsetX <= itemEntry->picStartX) {
-						pictureX += itemEntry->picStartX - planeOffsetX;
+				if ((it->planeOffsetX) || (itemEntry->picStartX)) {
+					if (it->planeOffsetX <= itemEntry->picStartX) {
+						pictureX += itemEntry->picStartX - it->planeOffsetX;
 						pictureOffsetX = 0;
 					} else {
-						pictureOffsetX = planeOffsetX - itemEntry->picStartX;
+						pictureOffsetX = it->planeOffsetX - itemEntry->picStartX;
 					}
 				}
 
-				itemEntry->picture->drawSci32Vga(itemEntry->celNo, pictureX, itemEntry->y, pictureOffsetX, planePictureMirrored);
+				itemEntry->picture->drawSci32Vga(itemEntry->celNo, pictureX, itemEntry->y, pictureOffsetX, it->planePictureMirrored);
 //				warning("picture cel %d %d", itemEntry->celNo, itemEntry->priority);
 
 			} else if (itemEntry->viewId != 0xFFFF) {
@@ -386,24 +495,19 @@ void GfxFrameout::kernelFrameout() {
 
 //				warning("view %s %04x:%04x", _segMan->getObjectName(itemEntry->object), PRINT_REG(itemEntry->object));
 
-				switch (getSciVersion()) {
-				case SCI_VERSION_2:
-					if (view->isSci2Hires()) {
-						int16 dummyX = 0;
-						_screen->adjustToUpscaledCoordinates(itemEntry->y, itemEntry->x);
-						_screen->adjustToUpscaledCoordinates(itemEntry->z, dummyX);
-					}
-					break;
-				case SCI_VERSION_2_1:
+
+				if (view->isSci2Hires()) {
+					int16 dummyX = 0;
+					view->adjustToUpscaledCoordinates(itemEntry->y, itemEntry->x);
+					view->adjustToUpscaledCoordinates(itemEntry->z, dummyX);
+				} else if (getSciVersion() == SCI_VERSION_2_1) {
 					itemEntry->y = (itemEntry->y * _screen->getHeight()) / scriptsRunningHeight;
 					itemEntry->x = (itemEntry->x * _screen->getWidth()) / scriptsRunningWidth;
 					itemEntry->z = (itemEntry->z * _screen->getHeight()) / scriptsRunningHeight;
-					break;
-				default:
-					break;
 				}
+
 				// Adjust according to current scroll position
-				itemEntry->x -= planeOffsetX;
+				itemEntry->x -= it->planeOffsetX;
 
 				uint16 useInsetRect = readSelectorValue(_segMan, itemEntry->object, SELECTOR(useInsetRect));
 				if (useInsetRect) {
@@ -412,8 +516,8 @@ void GfxFrameout::kernelFrameout() {
 					itemEntry->celRect.bottom = readSelectorValue(_segMan, itemEntry->object, SELECTOR(inBottom)) + 1;
 					itemEntry->celRect.right = readSelectorValue(_segMan, itemEntry->object, SELECTOR(inRight)) + 1;
 					if (view->isSci2Hires()) {
-						_screen->adjustToUpscaledCoordinates(itemEntry->celRect.top, itemEntry->celRect.left);
-						_screen->adjustToUpscaledCoordinates(itemEntry->celRect.bottom, itemEntry->celRect.right);
+						view->adjustToUpscaledCoordinates(itemEntry->celRect.top, itemEntry->celRect.left);
+						view->adjustToUpscaledCoordinates(itemEntry->celRect.bottom, itemEntry->celRect.right);
 					}
 					itemEntry->celRect.translate(itemEntry->x, itemEntry->y);
 					// TODO: maybe we should clip the cels rect with this, i'm not sure
@@ -426,23 +530,18 @@ void GfxFrameout::kernelFrameout() {
 
 					Common::Rect nsRect = itemEntry->celRect;
 					// Translate back to actual coordinate within scrollable plane
-					nsRect.translate(planeOffsetX, 0);
-					switch (getSciVersion()) {
-					case SCI_VERSION_2:
-						if (view->isSci2Hires()) {
-							_screen->adjustBackUpscaledCoordinates(nsRect.top, nsRect.left);
-							_screen->adjustBackUpscaledCoordinates(nsRect.bottom, nsRect.right);
-						}
-						break;
-					case SCI_VERSION_2_1:
+					nsRect.translate(it->planeOffsetX, 0);
+
+					if (view->isSci2Hires()) {
+						view->adjustBackUpscaledCoordinates(nsRect.top, nsRect.left);
+						view->adjustBackUpscaledCoordinates(nsRect.bottom, nsRect.right);
+					} else if (getSciVersion() == SCI_VERSION_2_1) {
 						nsRect.top = (nsRect.top * scriptsRunningHeight) / _screen->getHeight();
 						nsRect.left = (nsRect.left * scriptsRunningWidth) / _screen->getWidth();
 						nsRect.bottom = (nsRect.bottom * scriptsRunningHeight) / _screen->getHeight();
 						nsRect.right = (nsRect.right * scriptsRunningWidth) / _screen->getWidth();
-						break;
-					default:
-						break;
 					}
+
 					writeSelectorValue(_segMan, itemEntry->object, SELECTOR(nsLeft), nsRect.left);
 					writeSelectorValue(_segMan, itemEntry->object, SELECTOR(nsTop), nsRect.top);
 					writeSelectorValue(_segMan, itemEntry->object, SELECTOR(nsRight), nsRect.right);
@@ -465,13 +564,13 @@ void GfxFrameout::kernelFrameout() {
 				Common::Rect clipRect, translatedClipRect;
 				clipRect = itemEntry->celRect;
 				if (view->isSci2Hires()) {
-					clipRect.clip(upscaledPlaneClipRect);
+					clipRect.clip(it->upscaledPlaneClipRect);
 					translatedClipRect = clipRect;
-					translatedClipRect.translate(upscaledPlaneRect.left, upscaledPlaneRect.top);
+					translatedClipRect.translate(it->upscaledPlaneRect.left, it->upscaledPlaneRect.top);
 				} else {
-					clipRect.clip(planeClipRect);
+					clipRect.clip(it->planeClipRect);
 					translatedClipRect = clipRect;
-					translatedClipRect.translate(planeRect.left, planeRect.top);
+					translatedClipRect.translate(it->planeRect.left, it->planeRect.top);
 				}
 
 				if (!clipRect.isEmpty()) {
@@ -501,19 +600,43 @@ void GfxFrameout::kernelFrameout() {
 					itemEntry->y = ((itemEntry->y * _screen->getHeight()) / scriptsRunningHeight);
 					itemEntry->x = ((itemEntry->x * _screen->getWidth()) / scriptsRunningWidth);
 
-					uint16 curX = itemEntry->x + planeRect.left;
-					uint16 curY = itemEntry->y + planeRect.top;
-					for (uint32 i = 0; i < text.size(); i++) {
-						unsigned char curChar = text[i];
-						// TODO: proper text splitting... this is a hack
-						if ((curChar == ' ' && i > 0 && text[i - i] == ' ') || curChar == '\n' || 
-							(curX + font->getCharWidth(curChar) > _screen->getWidth())) {
-							curY += font->getHeight();
-							curX = itemEntry->x;
-						}
-						font->draw(curChar, curY, curX, foreColor, dimmed);
-						curX += font->getCharWidth(curChar);
+					uint16 startX = itemEntry->x + it->planeRect.left;
+					uint16 curY = itemEntry->y + it->planeRect.top;
+					const char *txt = text.c_str();
+					// HACK. The plane sometimes doesn't contain the correct width. This
+					// hack breaks the dialog options when speaking with Grace, but it's
+					// the best we got up to now. This happens because of the unimplemented
+					// kTextWidth function in SCI32.
+					// TODO: Remove this once kTextWidth has been implemented.
+					uint16 w = it->planeRect.width() >= 20 ? it->planeRect.width() : _screen->getWidth() - 10;
+					int16 charCount;
+
+					// Upscale the coordinates/width if the fonts are already upscaled
+					if (_screen->fontIsUpscaled()) {
+						startX = startX * _screen->getDisplayWidth() / _screen->getWidth();
+						curY = curY * _screen->getDisplayHeight() / _screen->getHeight();
+						w  = w * _screen->getDisplayWidth() / _screen->getWidth();
 					}
+
+					while (*txt) {
+						charCount = GetLongest(txt, w, font);
+						if (charCount == 0)
+							break;
+
+						uint16 curX = startX;
+
+						for (int i = 0; i < charCount; i++) {
+							unsigned char curChar = txt[i];
+							font->draw(curChar, curY, curX, foreColor, dimmed);
+							curX += font->getCharWidth(curChar);
+						}
+
+						curY += font->getHeight();
+						txt += charCount;
+						while (*txt == ' ')
+							txt++; // skip over breaking spaces
+					}
+
 				}
 			}
 		}
@@ -521,11 +644,11 @@ void GfxFrameout::kernelFrameout() {
 		for (PlanePictureList::iterator pictureIt = _planePictures.begin(); pictureIt != _planePictures.end(); pictureIt++) {
 			if (pictureIt->object == planeObject) {
 				delete[] pictureIt->pictureCels;
+				pictureIt->pictureCels = 0;
 			}
 		}
 	}
 
-	delete[] itemData;
 	_screen->copyToScreen();
 
 	g_sci->getEngineState()->_throttleTrigger = true;
