@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/frameout.h $
- * $Id: frameout.h 51313 2010-07-26 14:41:19Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,11 +28,20 @@
 
 namespace Sci {
 
+class GfxPicture;
+
 struct PlaneEntry {
 	reg_t object;
 	uint16 priority;
 	uint16 lastPriority;
+	int16 planeOffsetX;
 	GuiResourceId pictureId;
+	Common::Rect planeRect;
+	Common::Rect planeClipRect;
+	Common::Rect upscaledPlaneRect;
+	Common::Rect upscaledPlaneClipRect;
+	bool planePictureMirrored;
+	byte planeBack;
 };
 
 typedef Common::List<PlaneEntry> PlaneList;
@@ -81,8 +90,10 @@ public:
 
 	void kernelAddPlane(reg_t object);
 	void kernelUpdatePlane(reg_t object);
+	void kernelRepaintPlane(reg_t object);
 	void kernelDeletePlane(reg_t object);
 	void kernelAddScreenItem(reg_t object);
+	void kernelUpdateScreenItem(reg_t object);
 	void kernelDeleteScreenItem(reg_t object);
 	int16 kernelGetHighPlanePri();
 	void kernelAddPicAt(reg_t planeObj, int16 forWidth, GuiResourceId pictureId);
@@ -90,6 +101,7 @@ public:
 
 	void addPlanePicture(reg_t object, GuiResourceId pictureId, uint16 startX);
 	void deletePlanePictures(reg_t object);
+	void clear();
 
 private:
 	SegManager *_segMan;
@@ -100,7 +112,7 @@ private:
 	GfxScreen *_screen;
 	GfxPaint32 *_paint32;
 
-	Common::Array<reg_t> _screenItems;
+	FrameoutList _screenItems;
 	PlaneList _planes;
 	PlanePictureList _planePictures;
 
