@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/menu.cpp $
- * $Id: menu.cpp 52914 2010-09-26 18:59:01Z wjpalenstijn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -54,14 +54,20 @@ GfxMenu::GfxMenu(EventManager *event, SegManager *segMan, GfxPorts *ports, GfxPa
 }
 
 GfxMenu::~GfxMenu() {
-	// TODO: deallocate _list and _itemList
-	reset();
+	for (GuiMenuItemList::iterator itemIter = _itemList.begin(); itemIter != _itemList.end(); ++itemIter)
+		delete *itemIter;
+
+	_itemList.clear();
+
+	for (GuiMenuList::iterator menuIter = _list.begin(); menuIter != _list.end(); ++menuIter)
+		delete *menuIter;
+
+	_list.clear();
 }
 
 void GfxMenu::reset() {
 	_list.clear();
 	_itemList.clear();
-	_listCount = 0;
 
 	// We actually set active item in here and remember last selection of the
 	// user. Sierra SCI always defaulted to first item every time menu was
@@ -81,15 +87,16 @@ void GfxMenu::kernelAddEntry(Common::String title, Common::String content, reg_t
 	const char *tempPtr;
 
 	// Sierra SCI starts with id 1, so we do so as well
-	_listCount++;
-	menuEntry = new GuiMenuEntry(_listCount);
+	menuEntry = new GuiMenuEntry(_list.size() + 1);
 	menuEntry->text = title;
 	_list.push_back(menuEntry);
 
 	curPos = 0;
+	uint16 listSize = _list.size();
+
 	do {
 		itemCount++;
-		itemEntry = new GuiMenuItemEntry(_listCount, itemCount);
+		itemEntry = new GuiMenuItemEntry(listSize, itemCount);
 
 		beginPos = curPos;
 
@@ -276,7 +283,7 @@ void GfxMenu::kernelSetAttribute(uint16 menuId, uint16 itemId, uint16 attributeI
 		// PQ2 demo calls this, for example, but has no menus (bug report #3034507). Some SCI
 		// fan games (Al Pond 2, Aquarius) call this too on non-existent menu items. The
 		// original interpreter ignored these as well.
-		debugC(2, kDebugLevelGraphics, "Tried to setAttribute() on non-existent menu-item %d:%d", menuId, itemId);
+		debugC(kDebugLevelGraphics, "Tried to setAttribute() on non-existent menu-item %d:%d", menuId, itemId);
 		return;
 	}
 
@@ -296,7 +303,7 @@ void GfxMenu::kernelSetAttribute(uint16 menuId, uint16 itemId, uint16 attributeI
 		itemEntry->keyPress = tolower(value.offset);
 		itemEntry->keyModifier = 0;
 		// TODO: Find out how modifier is handled
-		printf("setAttr keypress %X %X\n", value.segment, value.offset);
+		debug("setAttr keypress %X %X", value.segment, value.offset);
 		break;
 	case SCI_MENU_ATTRIBUTE_TAG:
 		itemEntry->tag = value.offset;
@@ -345,7 +352,7 @@ void GfxMenu::drawBar() {
 	listIterator = _list.begin();
 	while (listIterator != listEnd) {
 		listEntry = *listIterator;
-		_text16->Draw_String(listEntry->textSplit.c_str());
+		_text16->DrawString(listEntry->textSplit.c_str());
 
 		listIterator++;
 	}
@@ -392,12 +399,10 @@ void GfxMenu::calculateMenuAndItemWidth() {
 reg_t GfxMenu::kernelSelect(reg_t eventObject, bool pauseSound) {
 	int16 eventType = readSelectorValue(_segMan, eventObject, SELECTOR(type));
 	int16 keyPress, keyModifier;
-	Common::Point mousePosition;
 	GuiMenuItemList::iterator itemIterator = _itemList.begin();
 	GuiMenuItemList::iterator itemEnd = _itemList.end();
 	GuiMenuItemEntry *itemEntry = NULL;
 	bool forceClaimed = false;
-	EngineState *s;
 
 	switch (eventType) {
 	case SCI_EVENT_KEYBOARD:
@@ -431,8 +436,6 @@ reg_t GfxMenu::kernelSelect(reg_t eventObject, bool pauseSound) {
 		break;
 
 	case SCI_EVENT_SAID:
-		// HACK: should be removed as soon as said() is cleaned up
-		s = g_sci->getEngineState();
 		while (itemIterator != itemEnd) {
 			itemEntry = *itemIterator;
 
@@ -444,7 +447,7 @@ reg_t GfxMenu::kernelSelect(reg_t eventObject, bool pauseSound) {
 					continue;
 				}
 
-				if (said(s, saidSpec, 0) != SAID_NO_MATCH)
+				if (said(saidSpec, 0) != SAID_NO_MATCH)
 					break;
 			}
 			itemIterator++;
@@ -453,15 +456,17 @@ reg_t GfxMenu::kernelSelect(reg_t eventObject, bool pauseSound) {
 			itemEntry = NULL;
 		break;
 
-	case SCI_EVENT_MOUSE_PRESS:
-		mousePosition = _cursor->getPosition();
+	case SCI_EVENT_MOUSE_PRESS: {
+		Common::Point mousePosition;
+		mousePosition.x = readSelectorValue(_segMan, eventObject, SELECTOR(x));
+		mousePosition.y = readSelectorValue(_segMan, eventObject, SELECTOR(y));
 		if (mousePosition.y < 10) {
 			interactiveStart(pauseSound);
 			itemEntry = interactiveWithMouse();
 			interactiveEnd(pauseSound);
 			forceClaimed = true;
 		}
-		break;
+		} break;
 	}
 
 	if (!_menuSaveHandle.isNull()) {
@@ -498,10 +503,10 @@ GuiMenuItemEntry *GfxMenu::interactiveGetItem(uint16 menuId, uint16 itemId, bool
 	GuiMenuItemEntry *lastItemEntry = NULL;
 
 	// Fixup menuId if needed
-	if (menuId > _listCount)
+	if (menuId > _list.size())
 		menuId = 1;
 	if (menuId == 0)
-		menuId = _listCount;
+		menuId = _list.size();
 	while (itemIterator != itemEnd) {
 		itemEntry = *itemIterator;
 		if (itemEntry->menuId == menuId) {
@@ -604,9 +609,9 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 			if (!listItemEntry->separatorLine) {
 				_ports->textGreyedOutput(listItemEntry->enabled ? false : true);
 				_ports->moveTo(_menuRect.left, topPos);
-				_text16->Draw_String(listItemEntry->textSplit.c_str());
+				_text16->DrawString(listItemEntry->textSplit.c_str());
 				_ports->moveTo(_menuRect.right - listItemEntry->textRightAlignedWidth - 5, topPos);
-				_text16->Draw_String(listItemEntry->textRightAligned.c_str());
+				_text16->DrawString(listItemEntry->textRightAligned.c_str());
 			} else {
 				// We dont 100% follow sierra here, we draw the line from left to right. Looks better
 				// BTW. SCI1.1 seems to put 2 pixels and then skip one, we don't do this at all (lsl6)
@@ -711,7 +716,6 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 	uint16 newItemId = _curItemId;
 	GuiMenuItemEntry *curItemEntry = findItem(_curMenuId, _curItemId);
 	GuiMenuItemEntry *newItemEntry = curItemEntry;
-	Common::Point mousePosition;
 
 	// We don't 100% follow Sierra here: we select last item instead of
 	// selecting first item of first menu every time. Also sierra sci didn't
@@ -789,9 +793,9 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 			}
 			break;
 
-		case SCI_EVENT_MOUSE_PRESS:
-			mousePosition = _cursor->getPosition();
-			if (_cursor->getPosition().y < 10) {
+		case SCI_EVENT_MOUSE_PRESS: {
+			Common::Point mousePosition = curEvent.mousePos;
+			if (mousePosition.y < 10) {
 				// Somewhere on the menubar
 				newMenuId = mouseFindMenuSelection(mousePosition);
 				if (newMenuId) {
@@ -820,7 +824,8 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 				}
 				newItemId = curItemEntry->id;
 			}
-			break;
+			} break;
+
 		case SCI_EVENT_NONE:
 			g_sci->sleep(2500 / 1000);
 			break;
@@ -836,7 +841,6 @@ GuiMenuItemEntry *GfxMenu::interactiveWithMouse() {
 	SciEvent curEvent;
 	uint16 newMenuId = 0, newItemId = 0;
 	uint16 curMenuId = 0, curItemId = 0;
-	Common::Point mousePosition = _cursor->getPosition();
 	bool firstMenuChange = true;
 	GuiMenuItemEntry *curItemEntry = NULL;
 
@@ -867,7 +871,7 @@ GuiMenuItemEntry *GfxMenu::interactiveWithMouse() {
 		}
 
 		// Find out where mouse is currently pointing to
-		mousePosition = _cursor->getPosition();
+		Common::Point mousePosition = curEvent.mousePos;
 		if (mousePosition.y < 10) {
 			// Somewhere on the menubar
 			newMenuId = mouseFindMenuSelection(mousePosition);
@@ -905,8 +909,15 @@ void GfxMenu::kernelDrawStatus(const char *text, int16 colorPen, int16 colorBack
 	_paint16->fillRect(_ports->_menuBarRect, 1, colorBack);
 	_ports->penColor(colorPen);
 	_ports->moveTo(0, 1);
-	_text16->Draw_Status(text);
+	_text16->DrawStatus(text);
 	_paint16->bitsShow(_ports->_menuBarRect);
+	// Also draw the line under the status bar. Normally, this is never drawn,
+	// but we need it to be drawn because Dr. Brain 1 Mac draws over it when
+	// it displays the icon bar. SSCI used negative rectangles to erase the
+	// area after drawing the icon bar, but this is a much cleaner way of
+	// achieving the same effect.
+	_paint16->fillRect(_ports->_menuLine, 1, 0);
+	_paint16->bitsShow(_ports->_menuLine);
 	_ports->setPort(oldPort);
 }
 
