@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/menu.h $
- * $Id: menu.h 50724 2010-07-06 14:10:09Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -119,7 +119,6 @@ private:
 	GfxScreen *_screen;
 	GfxCursor *_cursor;
 
-	uint16 _listCount;
 	GuiMenuList _list;
 	GuiMenuItemList _itemList;
 
