@@ -18,16 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/paint16.cpp $
- * $Id: paint16.cpp 52912 2010-09-26 15:54:04Z wjpalenstijn $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "common/util.h"
-#include "common/stack.h"
-#include "common/system.h"
-#include "graphics/primitives.h"
-
 #include "sci/sci.h"
 #include "sci/engine/features.h"
 #include "sci/engine/state.h"
@@ -121,11 +116,10 @@ void GfxPaint16::drawCel(GfxView *view, int16 loopNo, int16 celNo, const Common:
 
 	Common::Rect clipRectTranslated = clipRect;
 	_ports->offsetRect(clipRectTranslated);
-	if (scaleX == 128 && scaleY == 128) {
+	if (scaleX == 128 && scaleY == 128)
 		view->draw(celRect, clipRect, clipRectTranslated, loopNo, celNo, priority, paletteNo, false);
-	} else {
+	else
 		view->drawScaled(celRect, clipRect, clipRectTranslated, loopNo, celNo, priority, scaleX, scaleY);
-	}
 }
 
 // This is used as replacement for drawCelAndShow() when hires-cels are drawn to
@@ -160,8 +154,8 @@ void GfxPaint16::drawHiresCelAndShow(GuiResourceId viewId, int16 loopNo, int16 c
 		// adjust curPort to upscaled hires
 		clipRect = celRect;
 		curPortRect = _ports->_curPort->rect;
-		_screen->adjustToUpscaledCoordinates(curPortRect.top, curPortRect.left);
-		_screen->adjustToUpscaledCoordinates(curPortRect.bottom, curPortRect.right);
+		view->adjustToUpscaledCoordinates(curPortRect.top, curPortRect.left);
+		view->adjustToUpscaledCoordinates(curPortRect.bottom, curPortRect.right);
 		curPortRect.bottom++;
 		curPortRect.right++;
 		clipRect.clip(curPortRect);
@@ -171,7 +165,7 @@ void GfxPaint16::drawHiresCelAndShow(GuiResourceId viewId, int16 loopNo, int16 c
 		clipRectTranslated = clipRect;
 		if (!upscaledHiresHack) {
 			curPortPos.x = _ports->_curPort->left; curPortPos.y = _ports->_curPort->top;
-			_screen->adjustToUpscaledCoordinates(curPortPos.y, curPortPos.x);
+			view->adjustToUpscaledCoordinates(curPortPos.y, curPortPos.x);
 			clipRectTranslated.top += curPortPos.y; clipRectTranslated.bottom += curPortPos.y;
 			clipRectTranslated.left += curPortPos.x; clipRectTranslated.right += curPortPos.x;
 		}
@@ -278,9 +272,8 @@ void GfxPaint16::fillRect(const Common::Rect &rect, int16 drawFlags, byte color,
 }
 
 void GfxPaint16::frameRect(const Common::Rect &rect) {
-	Common::Rect r;
+	Common::Rect r = rect;
 	// left
-	r = rect;
 	r.right = rect.left + 1;
 	paintRect(r);
 	// right
@@ -304,6 +297,11 @@ void GfxPaint16::bitsShow(const Common::Rect &rect) {
 		return;
 
 	_ports->offsetRect(workerRect);
+
+	// We adjust the left/right coordinates to even coordinates
+	workerRect.left &= 0xFFFE; // round down
+	workerRect.right = (workerRect.right + 1) & 0xFFFE; // round up
+
 	_screen->copyRectToScreen(workerRect);
 }
 
@@ -362,7 +360,7 @@ void GfxPaint16::bitsRestore(reg_t memoryHandle) {
 
 		if (memoryPtr) {
 			_screen->bitsRestore(memoryPtr);
-			_segMan->freeHunkEntry(memoryHandle);
+			bitsFree(memoryHandle);
 		}
 	}
 }
@@ -474,6 +472,7 @@ void GfxPaint16::kernelGraphRedrawBox(Common::Rect rect) {
 #define SCI_DISPLAY_RESTOREUNDER		108
 #define SCI_DISPLAY_DUMMY1				114 // used in longbow demo/qfg1 ega demo, not supported in sierra sci - no parameters
 #define SCI_DISPLAY_DUMMY2				115 // used in longbow demo, not supported in sierra sci - has 1 parameter
+#define SCI_DISPLAY_DUMMY3				117 // used in qfg1 ega demo, not supported in sierra sci - no parameters
 #define SCI_DISPLAY_DONTSHOWBITS		121
 
 reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
@@ -544,9 +543,10 @@ reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
 			break;
 
 		// 2 Dummy functions, longbow-demo is using those several times but sierra sci doesn't support them at all
-		// The Quest for Glory 1 EGA demo also calls kDisplay(114)
+		// The Quest for Glory 1 EGA demo also calls kDisplay(114) and kDisplay(117)
 		case SCI_DISPLAY_DUMMY1:
 		case SCI_DISPLAY_DUMMY2:
+		case SCI_DISPLAY_DUMMY3:
 			if (!g_sci->isDemo() || (g_sci->getGameId() != GID_LONGBOW && g_sci->getGameId() != GID_QFG1))
 				error("Unknown kDisplay argument %d", displayArg.offset);
 			if (displayArg.offset == SCI_DISPLAY_DUMMY2) {
@@ -570,7 +570,10 @@ reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
 	// now drawing the text
 	_text16->Size(rect, text, -1, width);
 	rect.moveTo(_ports->getPort()->curLeft, _ports->getPort()->curTop);
-	if (getSciVersion() >= SCI_VERSION_1_LATE) {
+	// Note: This code has been found in SCI1 middle and newer games. It was
+	// previously only for SCI1 late and newer, but the LSL1 interpreter contains
+	// this code.
+	if (getSciVersion() >= SCI_VERSION_1_MIDDLE) {
 		int16 leftPos = rect.right <= _screen->getWidth() ? 0 : _screen->getWidth() - rect.right;
 		int16 topPos = rect.bottom <= _screen->getHeight() ? 0 : _screen->getHeight() - rect.bottom;
 		_ports->move(leftPos, topPos);
@@ -581,7 +584,7 @@ reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
 		result = bitsSave(rect, GFX_SCREEN_MASK_VISUAL);
 	if (colorBack != -1)
 		fillRect(rect, GFX_SCREEN_MASK_VISUAL, colorBack, 0, 0);
-	_text16->Box(text, 0, rect, alignment, -1);
+	_text16->Box(text, false, rect, alignment, -1);
 	if (_screen->_picNotValid == 0 && bRedraw)
 		bitsShow(rect);
 	// restoring port and cursor pos
