@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/palette.cpp $
- * $Id: palette.cpp 52353 2010-08-24 17:33:35Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,8 @@
 #include "common/util.h"
 #include "common/system.h"
 
+#include "graphics/palette.h"
+
 #include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/graphics/cache.h"
@@ -69,11 +71,42 @@ GfxPalette::GfxPalette(ResourceManager *resMan, GfxScreen *screen, bool useMergi
 	_useMerging = useMerging;
 
 	palVaryInit();
+
+	_macClut = 0;
+	loadMacIconBarPalette();
+	
+#ifdef ENABLE_SCI32
+	_clutTable = 0;
+#endif
+
+	switch (_resMan->getViewType()) {
+	case kViewEga:
+		_totalScreenColors = 16;
+		break;
+	case kViewAmiga:
+		_totalScreenColors = 32;
+		break;
+	case kViewAmiga64:
+		_totalScreenColors = 64;
+		break;
+	case kViewVga:
+	case kViewVga11:
+			_totalScreenColors = 256;
+		break;
+	default:
+		error("GfxPalette: Unknown view type");
+	}
 }
 
 GfxPalette::~GfxPalette() {
 	if (_palVaryResourceId != -1)
 		palVaryRemoveTimer();
+
+	delete[] _macClut;
+
+#ifdef ENABLE_SCI32
+	unloadClut();
+#endif
 }
 
 bool GfxPalette::isMerging() {
@@ -84,7 +117,7 @@ bool GfxPalette::isMerging() {
 void GfxPalette::setDefault() {
 	if (_resMan->getViewType() == kViewEga)
 		setEGA();
-	else if (_resMan->isAmiga32color())
+	else if (_resMan->getViewType() == kViewAmiga)
 		setAmiga();
 	else
 		kernelSetFromResource(999, true);
@@ -101,19 +134,21 @@ void GfxPalette::createFromData(byte *data, int bytesLeft, Palette *paletteOut)
 	int colorNo = 0;
 
 	memset(paletteOut, 0, sizeof(Palette));
+
 	// Setup 1:1 mapping
-	for (colorNo = 0; colorNo < 256; colorNo++) {
+	for (colorNo = 0; colorNo < 256; colorNo++)
 		paletteOut->mapping[colorNo] = colorNo;
-	}
+
 	if (bytesLeft < 37) {
 		// This happens when loading palette of picture 0 in sq5 - the resource is broken and doesn't contain a full
 		//  palette
-		debugC(2, "GfxPalette::createFromData() - not enough bytes in resource (%d), expected palette header", bytesLeft);
+		debugC(kDebugLevelResMan, "GfxPalette::createFromData() - not enough bytes in resource (%d), expected palette header", bytesLeft);
 		return;
 	}
+
 	// palette formats in here are not really version exclusive, we can not use sci-version to differentiate between them
 	//  they were just called that way, because they started appearing in sci1.1 for example
-	if ((data[0] == 0 && data[1] == 1) || (data[0] == 0 && data[1] == 0 && READ_LE_UINT16(data + 29) == 0)) {
+	if ((data[0] == 0 && data[1] == 1) || (data[0] == 0 && data[1] == 0 && READ_SCI11ENDIAN_UINT16(data + 29) == 0)) {
 		// SCI0/SCI1 palette
 		palFormat = SCI_PAL_FORMAT_VARIABLE; // CONSTANT;
 		palOffset = 260;
@@ -123,8 +158,10 @@ void GfxPalette::createFromData(byte *data, int bytesLeft, Palette *paletteOut)
 		// SCI1.1 palette
 		palFormat = data[32];
 		palOffset = 37;
-		palColorStart = READ_LE_UINT16(data + 25); palColorCount = READ_LE_UINT16(data + 29);
+		palColorStart = data[25];
+		palColorCount = READ_SCI11ENDIAN_UINT16(data + 29);
 	}
+
 	switch (palFormat) {
 		case SCI_PAL_FORMAT_CONSTANT:
 			// Check, if enough bytes left
@@ -132,6 +169,7 @@ void GfxPalette::createFromData(byte *data, int bytesLeft, Palette *paletteOut)
 				warning("GfxPalette::createFromData() - not enough bytes in resource, expected palette colors");
 				return;
 			}
+
 			for (colorNo = palColorStart; colorNo < palColorStart + palColorCount; colorNo++) {
 				paletteOut->colors[colorNo].used = 1;
 				paletteOut->colors[colorNo].r = data[palOffset++];
@@ -144,6 +182,7 @@ void GfxPalette::createFromData(byte *data, int bytesLeft, Palette *paletteOut)
 				warning("GfxPalette::createFromData() - not enough bytes in resource, expected palette colors");
 				return;
 			}
+
 			for (colorNo = palColorStart; colorNo < palColorStart + palColorCount; colorNo++) {
 				paletteOut->colors[colorNo].used = data[palOffset++];
 				paletteOut->colors[colorNo].r = data[palOffset++];
@@ -157,39 +196,52 @@ void GfxPalette::createFromData(byte *data, int bytesLeft, Palette *paletteOut)
 // Will try to set amiga palette by using "spal" file. If not found, we return false
 bool GfxPalette::setAmiga() {
 	Common::File file;
-	int curColor, byte1, byte2;
 
 	if (file.open("spal")) {
-		for (curColor = 0; curColor < 32; curColor++) {
-			byte1 = file.readByte();
-			byte2 = file.readByte();
-			if ((byte1 == EOF) || (byte2 == EOF))
+		for (int curColor = 0; curColor < 32; curColor++) {
+			byte byte1 = file.readByte();
+			byte byte2 = file.readByte();
+
+			if (file.eos())
 				error("Amiga palette file ends prematurely");
+
 			_sysPalette.colors[curColor].used = 1;
 			_sysPalette.colors[curColor].r = (byte1 & 0x0F) * 0x11;
 			_sysPalette.colors[curColor].g = ((byte2 & 0xF0) >> 4) * 0x11;
 			_sysPalette.colors[curColor].b = (byte2 & 0x0F) * 0x11;
 		}
-		file.close();
+
 		// Directly set the palette, because setOnScreen() wont do a thing for amiga
-		_screen->setPalette(&_sysPalette);
+		copySysPaletteToScreen();
 		return true;
 	}
+
 	return false;
 }
 
 // Called from picture class, some amiga sci1 games set half of the palette
 void GfxPalette::modifyAmigaPalette(byte *data) {
-	int16 curColor, curPos = 0;
-	byte byte1, byte2;
-	for (curColor = 0; curColor < 16; curColor++) {
-		byte1 = data[curPos++];
-		byte2 = data[curPos++];
+	int16 curPos = 0;
+
+	for (int curColor = 0; curColor < 16; curColor++) {
+		byte byte1 = data[curPos++];
+		byte byte2 = data[curPos++];
 		_sysPalette.colors[curColor].r = (byte1 & 0x0F) * 0x11;
 		_sysPalette.colors[curColor].g = ((byte2 & 0xF0) >> 4) * 0x11;
 		_sysPalette.colors[curColor].b = (byte2 & 0x0F) * 0x11;
 	}
-	_screen->setPalette(&_sysPalette);
+
+	copySysPaletteToScreen();
+}
+
+static byte blendColors(byte c1, byte c2) {
+	// linear
+	// return (c1/2+c2/2)+((c1&1)+(c2&1))/2;
+
+	// gamma 2.2
+	double t = (pow(c1/255.0, 2.2/1.0) * 255.0) + 
+	           (pow(c2/255.0, 2.2/1.0) * 255.0);
+	return (byte)(0.5 + (pow(0.5*t/255.0, 1.0/2.2) * 255.0));
 }
 
 void GfxPalette::setEGA() {
@@ -219,9 +271,10 @@ void GfxPalette::setEGA() {
 	for (curColor = 0x10; curColor <= 0xFE; curColor++) {
 		_sysPalette.colors[curColor].used = 1;
 		color1 = curColor & 0x0F; color2 = curColor >> 4;
-		_sysPalette.colors[curColor].r = (_sysPalette.colors[color1].r >> 1) + (_sysPalette.colors[color2].r >> 1);
-		_sysPalette.colors[curColor].g = (_sysPalette.colors[color1].g >> 1) + (_sysPalette.colors[color2].g >> 1);
-		_sysPalette.colors[curColor].b = (_sysPalette.colors[color1].b >> 1) + (_sysPalette.colors[color2].b >> 1);
+
+		_sysPalette.colors[curColor].r = blendColors(_sysPalette.colors[color1].r, _sysPalette.colors[color2].r);
+		_sysPalette.colors[curColor].g = blendColors(_sysPalette.colors[color1].g, _sysPalette.colors[color2].g);
+		_sysPalette.colors[curColor].b = blendColors(_sysPalette.colors[color1].b, _sysPalette.colors[color2].b);
 	}
 	_sysPalette.timestamp = 1;
 	setOnScreen();
@@ -272,19 +325,20 @@ bool GfxPalette::insert(Palette *newPalette, Palette *destPalette) {
 			newPalette->mapping[i] = i;
 		}
 	}
+
 	// We don't update the timestamp for SCI1.1, it's only updated on kDrawPic calls
 	return paletteChanged;
 }
 
 bool GfxPalette::merge(Palette *newPalette, bool force, bool forceRealMerge) {
 	uint16 res;
-	int i,j;
 	bool paletteChanged = false;
 
-	// colors 0 (black) and 255 (white) are not affected by merging
-	for (i = 1 ; i < 255; i++) {
-		if (!newPalette->colors[i].used)// color is not used - so skip it
+	for (int i = 1; i < 255; i++) {
+		// skip unused colors
+		if (!newPalette->colors[i].used)
 			continue;
+
 		// forced palette merging or dest color is not used yet
 		if (force || (!_sysPalette.colors[i].used)) {
 			_sysPalette.colors[i].used = newPalette->colors[i].used;
@@ -297,6 +351,7 @@ bool GfxPalette::merge(Palette *newPalette, bool force, bool forceRealMerge) {
 			newPalette->mapping[i] = i;
 			continue;
 		}
+
 		// is the same color already at the same position? -> match it directly w/o lookup
 		//  this fixes games like lsl1demo/sq5 where the same rgb color exists multiple times and where we would
 		//  otherwise match the wrong one (which would result into the pixels affected (or not) by palette changes)
@@ -304,14 +359,18 @@ bool GfxPalette::merge(Palette *newPalette, bool force, bool forceRealMerge) {
 			newPalette->mapping[i] = i;
 			continue;
 		}
+
 		// check if exact color could be matched
 		res = matchColor(newPalette->colors[i].r, newPalette->colors[i].g, newPalette->colors[i].b);
 		if (res & 0x8000) { // exact match was found
 			newPalette->mapping[i] = res & 0xFF;
 			continue;
 		}
+
+		int j = 1;
+
 		// no exact match - see if there is an unused color
-		for (j = 1; j < 256; j++)
+		for (; j < 256; j++) {
 			if (!_sysPalette.colors[j].used) {
 				_sysPalette.colors[j].used = newPalette->colors[i].used;
 				_sysPalette.colors[j].r = newPalette->colors[i].r;
@@ -321,6 +380,8 @@ bool GfxPalette::merge(Palette *newPalette, bool force, bool forceRealMerge) {
 				paletteChanged = true;
 				break;
 			}
+		}
+	
 		// if still no luck - set an approximate color
 		if (j == 256) {
 			newPalette->mapping[i] = res & 0xFF;
@@ -330,6 +391,7 @@ bool GfxPalette::merge(Palette *newPalette, bool force, bool forceRealMerge) {
 
 	if (!forceRealMerge)
 		_sysPalette.timestamp = g_system->getMillis() * 60 / 1000;
+
 	return paletteChanged;
 }
 
@@ -376,14 +438,35 @@ void GfxPalette::getSys(Palette *pal) {
 }
 
 void GfxPalette::setOnScreen() {
-	// We dont change palette at all times for amiga
-	if (_resMan->isAmiga32color())
-		return;
-	_screen->setPalette(&_sysPalette);
+	copySysPaletteToScreen();
+}
 
-	// Redraw the Mac SCI1.1 Icon bar every palette change
-	if (g_sci->_gfxMacIconBar)
-		g_sci->_gfxMacIconBar->drawIcons();
+static byte convertMacGammaToSCIGamma(int comp) {
+	return (byte)sqrt(comp * 255.0f);
+}
+
+void GfxPalette::copySysPaletteToScreen() {
+	// just copy palette to system
+	byte bpal[3 * 256];
+
+	// Get current palette, update it and put back
+	g_system->getPaletteManager()->grabPalette(bpal, 0, 256);
+
+	for (int16 i = 0; i < 256; i++) {
+		if (colorIsFromMacClut(i)) {
+			// If we've got a Mac CLUT, override the SCI palette with its non-black colors
+			bpal[i * 3    ] = convertMacGammaToSCIGamma(_macClut[i * 3    ]);
+			bpal[i * 3 + 1] = convertMacGammaToSCIGamma(_macClut[i * 3 + 1]);
+			bpal[i * 3 + 2] = convertMacGammaToSCIGamma(_macClut[i * 3 + 2]);
+		} else if (_sysPalette.colors[i].used != 0) {
+			// Otherwise, copy to the screen
+			bpal[i * 3    ] = CLIP(_sysPalette.colors[i].r * _sysPalette.intensity[i] / 100, 0, 255);
+			bpal[i * 3 + 1] = CLIP(_sysPalette.colors[i].g * _sysPalette.intensity[i] / 100, 0, 255);
+			bpal[i * 3 + 2] = CLIP(_sysPalette.colors[i].b * _sysPalette.intensity[i] / 100, 0, 255);
+		}
+	}
+
+	g_system->getPaletteManager()->setPalette(bpal, 0, 256);
 }
 
 bool GfxPalette::kernelSetFromResource(GuiResourceId resourceId, bool force) {
@@ -395,6 +478,7 @@ bool GfxPalette::kernelSetFromResource(GuiResourceId resourceId, bool force) {
 		set(&palette, force);
 		return true;
 	}
+
 	return false;
 }
 
@@ -540,7 +624,16 @@ void GfxPalette::kernelAssertPalette(GuiResourceId resourceId) {
 }
 
 void GfxPalette::kernelSyncScreenPalette() {
-	_screen->getPalette(&_sysPalette);
+	// just copy palette to system
+	byte bpal[3 * 256];
+
+	// Get current palette, update it and put back
+	g_system->getPaletteManager()->grabPalette(bpal, 0, 256);
+	for (int16 i = 1; i < 255; i++) {
+		_sysPalette.colors[i].r = bpal[i * 3];
+		_sysPalette.colors[i].g = bpal[i * 3 + 1];
+		_sysPalette.colors[i].b = bpal[i * 3 + 2];
+	}
 }
 
 // palVary
@@ -770,4 +863,138 @@ void GfxPalette::palVaryProcess(int signal, bool setPalette) {
 	}
 }
 
+static inline uint getMacColorDiff(byte r1, byte g1, byte b1, byte r2, byte g2, byte b2) {
+	// Use the difference of the top 4 bits and add together the differences
+	return ABS((r2 & 0xf0) - (r1 & 0xf0)) + ABS((g2 & 0xf0) - (g1 & 0xf0)) + ABS((b2 & 0xf0) - (b1 & 0xf0));
+}
+
+byte GfxPalette::findMacIconBarColor(byte r, byte g, byte b) {
+	// Find the best color for use with the Mac icon bar
+	// Check white, then the palette colors, and then black
+
+	// Try white first
+	byte found = 0xff;
+	uint diff = getMacColorDiff(r, g, b, 0xff, 0xff, 0xff);
+
+	if (diff == 0)
+		return found;
+
+	// Go through the main colors of the CLUT
+	for (uint16 i = 1; i < 255; i++) {
+		if (!colorIsFromMacClut(i))
+			continue;
+
+		uint cdiff = getMacColorDiff(r, g, b, _macClut[i * 3], _macClut[i * 3 + 1], _macClut[i * 3 + 2]);
+
+		if (cdiff == 0)
+			return i;
+		else if (cdiff < diff) {
+			found = i;
+			diff = cdiff;
+		}
+	}
+
+	// Also check black here
+	if (getMacColorDiff(r, g, b, 0, 0, 0) < diff)
+		return 0;
+
+	return found;
+}
+
+void GfxPalette::loadMacIconBarPalette() {
+	if (!g_sci->hasMacIconBar())
+		return;
+
+	Common::SeekableReadStream *clutStream = g_sci->getMacExecutable()->getResource(MKTAG('c','l','u','t'), 150);
+
+	if (!clutStream)
+		error("Could not find clut 150 for the Mac icon bar");
+
+	clutStream->readUint32BE(); // seed
+	clutStream->readUint16BE(); // flags
+	uint16 colorCount = clutStream->readUint16BE() + 1;
+	assert(colorCount == 256);
+
+	_macClut = new byte[256 * 3];
+
+	for (uint16 i = 0; i < colorCount; i++) {
+		clutStream->readUint16BE();
+		_macClut[i * 3    ] = clutStream->readUint16BE() >> 8;
+		_macClut[i * 3 + 1] = clutStream->readUint16BE() >> 8;
+		_macClut[i * 3 + 2] = clutStream->readUint16BE() >> 8;
+	}
+
+	// Adjust bounds on the KQ6 palette
+	// We don't use all of it for the icon bar
+	if (g_sci->getGameId() == GID_KQ6)
+		memset(_macClut + 32 * 3, 0, (256 - 32) * 3);
+
+	// Force black/white
+	_macClut[0x00 * 3    ] = 0;
+	_macClut[0x00 * 3 + 1] = 0;
+	_macClut[0x00 * 3 + 2] = 0;
+	_macClut[0xff * 3    ] = 0xff;
+	_macClut[0xff * 3 + 1] = 0xff;
+	_macClut[0xff * 3 + 2] = 0xff;
+
+	delete clutStream;
+}
+
+bool GfxPalette::colorIsFromMacClut(byte index) {
+	return index != 0 && _macClut && (_macClut[index * 3] != 0 || _macClut[index * 3 + 1] != 0 || _macClut[index * 3 + 1] != 0);
+}
+
+#ifdef ENABLE_SCI32
+
+bool GfxPalette::loadClut(uint16 clutId) {
+	// loadClut() will load a color lookup table from a clu file and set
+	// the palette found in the file. This is to be used with Phantasmagoria 2.
+
+	unloadClut();
+
+	Common::String filename = Common::String::format("%d.clu", clutId);
+	Common::File clut;
+
+	if (!clut.open(filename) || clut.size() != 0x10000 + 236 * 3)
+		return false;
+
+	// Read in the lookup table
+	// It maps each RGB565 color to a palette index
+	_clutTable = new byte[0x10000];
+	clut.read(_clutTable, 0x10000);
+
+	Palette pal;
+	memset(&pal, 0, sizeof(Palette));
+
+	// Setup 1:1 mapping
+	for (int i = 0; i < 256; i++)
+		pal.mapping[i] = i;
+
+	// Now load in the palette
+	for (int i = 1; i <= 236; i++) {
+		pal.colors[i].used = 1;
+		pal.colors[i].r = clut.readByte();
+		pal.colors[i].g = clut.readByte();
+		pal.colors[i].b = clut.readByte();
+	}
+
+	set(&pal, true);
+	setOnScreen();
+	return true;
+}
+
+byte GfxPalette::matchClutColor(uint16 color) {
+	// Match a color in RGB565 format to a palette index based on the loaded CLUT
+	assert(_clutTable);
+	return _clutTable[color];
+}
+
+void GfxPalette::unloadClut() {
+	// This will only unload the actual table, but not reset any palette
+	delete[] _clutTable;
+	_clutTable = 0;
+}
+ 
+#endif
+
 } // End of namespace Sci
