@@ -18,19 +18,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/palette.h $
- * $Id: palette.h 51381 2010-07-27 17:51:44Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef SCI_GRAPHICS_PALETTE_H
 #define SCI_GRAPHICS_PALETTE_H
 
+#include "common/array.h"
 #include "sci/graphics/helpers.h"
 
 namespace Sci {
 
-class Screen;
+class ResourceManager;
+class GfxScreen;
+
 /**
  * Palette class, handles palette operations like changing intensity, setting up the palette, merging different palettes
  */
@@ -51,8 +54,10 @@ public:
 	bool merge(Palette *pFrom, bool force, bool forceRealMerge);
 	uint16 matchColor(byte r, byte g, byte b);
 	void getSys(Palette *pal);
+	uint16 getTotalColorCount() const { return _totalScreenColors; }
 
 	void setOnScreen();
+	void copySysPaletteToScreen();
 
 	void drewPicture(GuiResourceId pictureId);
 
@@ -85,6 +90,15 @@ public:
 	virtual void saveLoadWithSerializer(Common::Serializer &s);
 	void palVarySaveLoadPalette(Common::Serializer &s, Palette *palette);
 
+	byte findMacIconBarColor(byte r, byte g, byte b);
+	bool colorIsFromMacClut(byte index);
+
+#ifdef ENABLE_SCI32
+	bool loadClut(uint16 clutId);
+	byte matchClutColor(uint16 color);
+	void unloadClut();
+#endif
+
 private:
 	void palVaryInit();
 	void palVaryInstallTimer();
@@ -110,6 +124,14 @@ private:
 	uint16 _palVaryTicks;
 	int _palVaryPaused;
 	int _palVarySignal;
+	uint16 _totalScreenColors;
+
+	void loadMacIconBarPalette();
+	byte *_macClut;
+	
+#ifdef ENABLE_SCI32
+	byte *_clutTable;
+#endif
 };
 
 } // End of namespace Sci
