@@ -18,15 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/portrait.cpp $
- * $Id: portrait.cpp 52431 2010-08-29 00:39:33Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/archive.h"
-#include "common/util.h"
-#include "common/stack.h"
-#include "graphics/primitives.h"
+#include "common/system.h"
 
 #include "sci/sci.h"
 #include "sci/event.h"
@@ -203,8 +201,12 @@ void Portrait::doit(Common::Point position, uint16 resourceId, uint16 noun, uint
 		}
 	}
 
-	if (userAbort)
+	if (userAbort) {
+		// Reset the portrait bitmap to "closed mouth" state, when skipping dialogs
+		drawBitmap(0);
+		bitsShow();
 		_audio->stopAudio();
+	}
 
 	_resMan->unlockResource(syncResource);
 }
