@@ -18,15 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/ports.cpp $
- * $Id: ports.cpp 52301 2010-08-23 16:33:19Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/util.h"
 
+#include "sci/console.h"
 #include "sci/sci.h"
 #include "sci/engine/features.h"
+#include "sci/engine/gc.h"
 #include "sci/engine/kernel.h"
 #include "sci/engine/state.h"
 #include "sci/engine/selector.h"
@@ -38,15 +40,6 @@
 
 namespace Sci {
 
-// window styles
-enum {
-	SCI_WINDOWMGR_STYLE_TRANSPARENT = (1 << 0),
-	SCI_WINDOWMGR_STYLE_NOFRAME     = (1 << 1),
-	SCI_WINDOWMGR_STYLE_TITLE       = (1 << 2),
-	SCI_WINDOWMGR_STYLE_TOPMOST     = (1 << 3),
-	SCI_WINDOWMGR_STYLE_USER        = (1 << 7)
-};
-
 GfxPorts::GfxPorts(SegManager *segMan, GfxScreen *screen)
 	: _segMan(segMan), _screen(screen) {
 }
@@ -115,7 +108,10 @@ void GfxPorts::init(bool usesOldGfxFunctions, GfxPaint16 *paint16, GfxText16 *te
 		offTop = 26;
 		break;
 	default:
-		offTop = 10;
+		// For Mac games running with a height of 190, we do not have a menu bar
+		// so the top offset should be 0.
+		if (_screen->getHeight() == 190)
+			offTop = 0;
 		break;
 	}
 
@@ -252,8 +248,10 @@ void GfxPorts::beginUpdate(Window *wnd) {
 	PortList::iterator it = _windowList.reverse_begin();
 	const PortList::iterator end = Common::find(_windowList.begin(), _windowList.end(), wnd);
 	while (it != end) {
-		// FIXME: We also store Port objects in the window list.
-		// We should add a check that we really only pass windows here...
+		// We also store Port objects in the window list, but they
+		// shouldn't be encountered during this iteration.
+		assert((*it)->isWindow());
+
 		updateWindow((Window *)*it);
 		--it;
 	}
@@ -269,11 +267,16 @@ void GfxPorts::endUpdate(Window *wnd) {
 	assert(it != end);
 
 	while (++it != end) {
-		// FIXME: We also store Port objects in the window list.
-		// We should add a check that we really only pass windows here...
+		// We also store Port objects in the window list, but they
+		// shouldn't be encountered during this iteration.
+		assert((*it)->isWindow());
+
 		updateWindow((Window *)*it);
 	}
 
+	if (getSciVersion() < SCI_VERSION_1_EGA_ONLY)
+		g_sci->_gfxPaint16->kernelGraphRedrawBox(_curPort->rect);
+
 	setPort(oldPort);
 }
 
@@ -301,18 +304,31 @@ Window *GfxPorts::addWindow(const Common::Rect &dims, const Common::Rect *restor
 	Common::Rect r;
 
 	if (!pwnd) {
-		error("Can't open window!");
+		error("Can't open window");
 		return 0;
 	}
 
 	_windowsById[id] = pwnd;
-	if (style & SCI_WINDOWMGR_STYLE_TOPMOST)
+
+	// KQ1sci, KQ4, iceman, QfG2 always add windows to the back of the list.
+	// KQ5CD checks style.
+	// Hoyle3-demo also always adds to the back (#3036763).
+	bool forceToBack = (getSciVersion() <= SCI_VERSION_1_EGA_ONLY) ||
+	                   (g_sci->getGameId() == GID_HOYLE3 && g_sci->isDemo());
+
+	if (!forceToBack && (style & SCI_WINDOWMGR_STYLE_TOPMOST))
 		_windowList.push_front(pwnd);
 	else
 		_windowList.push_back(pwnd);
 	openPort(pwnd);
 
 	r = dims;
+	// This looks fishy, but it's exactly what Sierra did. They removed last
+	// bit of the left dimension in their interpreter. It seems Sierra did it
+	// for EGA byte alignment (EGA uses 1 byte for 2 pixels) and left it in
+	// their interpreter even in the newer VGA games.
+	r.left = r.left & 0xFFFE;
+
 	if (r.width() > _screen->getWidth()) {
 		// We get invalid dimensions at least at the end of sq3 (script bug!).
 		// Same happens very often in lsl5, sierra sci didnt fix it but it looked awful.
@@ -347,42 +363,54 @@ Window *GfxPorts::addWindow(const Common::Rect &dims, const Common::Rect *restor
 	}
 
 	pwnd->dims = r;
-	const Common::Rect *wmprect = &_wmgrPort->rect;
+
+	// Clip window, if needed
+	Common::Rect wmprect = _wmgrPort->rect;
+	// Handle a special case for Dr. Brain 1 Mac. When hovering the mouse cursor
+	// over the status line on top, the game scripts try to draw the game's icon
+	// bar above the current port, by specifying a negative window top, so that
+	// the end result will be drawn 10 pixels above the current port. This is a
+	// hack by Sierra, and is only limited to user style windows. Normally, we
+	// should not clip, same as what Sierra does. However, this will result in
+	// having invalid rectangles with negative coordinates. For this reason, we
+	// adjust the containing rectangle instead.
+	if (pwnd->dims.top < 0 && g_sci->getPlatform() == Common::kPlatformMacintosh &&
+		(style & SCI_WINDOWMGR_STYLE_USER) && _wmgrPort->top + pwnd->dims.top >= 0) {
+		// Offset the final rect top by the requested pixels
+		wmprect.top += pwnd->dims.top;
+	}
+
 	int16 oldtop = pwnd->dims.top;
 	int16 oldleft = pwnd->dims.left;
-	if (wmprect->top > pwnd->dims.top)
-		pwnd->dims.moveTo(pwnd->dims.left, wmprect->top);
 
-	if (wmprect->bottom < pwnd->dims.bottom)
-		pwnd->dims.moveTo(pwnd->dims.left, wmprect->bottom - pwnd->dims.bottom + pwnd->dims.top);
+	if (wmprect.top > pwnd->dims.top)
+		pwnd->dims.moveTo(pwnd->dims.left, wmprect.top);
 
-	if (wmprect->right < pwnd->dims.right)
-		pwnd->dims.moveTo(wmprect->right + pwnd->dims.left - pwnd->dims.right, pwnd->dims.top);
+	if (wmprect.bottom < pwnd->dims.bottom)
+		pwnd->dims.moveTo(pwnd->dims.left, wmprect.bottom - pwnd->dims.bottom + pwnd->dims.top);
 
-	if (wmprect->left > pwnd->dims.left)
-		pwnd->dims.moveTo(wmprect->left, pwnd->dims.top);
+	if (wmprect.right < pwnd->dims.right)
+		pwnd->dims.moveTo(wmprect.right + pwnd->dims.left - pwnd->dims.right, pwnd->dims.top);
+
+	if (wmprect.left > pwnd->dims.left)
+		pwnd->dims.moveTo(wmprect.left, pwnd->dims.top);
 
 	pwnd->rect.moveTo(pwnd->rect.left + pwnd->dims.left - oldleft, pwnd->rect.top + pwnd->dims.top - oldtop);
+
 	if (restoreRect == 0)
 		pwnd->restoreRect = pwnd->dims;
 
+	if (pwnd->restoreRect.top < 0 && g_sci->getPlatform() == Common::kPlatformMacintosh &&
+		(style & SCI_WINDOWMGR_STYLE_USER) && _wmgrPort->top + pwnd->restoreRect.top >= 0) {
+		// Special case for Dr. Brain 1 Mac (check above), applied to the
+		// restore rectangle.
+		pwnd->restoreRect.moveTo(pwnd->restoreRect.left, wmprect.top);
+	}
+
 	if (draw)
 		drawWindow(pwnd);
 	setPort((Port *)pwnd);
 
-	// FIXME: changing setOrigin to not clear the rightmost bit fixes the display of windows
-	// in some fanmade games (e.g. New Year's Mystery (Updated)). Since the fanmade games
-	// use an unmodified SCI interpreter, this leads me to believe that there either is some
-	// off-by-one error in the window drawing code, or there is another place where the
-	// rightmost bit should be cleeared. New Year's Mystery is a good test case for this, as
-	// it draws dialogs and then draws cels on top of them, for fancier dialog corners (like,
-	// for example, KQ5). KQ5 has a custom window style, however, whereas New Year's mystery
-	// has a "classic" style with only SCI_WINDOWMGR_STYLE_NOFRAME set. If
-	// SCI_WINDOWMGR_STYLE_NOFRAME is removed, the window is cleared correctly, because it
-	// grows slightly, covering the view pixels on the left. In any case, the views and the
-	// window have a difference of one pixel when they're drawn via kNewWindow and kDrawCel,
-	// which causes the glitch to appear when the window is closed.
-
 	// All SCI0 games till kq4 .502 (not including) did not adjust against _wmgrPort, we set _wmgrPort->top to 0 in that case
 	setOrigin(pwnd->rect.left, pwnd->rect.top + _wmgrPort->top);
 	pwnd->rect.moveTo(0, 0);
@@ -392,7 +420,6 @@ Window *GfxPorts::addWindow(const Common::Rect &dims, const Common::Rect *restor
 void GfxPorts::drawWindow(Window *pWnd) {
 	if (pWnd->bDrawn)
 		return;
-	Common::Rect r;
 	int16 wndStyle = pWnd->wndStyle;
 
 	pWnd->bDrawn = true;
@@ -409,7 +436,8 @@ void GfxPorts::drawWindow(Window *pWnd) {
 
 	// drawing frame,shadow and title
 	if ((getSciVersion() >= SCI_VERSION_1_LATE) ? !(wndStyle & _styleUser) : wndStyle != _styleUser) {
-		r = pWnd->dims;
+		Common::Rect r = pWnd->dims;
+
 		if (!(wndStyle & SCI_WINDOWMGR_STYLE_NOFRAME)) {
 			r.top++;
 			r.left++;
@@ -431,7 +459,7 @@ void GfxPorts::drawWindow(Window *pWnd) {
 				if (!pWnd->title.empty()) {
 					int16 oldcolor = getPort()->penClr;
 					penColor(_screen->getColorWhite());
-					_text16->Box(pWnd->title.c_str(), 1, r, SCI_TEXT16_ALIGNMENT_CENTER, 0);
+					_text16->Box(pWnd->title.c_str(), true, r, SCI_TEXT16_ALIGNMENT_CENTER, 0);
 					penColor(oldcolor);
 				}
 
@@ -514,10 +542,7 @@ Port *GfxPorts::getPort() {
 }
 
 void GfxPorts::setOrigin(int16 left, int16 top) {
-	// This looks fishy, but it's exactly what sierra did. They removed last bit of left in their interpreter
-	//  It seems sierra did it for EGA byte alignment (EGA uses 1 byte for 2 pixels) and left it in their interpreter even
-	//  when going VGA.
-	_curPort->left = left & 0x7FFE;
+	_curPort->left = left;
 	_curPort->top = top;
 }
 
@@ -594,10 +619,6 @@ void GfxPorts::priorityBandsInit(int16 bandCount, int16 top, int16 bottom) {
 	int16 y;
 	int32 bandSize;
 
-	// This code is for 320x200 games only
-	if (_screen->getHeight() != 200)
-		return;
-
 	if (bandCount != -1)
 		_priorityBandCount = bandCount;
 
@@ -688,4 +709,26 @@ int16 GfxPorts::kernelPriorityToCoordinate(byte priority) {
 	return _priorityBottom;
 }
 
+void GfxPorts::processEngineHunkList(WorklistManager &wm) {
+	for (PortList::const_iterator it = _windowList.begin(); it != _windowList.end(); ++it) {
+		if ((*it)->isWindow()) {
+			Window *wnd = ((Window *)*it);
+			wm.push(wnd->hSaved1);
+			wm.push(wnd->hSaved2);
+		}
+	}
+}
+
+void GfxPorts::printWindowList(Console *con) {
+	for (PortList::const_iterator it = _windowList.begin(); it != _windowList.end(); ++it) {
+		if ((*it)->isWindow()) {
+			Window *wnd = ((Window *)*it);
+			con->DebugPrintf("%d: '%s' at %d, %d, (%d, %d, %d, %d), drawn: %d, style: %d\n",
+					wnd->id, wnd->title.c_str(), wnd->left, wnd->top, 
+					wnd->rect.left, wnd->rect.top, wnd->rect.right, wnd->rect.bottom,
+					wnd->bDrawn, wnd->wndStyle);
+		}
+	}
+}
+
 } // End of namespace Sci
