@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/screen.cpp $
- * $Id: screen.cpp 52615 2010-09-07 08:12:59Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,6 +32,7 @@
 #include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/graphics/screen.h"
+#include "sci/graphics/view.h"
 
 namespace Sci {
 
@@ -53,12 +54,18 @@ GfxScreen::GfxScreen(ResourceManager *resMan) : _resMan(resMan) {
 #endif
 	}
 
+#ifdef ENABLE_SCI32
+	// GK1 Mac uses a 640x480 resolution too
+	if (g_sci->getGameId() == GID_GK1 && g_sci->getPlatform() == Common::kPlatformMacintosh)
+		_upscaledHires = GFX_SCREEN_UPSCALED_640x480;
+#endif
+
 	if (_resMan->detectHires()) {
 		_width = 640;
 		_height = 480;
 	} else {
 		_width = 320;
-		_height = 200;
+		_height = getLowResScreenHeight();
 	}
 
 	// Japanese versions of games use hi-res font on upscaled version of the game.
@@ -105,8 +112,9 @@ GfxScreen::GfxScreen(ResourceManager *resMan) : _resMan(resMan) {
 	_picNotValid = 0;
 	_picNotValidSci11 = 0;
 	_unditherState = true;
+	_fontIsUpscaled = false;
 
-	if (_resMan->isVGA() || (_resMan->isAmiga32color())) {
+	if (_resMan->getViewType() != kViewEga) {
 		// It is not 100% accurate to set white to be 255 for Amiga 32-color
 		// games. But 255 is defined as white in our SCI at all times, so it
 		// doesn't matter.
@@ -122,13 +130,15 @@ GfxScreen::GfxScreen(ResourceManager *resMan) : _resMan(resMan) {
 
 	// Initialize the actual screen
 
-	if (_resMan->isSci11Mac() && getSciVersion() == SCI_VERSION_1_1) {
-		// For SCI1.1 Mac, we need to expand the screen to accommodate for
-		// the icon bar. Of course, both KQ6 and QFG1 VGA differ in size.
+	if (g_sci->hasMacIconBar()) {
+		// For SCI1.1 Mac games with the custom icon bar, we need to expand the screen
+		// to accommodate for the icon bar. Of course, both KQ6 and QFG1 VGA differ in size.
+		// We add 2 to the height of the icon bar to add a buffer between the screen and the
+		// icon bar (as did the original interpreter).
 		if (g_sci->getGameId() == GID_KQ6)
-			initGraphics(_displayWidth, _displayHeight + 26, _displayWidth > 320);
-		else if (g_sci->getGameId() == GID_QFG1VGA)
-			initGraphics(_displayWidth, _displayHeight + 20, _displayWidth > 320);
+			initGraphics(_displayWidth, _displayHeight + 26 + 2, _displayWidth > 320);
+		else if (g_sci->getGameId() == GID_FREDDYPHARKAS)
+			initGraphics(_displayWidth, _displayHeight + 28 + 2, _displayWidth > 320);
 		else
 			error("Unknown SCI1.1 Mac game");
 	} else
@@ -147,15 +157,15 @@ void GfxScreen::copyToScreen() {
 }
 
 void GfxScreen::copyFromScreen(byte *buffer) {
-	Graphics::Surface *screen;
-	screen = g_system->lockScreen();
+	// TODO this ignores the pitch
+	Graphics::Surface *screen = g_system->lockScreen();
 	memcpy(buffer, screen->pixels, _displayPixels);
 	g_system->unlockScreen();
 }
 
 void GfxScreen::kernelSyncWithFramebuffer() {
+	// TODO this ignores the pitch
 	Graphics::Surface *screen = g_system->lockScreen();
-
 	memcpy(_displayScreen, screen->pixels, _displayPixels);
 	g_system->unlockScreen();
 }
@@ -229,18 +239,23 @@ void GfxScreen::putPixel(int x, int y, byte drawMask, byte color, byte priority,
  *  Sierra SCI didn't do this
  */
 void GfxScreen::putFontPixel(int startingY, int x, int y, byte color) {
-	int offset = (startingY + y) * _width + x;
-
-	_visualScreen[offset] = color;
-	if (!_upscaledHires) {
-		_displayScreen[offset] = color;
+	if (_fontIsUpscaled) {
+		// Do not scale ourselves, but put it on the display directly
+		putPixelOnDisplay(x, y + startingY, color);
 	} else {
-		int displayOffset = (_upscaledMapping[startingY] + y * 2) * _displayWidth + x * 2;
-		_displayScreen[displayOffset] = color;
-		_displayScreen[displayOffset + 1] = color;
-		displayOffset += _displayWidth;
-		_displayScreen[displayOffset] = color;
-		_displayScreen[displayOffset + 1] = color;
+		int offset = (startingY + y) * _width + x;
+
+		_visualScreen[offset] = color;
+		if (!_upscaledHires) {
+			_displayScreen[offset] = color;
+		} else {
+			int displayOffset = (_upscaledMapping[startingY] + y * 2) * _displayWidth + x * 2;
+			_displayScreen[displayOffset] = color;
+			_displayScreen[displayOffset + 1] = color;
+			displayOffset += _displayWidth;
+			_displayScreen[displayOffset] = color;
+			_displayScreen[displayOffset + 1] = color;
+		}
 	}
 }
 
@@ -341,12 +356,29 @@ byte GfxScreen::getControl(int x, int y) {
 	return _controlScreen[y * _width + x];
 }
 
-byte GfxScreen::isFillMatch(int16 x, int16 y, byte screenMask, byte t_color, byte t_pri, byte t_con) {
+byte GfxScreen::isFillMatch(int16 x, int16 y, byte screenMask, byte t_color, byte t_pri, byte t_con, bool isEGA) {
 	int offset = y * _width + x;
 	byte match = 0;
 
-	if ((screenMask & GFX_SCREEN_MASK_VISUAL) && *(_visualScreen + offset) == t_color)
-		match |= GFX_SCREEN_MASK_VISUAL;
+	if (screenMask & GFX_SCREEN_MASK_VISUAL) {
+		if (!isEGA) {
+			if (*(_visualScreen + offset) == t_color)
+				match |= GFX_SCREEN_MASK_VISUAL;
+		} else {
+			// In EGA games a pixel in the framebuffer is only 4 bits. We store
+			// a full byte per pixel to allow undithering, but when comparing
+			// pixels for flood-fill purposes, we should only compare the
+			// visible color of a pixel.
+
+			byte c = *(_visualScreen + offset);
+			if ((x ^ y) & 1)
+				c = (c ^ (c >> 4)) & 0x0F;
+			else
+				c = c & 0x0F;
+			if (c == t_color)
+				match |= GFX_SCREEN_MASK_VISUAL;
+		}
+	}
 	if ((screenMask & GFX_SCREEN_MASK_PRIORITY) && *(_priorityScreen + offset) == t_pri)
 		match |= GFX_SCREEN_MASK_PRIORITY;
 	if ((screenMask & GFX_SCREEN_MASK_CONTROL) && *(_controlScreen + offset) == t_con)
@@ -499,34 +531,6 @@ void GfxScreen::bitsRestoreDisplayScreen(Common::Rect rect, byte *&memoryPtr) {
 	}
 }
 
-void GfxScreen::getPalette(Palette *pal) {
-	// just copy palette to system
-	byte bpal[4 * 256];
-	// Get current palette, update it and put back
-	g_system->grabPalette(bpal, 0, 256);
-	for (int16 i = 1; i < 255; i++) {
-		pal->colors[i].r = bpal[i * 4];
-		pal->colors[i].g = bpal[i * 4 + 1];
-		pal->colors[i].b = bpal[i * 4 + 2];
-	}
-}
-
-void GfxScreen::setPalette(Palette *pal) {
-	// just copy palette to system
-	byte bpal[4 * 256];
-	// Get current palette, update it and put back
-	g_system->grabPalette(bpal, 0, 256);
-	for (int16 i = 0; i < 256; i++) {
-		if (!pal->colors[i].used)
-			continue;
-		bpal[i * 4] = CLIP(pal->colors[i].r * pal->intensity[i] / 100, 0, 255);
-		bpal[i * 4 + 1] = CLIP(pal->colors[i].g * pal->intensity[i] / 100, 0, 255);
-		bpal[i * 4 + 2] = CLIP(pal->colors[i].b * pal->intensity[i] / 100, 0, 255);
-		bpal[i * 4 + 3] = 100;
-	}
-	g_system->setPalette(bpal, 0, 256);
-}
-
 void GfxScreen::setVerticalShakePos(uint16 shakePos) {
 	if (!_upscaledHires)
 		g_system->setShakePos(shakePos);
@@ -581,7 +585,7 @@ void GfxScreen::dither(bool addToFlag) {
 		}
 	} else {
 		if (!addToFlag)
-			memset(&_unditherMemorial, 0, sizeof(_unditherMemorial));
+			memset(&_ditheredPicColors, 0, sizeof(_ditheredPicColors));
 		// Do dithering on visual screen and put decoded but undithered byte onto display-screen
 		for (y = 0; y < _height; y++) {
 			for (x = 0; x < _width; x++) {
@@ -589,7 +593,7 @@ void GfxScreen::dither(bool addToFlag) {
 				if (color & 0xF0) {
 					color ^= color << 4;
 					// remember dither combination for cel-undithering
-					_unditherMemorial[color]++;
+					_ditheredPicColors[color]++;
 					// if decoded color wants do dither with black on left side, we turn it around
 					//  otherwise the normal ega color would get used for display
 					if (color & 0xF0) {
@@ -616,13 +620,17 @@ void GfxScreen::dither(bool addToFlag) {
 	}
 }
 
+void GfxScreen::ditherForceDitheredColor(byte color) {
+	_ditheredPicColors[color] = 256;
+}
+
 void GfxScreen::debugUnditherSetState(bool flag) {
 	_unditherState = flag;
 }
 
-int16 *GfxScreen::unditherGetMemorial() {
+int16 *GfxScreen::unditherGetDitheredBgColors() {
 	if (_unditherState)
-		return (int16 *)&_unditherMemorial;
+		return (int16 *)&_ditheredPicColors;
 	else
 		return NULL;
 }
@@ -649,29 +657,77 @@ void GfxScreen::debugShowMap(int mapNo) {
 	copyToScreen();
 }
 
-void GfxScreen::scale2x(const byte *src, byte *dst, int16 srcWidth, int16 srcHeight) {
+void GfxScreen::scale2x(const byte *src, byte *dst, int16 srcWidth, int16 srcHeight, byte bytesPerPixel) {
+	assert(bytesPerPixel == 1 || bytesPerPixel == 2);
 	const int newWidth = srcWidth * 2;
+	const int pitch = newWidth * bytesPerPixel;
 	const byte *srcPtr = src;
 
-	for (int y = 0; y < srcHeight; y++) {
-		for (int x = 0; x < srcWidth; x++) {
-			const byte color = *srcPtr++;
-			dst[0] = color;
-			dst[1] = color;
-			dst[newWidth] = color;
-			dst[newWidth + 1] = color;
-			dst += 2;
+	if (bytesPerPixel == 1) {
+		for (int y = 0; y < srcHeight; y++) {
+			for (int x = 0; x < srcWidth; x++) {
+				const byte color = *srcPtr++;
+				dst[0] = color;
+				dst[1] = color;
+				dst[newWidth] = color;
+				dst[newWidth + 1] = color;
+				dst += 2;
+			}
+			dst += newWidth;
+		}
+	} else if (bytesPerPixel == 2) {
+		for (int y = 0; y < srcHeight; y++) {
+			for (int x = 0; x < srcWidth; x++) {
+				const byte color = *srcPtr++;
+				const byte color2 = *srcPtr++;
+				dst[0] = color;
+				dst[1] = color2;
+				dst[2] = color;
+				dst[3] = color2;
+				dst[pitch] = color;
+				dst[pitch + 1] = color2;
+				dst[pitch + 2] = color;
+				dst[pitch + 3] = color2;
+				dst += 4;
+			}
+			dst += pitch;
 		}
-		dst += newWidth;
 	}
 }
 
-void GfxScreen::adjustToUpscaledCoordinates(int16 &y, int16 &x) {
+struct UpScaledAdjust {
+	GfxScreenUpscaledMode gameHiresMode;
+	Sci32ViewNativeResolution viewNativeRes;
+	int numerator;
+	int denominator;
+};
+
+static const UpScaledAdjust s_upscaledAdjustTable[] = {
+	{ GFX_SCREEN_UPSCALED_640x480, SCI_VIEW_NATIVERES_640x400, 5, 6 }
+};
+
+void GfxScreen::adjustToUpscaledCoordinates(int16 &y, int16 &x, Sci32ViewNativeResolution viewNativeRes) {
 	x *= 2;
 	y = _upscaledMapping[y];
+
+	for (int i = 0; i < ARRAYSIZE(s_upscaledAdjustTable); i++) {
+		if (s_upscaledAdjustTable[i].gameHiresMode == _upscaledHires &&
+				s_upscaledAdjustTable[i].viewNativeRes == viewNativeRes) {
+			y = (y * s_upscaledAdjustTable[i].numerator) / s_upscaledAdjustTable[i].denominator;
+			break;
+		}
+	}
 }
 
-void GfxScreen::adjustBackUpscaledCoordinates(int16 &y, int16 &x) {
+void GfxScreen::adjustBackUpscaledCoordinates(int16 &y, int16 &x, Sci32ViewNativeResolution viewNativeRes) {
+	for (int i = 0; i < ARRAYSIZE(s_upscaledAdjustTable); i++) {
+		if (s_upscaledAdjustTable[i].gameHiresMode == _upscaledHires &&
+				s_upscaledAdjustTable[i].viewNativeRes == viewNativeRes) {
+			y = (y * s_upscaledAdjustTable[i].denominator) / s_upscaledAdjustTable[i].numerator;
+			break;
+		}
+	}
+
 	switch (_upscaledHires) {
 	case GFX_SCREEN_UPSCALED_640x400:
 		x /= 2;
@@ -707,4 +763,23 @@ int16 GfxScreen::kernelPicNotValid(int16 newPicNotValid) {
 	return oldPicNotValid;
 }
 
+uint16 GfxScreen::getLowResScreenHeight() {
+	// Some Mac SCI1/1.1 games only take up 190 rows and do not
+	// have the menu bar.
+	if (g_sci->getPlatform() == Common::kPlatformMacintosh) {
+		switch (g_sci->getGameId()) {
+		case GID_FREDDYPHARKAS:
+		case GID_KQ5:
+		case GID_KQ6:
+		case GID_SQ1:
+			return 190;
+		default:
+			break;
+		}
+	}
+
+	// Everything else is 200
+	return 200;
+}
+
 } // End of namespace Sci
