@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/view.h $
- * $Id: view.h 53863 2010-10-26 21:59:36Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,13 @@
 
 namespace Sci {
 
+enum Sci32ViewNativeResolution {
+	SCI_VIEW_NATIVERES_NONE = -1,
+	SCI_VIEW_NATIVERES_320x200 = 0,
+	SCI_VIEW_NATIVERES_640x480 = 1,
+	SCI_VIEW_NATIVERES_640x400 = 2
+};
+
 struct CelInfo {
 	int16 width, height;
 	int16 scriptWidth, scriptHeight;
@@ -78,6 +85,9 @@ public:
 	bool isScaleable();
 	bool isSci2Hires();
 
+	void adjustToUpscaledCoordinates(int16 &y, int16 &x);
+	void adjustBackUpscaledCoordinates(int16 &y, int16 &x);
+
 private:
 	void initData(GuiResourceId resourceId);
 	void unpackCel(int16 loopNo, int16 celNo, byte *outPtr, uint32 pixelCount);
@@ -98,8 +108,8 @@ private:
 	bool _embeddedPal;
 	Palette _viewPalette;
 
-	// set for SCI2 views in gk1/windows, means that views are hires and should be handled accordingly
-	bool _isSci2Hires;
+	// specifies scaling resolution for SCI2 views (see gk1/windows, Wolfgang in room 720)
+	Sci32ViewNativeResolution _sci2ScaleRes;
 
 	byte *_EGAmapping;
 
