@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/parser/vocabulary.h $
- * $Id: vocabulary.h 51432 2010-07-28 19:03:49Z mthreepwood $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,6 +34,12 @@
 #include "sci/sci.h"
 #include "sci/engine/vm_types.h"
 
+namespace Common {
+
+class Serializer;
+
+}
+
 namespace Sci {
 
 class ResourceManager;
@@ -49,7 +55,9 @@ enum {
 
 	VOCAB_RESOURCE_SCI1_MAIN_VOCAB = 900,
 	VOCAB_RESOURCE_SCI1_PARSE_TREE_BRANCHES = 901,
-	VOCAB_RESOURCE_SCI1_SUFFIX_VOCAB = 902
+	VOCAB_RESOURCE_SCI1_SUFFIX_VOCAB = 902,
+
+	VOCAB_RESOURCE_ALT_INPUTS = 913
 };
 
 
@@ -117,8 +125,9 @@ struct ResultWord {
 };
 
 typedef Common::List<ResultWord> ResultWordList;
+typedef Common::List<ResultWordList> ResultWordListList;
 
-typedef Common::HashMap<Common::String, ResultWord, Common::CaseSensitiveString_Hash, Common::CaseSensitiveString_EqualTo> WordMap;
+typedef Common::HashMap<Common::String, ResultWordList, Common::CaseSensitiveString_Hash, Common::CaseSensitiveString_EqualTo> WordMap;
 
 
 struct ParseRuleList;
@@ -140,11 +149,20 @@ typedef Common::List<suffix_t> SuffixList;
 
 
 struct synonym_t {
-	int replaceant; /**< The word group to replace */
-	int replacement; /**< The replacement word group for this one */
+	uint16 replaceant; /**< The word group to replace */
+	uint16 replacement; /**< The replacement word group for this one */
+};
+
+typedef Common::Array<synonym_t> SynonymList;
+
+
+struct AltInput {
+	const char *_input;
+	const char *_replacement;
+	unsigned int _inputLength;
+	bool _prefix;
 };
 
-typedef Common::List<synonym_t> SynonymList;
 
 struct parse_tree_branch_t {
 	int id;
@@ -161,7 +179,7 @@ struct ParseTreeNode {
 	ParseTypes type;  /**< leaf or branch */
 	int value; /**< For leaves */
 	ParseTreeNode* left; /**< Left child, for branches */
-	ParseTreeNode* right; /**< Right child, for branches */
+	ParseTreeNode* right; /**< Right child, for branches (and word leaves) */
 };
 
 enum VocabularyVersions {
@@ -186,11 +204,11 @@ public:
 
 	/**
 	 * Looks up a single word in the words and suffixes list.
+	 * @param retval	the list of matches
 	 * @param word		pointer to the word to look up
 	 * @param word_len	length of the word to look up
-	 * @return the matching word (or (-1,-1) if there was no match)
 	 */
-	ResultWord lookupWord(const char *word, int word_len);
+	void lookupWord(ResultWordList &retval, const char *word, int word_len);
 
 
 	/**
@@ -204,7 +222,7 @@ public:
 	 * contain any useful words; if not, *error points to a malloc'd copy of
 	 * the offending word. The returned list may contain anywords.
 	 */
-	bool tokenizeString(ResultWordList &retval, const char *sentence, char **error);
+	bool tokenizeString(ResultWordListList &retval, const char *sentence, char **error);
 
 	/**
 	 * Builds a parse tree from a list of words, using a set of Greibach Normal
@@ -215,7 +233,7 @@ public:
 	 *			nodes or if the sentence structure in 'words' is not part of the
 	 *			language described by the grammar passed in 'rules'.
 	 */
-	int parseGNF(const ResultWordList &words, bool verbose = false);
+	int parseGNF(const ResultWordListList &words, bool verbose = false);
 
 	/**
 	 * Constructs the Greibach Normal Form of the grammar supplied in 'branches'.
@@ -231,7 +249,7 @@ public:
 	ParseRuleList *buildGNF(bool verbose = false);
 
 	/**
-	 * Deciphers a said block and dumps its content via printf.
+	 * Deciphers a said block and dumps its content via debugN.
 	 * For debugging only.
 	 * @param pos	pointer to the data to dump
 	 */
@@ -262,9 +280,9 @@ public:
 
 	/**
 	 * Synonymizes a token list
-	 * Parameters: (ResultWordList &) words: The word list to synonymize
+	 * Parameters: (ResultWordListList &) words: The word list to synonymize
 	 */
-	void synonymizeTokens(ResultWordList &words);
+	void synonymizeTokens(ResultWordListList &words);
 
 	void printParserNodes(int num);
 
@@ -272,6 +290,19 @@ public:
 
 	int parseNodes(int *i, int *pos, int type, int nr, int argc, const char **argv);
 
+	/**
+	 * Check text input against alternative inputs.
+	 * @param text The text to process. It will be modified in-place
+	 * @param cursorPos The cursor position
+	 * @return true if anything changed
+	 */
+	bool checkAltInput(Common::String& text, uint16& cursorPos);
+
+	/**
+	 * Save/load vocabulary data
+	 */
+	void saveLoadWithSerializer(Common::Serializer &ser);
+
 private:
 	/**
 	 * Loads all words from the main vocabulary.
@@ -304,6 +335,18 @@ private:
 	 */
 	void freeRuleList(ParseRuleList *rule_list);
 
+
+	/**
+	 * Retrieves all alternative input combinations from vocab 913.
+	 * @return true on success, false on error
+	 */
+	bool loadAltInputs();
+
+	/**
+	 * Frees all alternative input combinations.
+	 */
+	void freeAltInputs();
+
 	ResourceManager *_resMan;
 	VocabularyVersions _vocabVersion;
 
@@ -318,13 +361,13 @@ private:
 	Common::Array<parse_tree_branch_t> _parserBranches;
 	WordMap _parserWords;
 	SynonymList _synonyms; /**< The list of synonyms */
+	Common::Array<Common::List<AltInput> > _altInputs;
 
 public:
 	// Accessed by said()
 	ParseTreeNode _parserNodes[VOCAB_TREE_NODES]; /**< The parse tree */
 
 	// Parser data:
-	reg_t parser_base; /**< Base address for the parser error reporting mechanism */
 	reg_t parser_event; /**< The event passed to Parse() and later used by Said() */
 	bool parserIsValid; /**< If something has been correctly parsed */
 };
@@ -340,12 +383,11 @@ void vocab_dump_parse_tree(const char *tree_name, ParseTreeNode *nodes);
 
 /**
  * Builds a parse tree from a spec and compares it to a parse tree.
- * @param s			The affected state
  * @param spec		Pointer to the spec to build
  * @param verbose	Whether to display the parse tree after building it
  * @return 1 on a match, 0 otherwise
  */
-int said(EngineState *s, const byte *spec, bool verbose);
+int said(const byte *spec, bool verbose);
 
 } // End of namespace Sci
 
