@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/resource.h $
- * $Id: resource.h 52667 2010-09-10 14:07:32Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -96,9 +96,19 @@ enum ResourceType {
 	kResourceTypeAudio36,
 	kResourceTypeSync36,
 	kResourceTypeTranslation, // Currently unsupported
+
+	// SCI2.1+ Resources
 	kResourceTypeRobot,
 	kResourceTypeVMD,
 	kResourceTypeChunk,
+	kResourceTypeAnimation,
+
+	// SCI3 Resources
+	kResourceTypeEtc,
+	kResourceTypeDuck,
+	kResourceTypeClut,
+	kResourceTypeTGA,
+	kResourceTypeZZZ,
 
 	// Mac-only resources
 	kResourceTypeMacIconBarPictN, // IBIN resources (icon bar, not selected)
@@ -114,10 +124,12 @@ enum ResVersion {
 	kResVersionUnknown,
 	kResVersionSci0Sci1Early,
 	kResVersionSci1Middle,
+	kResVersionKQ5FMT,
 	kResVersionSci1Late,
 	kResVersionSci11,
 	kResVersionSci11Mac,
-	kResVersionSci32
+	kResVersionSci2,
+	kResVersionSci3
 };
 
 class ResourceManager;
@@ -272,7 +284,7 @@ public:
 	/**
 	 * Initializes the resource manager.
 	 */
-	void init();
+	void init(bool initFromFallbackDetector = false);
 
 	int addAppropriateSources();
 	int addAppropriateSources(const Common::FSList &fslist);	// TODO: Switch from FSList to Common::Archive?
@@ -317,9 +329,8 @@ public:
 
 	void setAudioLanguage(int language);
 	int getAudioLanguage() const;
+	void changeAudioDirectory(Common::String path);
 	bool isGMTrackIncluded();
-	bool isVGA() const { return (_viewType == kViewVga) || (_viewType == kViewVga11); }
-	bool isAmiga32color() const { return _viewType == kViewAmiga; }
 	bool isSci11Mac() const { return _volVersion == kResVersionSci11Mac; }
 	ViewType getViewType() const { return _viewType; }
 	const char *getMapVersionDesc() const { return versionDescription(_mapVersion); }
@@ -424,7 +435,8 @@ protected:
 	 */
 	void scanNewSources();
 
-	int addInternalSources();
+	bool addAudioSources();
+	void addScriptChunkSources();
 	void freeResourceSources();
 
 	/**
