@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/resource_audio.cpp $
- * $Id: resource_audio.cpp 52788 2010-09-18 09:46:06Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 
 #include "common/archive.h"
 #include "common/file.h"
+#include "common/textconsole.h"
 
 #include "sci/resource.h"
 #include "sci/resource_intern.h"
@@ -53,15 +54,15 @@ AudioVolumeResourceSource::AudioVolumeResourceSource(ResourceManager *resMan, co
 	fileStream->seek(0, SEEK_SET);
 	uint32 compressionType = fileStream->readUint32BE();
 	switch (compressionType) {
-	case MKID_BE('MP3 '):
-	case MKID_BE('OGG '):
-	case MKID_BE('FLAC'):
+	case MKTAG('M','P','3',' '):
+	case MKTAG('O','G','G',' '):
+	case MKTAG('F','L','A','C'):
 		// Detected a compressed audio volume
 		_audioCompressionType = compressionType;
 		// Now read the whole offset mapping table for later usage
 		int32 recordCount = fileStream->readUint32LE();
 		if (!recordCount)
-			error("compressed audio volume doesn't contain any entries!");
+			error("compressed audio volume doesn't contain any entries");
 		int32 *offsetMapping = new int32[(recordCount + 1) * 2];
 		_audioCompressionOffsetMapping = offsetMapping;
 		for (int recordNo = 0; recordNo < recordCount; recordNo++) {
@@ -91,7 +92,7 @@ bool Resource::loadFromWaveFile(Common::SeekableReadStream *file) {
 bool Resource::loadFromAudioVolumeSCI11(Common::SeekableReadStream *file) {
 	// Check for WAVE files here
 	uint32 riffTag = file->readUint32BE();
-	if (riffTag == MKID_BE('RIFF')) {
+	if (riffTag == MKTAG('R','I','F','F')) {
 		_headerSize = 0;
 		size = file->readUint32LE() + 8;
 		file->seek(-8, SEEK_CUR);
@@ -276,7 +277,7 @@ int ResourceManager::readAudioMapSCI11(ResourceSource *map) {
 #ifndef ENABLE_SCI32
 	// SCI32 support is not built in. Check if this is a SCI32 game
 	// and if it is abort here.
-	if (_volVersion == kResVersionSci32)
+	if (_volVersion >= kResVersionSci2)
 		return SCI_ERROR_RESMAP_NOT_FOUND;
 #endif
 
@@ -824,4 +825,136 @@ byte SoundResource::getInitialVoiceCount(byte channel) {
 		return data[channel * 2];
 }
 
+void WaveResourceSource::loadResource(ResourceManager *resMan, Resource *res) {
+	Common::SeekableReadStream *fileStream = getVolumeFile(resMan, res);
+	if (!fileStream)
+		return;
+
+	fileStream->seek(res->_fileOffset, SEEK_SET);
+	res->loadFromWaveFile(fileStream);
+	if (_resourceFile)
+		delete fileStream;
+}
+
+void AudioVolumeResourceSource::loadResource(ResourceManager *resMan, Resource *res) {
+	Common::SeekableReadStream *fileStream = getVolumeFile(resMan, res);
+	if (!fileStream)
+		return;
+
+	if (_audioCompressionType) {
+		// this file is compressed, so lookup our offset in the offset-translation table and get the new offset
+		//  also calculate the compressed size by using the next offset
+		int32 *mappingTable = _audioCompressionOffsetMapping;
+		int32 compressedOffset = 0;
+
+		do {
+			if (*mappingTable == res->_fileOffset) {
+				mappingTable++;
+				compressedOffset = *mappingTable;
+				// Go to next compressed offset and use that to calculate size of compressed sample
+				switch (res->getType()) {
+				case kResourceTypeSync:
+				case kResourceTypeSync36:
+					// we should already have a (valid) size
+					break;
+				default:
+					mappingTable += 2;
+					res->size = *mappingTable - compressedOffset;
+				}
+				break;
+			}
+			mappingTable += 2;
+		} while (*mappingTable);
+
+		if (!compressedOffset)
+			error("could not translate offset to compressed offset in audio volume");
+		fileStream->seek(compressedOffset, SEEK_SET);
+
+		switch (res->getType()) {
+		case kResourceTypeAudio:
+		case kResourceTypeAudio36:
+			// Directly read the stream, compressed audio wont have resource type id and header size for SCI1.1
+			res->loadFromAudioVolumeSCI1(fileStream);
+			if (_resourceFile)
+				delete fileStream;
+			return;
+		default:
+			break;
+		}
+	} else {
+		// original file, directly seek to given offset and get SCI1/SCI1.1 audio resource
+		fileStream->seek(res->_fileOffset, SEEK_SET);
+	}
+	if (getSciVersion() < SCI_VERSION_1_1)
+		res->loadFromAudioVolumeSCI1(fileStream);
+	else
+		res->loadFromAudioVolumeSCI11(fileStream);
+
+	if (_resourceFile)
+		delete fileStream;
+}
+
+bool ResourceManager::addAudioSources() {
+	Common::List<ResourceId> *resources = listResources(kResourceTypeMap);
+	Common::List<ResourceId>::iterator itr = resources->begin();
+
+	while (itr != resources->end()) {
+		ResourceSource *src = addSource(new IntMapResourceSource("MAP", itr->getNumber()));
+
+		if ((itr->getNumber() == 65535) && Common::File::exists("RESOURCE.SFX"))
+			addSource(new AudioVolumeResourceSource(this, "RESOURCE.SFX", src, 0));
+		else if (Common::File::exists("RESOURCE.AUD"))
+			addSource(new AudioVolumeResourceSource(this, "RESOURCE.AUD", src, 0));
+		else
+			return false;
+
+		++itr;
+	}
+
+	delete resources;
+
+	return true;
+}
+
+void ResourceManager::changeAudioDirectory(Common::String path) {
+	// Remove all of the audio map resource sources, as well as the audio resource sources
+	for (Common::List<ResourceSource *>::iterator it = _sources.begin(); it != _sources.end(); ++it) {
+		ResourceSource *source = *it;
+		ResSourceType sourceType = source->getSourceType();
+
+		// Remove the resource source, if it's an audio map or an audio file
+		if (sourceType == kSourceIntMap || sourceType == kSourceAudioVolume) {
+			// Don't remove 65535.map (the SFX map) or resource.sfx
+			if (source->_volumeNumber == 65535 || source->getLocationName() == "RESOURCE.SFX")
+				continue;
+
+			it = _sources.erase(it);
+			delete source;
+		}
+	}
+
+	// Now, readd the audio resource sources
+	Common::String mapName = "MAP";
+	Common::String audioResourceName = "RESOURCE.AUD";
+	if (!path.empty()) {
+		mapName = Common::String::format("%s/MAP", path.c_str());
+		audioResourceName = Common::String::format("%s/RESOURCE.AUD", path.c_str());
+	}
+
+	Common::List<ResourceId> *resources = listResources(kResourceTypeMap);
+	for (Common::List<ResourceId>::iterator it = resources->begin(); it != resources->end(); ++it) {
+		// Don't readd 65535.map or resource.sfx
+		if ((it->getNumber() == 65535))
+			continue;
+
+		ResourceSource *src = addSource(new IntMapResourceSource(mapName, it->getNumber()));
+		addSource(new AudioVolumeResourceSource(this, audioResourceName, src, 0));
+	}
+
+	delete resources;
+
+	// Rescan the newly added resources
+	scanNewSources();
+}
+
 } // End of namespace Sci
