@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sci.h $
- * $Id: sci.h 52490 2010-09-02 09:05:08Z m_kiewitz $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #define SCI_H
 
 #include "engines/engine.h"
+#include "common/macresman.h"
 #include "common/util.h"
 #include "common/random.h"
 #include "sci/engine/vm_types.h"	// for Selector
@@ -39,8 +40,11 @@ struct ADGameDescription;
  *
  * Status of this engine: ???
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Newer Sierra adventure games (based on FreeSCI) 
+ *
+ * @todo give a concrete list of supported games. Could also
+ * list future games, with status for each.
  */
 namespace Sci {
 
@@ -73,7 +77,7 @@ class GfxText16;
 class GfxTransitions;
 
 #ifdef ENABLE_SCI32
-class SciGui32;
+class RobotDecoder;
 class GfxFrameout;
 #endif
 
@@ -163,7 +167,7 @@ enum SciGameId {
 	GID_QFG4,
 	GID_RAMA,
 	GID_SHIVERS,
-	GID_SHIVERS2,
+	//GID_SHIVERS2,	// Not SCI
 	GID_SLATER,
 	GID_SQ1,
 	GID_SQ3,
@@ -175,20 +179,24 @@ enum SciGameId {
 	GID_FANMADE	// FIXME: Do we really need/want this?
 };
 
-/** SCI versions */
+/** 
+ * SCI versions
+ * For more information, check here:
+ * http://wiki.scummvm.org/index.php/Sierra_Game_Versions#SCI_Games
+ */
 enum SciVersion {
 	SCI_VERSION_NONE,
-	SCI_VERSION_0_EARLY, // Early KQ4, 1988 xmas card
+	SCI_VERSION_0_EARLY, // KQ4 early, LSL2 early, XMAS card 1988
 	SCI_VERSION_0_LATE, // KQ4, LSL2, LSL3, SQ3 etc
 	SCI_VERSION_01, // KQ1 and multilingual games (S.old.*)
-	SCI_VERSION_1_EGA, // EGA with parser, QFG2
-	SCI_VERSION_1_EARLY, // KQ5. (EGA/VGA)
-	SCI_VERSION_1_MIDDLE, // LSL1, JONESCD. (EGA?/VGA)
-	SCI_VERSION_1_LATE, // ECO1, LSL5. (EGA/VGA)
-	SCI_VERSION_1_1, // KQ6, ECO2
-	SCI_VERSION_2, // GK1, PQ4 (Floppy), QFG4 (Floppy)
-	SCI_VERSION_2_1, // GK2, KQ7, SQ6, Torin
-	SCI_VERSION_3 // LSL7, RAMA, Lighthouse
+	SCI_VERSION_1_EGA_ONLY, // SCI 1 EGA with parser (i.e. QFG2 only)
+	SCI_VERSION_1_EARLY, // KQ5 floppy, SQ4 floppy, XMAS card 1990, Fairy tales, Jones floppy
+	SCI_VERSION_1_MIDDLE, // LSL1, Jones CD
+	SCI_VERSION_1_LATE, // Dr. Brain 1, EcoQuest 1, Longbow, PQ3, SQ1, LSL5, KQ5 CD
+	SCI_VERSION_1_1, // Dr. Brain 2, EcoQuest 1 CD, EcoQuest 2, KQ6, QFG3, SQ4CD, XMAS 1992 and many more
+	SCI_VERSION_2, // GK1, PQ4 floppy, QFG4 floppy
+	SCI_VERSION_2_1, // GK2, KQ7, LSL6 hires, MUMG Deluxe, Phantasmagoria 1, PQ4CD, PQ:SWAT, QFG4CD, Shivers 1, SQ6, Torin
+	SCI_VERSION_3 // LSL7, Lighthouse, RAMA, Phantasmagoria 2
 };
 
 /** Supported languages */
@@ -203,7 +211,6 @@ enum kLanguage {
 	K_LANG_PORTUGUESE = 351
 };
 
-
 class SciEngine : public Engine {
 	friend class Console;
 public:
@@ -221,6 +228,7 @@ public:
 	bool canLoadGameStateCurrently();
 	bool canSaveGameStateCurrently();
 	void syncSoundSettings();
+	void syncIngameAudioOptions();
 
 	const SciGameId &getGameId() const { return _gameId; }
 	const char *getGameIdStr() const;
@@ -228,6 +236,12 @@ public:
 	Common::Language getLanguage() const;
 	Common::Platform getPlatform() const;
 	bool isDemo() const;
+	bool isCD() const;
+
+	/** Returns true if the game's original platform is big-endian. */
+	bool isBE() const;
+
+	bool hasMacIconBar() const;
 
 	inline ResourceManager *getResMan() const { return _resMan; }
 	inline Kernel *getKernel() const { return _kernel; }
@@ -235,7 +249,6 @@ public:
 	inline Vocabulary *getVocabulary() const { return _vocabulary; }
 	inline EventManager *getEventManager() const { return _eventMan; }
 	inline reg_t getGameObject() const { return _gameObjectAddress; }
-	inline reg_t getGameSuperClassAddress() const { return _gameSuperClassAddress; }
 
 	Common::RandomSource &getRNG() { return _rng; }
 
@@ -262,7 +275,7 @@ public:
 	bool checkExportBreakpoint(uint16 script, uint16 pubfunct);
 	bool checkSelectorBreakpoint(BreakpointType breakpointType, reg_t send_obj, int selector);
 
-	void patchGameSaveRestore(SegManager *segMan);
+	void patchGameSaveRestore();
 
 public:
 
@@ -307,6 +320,7 @@ public:
 	GfxMacIconBar *_gfxMacIconBar; // Mac Icon Bar manager
 
 #ifdef ENABLE_SCI32
+	RobotDecoder *_robotDecoder;
 	GfxFrameout *_gfxFrameout; // kFrameout and the like for 32-bit gfx
 #endif
 
@@ -316,6 +330,8 @@ public:
 
 	DebugState _debugState;
 
+	Common::MacResManager *getMacExecutable() { return &_macExecutable; }
+
 private:
 	/**
 	 * Initializes a SCI game
@@ -342,8 +358,16 @@ private:
 	 */
 	void exitGame();
 
+	/**
+	 * Loads the Mac executable for SCI1 games
+	 */
+	void loadMacExecutable();
+
 	void initStackBaseWithSelector(Selector selector);
 
+	bool gameHasFanMadePatch();
+	void setLauncherLanguage();
+
 	const ADGameDescription *_gameDescription;
 	const SciGameId _gameId;
 	ResourceManager *_resMan; /**< The resource manager */
@@ -353,9 +377,9 @@ private:
 	int16 _vocabularyLanguage;
 	EventManager *_eventMan;
 	reg_t _gameObjectAddress; /**< Pointer to the game object */
-	reg_t _gameSuperClassAddress; // Address of the super class of the game object
 	Console *_console;
 	Common::RandomSource _rng;
+	Common::MacResManager _macExecutable;
 };
 
 
