@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sound/music.cpp $
- * $Id: music.cpp 53820 2010-10-25 11:19:44Z wjpalenstijn $
+ * $URL$
+ * $Id$
  *
  */
 
-#include "sound/audiostream.h"
-#include "sound/decoders/raw.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/raw.h"
 #include "common/config-manager.h"
 
 #include "sci/sci.h"
@@ -36,10 +36,12 @@
 #include "sci/sound/midiparser_sci.h"
 #include "sci/sound/music.h"
 
+//#define DISABLE_REMAPPING
+
 namespace Sci {
 
 SciMusic::SciMusic(SciVersion soundVersion)
-	: _soundVersion(soundVersion), _soundOn(true), _masterVolume(0) {
+	: _soundVersion(soundVersion), _soundOn(true), _masterVolume(0), _globalReverb(0) {
 
 	// Reserve some space in the playlist, to avoid expensive insertion
 	// operations
@@ -66,7 +68,17 @@ void SciMusic::init() {
 
 	// Default to MIDI in SCI2.1+ games, as many don't have AdLib support.
 	Common::Platform platform = g_sci->getPlatform();
-	uint32 dev = MidiDriver::detectDevice((getSciVersion() >= SCI_VERSION_2_1) ? (MDT_PCSPK | MDT_PCJR | MDT_ADLIB | MDT_MIDI | MDT_PREFER_GM) : (MDT_PCSPK | MDT_PCJR | MDT_ADLIB | MDT_MIDI));
+
+	uint32 deviceFlags = MDT_PCSPK | MDT_PCJR | MDT_ADLIB | MDT_MIDI;
+
+	if (getSciVersion() >= SCI_VERSION_2_1)
+		deviceFlags |= MDT_PREFER_GM;
+
+	// Currently our CMS implementation only supports SCI1(.1)
+	if (getSciVersion() >= SCI_VERSION_1_EGA_ONLY && getSciVersion() <= SCI_VERSION_1_1)
+		deviceFlags |= MDT_CMS;
+
+	uint32 dev = MidiDriver::detectDevice(deviceFlags);
 	_musicType = MidiDriver::getMusicType(dev);
 
 	switch (_musicType) {
@@ -83,6 +95,9 @@ void SciMusic::init() {
 	case MT_PCSPK:
 		_pMidiDrv = MidiPlayer_PCSpeaker_create(_soundVersion);
 		break;
+	case MT_CMS:
+		_pMidiDrv = MidiPlayer_CMS_create(_soundVersion);
+		break;
 	default:
 		if (ConfMan.getBool("native_fb01"))
 			_pMidiDrv = MidiPlayer_Fb01_create(_soundVersion);
@@ -103,6 +118,8 @@ void SciMusic::init() {
 	// remapping).
 	_driverFirstChannel = _pMidiDrv->getFirstChannel();
 	_driverLastChannel = _pMidiDrv->getLastChannel();
+	if (getSciVersion() <= SCI_VERSION_0_LATE)
+		_globalReverb = _pMidiDrv->getReverb();	// Init global reverb for SCI0
 }
 
 void SciMusic::miditimerCallback(void *p) {
@@ -212,9 +229,36 @@ MusicEntry *SciMusic::getActiveSci0MusicSlot() {
 	return highestPrioritySlot;
 }
 
-void SciMusic::setReverb(byte reverb) {
+void SciMusic::setGlobalReverb(int8 reverb) {
 	Common::StackLock lock(_mutex);
-	_pMidiDrv->setReverb(reverb);
+	if (reverb != 127) {
+		// Set global reverb normally
+		_globalReverb = reverb;
+
+		// Check the reverb of the active song...
+		const MusicList::iterator end = _playList.end();
+		for (MusicList::iterator i = _playList.begin(); i != end; ++i) {
+			if ((*i)->status == kSoundPlaying) {
+				if ((*i)->reverb == 127)			// Active song has no reverb
+					_pMidiDrv->setReverb(reverb);	// Set the global reverb
+				break;
+			}
+		}
+	} else {
+		// Set reverb of the active song
+		const MusicList::iterator end = _playList.end();
+		for (MusicList::iterator i = _playList.begin(); i != end; ++i) {
+			if ((*i)->status == kSoundPlaying) {
+				_pMidiDrv->setReverb((*i)->reverb);	// Set the song's reverb
+				break;
+			}
+		}
+	}
+}
+
+byte SciMusic::getCurrentReverb() {
+	Common::StackLock lock(_mutex);
+	return _pMidiDrv->getReverb();
 }
 
 static bool musicEntryCompare(const MusicEntry *l, const MusicEntry *r) {
@@ -259,7 +303,7 @@ void SciMusic::soundInitSnd(MusicEntry *pSnd) {
 			pSnd->hCurrentAud = Audio::SoundHandle();
 		} else {
 			// play MIDI track
-			_mutex.lock();
+			Common::StackLock lock(_mutex);
 			pSnd->soundType = Audio::Mixer::kMusicSoundType;
 			if (pSnd->pMidiParser == NULL) {
 				pSnd->pMidiParser = new MidiParser_SCI(_soundVersion, this);
@@ -274,9 +318,22 @@ void SciMusic::soundInitSnd(MusicEntry *pSnd) {
 			channelFilterMask = pSnd->soundRes->getChannelFilterMask(_pMidiDrv->getPlayId(), _pMidiDrv->hasRhythmChannel());
 
 			pSnd->pMidiParser->mainThreadBegin();
+			// loadMusic() below calls jumpToTick.
+			// Disable sound looping and hold before jumpToTick is called,
+			// otherwise the song may keep looping forever when it ends in
+			// jumpToTick (e.g. LSL3, when going left from room 210).
+			uint16 prevLoop = pSnd->loop;
+			int16 prevHold = pSnd->hold;
+			pSnd->loop = 0;
+			pSnd->hold = -1;
+
 			pSnd->pMidiParser->loadMusic(track, pSnd, channelFilterMask, _soundVersion);
+			pSnd->reverb = pSnd->pMidiParser->getSongReverb();
+
+			// Restore looping and hold
+			pSnd->loop = prevLoop;
+			pSnd->hold = prevHold;
 			pSnd->pMidiParser->mainThreadEnd();
-			_mutex.unlock();
 		}
 	}
 }
@@ -284,6 +341,10 @@ void SciMusic::soundInitSnd(MusicEntry *pSnd) {
 // This one checks, if requested channel is available -> in that case give
 // caller that channel. Otherwise look for an unused one
 int16 SciMusic::tryToOwnChannel(MusicEntry *caller, int16 bestChannel) {
+#ifdef DISABLE_REMAPPING
+	return bestChannel;
+#endif
+
 	// Don't even try this for SCI0
 	if (_soundVersion <= SCI_VERSION_0_LATE)
 		return bestChannel;
@@ -294,7 +355,7 @@ int16 SciMusic::tryToOwnChannel(MusicEntry *caller, int16 bestChannel) {
 	}
 	// otherwise look for unused channel
 	for (int channelNr = _driverFirstChannel; channelNr < 15; channelNr++) {
-		if (channelNr == 9) // never map to channel 9 (precussion)
+		if (channelNr == 9) // never map to channel 9 (percussion)
 			continue;
 		if (!_usedChannel[channelNr]) {
 			_usedChannel[channelNr] = caller;
@@ -379,26 +440,52 @@ void SciMusic::soundPlay(MusicEntry *pSnd) {
 		}
 	} else {
 		if (pSnd->pMidiParser) {
-			_mutex.lock();
+			Common::StackLock lock(_mutex);
 			pSnd->pMidiParser->mainThreadBegin();
+
+			if (pSnd->status != kSoundPaused) {
+				// Stop any in progress music fading, as that will reset the
+				// volume of the sound channels that the faded song occupies..
+				// Fixes bug #3266480 and partially fixes bug #3041738.
+				for (uint i = 0; i < playListCount; i++) {
+					// Is another MIDI song being faded? If yes, stop it
+					// immediately instead
+					if (_playList[i]->fadeStep && _playList[i]->pMidiParser) {
+						_playList[i]->status = kSoundStopped;
+						if (_soundVersion <= SCI_VERSION_0_LATE)
+							_playList[i]->isQueued = false;
+						_playList[i]->pMidiParser->stop();
+						freeChannels(_playList[i]);
+						_playList[i]->fadeStep = 0;
+					}
+				}
+			}
+
 			pSnd->pMidiParser->tryToOwnChannels();
-			if (pSnd->status == kSoundStopped)
+			if (pSnd->status != kSoundPaused)
 				pSnd->pMidiParser->sendInitCommands();
 			pSnd->pMidiParser->setVolume(pSnd->volume);
-			if (pSnd->status == kSoundStopped) {
+
+			// Disable sound looping and hold before jumpToTick is called,
+			// otherwise the song may keep looping forever when it ends in jumpToTick.
+			// This is needed when loading saved games, or when a game
+			// stops the same sound twice (e.g. LSL3 Amiga, going left from
+			// room 210 to talk with Kalalau). Fixes bugs #3083151 and #3106107.
+			uint16 prevLoop = pSnd->loop;
+			int16 prevHold = pSnd->hold;
+			pSnd->loop = 0;
+			pSnd->hold = -1;
+
+			if (pSnd->status == kSoundStopped)
 				pSnd->pMidiParser->jumpToTick(0);
-			} else {
-				// Disable sound looping before fast forwarding to the last position,
-				// when loading a saved game. Fixes bug #3083151.
-				uint16 prevLoop = pSnd->loop;
-				pSnd->loop = 0;
+			else
 				// Fast forward to the last position and perform associated events when loading
-				pSnd->pMidiParser->jumpToTick(pSnd->ticker, true);
-				// Restore looping
-				pSnd->loop = prevLoop;
-			}
+				pSnd->pMidiParser->jumpToTick(pSnd->ticker, true, true, true);
+
+			// Restore looping and hold
+			pSnd->loop = prevLoop;
+			pSnd->hold = prevHold;
 			pSnd->pMidiParser->mainThreadEnd();
-			_mutex.unlock();
 		}
 	}
 
@@ -414,7 +501,7 @@ void SciMusic::soundStop(MusicEntry *pSnd) {
 		_pMixer->stopHandle(pSnd->hCurrentAud);
 
 	if (pSnd->pMidiParser) {
-		_mutex.lock();
+		Common::StackLock lock(_mutex);
 		pSnd->pMidiParser->mainThreadBegin();
 		// We shouldn't call stop in case it's paused, otherwise we would send
 		// allNotesOff() again
@@ -422,7 +509,6 @@ void SciMusic::soundStop(MusicEntry *pSnd) {
 			pSnd->pMidiParser->stop();
 		freeChannels(pSnd);
 		pSnd->pMidiParser->mainThreadEnd();
-		_mutex.unlock();
 	}
 
 	pSnd->fadeStep = 0; // end fading, if fading was in progress
@@ -434,11 +520,10 @@ void SciMusic::soundSetVolume(MusicEntry *pSnd, byte volume) {
 		// we simply ignore volume changes for samples, because sierra sci also
 		//  doesn't support volume for samples via kDoSound
 	} else if (pSnd->pMidiParser) {
-		_mutex.lock();
+		Common::StackLock lock(_mutex);
 		pSnd->pMidiParser->mainThreadBegin();
 		pSnd->pMidiParser->setVolume(volume);
 		pSnd->pMidiParser->mainThreadEnd();
-		_mutex.unlock();
 	}
 }
 
@@ -460,13 +545,12 @@ void SciMusic::soundKill(MusicEntry *pSnd) {
 	pSnd->status = kSoundStopped;
 
 	if (pSnd->pMidiParser) {
-		_mutex.lock();
+		Common::StackLock lock(_mutex);
 		pSnd->pMidiParser->mainThreadBegin();
 		pSnd->pMidiParser->unloadMusic();
 		pSnd->pMidiParser->mainThreadEnd();
 		delete pSnd->pMidiParser;
 		pSnd->pMidiParser = NULL;
-		_mutex.unlock();
 	}
 
 	if (pSnd->pStreamAud) {
@@ -477,7 +561,7 @@ void SciMusic::soundKill(MusicEntry *pSnd) {
 		pSnd->pLoopStream = 0;
 	}
 
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	uint sz = _playList.size(), i;
 	// Remove sound from playlist
 	for (i = 0; i < sz; i++) {
@@ -488,7 +572,6 @@ void SciMusic::soundKill(MusicEntry *pSnd) {
 			break;
 		}
 	}
-	_mutex.unlock();
 }
 
 void SciMusic::soundPause(MusicEntry *pSnd) {
@@ -511,12 +594,11 @@ void SciMusic::soundPause(MusicEntry *pSnd) {
 		_pMixer->pauseHandle(pSnd->hCurrentAud, true);
 	} else {
 		if (pSnd->pMidiParser) {
-			_mutex.lock();
+			Common::StackLock lock(_mutex);
 			pSnd->pMidiParser->mainThreadBegin();
 			pSnd->pMidiParser->pause();
 			freeChannels(pSnd);
 			pSnd->pMidiParser->mainThreadEnd();
-			_mutex.unlock();
 		}
 	}
 }
@@ -581,9 +663,11 @@ void SciMusic::printPlayList(Console *con) {
 
 	for (uint32 i = 0; i < _playList.size(); i++) {
 		MusicEntry *song = _playList[i];
-		con->DebugPrintf("%d: %04x:%04x, resource id: %d, status: %s, %s type\n", i,
-						PRINT_REG(song->soundObj), song->resourceId,
-						musicStatus[song->status], song->pMidiParser ? "MIDI" : "digital audio");
+		con->DebugPrintf("%d: %04x:%04x (%s), resource id: %d, status: %s, %s type\n",
+						i, PRINT_REG(song->soundObj),
+						g_sci->getEngineState()->_segMan->getObjectName(song->soundObj),
+						song->resourceId, musicStatus[song->status],
+						song->pMidiParser ? "MIDI" : "digital audio");
 	}
 }
 
@@ -643,6 +727,7 @@ MusicEntry::MusicEntry() {
 	loop = 0;
 	volume = MUSIC_VOLUME_DEFAULT;
 	hold = -1;
+	reverb = -1;
 
 	pauseCounter = 0;
 	sampleLoopCounter = 0;
