@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sound/soundcmd.h $
- * $Id: soundcmd.h 52500 2010-09-02 21:50:00Z thebluegr $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,7 @@
 #define SCI_SOUNDCMD_H
 
 #include "common/list.h"
-#include "sound/mididrv.h"	// for MusicType
+#include "audio/mididrv.h"	// for MusicType
 #include "sci/engine/state.h"
 
 namespace Sci {
@@ -53,7 +53,7 @@ public:
 	// Functions used for game state loading
 	void clearPlayList();
 	void syncPlayList(Common::Serializer &s);
-	void reconstructPlayList(int savegame_version);
+	void reconstructPlayList();
 
 	// Functions used for the ScummVM menus
 	void setMasterVolume(int vol);
@@ -94,7 +94,7 @@ public:
 	reg_t kDoSoundUpdate(int argc, reg_t *argv, reg_t acc);
 	reg_t kDoSoundUpdateCues(int argc, reg_t *argv, reg_t acc);
 	reg_t kDoSoundSendMidi(int argc, reg_t *argv, reg_t acc);
-	reg_t kDoSoundReverb(int argc, reg_t *argv, reg_t acc);
+	reg_t kDoSoundGlobalReverb(int argc, reg_t *argv, reg_t acc);
 	reg_t kDoSoundSetHold(int argc, reg_t *argv, reg_t acc);
 	reg_t kDoSoundDummy(int argc, reg_t *argv, reg_t acc);
 	reg_t kDoSoundGetAudioCapability(int argc, reg_t *argv, reg_t acc);
