@@ -18,27 +18,37 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/video/seq_decoder.h $
- * $Id: seq_decoder.h 51725 2010-08-04 08:25:05Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
-#ifndef SEQ_DECODER_H
-#define SEQ_DECODER_H
+#ifndef SCI_VIDEO_SEQ_DECODER_H
+#define SCI_VIDEO_SEQ_DECODER_H
 
-#include "graphics/video/video_decoder.h"
+#include "common/rational.h"
+#include "graphics/pixelformat.h"
+#include "video/video_decoder.h"
+
+namespace Common {
+class SeekableReadStream;
+}
+
+namespace Graphics {
+struct Surface;
+}
 
 namespace Sci {
 
 /**
  * Implementation of the Sierra SEQ decoder, used in KQ6 DOS floppy/CD and GK1 DOS
  */
-class SeqDecoder : public Graphics::FixedRateVideoDecoder {
+class SeqDecoder : public Video::FixedRateVideoDecoder {
 public:
 	SeqDecoder();
 	virtual ~SeqDecoder();
 
-	bool load(Common::SeekableReadStream *stream);
+	bool loadStream(Common::SeekableReadStream *stream);
 	void close();
 
 	void setFrameDelay(int frameDelay) { _frameDelay = frameDelay; }
@@ -47,9 +57,9 @@ public:
 	uint16 getWidth() const { return SEQ_SCREEN_WIDTH; }
 	uint16 getHeight() const { return SEQ_SCREEN_HEIGHT; }
 	uint32 getFrameCount() const { return _frameCount; }
-	Graphics::Surface *decodeNextFrame();
+	const Graphics::Surface *decodeNextFrame();
 	Graphics::PixelFormat getPixelFormat() const { return Graphics::PixelFormat::createFormatCLUT8(); }
-	byte *getPalette() { _dirtyPalette = false; return _palette; }
+	const byte *getPalette() { _dirtyPalette = false; return _palette; }
 	bool hasDirtyPalette() const { return _dirtyPalette; }
   
 protected:
@@ -61,6 +71,7 @@ private:
 		SEQ_SCREEN_HEIGHT = 200
 	};
 
+	void readPaletteChunk(uint16 chunkSize);
 	bool decodeFrame(byte *rleData, int rleSize, byte *litData, int litSize, byte *dest, int left, int width, int height, int colorKey);
 
 	uint16 _width, _height;
