@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/actor.h $
- * $Id: actor.h 46146 2009-11-26 00:45:06Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -34,7 +34,6 @@
 
 namespace Scumm {
 
-
 enum {
 	V12_X_MULTIPLIER = 8,
 	V12_Y_MULTIPLIER = 2,
@@ -305,7 +304,7 @@ public:
 	void classChanged(int cls, bool value);
 
 	// Used by the save/load system:
-	void saveLoadWithSerializer(Serializer *ser);
+	virtual void saveLoadWithSerializer(Serializer *ser);
 
 protected:
 	bool isInClass(int cls);
@@ -315,46 +314,6 @@ protected:
 	bool findPathTowards(byte box, byte box2, byte box3, Common::Point &foundPath);
 };
 
-class ActorHE : public Actor {
-public:
-	ActorHE(ScummEngine *scumm, int id) : Actor(scumm, id) {}
-
-	virtual void initActor(int mode);
-
-	virtual void hideActor();
-
-	void drawActorToBackBuf(int x, int y);
-
-	void setHEFlag(int bit, int set);
-
-	void setUserCondition(int slot, int set);
-	bool isUserConditionSet(int slot) const;
-
-	void setTalkCondition(int slot);
-	bool isTalkConditionSet(int slot) const;
-
-public:
-	/** This rect is used to clip actor drawing. */
-	Common::Rect _clipOverride;
-
-	bool _heNoTalkAnimation;
-	bool _heTalking;
-	byte _heFlags;
-
-	AuxBlock _auxBlock;
-
-	struct {
-		int16 posX;
-		int16 posY;
-		int16 color;
-		byte sentence[128];
-	} _heTalkQueue[16];
-
-
-	virtual void prepareDrawActorCostume(BaseCostumeRenderer *bcr);
-	virtual void setActorCostume(int c);
-};
-
 class Actor_v3 : public Actor {
 public:
 	Actor_v3(ScummEngine *scumm, int id) : Actor(scumm, id) {}
@@ -381,14 +340,16 @@ protected:
 
 class ActorC64 : public Actor_v2 {
 public:
-	// FIXME: These vars are never saved, which might lead to broken save states.
-	byte _miscflags;
-	byte _speaking, _speakingPrev;
 	byte _costCommand, _costFrame;
+	byte _miscflags; // 0x1: strong, 0x8: Ed's enemy, 0x40: stop moving, 0x80: hide(dead/radiation suit)
+	byte _speaking, _speakingPrev;
 
 public:
 	ActorC64(ScummEngine *scumm, int id) : Actor_v2(scumm, id) {
-		 _speaking = _speakingPrev = _costCommand = _costFrame = 0;
+		 _costCommand = 0;
+		 _costFrame = 0;
+		 _speaking = 0;
+		 _speakingPrev = 0;
 	}
 	virtual void initActor(int mode) {
 		Actor_v2::initActor(mode);
@@ -397,6 +358,9 @@ public:
 		}
 	}
 
+	// Used by the save/load system:
+	virtual void saveLoadWithSerializer(Serializer *ser);
+
 protected:
 
 };
