@@ -53,6 +53,7 @@ void ScummEngine::loadCJKFont() {
 
 	if (_game.version <= 5 && _game.platform == Common::kPlatformFMTowns && _language == Common::JA_JPN) { // FM-TOWNS v3 / v5 Kanji
 #ifdef DISABLE_TOWNS_DUAL_LAYER_MODE
+		GUIErrorMessage("FM-Towns Kanji font drawing requires dual graphics layer support which is disabled in this build");
 		error("FM-Towns Kanji font drawing requires dual graphics layer support which is disabled in this build");
 #else
 		// use FM-TOWNS font rom, since game files don't have kanji font resources
@@ -780,7 +781,7 @@ void CharsetRendererV3::printChar(int chr, bool ignoreCharsetMask) {
 			drawBits1(*vs, dst, charPtr, drawTop, origWidth, origHeight, vs->bytesPerPixel);
 #ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
 		else if (_vm->_cjkFont)
-			_vm->_cjkFont->drawChar(vs, chr, _left, drawTop, _color, _shadowColor);
+			_vm->_cjkFont->drawChar(*vs, chr, _left, drawTop, _color, _shadowColor);
 #endif
 	} else {
 		dst = (byte *)_vm->_textSurface.getBasePtr(_left * _vm->_textSurfaceMultiplier, _top * _vm->_textSurfaceMultiplier);
@@ -790,8 +791,10 @@ void CharsetRendererV3::printChar(int chr, bool ignoreCharsetMask) {
 		else if (_vm->_cjkFont)
 			_vm->_cjkFont->drawChar(_vm->_textSurface, chr, _left * _vm->_textSurfaceMultiplier, _top * _vm->_textSurfaceMultiplier, _color, _shadowColor);
 #endif
-		if (is2byte)
+		if (is2byte) {
 			origWidth /= _vm->_textSurfaceMultiplier;
+			height /= _vm->_textSurfaceMultiplier;
+		}
 	}
 
 	if (_str.left > _left)
@@ -805,8 +808,8 @@ void CharsetRendererV3::printChar(int chr, bool ignoreCharsetMask) {
 			_str.right++;
 	}
 
-	if (_str.bottom < _top + height / _vm->_textSurfaceMultiplier)
-		_str.bottom = _top + height / _vm->_textSurfaceMultiplier;
+	if (_str.bottom < _top + height)
+		_str.bottom = _top + height;
 }
 
 void CharsetRendererV3::drawChar(int chr, Graphics::Surface &s, int x, int y) {
