@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/costume.cpp $
- * $Id: costume.cpp 48272 2010-03-16 14:34:25Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -419,6 +419,11 @@ void ClassicCostumeRenderer::procC64(Codec1 &v1, int actor) {
 #undef MASK_AT
 
 #ifdef USE_ARM_COSTUME_ASM
+
+#ifndef IPHONE
+#define ClassicProc3RendererShadowARM _ClassicProc3RendererShadowARM
+#endif
+
 extern "C" int ClassicProc3RendererShadowARM(int _scaleY,
                                         ClassicCostumeRenderer::Codec1 *v1,
                                         Graphics::Surface *_out,
@@ -648,7 +653,7 @@ void ClassicCostumeRenderer::procPCEngine(Codec1 &v1) {
 				}
 			}
 			if (index != 128) {
-				printf("%d\n", index);
+				warning("ClassicCostumeRenderer::procPCEngine: index %d != 128\n", index);
 			}
 
 			for (int row = 0; row < 16; ++row) {
