@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/debugger.h $
- * $Id: debugger.h 46516 2009-12-23 21:12:15Z sev $
+ * $URL$
+ * $Id$
  */
 
 #ifndef SCUMM_DEBUGGER_H
@@ -36,13 +36,10 @@ public:
 	ScummDebugger(ScummEngine *s);
 	virtual ~ScummDebugger(); // we need this here for __SYMBIAN32__
 
-protected:
+private:
 	ScummEngine *_vm;
 	bool  _old_soundsPaused;
 
-	virtual void preEnter();
-	virtual void postEnter();
-
 	// Commands
 	bool Cmd_Room(int argc, const char **argv);
 	bool Cmd_LoadGame(int argc, const char **argv);
