@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/detection.cpp $
- * $Id: detection.cpp 52370 2010-08-25 07:40:13Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -77,8 +77,6 @@ Common::String ScummEngine::generateFilename(const int room) const {
 			snprintf(buf, sizeof(buf), "disk%02d.lec", diskNumber);
 		}
 	} else {
-		char id = 0;
-
 		switch (_filenamePattern.genMethod) {
 		case kGenDiskNum:
 			snprintf(buf, sizeof(buf), _filenamePattern.pattern, diskNumber);
@@ -88,59 +86,6 @@ Common::String ScummEngine::generateFilename(const int room) const {
 			snprintf(buf, sizeof(buf), _filenamePattern.pattern, room);
 			break;
 
-		case kGenHEMac:
-		case kGenHEMacNoParens:
-		case kGenHEPC:
-			if (room < 0) {
-				id = '0' - room;
-			} else if (_game.heversion >= 98) {
-				int disk = 0;
-				if (_heV7DiskOffsets)
-					disk = _heV7DiskOffsets[room];
-
-				switch (disk) {
-				case 2:
-					id = 'b';
-					// Special cases for Blue's games, which share common (b) files
-					if (_game.id == GID_BIRTHDAY)
-						strcpy(buf, "Blue'sBirthday.(b)");
-					else if (_game.id == GID_TREASUREHUNT)
-						strcpy(buf, "Blue'sTreasureHunt.(b)");
-					else
-						snprintf(buf, sizeof(buf), "%s.(b)", _filenamePattern.pattern);
-					break;
-				case 1:
-					id = 'a';
-					snprintf(buf, sizeof(buf), "%s.(a)", _filenamePattern.pattern);
-					break;
-				default:
-					id = '0';
-					snprintf(buf, sizeof(buf), "%s.he0", _filenamePattern.pattern);
-				}
-			} else if (_game.heversion >= 70) {
-				id = (room == 0) ? '0' : '1';
-			} else {
-				id = diskNumber + '0';
-			}
-
-			if (_filenamePattern.genMethod == kGenHEPC) {
-				// For HE >= 98, we already called snprintf above.
-				if (_game.heversion < 98 || room < 0)
-					snprintf(buf, sizeof(buf), "%s.he%c", _filenamePattern.pattern, id);
-			} else {
-				if (id == '3') { // special case for cursors
-					// For mac they're stored in game binary
-					strncpy(buf, _filenamePattern.pattern, sizeof(buf));
-				} else {
-					if (_filenamePattern.genMethod == kGenHEMac)
-						snprintf(buf, sizeof(buf), "%s (%c)", _filenamePattern.pattern, id);
-					else
-						snprintf(buf, sizeof(buf), "%s %c", _filenamePattern.pattern, id);
-				}
-			}
-
-			break;
-
 		case kGenUnchanged:
 			strncpy(buf, _filenamePattern.pattern, sizeof(buf));
 			break;
@@ -153,6 +98,109 @@ Common::String ScummEngine::generateFilename(const int room) const {
 	return buf;
 }
 
+Common::String ScummEngine_v60he::generateFilename(const int room) const {
+	char buf[128];
+	char id = 0;
+
+	switch (_filenamePattern.genMethod) {
+	case kGenHEMac:
+	case kGenHEMacNoParens:
+	case kGenHEPC:
+		if (room < 0) {
+			id = '0' - room;
+		} else {
+			const int diskNumber = (room > 0) ? _res->roomno[rtRoom][room] : 0;
+			id = diskNumber + '0';
+		}
+
+		if (_filenamePattern.genMethod == kGenHEPC) {
+			snprintf(buf, sizeof(buf), "%s.he%c", _filenamePattern.pattern, id);
+		} else {
+			if (id == '3') { // special case for cursors
+				// For mac they're stored in game binary
+				strncpy(buf, _filenamePattern.pattern, sizeof(buf));
+			} else {
+				if (_filenamePattern.genMethod == kGenHEMac)
+					snprintf(buf, sizeof(buf), "%s (%c)", _filenamePattern.pattern, id);
+				else
+					snprintf(buf, sizeof(buf), "%s %c", _filenamePattern.pattern, id);
+			}
+		}
+
+		break;
+
+	default:
+		// Fallback to parent method
+		return ScummEngine::generateFilename(room);
+	}
+
+	return buf;
+}
+
+Common::String ScummEngine_v70he::generateFilename(const int room) const {
+	char buf[128];
+	char id = 0;
+
+	switch (_filenamePattern.genMethod) {
+	case kGenHEMac:
+	case kGenHEMacNoParens:
+	case kGenHEPC:
+		if (_game.heversion >= 98 && room >= 0) {
+			int disk = 0;
+			if (_heV7DiskOffsets)
+				disk = _heV7DiskOffsets[room];
+
+			switch (disk) {
+			case 2:
+				id = 'b';
+				// Special cases for Blue's games, which share common (b) files
+				if (_game.id == GID_BIRTHDAY && !(_game.features & GF_DEMO))
+					strcpy(buf, "Blue'sBirthday.(b)");
+				else if (_game.id == GID_TREASUREHUNT)
+					strcpy(buf, "Blue'sTreasureHunt.(b)");
+				else
+					snprintf(buf, sizeof(buf), "%s.(b)", _filenamePattern.pattern);
+				break;
+			case 1:
+				id = 'a';
+				snprintf(buf, sizeof(buf), "%s.(a)", _filenamePattern.pattern);
+				break;
+			default:
+				id = '0';
+				snprintf(buf, sizeof(buf), "%s.he0", _filenamePattern.pattern);
+			}
+		} else if (room < 0) {
+			id = '0' - room;
+		} else {
+			id = (room == 0) ? '0' : '1';
+		}
+
+		if (_filenamePattern.genMethod == kGenHEPC) {
+			// For HE >= 98, we already called snprintf above.
+			if (_game.heversion < 98 || room < 0)
+				snprintf(buf, sizeof(buf), "%s.he%c", _filenamePattern.pattern, id);
+		} else {
+			if (id == '3') { // special case for cursors
+				// For mac they're stored in game binary
+				strncpy(buf, _filenamePattern.pattern, sizeof(buf));
+			} else {
+				if (_filenamePattern.genMethod == kGenHEMac)
+					snprintf(buf, sizeof(buf), "%s (%c)", _filenamePattern.pattern, id);
+				else
+					snprintf(buf, sizeof(buf), "%s %c", _filenamePattern.pattern, id);
+			}
+		}
+
+		break;
+
+	default:
+		// Fallback to parent method
+		return ScummEngine_v60he::generateFilename(room);
+	}
+
+	return buf;
+}
+
 static Common::String generateFilenameForDetection(const char *pattern, FilenameGenMethod genMethod) {
 	char buf[128];
 
@@ -422,7 +470,6 @@ static void composeFileHashMap(const Common::FSList &fslist, DescMap &fileMD5Map
 static void detectGames(const Common::FSList &fslist, Common::List<DetectorResult> &results, const char *gameid) {
 	DescMap fileMD5Map;
 	DetectorResult dr;
-	char md5str[32+1];
 
 	// Dive one level down since mac indy3/loom has its files split into directories. See Bug #1438631
 	composeFileHashMap(fslist, fileMD5Map, 2, directoryGlobs);
@@ -467,7 +514,7 @@ static void detectGames(const Common::FSList &fslist, Common::List<DetectorResul
 		//
 		DetectorDesc &d = fileMD5Map[file];
 		if (d.md5.empty()) {
-			Common::File *tmp = 0;
+			Common::SeekableReadStream *tmp = 0;
 			bool isDiskImg = (file.hasSuffix(".d64") || file.hasSuffix(".dsk") || file.hasSuffix(".prg"));
 			
 			if (isDiskImg) {
@@ -475,14 +522,16 @@ static void detectGames(const Common::FSList &fslist, Common::List<DetectorResul
 
 				debug(2, "Falling back to disk-based detection");
 			} else {
-				tmp = new Common::File;
-				tmp->open(d.node);
+				tmp = d.node.createReadStream();
 			}
 
-			if (tmp && tmp->isOpen() && Common::md5_file_string(*tmp, md5str, kMD5FileSizeLimit)) {
+			Common::String md5str;
+			if (tmp)
+				md5str = computeStreamMD5AsString(*tmp, kMD5FileSizeLimit);
+			if (!md5str.empty()) {
 
 				d.md5 = md5str;
-				d.md5Entry = findInMD5Table(md5str);
+				d.md5Entry = findInMD5Table(md5str.c_str());
 
 				dr.md5 = d.md5;
 
@@ -494,7 +543,7 @@ static void detectGames(const Common::FSList &fslist, Common::List<DetectorResul
 					int filesize = tmp->size();
 					if (d.md5Entry->filesize != filesize)
 					debug(1, "SCUMM detector found matching file '%s' with MD5 %s, size %d\n",
-						file.c_str(), md5str, filesize);
+						file.c_str(), md5str.c_str(), filesize);
 
 					// Sanity check: We *should* have found a matching gameid / variant at this point.
 					// If not, then there's a bug in our data tables...
@@ -945,7 +994,7 @@ Common::Error ScummMetaEngine::createInstance(OSystem *syst, Engine **engine) co
 	Common::FSList fslist;
 	Common::FSNode dir(ConfMan.get("path"));
 	if (!dir.isDirectory())
-		return Common::kInvalidPathError;
+		return Common::kPathNotDirectory;
 	if (!dir.getChildren(fslist, Common::FSNode::kListFilesOnly))
 		return Common::kNoGameDataFoundError;
 
@@ -1082,6 +1131,7 @@ Common::Error ScummMetaEngine::createInstance(OSystem *syst, Engine **engine) co
 			break;
 		case 62:
 		case 61:
+		case 60:
 			*engine = new ScummEngine_v60he(syst, res);
 			break;
 		default:
@@ -1185,7 +1235,7 @@ SaveStateDescriptor ScummMetaEngine::querySaveMetaInfos(const char *target, int
 	desc.setDeletableFlag(true);
 	desc.setThumbnail(thumbnail);
 
-	InfoStuff infos;
+	SaveStateMetaInfos infos;
 	memset(&infos, 0, sizeof(infos));
 	if (ScummEngine::loadInfosFromSlot(target, slot, &infos)) {
 		int day = (infos.date >> 24) & 0xFF;
@@ -1198,12 +1248,7 @@ SaveStateDescriptor ScummMetaEngine::querySaveMetaInfos(const char *target, int
 		int minutes = infos.time & 0xFF;
 
 		desc.setSaveTime(hour, minutes);
-
-		minutes = infos.playtime / 60;
-		hour = minutes / 60;
-		minutes %= 60;
-
-		desc.setPlayTime(hour, minutes);
+		desc.setPlayTime(infos.playtime * 1000);
 	}
 
 	return desc;
