@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/file.cpp $
- * $Id: file.cpp 48981 2010-05-09 18:05:00Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,8 @@
 
 #include "scumm/scumm.h"
 
-using Common::File;
+#include "common/memstream.h"
+#include "common/substream.h"
 
 namespace Scumm {
 
@@ -35,11 +36,7 @@ namespace Scumm {
 #pragma mark --- ScummFile ---
 #pragma mark -
 
-ScummFile::ScummFile() : _encbyte(0), _subFileStart(0), _subFileLen(0) {
-}
-
-void ScummFile::setEnc(byte value) {
-	_encbyte = value;
+ScummFile::ScummFile() : _subFileStart(0), _subFileLen(0) {
 }
 
 void ScummFile::setSubfileRange(int32 start, int32 len) {
@@ -248,10 +245,6 @@ ScummDiskImage::ScummDiskImage(const char *disk1, const char *disk2, GameSetting
 	}
 }
 
-void ScummDiskImage::setEnc(byte enc) {
-	_stream->setEnc(enc);
-}
-
 byte ScummDiskImage::fileReadByte() {
 	byte b = 0;
 	File::read(&b, 1);
@@ -499,4 +492,17 @@ bool ScummDiskImage::openSubFile(const Common::String &filename) {
 	return true;
 }
 
+uint32 ScummDiskImage::read(void *dataPtr, uint32 dataSize) {
+	uint32 realLen = _stream->read(dataPtr, dataSize);
+
+	if (_encbyte) {
+		byte *p = (byte *)dataPtr;
+		byte *end = p + realLen;
+		while (p < end)
+			*p++ ^= _encbyte;
+	}
+
+	return realLen;
+}
+
 } // End of namespace Scumm
