@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/file.h $
- * $Id: file.h 42632 2009-07-20 20:55:28Z wjpalenstijn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,14 +27,19 @@
 #define SCUMM_FILE_H
 
 #include "common/file.h"
+#include "common/stream.h"
 
 #include "scumm/detection.h"
 
 namespace Scumm {
 
 class BaseScummFile : public Common::File {
+protected:
+	byte _encbyte;
+
 public:
-	virtual void setEnc(byte value) = 0;
+	BaseScummFile() : _encbyte(0) {}
+	void setEnc(byte value) { _encbyte = value; }
 
 	virtual bool open(const Common::String &filename) = 0;
 	virtual bool openSubFile(const Common::String &filename) = 0;
@@ -52,7 +57,6 @@ public:
 
 class ScummFile : public BaseScummFile {
 private:
-	byte _encbyte;
 	int32	_subFileStart;
 	int32	_subFileLen;
 	bool	_myEos; // Have we read past the end of the subfile?
@@ -62,7 +66,6 @@ private:
 
 public:
 	ScummFile();
-	void setEnc(byte value);
 
 	bool open(const Common::String &filename);
 	bool openSubFile(const Common::String &filename);
@@ -78,7 +81,7 @@ public:
 
 class ScummDiskImage : public BaseScummFile {
 private:
-	Common::MemoryReadStream *_stream;
+	Common::SeekableReadStream *_stream;
 	byte _roomDisks[59], _roomTracks[59], _roomSectors[59];
 
 	byte *_buf;
@@ -108,7 +111,6 @@ private:
 
 public:
 	ScummDiskImage(const char *disk1, const char *disk2, GameSettings game);
-	void setEnc(byte value);
 
 	bool open(const Common::String &filename);
 	bool openSubFile(const Common::String &filename);
@@ -118,7 +120,7 @@ public:
 	int32 pos() const { return _stream->pos(); }
 	int32 size() const { return _stream->size(); }
 	bool seek(int32 offs, int whence = SEEK_SET) { return _stream->seek(offs, whence); }
-	uint32 read(void *dataPtr, uint32 dataSize) { return _stream->read(dataPtr, dataSize); }
+	uint32 read(void *dataPtr, uint32 dataSize);
 };
 
 } // End of namespace Scumm
