@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/he/script_v60he.cpp $
- * $Id: script_v60he.cpp 53727 2010-10-23 02:20:19Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -741,10 +741,14 @@ void ScummEngine_v60he::o60_openFile() {
 void ScummEngine_v60he::o60_closeFile() {
 	int slot = pop();
 	if (0 <= slot && slot < 17) {
-		delete _hInFileTable[slot];
-		delete _hOutFileTable[slot];
+		if (_hOutFileTable[slot]) {
+			_hOutFileTable[slot]->finalize();
+			delete _hOutFileTable[slot];
+			_hOutFileTable[slot] = 0;
+		}
+
+		delete _hInFileTable[slot];		
 		_hInFileTable[slot] = 0;
-		_hOutFileTable[slot] = 0;
 	}
 }
 
