@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/he/script_v80he.cpp $
- * $Id: script_v80he.cpp 43577 2009-08-21 09:37:51Z upthorn $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifdef ENABLE_HE
 
+#include "common/archive.h"
 #include "common/config-file.h"
 #include "common/config-manager.h"
 #include "common/savefile.h"
@@ -35,7 +36,6 @@
 #include "scumm/he/intern_he.h"
 #include "scumm/object.h"
 #include "scumm/resource.h"
-#include "scumm/he/resource_he.h"
 #include "scumm/scumm.h"
 #include "scumm/he/sound_he.h"
 
@@ -95,14 +95,9 @@ void ScummEngine_v80he::o80_getFileSize() {
 
 	Common::SeekableReadStream *f = 0;
 	if (!_saveFileMan->listSavefiles(filename).empty()) {
-		f = _saveFileMan->openForLoading((const char *)filename);
+		f = _saveFileMan->openForLoading(filename);
 	} else {
-		Common::File *file = new Common::File();
-		file->open((const char *)filename);
-		if (!file->isOpen())
-			delete file;
-		else
-			f = file;
+		f = SearchMan.createReadStreamForMember(filename);
 	}
 
 	if (!f) {
