@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/he/script_v90he.cpp $
- * $Id: script_v90he.cpp 53665 2010-10-21 05:33:13Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -32,7 +32,6 @@
 #include "scumm/he/logic_he.h"
 #include "scumm/object.h"
 #include "scumm/resource.h"
-#include "scumm/he/resource_he.h"
 #include "scumm/scumm.h"
 #include "scumm/sound.h"
 #include "scumm/he/sprite_he.h"
@@ -352,12 +351,12 @@ void ScummEngine_v90he::o90_max() {
 }
 
 void ScummEngine_v90he::o90_sin() {
-	double a = pop() * PI / 180.;
+	double a = pop() * M_PI / 180.;
 	push((int)(sin(a) * 100000));
 }
 
 void ScummEngine_v90he::o90_cos() {
-	double a = pop() * PI / 180.;
+	double a = pop() * M_PI / 180.;
 	push((int)(cos(a) * 100000));
 }
 
@@ -373,7 +372,7 @@ void ScummEngine_v90he::o90_sqrt() {
 void ScummEngine_v90he::o90_atan2() {
 	int y = pop();
 	int x = pop();
-	int a = (int)(atan2((double)y, (double)x) * 180. / PI);
+	int a = (int)(atan2((double)y, (double)x) * 180. / M_PI);
 	if (a < 0) {
 		a += 360;
 	}
@@ -385,7 +384,7 @@ void ScummEngine_v90he::o90_getSegmentAngle() {
 	int x1 = pop();
 	int dy = y1 - pop();
 	int dx = x1 - pop();
-	int a = (int)(atan2((double)dy, (double)dx) * 180. / PI);
+	int a = (int)(atan2((double)dy, (double)dx) * 180. / M_PI);
 	if (a < 0) {
 		a += 360;
 	}
@@ -1986,6 +1985,13 @@ static int compareDwordArrayReverse(const void *a, const void *b) {
 	return vb - va;
 }
 
+
+/**
+ * Sort a row range in a two-dimensional array by the value in a given column.
+ *
+ * We sort the data in the row range [dim2start..dim2end], according to the value
+ * in column dim1start == dim1end.
+ */
 void ScummEngine_v90he::sortArray(int array, int dim2start, int dim2end, int dim1start, int dim1end, int sortOrder) {
 	debug(9, "sortArray(%d, [%d,%d,%d,%d], %d)", array, dim2start, dim2end, dim1start, dim1end, sortOrder);
 
@@ -1994,11 +2000,21 @@ void ScummEngine_v90he::sortArray(int array, int dim2start, int dim2end, int dim
 	ArrayHeader *ah = (ArrayHeader *)getResourceAddress(rtString, readVar(array));
 	assert(ah);
 
-	const int num = dim2end - dim2start + 1;
-	const int pitch = FROM_LE_32(ah->dim1end) - FROM_LE_32(ah->dim1start) + 1;
-	const int offset = pitch * (dim2start - FROM_LE_32(ah->dim2start));
-	sortArrayOffset = dim1start - FROM_LE_32(ah->dim1start);
+	const int num = dim2end - dim2start + 1;	// number of rows to sort
+	const int pitch = FROM_LE_32(ah->dim1end) - FROM_LE_32(ah->dim1start) + 1;	// length of a row = number of columns in it
+	const int offset = pitch * (dim2start - FROM_LE_32(ah->dim2start));	// memory offset to the first row to be sorted
+	sortArrayOffset = dim1start - FROM_LE_32(ah->dim1start);	// offset to the column by which we sort
 
+	// Now we just have to invoke qsort on the appropriate row range. We
+	// need to pass sortArrayOffset as an implicit parameter to the
+	// comparison functions, which makes it necessary to use a global
+	// (albeit local to this file) variable.
+	// This could be avoided by using qsort_r or a self-written portable
+	// analog (this function passes an additional, user determined
+	// parameter to the comparison function).
+	// Another idea would be to use Common::sort, but that only is
+	// suitable if you sort objects of fixed size, which must be known
+	// during compilation time; clearly this not the case here.
 	switch (FROM_LE_32(ah->type)) {
 	case kByteArray:
 	case kStringArray:
@@ -2041,7 +2057,6 @@ void ScummEngine_v90he::o90_sortArray() {
 			int dim2end = pop();
 			int dim2start = pop();
 			getArrayDim(array, &dim2start, &dim2end, &dim1start, &dim1end);
-			checkArrayLimits(array, dim2start, dim2end, dim1start, dim1end);
 			sortArray(array, dim2start, dim2end, dim1start, dim1end, sortOrder);
 		}
 		break;
@@ -2277,13 +2292,13 @@ void ScummEngine_v90he::o90_kernelGetFunctions() {
 	switch (args[0]) {
 	case 1001:
 		{
-		double b = args[1] * PI / 180.;
+		double b = args[1] * M_PI / 180.;
 		push((int)(sin(b) * 100000));
 		}
 		break;
 	case 1002:
 		{
-		double b = args[1] * PI / 180.;
+		double b = args[1] * M_PI / 180.;
 		push((int)(cos(b) * 100000));
 		}
 		break;
