@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/imuse/imuse.h $
- * $Id: imuse.h 46081 2009-11-22 11:58:14Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -58,7 +58,6 @@ public:
 		PROP_GS,
 		PROP_LIMIT_PLAYERS,
 		PROP_RECYCLE_PLAYERS,
-		PROP_DIRECT_PASSTHROUGH,
 		PROP_GAME_ID
 	};
 
