@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/imuse/imuse_part.cpp $
- * $Id: imuse_part.cpp 47279 2010-01-12 21:07:56Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 
 
+#include "common/debug.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 #include "scumm/imuse/imuse_internal.h"
 #include "scumm/saveload.h"
