@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/imuse/imuse_player.cpp $
- * $Id: imuse_player.cpp 52198 2010-08-18 21:38:43Z athrxx $
+ * $URL$
+ * $Id$
  */
 
 
@@ -31,7 +31,7 @@
 #include "scumm/saveload.h"
 #include "scumm/scumm.h"
 
-#include "sound/midiparser.h"
+#include "audio/midiparser.h"
 
 namespace Scumm {
 
@@ -61,7 +61,6 @@ uint16 Player::_active_notes[128];
 Player::Player() :
 	_midi(NULL),
 	_parser(NULL),
-	_passThrough(0),
 	_parts(NULL),
 	_active(false),
 	_scanning(false),
@@ -93,7 +92,7 @@ Player::~Player() {
 	}
 }
 
-bool Player::startSound(int sound, MidiDriver *midi, bool passThrough) {
+bool Player::startSound(int sound, MidiDriver *midi) {
 	void *ptr;
 	int i;
 
@@ -119,7 +118,6 @@ bool Player::startSound(int sound, MidiDriver *midi, bool passThrough) {
 	_pan = 0;
 	_transpose = 0;
 	_detune = 0;
-	_passThrough = passThrough;
 
 	for (i = 0; i < ARRAYSIZE(_parameterFaders); ++i)
 		_parameterFaders[i].init();
@@ -192,13 +190,6 @@ int Player::start_seq_sound(int sound, bool reset_vars) {
 	if (!memcmp(ptr, "RO", 2)) {
 		// Old style 'RO' resource
 		_parser = MidiParser_createRO();
-	} else if (!memcmp(ptr, "SO", 2)) {
-		// Euphony (FM-TOWNS) resource
-		
-		//////////// REMOVE
-		//_parser = MidiParser_createEUP();
-		///////////
-
 	} else if (!memcmp(ptr, "FORM", 4)) {
 		// Humongous Games XMIDI resource
 		_parser = MidiParser::createParser_XMIDI();
@@ -234,11 +225,6 @@ void Player::setSpeed(byte speed) {
 }
 
 void Player::send(uint32 b) {
-	if (_passThrough) {
-		_midi->send(b);
-		return;
-	}
-
 	byte cmd = (byte)(b & 0xF0);
 	byte chan = (byte)(b & 0x0F);
 	byte param1 = (byte)((b >> 8) & 0xFF);
@@ -355,11 +341,6 @@ void Player::sysEx(const byte *p, uint16 len) {
 	byte buf[128];
 	Part *part;
 
-	if (_passThrough) {
-		_midi->sysEx(p, len);
-		return;
-	}
-
 	// Check SysEx manufacturer.
 	a = *p++;
 	--len;
@@ -1005,10 +986,6 @@ void Player::fixAfterLoad() {
 	}
 }
 
-uint32 Player::getBaseTempo() {
-	return (_midi ? _midi->getBaseTempo() : 0);
-}
-
 void Player::metaEvent(byte type, byte *msg, uint16 len) {
 	if (type == 0x2F)
 		clear();
