@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/imuse/instrument.cpp $
- * $Id: instrument.cpp 49489 2010-06-07 17:18:25Z jvprat $
+ * $URL$
+ * $Id$
  */
 
 
 #include "scumm/scumm.h"
 #include "scumm/saveload.h"
 #include "scumm/imuse/instrument.h"
-#include "sound/mididrv.h"
+#include "audio/mididrv.h"
 
 namespace Scumm {
 
