@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/input.cpp $
- * $Id: input.cpp 49249 2010-05-26 19:54:50Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,7 +28,7 @@
 #include "common/system.h"
 
 #include "gui/message.h"
-#include "gui/GuiManager.h"
+#include "gui/gui-manager.h"
 
 #include "scumm/debugger.h"
 #include "scumm/dialogs.h"
