@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/midiparser_ro.cpp $
- * $Id: midiparser_ro.cpp 30202 2008-01-03 19:43:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 
-#include "sound/midiparser.h"
-#include "sound/mididrv.h"
+#include "audio/midiparser.h"
+#include "audio/mididrv.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
 namespace Scumm {
