@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/nut_renderer.cpp $
- * $Id: nut_renderer.cpp 31927 2008-05-07 14:31:45Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 
@@ -95,7 +95,7 @@ void NutRenderer::loadFont(const char *filename) {
 	}
 
 	uint32 tag = file.readUint32BE();
-	if (tag != MKID_BE('ANIM')) {
+	if (tag != MKTAG('A','N','I','M')) {
 		error("NutRenderer::loadFont() there is no ANIM chunk in font header");
 	}
 
@@ -104,7 +104,7 @@ void NutRenderer::loadFont(const char *filename) {
 	file.read(dataSrc, length);
 	file.close();
 
-	if (READ_BE_UINT32(dataSrc) != MKID_BE('AHDR')) {
+	if (READ_BE_UINT32(dataSrc) != MKTAG('A','H','D','R')) {
 		error("NutRenderer::loadFont() there is no AHDR chunk in font header");
 	}
 
@@ -142,12 +142,12 @@ void NutRenderer::loadFont(const char *filename) {
 	offset = 0;
 	for (l = 0; l < _numChars; l++) {
 		offset += READ_BE_UINT32(dataSrc + offset + 4) + 8;
-		if (READ_BE_UINT32(dataSrc + offset) != MKID_BE('FRME')) {
+		if (READ_BE_UINT32(dataSrc + offset) != MKTAG('F','R','M','E')) {
 			error("NutRenderer::loadFont(%s) there is no FRME chunk %d (offset %x)", filename, l, offset);
 			break;
 		}
 		offset += 8;
-		if (READ_BE_UINT32(dataSrc + offset) != MKID_BE('FOBJ')) {
+		if (READ_BE_UINT32(dataSrc + offset) != MKTAG('F','O','B','J')) {
 			error("NutRenderer::loadFont(%s) there is no FOBJ chunk in FRME chunk %d (offset %x)", filename, l, offset);
 			break;
 		}
