@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/player_nes.h $
- * $Id: player_nes.h 48230 2010-03-10 21:03:50Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,14 +28,14 @@
 
 #include "common/scummsys.h"
 #include "scumm/music.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 namespace Scumm {
 
 class ScummEngine;
 namespace APUe {
-	class APU;
+class APU;
 }
 
 static const int MAXVOLUME = 0x7F;
@@ -75,8 +75,6 @@ private:
 	void APU_writeControl(byte value);
 	byte APU_readStatus();
 
-	void do_mix(int16 *buf, uint len);
-
 	ScummEngine *_vm;
 	Audio::Mixer *_mixer;
 	Audio::SoundHandle _soundHandle;
