@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/resource_v4.cpp $
- * $Id: resource_v4.cpp 44779 2009-10-08 09:33:20Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -33,7 +33,7 @@ namespace Scumm {
 
 extern const char *resTypeFromId(int id);
 
-void ScummEngine_v4::readResTypeList(int id) {
+int ScummEngine_v4::readResTypeList(int id) {
 	int num;
 	int i;
 
@@ -49,6 +49,8 @@ void ScummEngine_v4::readResTypeList(int id) {
 		_res->roomno[id][i] = _fileHandle->readByte();
 		_res->roomoffs[id][i] = _fileHandle->readUint32LE();
 	}
+
+	return num;
 }
 
 void ScummEngine_v4::readIndexFile() {
