@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/script_v6.cpp $
- * $Id: script_v6.cpp 48499 2010-04-04 09:36:10Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -42,9 +42,6 @@
 #include "scumm/util.h"
 #include "scumm/verbs.h"
 
-#include "sound/mididrv.h"
-#include "sound/mixer.h"
-
 namespace Scumm {
 
 #define OPCODE(i, x)	_opcodes[i]._OPCODE(ScummEngine_v6, x)
@@ -381,15 +378,17 @@ ScummEngine_v6::ArrayHeader *ScummEngine_v6::getArray(int array) {
 	if (!ah)
 		return 0;
 
-	// Workaround for a long standing bug where we saved array headers in native
-	// endianness, instead of a fixed endianness. We now always store the
-	// dimensions in little endian byte order. But to stay compatible with older
-	// savegames, we try to detect savegames which were created on a big endian
-	// system and convert them to the proper little endian format on the fly.
-	if ((FROM_LE_16(ah->dim1) & 0xF000) || (FROM_LE_16(ah->dim2) & 0xF000) || (FROM_LE_16(ah->type) & 0xFF00)) {
-		SWAP16(ah->dim1);
-		SWAP16(ah->dim2);
-		SWAP16(ah->type);
+	if (_game.heversion == 0) {
+		// Workaround for a long standing bug where we saved array headers in native
+		// endianness, instead of a fixed endianness. We now always store the
+		// dimensions in little endian byte order. But to stay compatible with older
+		// savegames, we try to detect savegames which were created on a big endian
+		// system and convert them to the proper little endian format on the fly.
+		if ((FROM_LE_16(ah->dim1) & 0xF000) || (FROM_LE_16(ah->dim2) & 0xF000) || (FROM_LE_16(ah->type) & 0xFF00)) {
+			SWAP16(ah->dim1);
+			SWAP16(ah->dim2);
+			SWAP16(ah->type);
+		}
 	}
 
 	return ah;
@@ -536,7 +535,18 @@ void ScummEngine_v6::o6_not() {
 }
 
 void ScummEngine_v6::o6_eq() {
-	push(pop() == pop());
+	int a = pop();
+	int b = pop();
+
+	// WORKAROUND: Forces the game version string set via script 1 to be used in both Macintosh and Windows versions,
+	// when checking for save game compatibility. Allows saved games to be shared between Macintosh and Windows versions.
+	// The scripts check VAR_PLATFORM (b) against the value (2) of the Macintosh platform (a).
+	if (_game.id == GID_BASEBALL2001 && (vm.slot[_currentScript].number == 291 || vm.slot[_currentScript].number == 292) &&
+		a == 2 && b == 1) {
+		push(1);
+	} else {
+		push(a == b);
+	}
 }
 
 void ScummEngine_v6::o6_neq() {
@@ -1218,11 +1228,11 @@ void ScummEngine_v6::o6_animateActor() {
 }
 
 void ScummEngine_v6::o6_doSentence() {
-	int verb, objectA, objectB, dummy = 0;
+	int verb, objectA, objectB;
 
 	objectB = pop();
 	if (_game.version < 8)
-		dummy = pop();	// dummy pop (in Sam&Max, seems to be always 0 or 130)
+		pop();	// dummy pop (in Sam&Max, seems to be always 0 or 130)
 	objectA = pop();
 	verb = pop();
 
@@ -1285,7 +1295,7 @@ void ScummEngine_v6::o6_loadRoomWithEgo() {
 
 void ScummEngine_v6::o6_getRandomNumber() {
 	int rnd;
-	rnd = _rnd.getRandomNumber(pop());
+	rnd = _rnd.getRandomNumber(ABS(pop()));
 	if (VAR_RANDOM_NR != 0xFF)
 		VAR(VAR_RANDOM_NR) = rnd;
 	push(rnd);
@@ -3004,7 +3014,7 @@ void ScummEngine_v6::o6_setBoxSet() {
 
 	ResourceIterator boxds(room, false);
 	for (i = 0; i < arg; i++)
-		boxd = boxds.findNext(MKID_BE('BOXD'));
+		boxd = boxds.findNext(MKTAG('B','O','X','D'));
 
 	if (!boxd)
 		error("ScummEngine_v6::o6_setBoxSet: Can't find dboxes for set %d", arg);
@@ -3017,7 +3027,7 @@ void ScummEngine_v6::o6_setBoxSet() {
 
 	ResourceIterator boxms(room, false);
 	for (i = 0; i < arg; i++)
-		boxm = boxms.findNext(MKID_BE('BOXM'));
+		boxm = boxms.findNext(MKTAG('B','O','X','M'));
 
 	if (!boxm)
 		error("ScummEngine_v6::o6_setBoxSet: Can't find mboxes for set %d", arg);
