@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/scumm_v2.h $
- * $Id: scumm_v2.h 48957 2010-05-05 20:43:22Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -93,7 +93,7 @@ protected:
 	void setStateCommon(byte type);
 	void clearStateCommon(byte type);
 
-	virtual void resetSentence();
+	virtual void resetSentence(bool walking);
 	void setUserState(byte state);
 
 	virtual void handleMouseOver(bool updateInventory);
@@ -103,8 +103,6 @@ protected:
 
 	virtual void setBuiltinCursor(int index);
 
-	virtual void runObject(int obj, int entry);
-
 	/* Version 2 script opcodes */
 	void o2_actorFromPos();
 	void o2_actorOps();
