@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/scumm_v4.h $
- * $Id: scumm_v4.h 40014 2009-04-19 01:01:54Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -59,7 +59,7 @@ protected:
 
 	virtual void scummLoop_handleSaveLoad();
 
-	virtual void readResTypeList(int id);
+	virtual int readResTypeList(int id);
 	virtual void readIndexFile();
 	virtual void loadCharset(int no);
 	virtual void resetRoomObjects();
