@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/smush/codec37.cpp $
- * $Id: codec37.cpp 31929 2008-05-07 15:09:10Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/endian.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 #include "scumm/bomp.h"
 #include "scumm/smush/codec37.h"
