@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/smush/codec47.cpp $
- * $Id: codec47.cpp 35648 2009-01-01 15:06:43Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/endian.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 #include "scumm/bomp.h"
 #include "scumm/smush/codec47.h"
@@ -301,9 +302,11 @@ void Codec47Decoder::makeTables47(int width) {
 	int32 a, c, d;
 	int16 tmp;
 
-	for (int l = 0; l < 512; l += 2) {
+	for (int l = 0; l < ARRAYSIZE(codec47_table); l += 2) {
 		_table[l / 2] = (int16)(codec47_table[l + 1] * width + codec47_table[l]);
 	}
+	// Note: _table[255] is never inited; but since only the first 0xF8
+	// entries of it are used anyway, this doesn't matter.
 
 	a = 0;
 	c = 0;
@@ -340,11 +343,9 @@ void Codec47Decoder::makeTables47(int width) {
 
 #ifdef USE_ARM_SMUSH_ASM
 
-extern "C" {
 #ifndef IPHONE
 #define ARM_Smush_decode2 _ARM_Smush_decode2
 #endif
-}
 
 extern "C" void ARM_Smush_decode2(      byte  *dst,
                                   const byte  *src,
