@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/smush/smush_mixer.h $
- * $Id: smush_mixer.h 47183 2010-01-08 22:10:19Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,8 @@
 #define SCUMM_SMUSH_MIXER_H
 
 
+#include "audio/mixer.h"
+#include "common/mutex.h"
 #include "scumm/sound.h"
 
 namespace Scumm {
