@@ -18,16 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/sound.h $
- * $Id: sound.h 52797 2010-09-18 14:22:22Z Kirben $
+ * $URL$
+ * $Id$
  */
 
 #ifndef SCUMM_SOUND_H
 #define SCUMM_SOUND_H
 
 #include "common/scummsys.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 #include "scumm/saveload.h"
 
 namespace Audio {
