@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/string.cpp $
- * $Id: string.cpp 54666 2010-11-30 07:57:59Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -224,7 +224,7 @@ void ScummEngine_v6::removeBlastTexts() {
 void ScummEngine_v7::processSubtitleQueue() {
 	for (int i = 0; i < _subtitleQueuePos; ++i) {
 		SubtitleText *st = &_subtitleQueue[i];
-		if ((!ConfMan.getBool("subtitles") || VAR(VAR_VOICE_MODE) == 0) && (!st->actorSpeechMsg || _mixer->isSoundHandleActive(_sound->_talkChannelHandle)))
+		if (!st->actorSpeechMsg && (!ConfMan.getBool("subtitles") || VAR(VAR_VOICE_MODE) == 0))
 			// no subtitles and there's a speech variant of the message, don't display the text
 			continue;
 		enqueueText(st->text, st->xpos, st->ypos, st->color, st->charset, false);
@@ -426,6 +426,33 @@ bool ScummEngine_v72he::handleNextCharsetCode(Actor *a, int *code) {
 }
 #endif
 
+bool ScummEngine::newLine() {
+	_nextLeft = _string[0].xpos;
+	if (_charset->_center) {
+		_nextLeft -= _charset->getStringWidth(0, _charsetBuffer + _charsetBufPos) / 2;
+		if (_nextLeft < 0)
+			_nextLeft = _game.version >= 6 ? _string[0].xpos : 0;
+	}
+
+	if (_game.version == 0) {
+		return false;
+	} else if (!(_game.platform == Common::kPlatformFMTowns) && _string[0].height) {
+		_nextTop += _string[0].height;
+	} else {
+		bool useCJK = _useCJKMode;
+		// SCUMM5 FM-Towns doesn't use the height of the ROM font here.
+		if (_game.platform == Common::kPlatformFMTowns && _game.version == 5)
+			_useCJKMode = false;
+		_nextTop += _charset->getFontHeight();
+		_useCJKMode = useCJK;
+	}
+	if (_game.version > 3) {
+		// FIXME: is this really needed?
+		_charset->_disableOffsX = true;
+	}
+	return true;
+}
+
 void ScummEngine::CHARSET_1() {
 	Actor *a;
 #ifdef ENABLE_SCUMM_7_8
@@ -505,6 +532,11 @@ void ScummEngine::CHARSET_1() {
 	if (_game.version >= 5)
 		memcpy(_charsetColorMap, _charsetData[_charset->getCurID()], 4);
 
+#ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
+	if (_keepText && _game.platform == Common::kPlatformFMTowns)
+		memcpy(&_charset->_str, &_curStringRect, sizeof(Common::Rect));
+#endif
+
 	if (_talkDelay)
 		return;
 
@@ -536,7 +568,12 @@ void ScummEngine::CHARSET_1() {
 			_nextTop = _string[0].ypos + _screenTop;
 #endif
 		} else {
-			restoreCharsetBg();
+#ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
+			if (_game.platform == Common::kPlatformFMTowns)
+				towns_restoreCharsetBg();
+			else
+#endif
+				restoreCharsetBg();
 		}
 	}
 
@@ -569,31 +606,14 @@ void ScummEngine::CHARSET_1() {
 		}
 
 		if (c == 13) {
-		newLine:;
-			_nextLeft = _string[0].xpos;
 #ifdef ENABLE_SCUMM_7_8
 			if (_game.version >= 7 && subtitleLine != subtitleBuffer) {
 				((ScummEngine_v7 *)this)->addSubtitleToQueue(subtitleBuffer, subtitlePos, _charsetColor, _charset->getCurID());
 				subtitleLine = subtitleBuffer;
 			}
 #endif
-			if (_charset->_center) {
-				_nextLeft -= _charset->getStringWidth(0, _charsetBuffer + _charsetBufPos) / 2;
-				if (_nextLeft < 0)
-					_nextLeft = _game.version >= 6 ? _string[0].xpos : 0;
-			}
-
-			if (_game.version == 0) {
+			if (!newLine())
 				break;
-			} else if (!(_game.platform == Common::kPlatformFMTowns) && _string[0].height) {
-				_nextTop += _string[0].height;
-			} else {
-				_nextTop += _charset->getFontHeight();
-			}
-			if (_game.version > 3) {
-				// FIXME: is this really needed?
-				_charset->_disableOffsX = true;
-			}
 			continue;
 		}
 
@@ -603,7 +623,8 @@ void ScummEngine::CHARSET_1() {
 		}
 		// Handle line breaks for V1-V2
 		if (_game.version <= 2 && _nextLeft >= _screenWidth) {
-			goto newLine;
+			if (!newLine())
+				break;	// FIXME: Is this necessary? Only would be relevant for v0 games
 		}
 
 		_charset->_left = _nextLeft;
@@ -621,9 +642,7 @@ void ScummEngine::CHARSET_1() {
 #endif
 		} else {
 			if (c & 0x80 && _useCJKMode) {
-				if (_language == Common::JA_JPN && !checkSJISCode(c)) {
-					c = 0x20; //not in S-JIS
-				} else {
+				if (checkSJISCode(c)) {
 					byte *buffer = _charsetBuffer + _charsetBufPos;
 					c += *buffer++ * 256; //LE
 					_charsetBufPos = buffer - _charsetBuffer;
@@ -657,6 +676,11 @@ void ScummEngine::CHARSET_1() {
 		}
 	}
 
+#ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
+	if (_game.platform == Common::kPlatformFMTowns && (c == 0 || c == 2 || c == 3))
+		memcpy(&_curStringRect, &_charset->_str, sizeof(Common::Rect));
+#endif
+
 #ifdef ENABLE_SCUMM_7_8
 	if (_game.version >= 7 && subtitleLine != subtitleBuffer) {
 		((ScummEngine_v7 *)this)->addSubtitleToQueue(subtitleBuffer, subtitlePos, _charsetColor, _charset->getCurID());
@@ -975,11 +999,8 @@ void ScummEngine::drawString(int a, const byte *msg) {
 				}
 			}
 			if (c & 0x80 && _useCJKMode) {
-				if (_language == Common::JA_JPN && !checkSJISCode(c)) {
-					c = 0x20; //not in S-JIS
-				} else {
+				if (checkSJISCode(c))
 					c += buf[i++] * 256;
-				}
 			}
 			_charset->printChar(c, true);
 			_charset->_blitAlso = false;
@@ -1003,6 +1024,7 @@ int ScummEngine::convertMessageToString(const byte *msg, byte *dst, int dstSize)
 	uint num = 0;
 	uint32 val;
 	byte chr;
+	byte lastChr = 0;
 	const byte *src;
 	byte *end;
 	byte transBuf[384];
@@ -1110,11 +1132,12 @@ int ScummEngine::convertMessageToString(const byte *msg, byte *dst, int dstSize)
 		} else if (_game.id == GID_DIG && (chr == 1 || chr == 2 || chr == 3 || chr == 8)) {
 			// Skip these characters
 		} else {
-			if (!(chr == '@') || (_game.id == GID_CMI && _language == Common::ZH_TWN) ||
-				(_game.id == GID_LOOM && _game.platform == Common::kPlatformPCEngine && _language == Common::JA_JPN))
-			{
+			if ((chr != '@') || (_game.id == GID_CMI && _language == Common::ZH_TWN) ||
+				(_game.id == GID_LOOM && _game.platform == Common::kPlatformPCEngine && _language == Common::JA_JPN) ||
+				(_game.platform == Common::kPlatformFMTowns && _language == Common::JA_JPN && checkSJISCode(lastChr))) {
 				*dst++ = chr;
 			}
+			lastChr = chr;
 		}
 
 		// Check for a buffer overflow
