@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/vars.cpp $
- * $Id: vars.cpp 52797 2010-09-18 14:22:22Z Kirben $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -30,7 +30,6 @@
 #include "scumm/scumm_v8.h"
 #include "scumm/he/intern_he.h"
 #include "scumm/he/logic_he.h"
-#include "sound/mididrv.h"
 
 namespace Scumm {
 
@@ -547,7 +546,7 @@ void ScummEngine_v8::setupScummVars() {
 #endif
 
 void ScummEngine_v0::resetScummVars() {
-	resetSentence();
+	resetSentence(false);
 
 	VAR(VAR_EGO) = 3;
 
