@@ -18,15 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/compact.cpp $
- * $Id: compact.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
+#include "common/debug.h"
 #include "common/endian.h"
-#include "common/util.h"
 #include "common/file.h"
+#include "common/textconsole.h"
 #include "sky/compact.h"
 #include "gui/message.h"
 #include <stddef.h>	// for ptrdiff_t
@@ -85,7 +86,7 @@ static const uint32 compactOffsets[] = {
 	MK16(Compact, alt),
 	MK16(Compact, request),
 	MK16(Compact, spWidth_xx),
-	MK16(Compact, spColour),
+	MK16(Compact, spColor),
 	MK16(Compact, spTextId),
 	MK16(Compact, spTime),
 	MK16(Compact, arAnimIndex),
