@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/control.h $
- * $Id: control.h 53020 2010-10-04 22:37:45Z agent-q $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -33,7 +33,7 @@
 
 class OSystem;
 namespace Common {
-	class SaveFileManager;
+class SaveFileManager;
 }
 
 namespace Sky {
@@ -50,14 +50,7 @@ struct Compact;
 struct DataFileHeader;
 struct MegaSet;
 
-#ifdef __DS__
-// Fix out of memory crash on the DS in SkyMetaEngine::listSaves() when saving or loading
-// from GMM.
-#define MAX_SAVE_GAMES 50
-#else
 #define MAX_SAVE_GAMES 999
-#endif
-
 #define MAX_TEXT_LEN 80
 #define PAN_LINE_WIDTH 184
 #define PAN_CHAR_HEIGHT 12
