@@ -18,18 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/disk.cpp $
- * $Id: disk.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
+#include "common/debug.h"
+#include "common/textconsole.h"
 #include "common/endian.h"
 #include "common/file.h"
-#include "common/util.h"
 
 #include "sky/disk.h"
-#include "sky/rnc_deco.h"
 #include "sky/sky.h"
 #include "sky/struc.h"
 
@@ -59,7 +59,7 @@ Disk::Disk() {
 	if (!_dataDiskHandle->isOpen())
 		error("Error opening %s", dataFilename);
 
-	printf("Found BASS version v0.0%d (%d dnr entries)\n", determineGameVersion(), _dinnerTableEntries);
+	debug("Found BASS version v0.0%d (%d dnr entries)", determineGameVersion(), _dinnerTableEntries);
 
 	memset(_buildList, 0, 60 * 2);
 	memset(_loadedFilesList, 0, 60 * 4);
