@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/disk.h $
- * $Id: disk.h 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,13 +28,12 @@
 
 
 #include "common/scummsys.h"
-#include "common/str.h"
 #include "sky/rnc_deco.h"
 
 #define MAX_FILES_IN_LIST 60
 
 namespace Common {
-	class File;
+class File;
 }
 
 namespace Sky {
