@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/intro.cpp $
- * $Id: intro.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,6 +28,7 @@
 #include "common/util.h"
 #include "common/events.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "sky/disk.h"
 #include "sky/intro.h"
@@ -38,8 +39,8 @@
 #include "sky/struc.h"
 #include "sky/text.h"
 
-#include "sound/audiostream.h"
-#include "sound/decoders/raw.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/raw.h"
 
 namespace Sky {
 
@@ -644,8 +645,10 @@ Intro::Intro(Disk *disk, Screen *screen, MusicBase *music, Sound *sound, Text *t
 Intro::~Intro() {
 	if (_skyScreen->sequenceRunning())
 		_skyScreen->stopSequence();
+
 	free(_textBuf);
 	free(_saveBuf);
+	_mixer->stopID(SOUND_BG);
 	free(_bgBuf);
 }
 
@@ -658,6 +661,7 @@ bool Intro::doIntro(bool floppyIntro) {
 
 	if (!escDelay(3000))
 		return false;
+
 	if (floppyIntro)
 		_skyMusic->startMusic(1);
 
@@ -817,6 +821,7 @@ bool Intro::floppyScrollFlirt() {
 
 bool Intro::commandFlirt(uint16 *&data) {
 	_skyScreen->startSequence(*data++);
+
 	while ((*data != COMMANDEND) || _skyScreen->sequenceRunning()) {
 		while ((_skyScreen->seqFramesLeft() < *data)) {
 			data++;
@@ -844,11 +849,13 @@ bool Intro::commandFlirt(uint16 *&data) {
 				error("Unknown FLIRT command %X", command);
 			}
 		}
+
 		if (!escDelay(50)) {
 			_skyScreen->stopSequence();
 			return false;
 		}
 	}
+
 	data++; // move pointer over "COMMANDEND"
 	return true;
 }
@@ -893,6 +900,7 @@ void Intro::restoreScreen() {
 bool Intro::escDelay(uint32 msecs) {
 	Common::EventManager *eventMan = _system->getEventManager();
 	Common::Event event;
+
 	if (_relDelay == 0) // first call, init with system time
 		_relDelay = (int32)_system->getMillis();
 
@@ -911,11 +919,15 @@ bool Intro::escDelay(uint32 msecs) {
 		nDelay = _relDelay - _system->getMillis();
 		if (nDelay < 0)
 			nDelay = 0;
-		else if (nDelay > 40)
-			nDelay = 40;
+		else if (nDelay > 20)
+			nDelay = 20;
+
 		_system->delayMillis(nDelay);
+
+		_skyScreen->processSequence();
 		_system->updateScreen();
-	} while (nDelay == 40);
+	} while (nDelay == 20);
+
 	return true;
 }
 
