@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/music/adlibmusic.cpp $
- * $Id: adlibmusic.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,7 +28,7 @@
 
 #include "sky/music/adlibmusic.h"
 #include "sky/music/adlibchannel.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 #include "sky/sky.h"
 
 namespace Sky {
