@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/music/mt32music.cpp $
- * $Id: mt32music.cpp 52736 2010-09-15 22:00:20Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -28,7 +28,8 @@
 #include "common/util.h"
 #include "common/system.h"
 #include "common/endian.h"
-#include "sound/mididrv.h"
+#include "common/textconsole.h"
+#include "audio/mididrv.h"
 
 namespace Sky {
 
