@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/music/musicbase.cpp $
- * $Id: musicbase.cpp 46941 2010-01-03 19:37:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #include "sky/disk.h"
 #include "common/util.h"
 #include "common/endian.h"
+#include "common/textconsole.h"
 
 namespace Sky {
 
@@ -44,7 +45,7 @@ MusicBase::~MusicBase() {
 }
 
 void MusicBase::loadSection(uint8 pSection) {
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	if (_currentMusic)
 		stopMusicInternal();
 	free(_musicData);
@@ -58,7 +59,6 @@ void MusicBase::loadSection(uint8 pSection) {
 	_numberOfChannels = _currentMusic = 0;
 	setupPointers();
 	startDriver();
-	_mutex.unlock();
 }
 
 bool MusicBase::musicIsPlaying() {
@@ -69,9 +69,8 @@ bool MusicBase::musicIsPlaying() {
 }
 
 void MusicBase::stopMusic() {
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	stopMusicInternal();
-	_mutex.unlock();
 }
 
 void MusicBase::stopMusicInternal() {
@@ -113,7 +112,7 @@ void MusicBase::loadNewMusic() {
 }
 
 void MusicBase::pollMusic() {
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	uint8 newTempo;
 	if (_onNextPoll.musicToProcess != _currentMusic)
 		loadNewMusic();
@@ -127,7 +126,6 @@ void MusicBase::pollMusic() {
 			updateTempo();
 		}
 	}
-	_mutex.unlock();
 	_aktTime &= 0xFFFF;
 }
 
