@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/sky.h $
- * $Id: sky.h 46128 2009-11-24 22:10:14Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,7 +27,8 @@
 #define SKY_H
 
 
-#include "common/events.h"
+#include "common/error.h"
+#include "common/keyboard.h"
 #include "engines/engine.h"
 
 /**
@@ -35,8 +36,8 @@
  *
  * Status of this engine: ???
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Beneath a Steel Sky
  */
 namespace Sky {
 
@@ -52,7 +53,6 @@ struct SystemVars {
 	bool paused;
 };
 
-struct Compact;
 class Sound;
 class Disk;
 class Text;
@@ -84,6 +84,8 @@ public:
 	SkyEngine(OSystem *syst);
 	virtual ~SkyEngine();
 
+	virtual void syncSoundSettings();
+
 	static bool isDemo();
 	static bool isCDVersion();
 
@@ -104,7 +106,7 @@ protected:
 	virtual Common::Error run() {
 		Common::Error err;
 		err = init();
-		if (err != Common::kNoError)
+		if (err.getCode() != Common::kNoError)
 			return err;
 		return go();
 	}
@@ -121,8 +123,6 @@ protected:
 	void initItemList();
 
 	void initVirgin();
-	static void timerHandler(void *ptr);
-	void gotTimerTick();
 	void loadFixedItems();
 };
 
