@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/struc.h $
- * $Id: struc.h 39147 2009-03-06 00:41:46Z joostp $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -37,9 +37,9 @@ struct DisplayedText {
 #include "common/pack-start.h"	// START STRUCT PACKING
 
 struct DataFileHeader {
-	uint16 flag; // bit 0: set for colour data, clear for not
+	uint16 flag; // bit 0: set for color data, clear for not
 	// bit 1: set for compressed, clear for uncompressed
-	// bit 2: set for 32 colours, clear for 16 colours
+	// bit 2: set for 32 colors, clear for 16 colors
 	uint16 s_x;
 	uint16 s_y;
 	uint16 s_width;
@@ -139,7 +139,7 @@ struct Compact {
 	uint16 request;		 // 42
 
 	uint16 spWidth_xx;	 // 43
-	uint16 spColour;	 // 44
+	uint16 spColor;	 // 44
 	uint16 spTextId;	 // 45
 	uint16 spTime;		 // 46
 
