@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/text.cpp $
- * $Id: text.cpp 46941 2010-01-03 19:37:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 
+#include "common/debug.h"
 #include "common/endian.h"
+#include "common/textconsole.h"
 
 #include "sky/disk.h"
 #include "sky/logic.h"
@@ -231,13 +233,13 @@ char Text::getTextChar(uint8 **data, uint32 *bitPos) {
 	}
 }
 
-DisplayedText Text::displayText(uint32 textNum, uint8 *dest, bool centre, uint16 pixelWidth, uint8 color) {
+DisplayedText Text::displayText(uint32 textNum, uint8 *dest, bool center, uint16 pixelWidth, uint8 color) {
 	//Render text into buffer *dest
 	getText(textNum);
-	return displayText(_textBuffer, dest, centre, pixelWidth, color);
+	return displayText(_textBuffer, dest, center, pixelWidth, color);
 }
 
-DisplayedText Text::displayText(char *textPtr, uint8 *dest, bool centre, uint16 pixelWidth, uint8 color) {
+DisplayedText Text::displayText(char *textPtr, uint8 *dest, bool center, uint16 pixelWidth, uint8 color) {
 	//Render text pointed to by *textPtr in buffer *dest
 	uint32 centerTable[10];
 	uint16 lineWidth = 0;
@@ -319,7 +321,7 @@ DisplayedText Text::displayText(char *textPtr, uint8 *dest, bool centre, uint16
 	uint32 *centerTblPtr = centerTable;
 
 	do {
-		if (centre) {
+		if (center) {
 			uint32 width = (pixelWidth - *centerTblPtr) >> 1;
 			centerTblPtr++;
 			curDest += width;
@@ -379,9 +381,9 @@ void Text::makeGameCharacter(uint8 textChar, uint8 *charSetPtr, uint8 *&dest, ui
 	dest = startPos + charWidth + _dtCharSpacing * 2 - 1;
 }
 
-DisplayedText Text::lowTextManager(uint32 textNum, uint16 width, uint16 logicNum, uint8 color, bool centre) {
+DisplayedText Text::lowTextManager(uint32 textNum, uint16 width, uint16 logicNum, uint8 color, bool center) {
 	getText(textNum);
-	DisplayedText textInfo = displayText(_textBuffer, NULL, centre, width, color);
+	DisplayedText textInfo = displayText(_textBuffer, NULL, center, width, color);
 
 	uint32 compactNum = FIRST_TEXT_COMPACT;
 	Compact *cpt = _skyCompact->fetchCpt(compactNum);
@@ -405,7 +407,7 @@ DisplayedText Text::lowTextManager(uint32 textNum, uint16 width, uint16 logicNum
 	return textInfo;
 }
 
-void Text::changeTextSpriteColour(uint8 *sprData, uint8 newCol) {
+void Text::changeTextSpriteColor(uint8 *sprData, uint8 newCol) {
 	DataFileHeader *header = (DataFileHeader *)sprData;
 	sprData += sizeof(DataFileHeader);
 	for (uint16 cnt = 0; cnt < header->s_sp_size; cnt++)
