@@ -18,21 +18,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/animation.h $
- * $Id: animation.h 49154 2010-05-23 11:16:10Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 #ifndef SWORD1_ANIMATION_H
 #define SWORD1_ANIMATION_H
 
-#include "graphics/video/dxa_decoder.h"
-#include "graphics/video/smk_decoder.h"
-#include "graphics/video/video_decoder.h"
+#include "video/dxa_decoder.h"
+#include "video/smk_decoder.h"
+#include "video/video_decoder.h"
 
 #include "common/array.h"
 
-#include "sound/audiostream.h"
+#include "audio/audiostream.h"
 
 #include "sword1/screen.h"
 #include "sword1/sound.h"
@@ -59,7 +59,7 @@ public:
 	}
 };
 
-class DXADecoderWithSound : public Graphics::DXADecoder {
+class DXADecoderWithSound : public Video::DXADecoder {
 public:
 	DXADecoderWithSound(Audio::Mixer *mixer, Audio::SoundHandle *bgSoundHandle);
 	~DXADecoderWithSound() {}
@@ -73,7 +73,7 @@ private:
 
 class MoviePlayer {
 public:
-	MoviePlayer(SwordEngine *vm, Text *textMan, Audio::Mixer *snd, OSystem *system, Audio::SoundHandle *bgSoundHandle, Graphics::VideoDecoder *decoder, DecoderType decoderType);
+	MoviePlayer(SwordEngine *vm, Text *textMan, Audio::Mixer *snd, OSystem *system, Audio::SoundHandle *bgSoundHandle, Video::VideoDecoder *decoder, DecoderType decoderType);
 	virtual ~MoviePlayer();
 	bool load(uint32 id);
 	void play();
@@ -88,7 +88,7 @@ protected:
 	byte _white, _black;
 	DecoderType _decoderType;
 
-	Graphics::VideoDecoder *_decoder;
+	Video::VideoDecoder *_decoder;
 	Audio::SoundHandle *_bgSoundHandle;
 	Audio::AudioStream *_bgSoundStream;
 
