@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/control.cpp $
- * $Id: control.cpp 51668 2010-08-02 22:28:30Z lordhoto $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,7 +29,9 @@
 #include "common/events.h"
 #include "common/system.h"
 #include "common/config-manager.h"
+#include "common/textconsole.h"
 
+#include "graphics/palette.h"
 #include "graphics/thumbnail.h"
 #include "gui/message.h"
 
@@ -122,7 +124,7 @@ ControlButton::ControlButton(uint16 x, uint16 y, uint32 resId, uint8 id, uint8 f
 	_width = (_width > SCREEN_WIDTH) ? SCREEN_WIDTH : _width;
 	_height = _resMan->getUint16(tmp->height);
 	if ((x == 0) && (y == 0)) { // center the frame (used for panels);
-		_x = (((640 - _width) / 2) < 0)? 0 : ((640 - _width) / 2) ;
+		_x = (((640 - _width) / 2) < 0)? 0 : ((640 - _width) / 2);
 		_y = (((480 - _height) / 2) < 0)? 0 : ((480 - _height) / 2);
 	}
 	_dstBuf = screenBuf + _y * SCREEN_WIDTH + _x;
@@ -248,15 +250,15 @@ void Control::askForCd() {
 		fontId = CZECH_SR_FONT;
 	_font = (uint8*)_resMan->openFetchRes(fontId);
 	uint8 *pal = (uint8*)_resMan->openFetchRes(SR_PALETTE);
-	uint8 *palOut = (uint8*)malloc(256 * 4);
+	uint8 *palOut = (uint8*)malloc(256 * 3);
 	for (uint16 cnt = 1; cnt < 256; cnt++) {
-		palOut[cnt * 4 + 0] = pal[cnt * 3 + 0] << 2;
-		palOut[cnt * 4 + 1] = pal[cnt * 3 + 1] << 2;
-		palOut[cnt * 4 + 2] = pal[cnt * 3 + 2] << 2;
+		palOut[cnt * 3 + 0] = pal[cnt * 3 + 0] << 2;
+		palOut[cnt * 3 + 1] = pal[cnt * 3 + 1] << 2;
+		palOut[cnt * 3 + 2] = pal[cnt * 3 + 2] << 2;
 	}
-	palOut[0] = palOut[1] = palOut[2] = palOut[3] = 0;
+	palOut[0] = palOut[1] = palOut[2] = 0;
 	_resMan->resClose(SR_PALETTE);
-	_system->setPalette(palOut, 0, 256);
+	_system->getPaletteManager()->setPalette(palOut, 0, 256);
 	free(palOut);
 
 	char fName[10];
@@ -318,15 +320,15 @@ uint8 Control::runPanel() {
 	_redFont = (uint8*)_resMan->openFetchRes(redFontId);
 
 	uint8 *pal = (uint8*)_resMan->openFetchRes(SR_PALETTE);
-	uint8 *palOut = (uint8*)malloc(256 * 4);
+	uint8 *palOut = (uint8*)malloc(256 * 3);
 	for (uint16 cnt = 1; cnt < 256; cnt++) {
-		palOut[cnt * 4 + 0] = pal[cnt * 3 + 0] << 2;
-		palOut[cnt * 4 + 1] = pal[cnt * 3 + 1] << 2;
-		palOut[cnt * 4 + 2] = pal[cnt * 3 + 2] << 2;
+		palOut[cnt * 3 + 0] = pal[cnt * 3 + 0] << 2;
+		palOut[cnt * 3 + 1] = pal[cnt * 3 + 1] << 2;
+		palOut[cnt * 3 + 2] = pal[cnt * 3 + 2] << 2;
 	}
-	palOut[0] = palOut[1] = palOut[2] = palOut[3] = 0;
+	palOut[0] = palOut[1] = palOut[2] = 0;
 	_resMan->resClose(SR_PALETTE);
-	_system->setPalette(palOut, 0, 256);
+	_system->getPaletteManager()->setPalette(palOut, 0, 256);
 	free(palOut);
 	uint8 mode = 0, newMode = BUTTON_MAIN_PANEL;
 	bool fullRefresh = false;
@@ -1118,8 +1120,7 @@ void Control::saveGameToFile(uint8 slot) {
 	outf->writeUint32BE(saveDate);
 	outf->writeUint16BE(saveTime);
 
-	uint32 currentTime = _system->getMillis() / 1000;
-	outf->writeUint32BE(currentTime - SwordEngine::_systemVars.engineStartTime);
+	outf->writeUint32BE(g_engine->getTotalPlayTime() / 1000);
 
 	_objMan->saveLiveList(liveBuf);
 	for (cnt = 0; cnt < TOTAL_SECTIONS; cnt++)
@@ -1181,10 +1182,9 @@ bool Control::restoreGameFromFile(uint8 slot) {
 	inf->readUint16BE();	// save time
 
 	if (saveVersion < 2) { // Before version 2 we didn't had play time feature
-		SwordEngine::_systemVars.engineStartTime =	_system->getMillis() / 1000; // Start counting
+		g_engine->setTotalPlayTime(0);
 	} else {
-		uint32 currentTime = _system->getMillis() / 1000;
-		SwordEngine::_systemVars.engineStartTime = currentTime - inf->readUint32BE(); // Engine start time
+		g_engine->setTotalPlayTime(inf->readUint32BE() * 1000);
 	}
 
 	_restoreBuf = (uint8*)malloc(
