@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/control.h $
- * $Id: control.h 48282 2010-03-18 15:09:24Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -33,7 +33,7 @@
 
 class OSystem;
 namespace Common {
-	class SaveFileManager;
+class SaveFileManager;
 }
 
 namespace Sword1 {
@@ -44,7 +44,7 @@ class Mouse;
 class Music;
 class Sound;
 
-#define SAVEGAME_HEADER MKID_BE('BS_1')
+#define SAVEGAME_HEADER MKTAG('B','S','_','1')
 #define SAVEGAME_VERSION 2
 
 #define MAX_BUTTONS 16
