@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/detection.cpp $
- * $Id: detection.cpp 48287 2010-03-18 15:54:40Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,12 +27,11 @@
 #include "sword1/control.h"
 
 #include "base/plugins.h"
-#include "common/config-manager.h"
-#include "common/file.h"
 #include "common/fs.h"
 #include "common/savefile.h"
 #include "common/system.h"
 #include "graphics/thumbnail.h"
+#include "graphics/surface.h"
 
 #include "engines/metaengine.h"
 
@@ -309,12 +308,9 @@ SaveStateDescriptor SwordMetaEngine::querySaveMetaInfos(const char *target, int
 		desc.setSaveTime(hour, minutes);
 
 		if (versionSave > 1) {
-			minutes = playTime / 60;
-			hour = minutes / 60;
-			minutes %= 60;
-			desc.setPlayTime(hour, minutes);
+			desc.setPlayTime(playTime * 1000);
 		} else { //We have no playtime data
-			desc.setPlayTime(0, 0);
+			desc.setPlayTime(0);
 		}
 
 		delete in;
