@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/eventman.cpp $
- * $Id: eventman.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "sword1/eventman.h"
 #include "sword1/sworddefs.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
 namespace Sword1 {
