@@ -18,16 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/logic.cpp $
- * $Id: logic.cpp 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
 #include "common/endian.h"
 #include "common/util.h"
-#include "common/system.h"
-#include "common/events.h"
 #include "common/EventRecorder.h"
+#include "common/textconsole.h"
 
 #include "sword1/logic.h"
 #include "sword1/text.h"
@@ -1017,7 +1016,7 @@ int Logic::fnNewScript(Object *cpt, int32 id, int32 script, int32 d, int32 e, in
 int Logic::fnSubScript(Object *cpt, int32 id, int32 script, int32 d, int32 e, int32 f, int32 z, int32 x) {
 	cpt->o_tree.o_script_level++;
 	if (cpt->o_tree.o_script_level == TOTAL_script_levels)
-		error("Compact %d: script level exceeded in fnSubScript.", id);
+		error("Compact %d: script level exceeded in fnSubScript", id);
 	cpt->o_tree.o_script_pc[cpt->o_tree.o_script_level] = script;
 	cpt->o_tree.o_script_id[cpt->o_tree.o_script_level] = script;
 	return SCRIPT_STOP;
@@ -1605,7 +1604,7 @@ int Logic::fnStopMusic(Object *cpt, int32 id, int32 a, int32 b, int32 c, int32 d
 }
 
 int Logic::fnInnerSpace(Object *cpt, int32 id, int32 a, int32 b, int32 c, int32 d, int32 z, int32 x) {
-	error("fnInnerSpace() not working.");
+	error("fnInnerSpace() not working");
 	return SCRIPT_STOP;	// for compilers that don't support NORETURN
 }
 
