@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/mouse.h $
- * $Id: mouse.h 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,6 +27,7 @@
 #define SWORD1_MOUSE_H
 
 #include "common/scummsys.h"
+#include "common/rect.h"
 #include "sword1/sworddefs.h"
 #include "sword1/object.h"
 
@@ -99,8 +100,9 @@ private:
 	ObjectMan *_objMan;
 	Common::Point _mouse;
 
-	uint32 _currentPtrId, _currentLuggageId, _frame;
+	uint32 _currentPtrId, _currentLuggageId;
 	MousePtr *_currentPtr;
+	int _frame, _activeFrame;
 	uint16 _numObjs;
 	uint16 _lastState, _state;
 	uint32 _getOff;
