@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/music.h $
- * $Id: music.h 38956 2009-02-28 10:46:33Z sev $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -29,9 +29,9 @@
 #include "common/scummsys.h"
 #include "common/mutex.h"
 #include "common/file.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
-#include "sound/rate.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/rate.h"
 
 namespace Sword1 {
 
