@@ -18,25 +18,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/resman.cpp $
- * $Id: resman.cpp 46941 2010-01-03 19:37:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 
-#include "common/config-manager.h"
-#include "common/util.h"
-#include "common/str.h"
-
-#include "engines/engine.h"
+#include "common/debug.h"
+#include "common/textconsole.h"
 
 #include "sword1/memman.h"
 #include "sword1/resman.h"
-#include "sword1/sworddefs.h"
 #include "sword1/swordres.h"
 
 #include "gui/message.h"
-#include "gui/GuiManager.h"
 
 namespace Sword1 {
 	void guiFatalError(char *msg) {
@@ -332,10 +327,13 @@ Common::File *ResMan::resFile(uint32 id) {
 			Clu *closeClu = _openCluStart;
 			_openCluStart = _openCluStart->nextOpen;
 
-			closeClu->file->close();
-			delete closeClu->file;
-			closeClu->file = NULL;
-			closeClu->nextOpen = NULL;
+			if (closeClu) {
+				if (closeClu->file)
+					closeClu->file->close();
+				delete closeClu->file;
+				closeClu->file = NULL;
+				closeClu->nextOpen = NULL;
+			}
 			_openClus--;
 		}
 	}
