@@ -18,15 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/screen.cpp $
- * $Id: screen.cpp 46941 2010-01-03 19:37:43Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  */
 
 
 #include "common/system.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
+#include "graphics/palette.h"
+
 #include "sword1/screen.h"
 #include "sword1/logic.h"
 #include "sword1/sworddefs.h"
@@ -55,6 +58,8 @@ Screen::Screen(OSystem *system, ResMan *pResMan, ObjectMan *pObjMan) {
 	_updatePalette = false;
 	_psxCache.decodedBackground = NULL;
 	_psxCache.extPlxCache = NULL;
+	_oldScrollX = 0;
+	_oldScrollY = 0;
 }
 
 Screen::~Screen() {
@@ -142,24 +147,24 @@ void Screen::fnSetPalette(uint8 start, uint16 length, uint32 id, bool fadeUp) {
 	}
 
 	for (uint32 cnt = 0; cnt < length; cnt++) {
-		_targetPalette[(start + cnt) * 4 + 0] = palData[cnt * 3 + 0] << 2;
-		_targetPalette[(start + cnt) * 4 + 1] = palData[cnt * 3 + 1] << 2;
-		_targetPalette[(start + cnt) * 4 + 2] = palData[cnt * 3 + 2] << 2;
+		_targetPalette[(start + cnt) * 3 + 0] = palData[cnt * 3 + 0] << 2;
+		_targetPalette[(start + cnt) * 3 + 1] = palData[cnt * 3 + 1] << 2;
+		_targetPalette[(start + cnt) * 3 + 2] = palData[cnt * 3 + 2] << 2;
 	}
 	_resMan->resClose(id);
 	_isBlack = false;
 	if (fadeUp) {
 		_fadingStep = 1;
 		_fadingDirection = FADE_UP;
-		memset(_currentPalette, 0, 256 * 4);
-		_system->setPalette(_currentPalette, 0, 256);
+		memset(_currentPalette, 0, 256 * 3);
+		_system->getPaletteManager()->setPalette(_currentPalette, 0, 256);
 	} else
-		_system->setPalette(_targetPalette + 4 * start, start, length);
+		_system->getPaletteManager()->setPalette(_targetPalette + 3 * start, start, length);
 }
 
 void Screen::fullRefresh() {
 	_fullRefresh = true;
-	_system->setPalette(_targetPalette, 0, 256);
+	_system->getPaletteManager()->setPalette(_targetPalette, 0, 256);
 }
 
 bool Screen::stillFading() {
@@ -195,7 +200,7 @@ void Screen::updateScreen() {
 	}
 	if (_fadingStep) {
 		fadePalette();
-		_system->setPalette(_currentPalette, 0, 256);
+		_system->getPaletteManager()->setPalette(_currentPalette, 0, 256);
 	}
 
 	uint16 scrlX = (uint16)Logic::_scriptVars[SCROLL_OFFSET_X];
@@ -366,7 +371,7 @@ void Screen::draw() {
 
 	if (_currentScreen == 54) {
 		// rm54 has a BACKGROUND parallax layer in parallax[0]
-		if (_parallax[0] && !SwordEngine::isPsx() ) //Avoid drawing this parallax on PSX edition, it gets occluded by background
+		if (_parallax[0] && !SwordEngine::isPsx()) //Avoid drawing this parallax on PSX edition, it gets occluded by background
 			renderParallax(_parallax[0]);
 		uint8 *src = _layerBlocks[0];
 		uint8 *dest = _screenBuf;
@@ -539,7 +544,7 @@ void Screen::processImage(uint32 id) {
 		|| (compact->o_resource == LVSFLY) || (!(compact->o_resource == GEORGE_MEGA) && (sprSizeX < 260))))
 			drawSprite(sprData + incr, spriteX, spriteY, sprSizeX, sprSizeY, sprPitch);
 		else if (((sprSizeX >= 260) && (sprSizeX < 450)) || ((compact->o_resource == GMWRITH) && (sprSizeX < 515))  // a psx shrinked sprite (1/2 width)
-				|| ((compact->o_resource == GMPOWER) && (sprSizeX < 515)) )                                         // some needs to be hardcoded, headers don't give useful infos
+				|| ((compact->o_resource == GMPOWER) && (sprSizeX < 515)))                                         // some needs to be hardcoded, headers don't give useful infos
 			drawPsxHalfShrinkedSprite(sprData + incr, spriteX, spriteY, sprSizeX / 2, sprSizeY, sprPitch / 2);
 		else if (sprSizeX >= 450) // A PSX double shrinked sprite (1/3 width)
 			drawPsxFullShrinkedSprite(sprData + incr, spriteX, spriteY, sprSizeX / 3, sprSizeY, sprPitch / 3);
@@ -758,7 +763,7 @@ void Screen::drawPsxFullShrinkedSprite(uint8 *sprData, uint16 sprX, uint16 sprY,
 	uint8 *dest = _screenBuf + (sprY * _scrnSizeX) + sprX;
 
 	for (uint16 cnty = 0; cnty < sprHeight; cnty++) {
-		for (uint16 cntx = 0; cntx < sprWidth ; cntx++)
+		for (uint16 cntx = 0; cntx < sprWidth; cntx++)
 			if (sprData[cntx]) {
 				dest[cntx * 3] = sprData[cntx]; //In these sprites we need to double vertical lines too...
 				dest[cntx * 3 + 1] = sprData[cntx];
@@ -886,8 +891,8 @@ uint8* Screen::psxBackgroundToIndexed(uint8 *psxBackground, uint32 bakXres, uint
 
 // needed because some psx backgrounds are half width and half height
 uint8* Screen::psxShrinkedBackgroundToIndexed(uint8 *psxBackground, uint32 bakXres, uint32 bakYres) {
-	uint32 xresInTiles = (bakXres / 2) % 16 ? (bakXres / 32) + 1 : (bakXres / 32);
-	uint32 yresInTiles =  (bakYres / 2) % 16 ? (bakYres / 32) + 1 : (bakYres / 32);
+	uint32 xresInTiles = ((bakXres / 2) % 16) ? (bakXres / 32) + 1 : (bakXres / 32);
+	uint32 yresInTiles = ((bakYres / 2) % 16) ? (bakYres / 32) + 1 : (bakYres / 32);
 	uint32 totTiles = xresInTiles * yresInTiles;
 	uint32 tileYpos = 0; //tile position in a virtual xresInTiles * yresInTiles grid
 	uint32 tileXpos = 0;
@@ -897,7 +902,7 @@ uint8* Screen::psxShrinkedBackgroundToIndexed(uint8 *psxBackground, uint32 bakXr
 	uint8 *fullres_buffer = (uint8 *)malloc(bakXres * (yresInTiles + 1) * 32);
 	memset(fullres_buffer, 0, bakXres * (yresInTiles + 1) * 32);
 
-	bool isCompressed = (READ_LE_UINT32(psxBackground) == MKID_BE('COMP'));
+	bool isCompressed = (READ_LE_UINT32(psxBackground) == MKTAG('C','O','M','P'));
 
 	totTiles -= xresInTiles;
 	psxBackground += 4; //We skip the id tag
@@ -1123,11 +1128,11 @@ void Screen::flushPsxCache() {
 
 void Screen::fadePalette() {
 	if (_fadingStep == 16)
-		memcpy(_currentPalette, _targetPalette, 256 * 4);
+		memcpy(_currentPalette, _targetPalette, 256 * 3);
 	else if ((_fadingStep == 1) && (_fadingDirection == FADE_DOWN)) {
-		memset(_currentPalette, 0, 4 * 256);
+		memset(_currentPalette, 0, 3 * 256);
 	} else
-		for (uint16 cnt = 0; cnt < 256 * 4; cnt++)
+		for (uint16 cnt = 0; cnt < 256 * 3; cnt++)
 			_currentPalette[cnt] = (_targetPalette[cnt] * _fadingStep) >> 4;
 
 	_fadingStep += _fadingDirection;
@@ -1187,7 +1192,7 @@ void Screen::spriteClipAndSet(uint16 *pSprX, uint16 *pSprY, uint16 *pSprWidth, u
 			gridW *= 2; // and masking problems when sprites are stretched in width
 
 			uint16 bottomSprPos = (*pSprY + (*pSprHeight) * 2); //Position of bottom line of sprite
-			if ( bottomSprPos > _scrnSizeY ) { //Check that resized psx sprite isn't drawn outside of screen boundaries
+			if (bottomSprPos > _scrnSizeY) { //Check that resized psx sprite isn't drawn outside of screen boundaries
 				uint16 outScreen = bottomSprPos - _scrnSizeY;
 				*pSprHeight -= (outScreen % 2) ? (outScreen + 1) / 2 : outScreen / 2;
 			}
