@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/sound.cpp $
- * $Id: sound.cpp 48637 2010-04-12 09:14:17Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,22 +27,22 @@
 #include "common/endian.h"
 
 #include "common/util.h"
-#include "common/events.h"
 #include "common/EventRecorder.h"
-#include "common/system.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 #include "sword1/sound.h"
 #include "sword1/resman.h"
 #include "sword1/logic.h"
 #include "sword1/sword1.h"
 
-#include "sound/audiostream.h"
-#include "sound/decoders/flac.h"
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/wave.h"
-#include "sound/decoders/vag.h"
+#include "audio/audiostream.h"
+#include "audio/decoders/flac.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/wave.h"
+#include "audio/decoders/vag.h"
 
 namespace Sword1 {
 
@@ -129,7 +129,7 @@ void Sound::checkSpeechFileEndianness() {
 			else
 				size /= 2;
 			int16 prev_be_value = (int16)SWAP_BYTES_16(*((uint16*)(data)));
-			for (uint32 i = 1 ; i < size ; ++i) {
+			for (uint32 i = 1; i < size; ++i) {
 				le_diff_sum += fabs((double)(data[i] - data[i-1]));
 				int16 be_value = (int16)SWAP_BYTES_16(*((uint16*)(data + i)));
 				be_diff_sum += fabs((double)(be_value - prev_be_value));
@@ -208,7 +208,7 @@ void Sound::fnStopFx(int32 fxNo) {
 			if (cnt != _endOfQueue-1)
 				_fxQueue[cnt] = _fxQueue[_endOfQueue-1];
 			_endOfQueue--;
-			return ;
+			return;
 		}
 	debug(8, "fnStopFx: id not found in queue");
 }
@@ -366,7 +366,7 @@ bool Sound::startSpeech(uint16 roomNo, uint16 localNo) {
 			}
 		} else if (_cowMode == CowPSX && sampleSize != 0xffffffff) {
 			_cowFile.seek(index * 2048);
-			Common::MemoryReadStream *tmp = _cowFile.readStream(sampleSize);
+			Common::SeekableReadStream *tmp = _cowFile.readStream(sampleSize);
 			assert(tmp);
 			stream = Audio::makeVagStream(tmp);
 			_mixer->playStream(Audio::Mixer::kSpeechSoundType, &_speechHandle, stream, SOUND_SPEECH_ID, speechVol, speechPan);
@@ -379,7 +379,7 @@ bool Sound::startSpeech(uint16 roomNo, uint16 localNo) {
 #ifdef USE_FLAC
 		else if (_cowMode == CowFLAC) {
 			_cowFile.seek(index);
-			Common::MemoryReadStream *tmp = _cowFile.readStream(sampleSize);
+			Common::SeekableReadStream *tmp = _cowFile.readStream(sampleSize);
 			assert(tmp);
 			stream = Audio::makeFLACStream(tmp, DisposeAfterUse::YES);
 			_mixer->playStream(Audio::Mixer::kSpeechSoundType, &_speechHandle, stream, SOUND_SPEECH_ID, speechVol, speechPan);
@@ -393,7 +393,7 @@ bool Sound::startSpeech(uint16 roomNo, uint16 localNo) {
 #ifdef USE_VORBIS
 		else if (_cowMode == CowVorbis) {
 			_cowFile.seek(index);
-			Common::MemoryReadStream *tmp = _cowFile.readStream(sampleSize);
+			Common::SeekableReadStream *tmp = _cowFile.readStream(sampleSize);
 			assert(tmp);
 			stream = Audio::makeVorbisStream(tmp, DisposeAfterUse::YES);
 			_mixer->playStream(Audio::Mixer::kSpeechSoundType, &_speechHandle, stream, SOUND_SPEECH_ID, speechVol, speechPan);
@@ -407,7 +407,7 @@ bool Sound::startSpeech(uint16 roomNo, uint16 localNo) {
 #ifdef USE_MAD
 		else if (_cowMode == CowMP3) {
 			_cowFile.seek(index);
-			Common::MemoryReadStream *tmp = _cowFile.readStream(sampleSize);
+			Common::SeekableReadStream *tmp = _cowFile.readStream(sampleSize);
 			assert(tmp);
 			stream = Audio::makeMP3Stream(tmp, DisposeAfterUse::YES);
 			_mixer->playStream(Audio::Mixer::kSpeechSoundType, &_speechHandle, stream, SOUND_SPEECH_ID, speechVol, speechPan);
@@ -535,7 +535,7 @@ void Sound::calcWaveVolume(int16 *data, uint32 length) {
 	_waveVolPos = 0;
 	for (uint32 blkCnt = 1; blkCnt < length / 918; blkCnt++) {
 		if (blkCnt >= WAVE_VOL_TAB_LENGTH) {
-			warning("Wave vol tab too small.");
+			warning("Wave vol tab too small");
 			return;
 		}
 		int32 average = 0;
