@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/sword1.h $
- * $Id: sword1.h 46128 2009-11-24 22:10:14Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -27,17 +27,20 @@
 #define SWORD1_H
 
 #include "engines/engine.h"
-#include "common/events.h"
+#include "common/error.h"
+#include "common/keyboard.h"
+#include "common/rect.h"
 #include "common/util.h"
 #include "sword1/sworddefs.h"
+#include "sword1/console.h"
 
 /**
  * This is the namespace of the Sword1 engine.
  *
  * Status of this engine: ???
  *
- * Supported games:
- * - ???
+ * Games using this engine:
+ * - Broken Sword: The Shadow of the Templars
  */
 namespace Sword1 {
 
@@ -74,7 +77,6 @@ struct SystemVars {
 	uint8	showText;
 	uint8	language;
 	bool    isDemo;
-	uint32	engineStartTime;    // Used for playtime
 	Common::Platform platform;
 };
 
@@ -100,13 +102,15 @@ protected:
 	virtual Common::Error run() {
 		Common::Error err;
 		err = init();
-		if (err != Common::kNoError)
+		if (err.getCode() != Common::kNoError)
 			return err;
 		return go();
 	}
 	virtual bool hasFeature(EngineFeature f) const;
 	virtual void syncSoundSettings();
 
+	GUI::Debugger *getDebugger() { return _console; }
+
 	Common::Error loadGameState(int slot);
 	bool canLoadGameStateCurrently();
 	Common::Error saveGameState(int slot, const char *desc);
@@ -122,6 +126,8 @@ private:
 
 	void reinitRes(); //Reinits the resources after a GMM load
 
+	SwordConsole *_console;
+
 	uint8 mainLoop();
 
 	Common::Point _mouseCoord;
