@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/debug.cpp $
- * $Id: debug.cpp 30667 2008-01-28 00:14:17Z jvprat $
+ * $URL$
+ * $Id$
  */
 
 
@@ -120,15 +120,6 @@ void Debugger::buildDebugText() {
 		makeDebugTextBlock(buf, 0, 105);
 	}
 
-#ifdef SWORD2_DEBUG
-	// speed-up indicator
-
-	if (_vm->_renderSkip) {		// see sword2.cpp
-		sprintf(buf, "SKIPPING FRAMES FOR SPEED-UP!");
-		makeDebugTextBlock(buf, 0, 120);
-	}
-#endif
-
 	// debug info at top of screen - enabled/disabled as one complete unit
 
 	if (_displayTime) {
