@@ -21,13 +21,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/interpreter.cpp $
- * $Id: interpreter.cpp 48961 2010-05-06 19:00:39Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 
 #include "common/util.h"
 #include "common/stack.h"
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/header.h"
@@ -147,7 +148,7 @@ void Logic::setupOpcodes() {
 		OPCODE(fnSetScrollLeftMouse),
 		OPCODE(fnSetScrollRightMouse),
 		/* 4C */
-		OPCODE(fnColour),
+		OPCODE(fnColor),
 		OPCODE(fnFlash),
 		OPCODE(fnPreFetch),
 		OPCODE(fnGetPlayerSaveData),
