@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/layers.cpp $
- * $Id: layers.cpp 40867 2009-05-24 15:17:42Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 // high level layer initialising
@@ -35,6 +35,7 @@
 
 
 #include "common/rect.h"
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -166,7 +167,7 @@ void Screen::initBackground(int32 res, int32 new_palette) {
 		spriteInfo.type = 0;
 		spriteInfo.blend = 0;
 		spriteInfo.data = _vm->fetchShadingMask(file);
-		spriteInfo.colourTable = 0;
+		spriteInfo.colorTable = 0;
 
 		if (openLightMask(&spriteInfo) != RD_OK)
 			error("Could not open light mask");
