@@ -21,11 +21,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/logic.cpp $
- * $Id: logic.cpp 45284 2009-10-20 19:51:32Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -277,16 +278,6 @@ void Logic::resetKillList() {
 	_kills = 0;
 }
 
-/**
- * Pause or unpause the currently playing cutscene movie, if any.
- * @param pause		true if pausing, false if unpausing
- */
-
-void Logic::pauseMovie(bool pause) {
-	if (_moviePlayer)
-		_moviePlayer->pauseMovie(pause);
-}
-
 /**
  * Read current location number from script vars
  */
