@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/music.cpp $
- * $Id: music.cpp 50923 2010-07-16 03:07:30Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 // One feature still missing is the original's DipMusic() function which, as
@@ -33,14 +33,17 @@
 
 
 #include "common/file.h"
+#include "common/memstream.h"
+#include "common/substream.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/flac.h"
-#include "sound/decoders/wave.h"
-#include "sound/decoders/vag.h"
-#include "sound/rate.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/flac.h"
+#include "audio/decoders/wave.h"
+#include "audio/decoders/vag.h"
+#include "audio/rate.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -496,9 +499,16 @@ int Sound::readBuffer(int16 *buffer, const int numSamples) {
 	memset(buffer, 0, 2 * numSamples);
 
 	if (!_mixBuffer || numSamples > _mixBufferLen) {
-		if (_mixBuffer)
-			_mixBuffer = (int16 *)realloc(_mixBuffer, 2 * numSamples);
-		else
+		if (_mixBuffer) {
+			int16 *newBuffer = (int16 *)realloc(_mixBuffer, 2 * numSamples);
+			if (newBuffer) {
+				_mixBuffer = newBuffer;
+			} else {
+				// We can't use the old buffer any more. It's too small.
+				free(_mixBuffer);
+				_mixBuffer = 0;
+			}
+		} else
 			_mixBuffer = (int16 *)malloc(2 * numSamples);
 
 		_mixBufferLen = numSamples;
