@@ -21,13 +21,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/resman.cpp $
- * $Id: resman.cpp 46951 2010-01-03 21:20:05Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 
 #include "common/file.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -302,6 +303,8 @@ byte *ResourceManager::openResource(uint32 res, bool dump) {
 			readCluIndex(cluFileNum, file);
 		}
 
+		assert(_resFiles[cluFileNum].entryTab);
+
 		uint32 pos = _resFiles[cluFileNum].entryTab[actual_res * 2 + 0];
 		uint32 len = _resFiles[cluFileNum].entryTab[actual_res * 2 + 1];
 
@@ -474,15 +477,18 @@ void ResourceManager::readCluIndex(uint16 fileNum, Common::File *file) {
 	file->seek(table_offset);
 
 	assert((tableSize % 8) == 0);
-	_resFiles[fileNum].entryTab = (uint32*)malloc(tableSize);
+	_resFiles[fileNum].entryTab = (uint32 *)malloc(tableSize);
 	_resFiles[fileNum].numEntries = tableSize / 8;
+
+	assert(_resFiles[fileNum].entryTab);
+
 	file->read(_resFiles[fileNum].entryTab, tableSize);
 	if (file->eos() || file->err())
 		error("unable to read index table from file %s", _resFiles[fileNum].fileName);
 
 #ifdef SCUMM_BIG_ENDIAN
 	for (int tabCnt = 0; tabCnt < _resFiles[fileNum].numEntries * 2; tabCnt++)
-	  _resFiles[fileNum].entryTab[tabCnt] = FROM_LE_32(_resFiles[fileNum].entryTab[tabCnt]);
+		_resFiles[fileNum].entryTab[tabCnt] = FROM_LE_32(_resFiles[fileNum].entryTab[tabCnt]);
 #endif
 }
 
