@@ -21,12 +21,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/router.cpp $
- * $Id: router.cpp 45282 2009-10-20 19:12:31Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 
-#include "common/stream.h"
+#include "common/memstream.h"
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -2344,9 +2345,9 @@ void Router::plotWalkGrid() {
 		plotCross(_node[i].x, _node[i].y, 184);
 }
 
-void Router::plotCross(int16 x, int16 y, uint8 colour) {
-	_vm->_screen->drawLine(x - 1, y - 1, x + 1, y + 1, colour);
-	_vm->_screen->drawLine(x + 1, y - 1, x - 1, y + 1, colour);
+void Router::plotCross(int16 x, int16 y, uint8 color) {
+	_vm->_screen->drawLine(x - 1, y - 1, x + 1, y + 1, color);
+	_vm->_screen->drawLine(x + 1, y - 1, x - 1, y + 1, color);
 }
 
 void Router::loadWalkGrid() {
