@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/router.h $
- * $Id: router.h 45282 2009-10-20 19:12:31Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #ifndef SWORD2_ROUTER_H
@@ -193,7 +193,7 @@ private:
 	int32 solidWalkAnimator(WalkData *walkAnim);
 #endif
 
-	void plotCross(int16 x, int16 y, uint8 colour);
+	void plotCross(int16 x, int16 y, uint8 color);
 
 public:
 	Router(Sword2Engine *vm) : _vm(vm), _diagonalx(0), _diagonaly(0) {
