@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/screen.h $
- * $Id: screen.h 48692 2010-04-17 17:23:30Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 #ifndef	SWORD2_SCREEN_H
@@ -172,7 +172,7 @@ struct SpriteInfo {
 	uint16 type;		// mask containing 'RDSPR_' bits specifying compression type, flip, transparency, etc
 	uint16 blend;		// holds the blending values.
 	byte *data;		// pointer to the sprite data
-	byte *colourTable;	// pointer to 16-byte colour table, only applicable to 16-col compression type
+	byte *colorTable;	// pointer to 16-byte color table, only applicable to 16-col compression type
 	bool isText;		// It is a engine-generated sprite containing text
 };
 
@@ -192,19 +192,8 @@ struct Parallax {
 		return 4;
 	}
 
-	void read(byte *addr) {
-		Common::MemoryReadStream readS(addr, size());
-
-		w = readS.readUint16LE();
-		h = readS.readUint16LE();
-	}
-
-	void write(byte *addr) {
-		Common::MemoryWriteStream writeS(addr, size());
-
-		writeS.writeUint16LE(w);
-		writeS.writeUint16LE(h);
-	}
+	void read(byte *addr);
+	void write(byte *addr);
 };
 
 class Screen {
@@ -253,7 +242,7 @@ private:
 	uint16 _gridWide;
 	uint16 _gridDeep;
 
-	byte _palette[256 * 4];
+	byte _palette[256 * 3];
 	byte _paletteMatch[PALTABLESIZE];
 
 	uint8 _fadeStatus;
@@ -453,8 +442,8 @@ public:
 
 	void buildDisplay();
 
-	void plotPoint(int x, int y, uint8 colour);
-	void drawLine(int x0, int y0, int x1, int y1, uint8 colour);
+	void plotPoint(int x, int y, uint8 color);
+	void drawLine(int x0, int y0, int x1, int y1, uint8 color);
 
 	void rollCredits();
 	void splashScreen();
