@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/sound.cpp $
- * $Id: sound.cpp 49036 2010-05-15 08:38:19Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 // ---------------------------------------------------------------------------
@@ -37,7 +37,9 @@
 
 
 #include "common/file.h"
+#include "common/memstream.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 #include "sword2/sword2.h"
 #include "sword2/defs.h"
@@ -47,8 +49,8 @@
 #include "sword2/resman.h"
 #include "sword2/sound.h"
 
-#include "sound/decoders/wave.h"
-#include "sound/decoders/vag.h"
+#include "audio/decoders/wave.h"
+#include "audio/decoders/vag.h"
 
 #define Debug_Printf _vm->_debugger->DebugPrintf
 
@@ -393,18 +395,6 @@ int32 Sound::stopFx(int32 i) {
 	return RD_OK;
 }
 
-void Sound::pauseAllSound() {
-	pauseMusic();
-	pauseSpeech();
-	pauseFx();
-}
-
-void Sound::unpauseAllSound() {
-	unpauseMusic();
-	unpauseSpeech();
-	unpauseFx();
-}
-
 void Sound::printFxQueue() {
 	int freeSlots = 0;
 
