@@ -21,8 +21,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword2/sound.h $
- * $Id: sound.h 48458 2010-04-01 16:11:29Z eriktorbjorn $
+ * $URL$
+ * $Id$
  */
 
 /*****************************************************************************
@@ -39,8 +39,9 @@
 #define SWORD2_SOUND_H
 
 #include "common/file.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "common/mutex.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 // Max number of sound fx
 #define MAXMUS 2
@@ -262,9 +263,6 @@ public:
 	void pauseMusic();
 	void unpauseMusic();
 
-	void pauseAllSound();
-	void unpauseAllSound();
-
 	void playMovieSound(int32 res, int type);
 	void stopMovieSounds();
 
