@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/font.h $
- * $Id: font.h 48292 2010-03-18 22:35:58Z megath $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_FONT_H
 #define TEENAGENT_FONT_H
 
+#include "common/str.h"
 #include "graphics/surface.h"
 
 namespace TeenAgent {
