@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/inventory.cpp $
- * $Id: inventory.cpp 48933 2010-05-04 11:56:52Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
-#include "common/stream.h"
+#include "common/memstream.h"
 #include "common/ptr.h"
+#include "common/textconsole.h"
 
 #include "teenagent/inventory.h"
 #include "teenagent/resources.h"
@@ -33,7 +34,7 @@
 
 namespace TeenAgent {
 
-void Inventory::init(TeenAgentEngine *engine) {
+Inventory::Inventory(TeenAgentEngine *engine) {
 	_engine = engine;
 	_active = false;
 
@@ -86,6 +87,10 @@ void Inventory::init(TeenAgentEngine *engine) {
 	hovered_obj = selected_obj = NULL;
 }
 
+Inventory::~Inventory() {
+	delete[] items;
+}
+
 bool Inventory::has(byte item) const {
 	for (int i = 0; i < 24; ++i) {
 		if (inventory[i] == item)
