@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/inventory.h $
- * $Id: inventory.h 48350 2010-03-21 07:49:53Z megath $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_INVENTORY_H
@@ -38,7 +38,9 @@ class TeenAgentEngine;
 
 class Inventory {
 public:
-	void init(TeenAgentEngine *engine);
+	Inventory(TeenAgentEngine *engine);
+	~Inventory();
+
 	void render(Graphics::Surface *surface, int delta);
 
 	void clear();
