@@ -18,12 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/objects.cpp $
- * $Id: objects.cpp 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 #include "common/debug.h"
-#include "common/stream.h"
+#include "common/memstream.h"
 #include "teenagent/objects.h"
 #include "teenagent/resources.h"
 
