@@ -18,13 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/pack.cpp $
- * $Id: pack.cpp 48831 2010-04-28 19:50:28Z megath $
+ * $URL$
+ * $Id$
  */
 
 #include "teenagent/pack.h"
 #include "common/util.h"
 #include "common/debug.h"
+#include "common/memstream.h"
+#include "common/substream.h"
 
 namespace TeenAgent {
 
