@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/resources.cpp $
- * $Id: resources.cpp 48962 2010-05-07 07:56:57Z megath $
+ * $URL$
+ * $Id$
  */
 
 #include "teenagent/resources.h"
 #include "teenagent/teenagent.h"
+#include "common/textconsole.h"
 #include "common/zlib.h"
 
 namespace TeenAgent {
@@ -63,19 +64,20 @@ quick note on varia resources:
 */
 
 bool Resources::loadArchives(const ADGameDescription *gd) {
-	Common::File dat_file;
-	if (!dat_file.open("teenagent.dat")) {
+	Common::File *dat_file = new Common::File();
+	if (!dat_file->open("teenagent.dat")) {
+		delete dat_file;
 		Common::String errorMessage = "You're missing the 'teenagent.dat' file. Get it from the ScummVM website";
 		GUIErrorMessage(errorMessage);
 		warning("%s", errorMessage.c_str());
 		return false;
 	}
-	Common::SeekableReadStream *dat = Common::wrapCompressedReadStream(&dat_file);
+	Common::SeekableReadStream *dat = Common::wrapCompressedReadStream(dat_file);
 	cseg.read(dat, 0xb3b0);
 	dseg.read(dat, 0xe790);
 	eseg.read(dat, 0x8be2);
 
-	dat_file.close();
+	delete dat;
 
 	{
 		FilePack varia;
