@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/scene.h $
- * $Id: scene.h 48349 2010-03-21 07:38:09Z megath $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_SCENE_H
@@ -35,6 +35,10 @@
 #include "common/array.h"
 #include "common/list.h"
 
+namespace Common {
+struct Event;
+}
+
 namespace TeenAgent {
 
 class TeenAgentEngine;
@@ -125,11 +129,11 @@ struct SceneEvent {
 
 class Scene {
 public:
+	Scene(TeenAgentEngine *engine, OSystem *system);
+	~Scene();
+
 	bool intro;
 
-	Scene();
-
-	void init(TeenAgentEngine *engine, OSystem *system);
 	void init(int id, const Common::Point &pos);
 	bool render(bool tick_game, bool tick_mark, uint32 message_delta);
 	int getId() const { return _id; }
