@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/surface.cpp $
- * $Id: surface.cpp 48694 2010-04-17 23:19:52Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #include "teenagent/surface.h"
@@ -32,6 +32,10 @@ namespace TeenAgent {
 Surface::Surface() : x(0), y(0) {
 }
 
+Surface::~Surface() {
+	free();
+}
+
 void Surface::load(Common::SeekableReadStream *stream, Type type) {
 	//debug(0, "load()");
 	free();
