@@ -18,15 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/surface.h $
- * $Id: surface.h 45962 2009-11-17 22:09:16Z megath $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_SURFACE_H
 #define TEENAGENT_SURFACE_H
 
+#include "common/rect.h"
 #include "graphics/surface.h"
-#include "common/stream.h"
+
+namespace Common {
+   class SeekableReadStream;
+}
 
 namespace TeenAgent {
 
@@ -38,6 +42,7 @@ public:
 	uint16 x, y;
 
 	Surface();
+	~Surface();
 	void load(Common::SeekableReadStream *stream, Type type);
 	Common::Rect render(Graphics::Surface *surface, int dx = 0, int dy = 0, bool mirror = false, Common::Rect src_rect = Common::Rect(), uint zoom = 256) const;
 
