@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/surface_list.cpp $
- * $Id: surface_list.cpp 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 #include "teenagent/surface.h"
@@ -30,6 +30,10 @@ namespace TeenAgent {
 
 SurfaceList::SurfaceList() : surfaces(NULL), surfaces_n(0) {}
 
+SurfaceList::~SurfaceList() {
+	free();
+}
+
 void SurfaceList::load(Common::SeekableReadStream *stream, Type type, int sub_hack) {
 	free();
 
