@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/surface_list.h $
- * $Id: surface_list.h 47541 2010-01-25 01:39:44Z lordhoto $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_SURFACE_LIST_H__
@@ -35,6 +35,7 @@ public:
 	enum Type { kTypeOn };
 
 	SurfaceList();
+	~SurfaceList();
 	void load(Common::SeekableReadStream *stream, Type type, int sub_hack = 0);
 	void free();
 	void render(Graphics::Surface *surface, const Common::Rect & clip) const;
