@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/teenagent.cpp $
- * $Id: teenagent.cpp 50963 2010-07-17 18:38:42Z fingolfin $
+ * $URL$
+ * $Id$
  */
 
 #include "common/config-manager.h"
@@ -27,15 +27,18 @@
 #include "common/events.h"
 #include "common/savefile.h"
 #include "common/system.h"
+#include "common/textconsole.h"
+
+#include "backends/audiocd/audiocd.h"
 
 #include "engines/advancedDetector.h"
 #include "engines/util.h"
 
-#include "sound/audiocd.h"
-#include "sound/mixer.h"
-#include "sound/decoders/raw.h"
+#include "audio/mixer.h"
+#include "audio/decoders/raw.h"
 
 #include "graphics/cursorman.h"
+#include "graphics/palette.h"
 #include "graphics/thumbnail.h"
 
 #include "teenagent/console.h"
@@ -49,6 +52,14 @@ namespace TeenAgent {
 
 TeenAgentEngine::TeenAgentEngine(OSystem *system, const ADGameDescription *gd) : Engine(system), action(kActionNone), _gameDescription(gd) {
 	music = new MusicPlayer();
+
+	console = 0;
+}
+
+TeenAgentEngine::~TeenAgentEngine() {
+	delete music;
+
+	delete console;
 }
 
 bool TeenAgentEngine::trySelectedObject() {
@@ -197,9 +208,9 @@ void TeenAgentEngine::deinit() {
 Common::Error TeenAgentEngine::loadGameState(int slot) {
 	debug(0, "loading from slot %d", slot);
 	Common::ScopedPtr<Common::InSaveFile> 
-		in(_saveFileMan->openForLoading(Common::String::printf("teenagent.%02d", slot)));
+		in(_saveFileMan->openForLoading(Common::String::format("teenagent.%02d", slot)));
 	if (!in)
-		in.reset(_saveFileMan->openForLoading(Common::String::printf("teenagent.%d", slot)));
+		in.reset(_saveFileMan->openForLoading(Common::String::format("teenagent.%d", slot)));
 
 	if (!in)
 		return Common::kReadPermissionDenied;
@@ -232,7 +243,7 @@ Common::Error TeenAgentEngine::loadGameState(int slot) {
 
 Common::Error TeenAgentEngine::saveGameState(int slot, const char *desc) {
 	debug(0, "saving to slot %d", slot);
-	Common::ScopedPtr<Common::OutSaveFile> out(_saveFileMan->openForSaving(Common::String::printf("teenagent.%02d", slot)));
+	Common::ScopedPtr<Common::OutSaveFile> out(_saveFileMan->openForSaving(Common::String::format("teenagent.%02d", slot)));
 	if (!out)
 		return Common::kWritingFailed;
 
@@ -268,7 +279,8 @@ int TeenAgentEngine::skipEvents() const {
 		case Common::EVENT_KEYDOWN:
 		if (event.kbd.ascii)
 			return 1;
-		default: ;
+		default:
+			break;
 		}
 	}
 	return 0;
@@ -280,19 +292,13 @@ bool TeenAgentEngine::showCDLogo() {
 		return true;
 
 	byte bg[0xfa00];
-	byte palette[0x400];
+	byte palette[3*256];
 
 	cdlogo.read(bg, sizeof(bg));
-	memset(palette, 0, sizeof(palette));
-
-	for(uint c = 0; c < 0x100; ++c) {
-		uint idx = c * 4;
-		cdlogo.read(palette + idx, 3);
-		palette[idx] *= 4;
-		palette[idx + 1] *= 4;
-		palette[idx + 2] *= 4;
-	}
-	_system->setPalette(palette, 0, 0x100);
+	cdlogo.read(palette, sizeof(palette));
+	for (uint c = 0; c < 3*256; ++c)
+		palette[c] *= 4;
+	_system->getPaletteManager()->setPalette(palette, 0, 0x100);
 	_system->copyRectToScreen(bg, 320, 0, 0, 320, 200);
 	_system->updateScreen();
 
@@ -313,23 +319,17 @@ bool TeenAgentEngine::showLogo() {
 		return true;
 
 	byte bg[0xfa00];
-	byte palette[0x400];
+	byte palette[3*256];
 
 	Common::ScopedPtr<Common::SeekableReadStream> frame(logo.getStream(1));
 	if (!frame)
 		return true;
 
 	frame->read(bg, sizeof(bg));
-	memset(palette, 0, sizeof(palette));
-
-	for(uint c = 0; c < 0x100; ++c) {
-		uint idx = c * 4;
-		frame->read(palette + idx, 3);
-		palette[idx] *= 4;
-		palette[idx + 1] *= 4;
-		palette[idx + 2] *= 4;
-	}
-	_system->setPalette(palette, 0, 0x100);
+	frame->read(palette, sizeof(palette));
+	for (uint c = 0; c < 3*256; ++c)
+		palette[c] *= 4;
+	_system->getPaletteManager()->setPalette(palette, 0, 0x100);
 
 	uint n = logo.fileCount();
 	for(uint f = 0; f < 4; ++f)
@@ -365,19 +365,15 @@ bool TeenAgentEngine::showMetropolis() {
 	FilePack varia;
 	varia.open("varia.res");
 
-	byte palette[0x400];
-	memset(palette, 0, sizeof(palette));
+	byte palette[3*256];
 	{
 		Common::ScopedPtr<Common::SeekableReadStream> s(varia.getStream(5));
-		for(uint c = 0; c < 0x400; c += 4) {
-			s->read(palette + c, 3);
+		s->read(palette, sizeof(palette));
+		for (uint c = 0; c < 3*256; ++c)
 			palette[c] *= 4;
-			palette[c + 1] *= 4;
-			palette[c + 2] *= 4;
-		}
 	}
 
-	_system->setPalette(palette, 0, 0x100);
+	_system->getPaletteManager()->setPalette(palette, 0, 0x100);
 
 	byte varia_6[21760], varia_9[18302];
 	varia.read(6, varia_6, sizeof(varia_6));
@@ -457,13 +453,10 @@ Common::Error TeenAgentEngine::run() {
 	Common::EventManager *_event = _system->getEventManager();
 
 	initGraphics(320, 200, false);
-
-	scene = new Scene;
-	inventory = new Inventory;
 	console = new Console(this);
 
-	scene->init(this, _system);
-	inventory->init(this);
+	scene = new Scene(this, _system);
+	inventory = new Inventory(this);
 
 	init();
 
@@ -983,7 +976,7 @@ void TeenAgentEngine::setMusic(byte id) {
 		}
 		byte track = track2cd[id - 1];
 		debug(0, "playing cd track %u", track);
-		Audio::AudioCDManager::instance().play(track, -1, 0, 0);
+		_system->getAudioCDManager()->play(track, -1, 0, 0);
 	} else if (music->load(id))
 		music->start();
 }
