@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/teenagent.h $
- * $Id: teenagent.h 48831 2010-04-28 19:50:28Z megath $
+ * $URL$
+ * $Id$
  */
 
 #ifndef TEENAGENT_ENGINE_H
@@ -29,8 +29,8 @@
 #include "teenagent/pack.h"
 #include "teenagent/resources.h"
 #include "teenagent/inventory.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 #include "common/random.h"
 
 struct ADGameDescription;
@@ -40,7 +40,7 @@ struct ADGameDescription;
  *
  * Status of this engine: Complete
  *
- * Supported games:
+ * Games using this engine:
  * - Teen Agent
  */
 namespace TeenAgent {
@@ -55,6 +55,7 @@ public:
 	enum Action { kActionNone, kActionExamine, kActionUse };
 
 	TeenAgentEngine(OSystem *system, const ADGameDescription *gd);
+	~TeenAgentEngine();
 
 	virtual Common::Error run();
 	virtual Common::Error loadGameState(int slot);
