@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/background.h $
- * $Id: background.h 45616 2009-11-02 21:54:57Z fingolfin $
+ * $URL$
+ * $Id$
  *
  * Data structures used for handling backgrounds
  */
@@ -60,7 +60,7 @@ struct PLAYFIELD {
 
 /** multi-playfield background structure - a backgnd is a container of playfields */
 struct BACKGND {
-	COLORREF rgbSkyColour;	///< background sky colour
+	COLORREF rgbSkyColor;	///< background sky color
 	Common::Point ptInitWorld;		///< initial world position
 	Common::Rect rcScrollLimits;	///< scroll limits
 	int refreshRate;		///< background update process refresh rate
@@ -77,7 +77,7 @@ struct BACKGND {
 \*----------------------------------------------------------------------*/
 
 void InitBackground(		// called to initialise a background
-	BACKGND *pBgnd);	// pointer to data struct for current background
+	const BACKGND *pBgnd);	// pointer to data struct for current background
 
 void StartupBackground(CORO_PARAM, SCNHANDLE hFilm);
 
@@ -93,7 +93,7 @@ void PlayfieldGetPos(		// Returns the xy position of the specified playfield in
 	int *pXpos,		// returns current x position
 	int *pYpos);		// returns current y position
 
-int PlayfieldGetCentreX(	// Returns the xy position of the specified playfield in the current background
+int PlayfieldGetCenterX(	// Returns the xy position of the specified playfield in the current background
 	int which);		// which playfield
 
 OBJECT *GetPlayfieldList(	// Returns the display list for the specified playfield
@@ -110,8 +110,6 @@ OBJECT *GetBgObject();
 
 SCNHANDLE BgPal();
 
-void ForceEntireRedraw();
-
 int BgWidth();
 
 int BgHeight();
