@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/bmv.cpp $
- * $Id: bmv.cpp 50924 2010-07-16 03:14:03Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  * The movie player.
  */
@@ -42,7 +42,9 @@
 #include "tinsel/tinlib.h"
 #include "tinsel/tinsel.h"
 
-#include "sound/decoders/raw.h"
+#include "audio/decoders/raw.h"
+
+#include "common/textconsole.h"
 
 namespace Tinsel {
 
@@ -66,13 +68,7 @@ namespace Tinsel {
 
 #define PREFETCH	(NUM_SLOTS/2)	// For initial test
 
-#ifndef _Windows
-//#define ADVANCE_SOUND		12	// 1 second
-#define ADVANCE_SOUND		18	// 1 1/2 second
-//#define MAX_ADVANCE_SOUND	36	// 3 seconds
-#else
 #define ADVANCE_SOUND		18	// 1 1/2 seconds
-#endif
 #define SUBSEQUENT_SOUND	6	// 1/2 second
 
 
@@ -87,7 +83,7 @@ namespace Tinsel {
 #define BIT0		0x01
 
 #define CD_XSCR		0x04	// Screen has a scroll offset
-#define CD_CMAP	0x08	// Colour map is included
+#define CD_CMAP	0x08	// Color map is included
 #define CD_CMND	0x10	// Command is included
 #define CD_AUDIO	0x20	// Audio data is included
 #define CD_EXTEND	0x40	// Extended modes "A"-"z"
@@ -356,7 +352,7 @@ BMVPlayer::BMVPlayer() {
 
 	memset(texts, 0, sizeof(texts));
 
-	talkColour = 0;
+	talkColor = 0;
 	bigProblemCount = 0;
 	bIsText = 0;
 	movieTick = 0;
@@ -388,8 +384,8 @@ void BMVPlayer::MoviePalette(int paletteOffset) {
 	UpdateDACqueue(1, 255, &moviePal[1]);
 
 	// Don't clobber talk
-	if (talkColour != 0)
-		SetTextPal(talkColour);
+	if (talkColor != 0)
+		SetTextPal(talkColor);
 }
 
 void BMVPlayer::InitialiseMovieSound() {
@@ -496,7 +492,7 @@ void BMVPlayer::BmvDrawText(bool bDraw) {
 |-------------------------------------------------------|
 \*-----------------------------------------------------*/
 
-void BMVPlayer::MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, COLORREF *pTalkColour, int duration) {
+void BMVPlayer::MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, COLORREF *pTalkColor, int duration) {
 	SCNHANDLE hFont;
 	int	index;
 
@@ -508,8 +504,8 @@ void BMVPlayer::MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, CO
 	} else {
 		// It's a 'talk'
 
-		if (pTalkColour != NULL)
-			SetTextPal(*pTalkColour);
+		if (pTalkColor != NULL)
+			SetTextPal(*pTalkColor);
 		hFont = GetTalkFontHandle();
 		index = 1;
 	}
@@ -520,12 +516,12 @@ void BMVPlayer::MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, CO
 	LoadSubString(stringId, 0, TextBufferAddr(), TBUFSZ);
 
 	texts[index].dieFrame = currentFrame + duration;
-	texts[index].pText = ObjectTextOut(coroParam, GetPlayfieldList(FIELD_STATUS),
+	texts[index].pText = ObjectTextOut(GetPlayfieldList(FIELD_STATUS),
 						TextBufferAddr(),
 						0,
 						x, y,
 						hFont,
-						TXT_CENTRE, 0);
+						TXT_CENTER, 0);
 	KeepOnScreen(texts[index].pText, &x, &y);
 }
 
@@ -547,13 +543,13 @@ int BMVPlayer::MovieCommand(char cmd, int commandOffset) {
 	} else {
 		if (_vm->_config->_useSubtitles) {
 			TALK_CMD *pCmd = (TALK_CMD *)(bigBuffer + commandOffset);
-			talkColour = TINSEL_RGB(pCmd->r, pCmd->g, pCmd->b);
+			talkColor = TINSEL_RGB(pCmd->r, pCmd->g, pCmd->b);
 
 			MovieText(nullContext, (int16)READ_LE_UINT16(&pCmd->stringId),
 					(int16)READ_LE_UINT16(&pCmd->x),
 					(int16)READ_LE_UINT16(&pCmd->y),
 					0,
-					&talkColour,
+					&talkColor,
 					pCmd->duration);
 		}
 		return sz_CMD_TALK_pkt;
@@ -699,7 +695,7 @@ void BMVPlayer::InitialiseBMV() {
 	bFileEnd = false;
 	blobsInBuffer = 0;
 	memset(texts, 0, sizeof(texts));
-	talkColour = 0;
+	talkColor = 0;
 	bigProblemCount = 0;
 
 	movieTick = 0;
@@ -1031,7 +1027,6 @@ bool BMVPlayer::DoSoundFrame() {
 void BMVPlayer::CopyMovieToScreen() {
 	// Not if not up and running yet!
 	if (!screenBuffer || (currentFrame == 0)) {
-		ForceEntireRedraw();
 		DrawBackgnd();
 		return;
 	}
@@ -1051,20 +1046,6 @@ void BMVPlayer::CopyMovieToScreen() {
 	BmvDrawText(false);
 }
 
-/**
- * LookAtBuffers
- */
-void BMVPlayer::LookAtBuffers() {
-	// FIXME: What's the point of this function???
-	static int junk;
-	int i;
-
-	if (bigBuffer) {
-		for (i = 0; i < NUM_SLOTS; i++)
-			junk += bigBuffer[i*SLOT_SIZE];
-	}
-}
-
 /**
  * Handles playback of any active movie. Called from the foreground 24 times a second.
  */
@@ -1083,8 +1064,6 @@ void BMVPlayer::FettleBMV() {
 		return;
 	}
 
-	LookAtBuffers();
-
 	if (!stream.isOpen()) {
 		int i;
 
