@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/bmv.h $
- * $Id: bmv.h 47179 2010-01-08 22:06:04Z fingolfin $
+ * $URL$
+ * $Id$
  *
  * Plays films within a scene, takes into account the actor in each 'column'.
  */
@@ -29,8 +29,8 @@
 
 #include "common/file.h"
 
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 #include "tinsel/coroutine.h"
 #include "tinsel/object.h"
@@ -96,7 +96,7 @@ class BMVPlayer {
 		int	dieFrame;
 	} texts[2];
 
-	COLORREF talkColour;
+	COLORREF talkColor;
 
 	int bigProblemCount;
 
@@ -143,7 +143,7 @@ private:
 	void MovieAudio(int audioOffset, int blobs);
 	void FettleMovieText();
 	void BmvDrawText(bool bDraw);
-	void MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, COLORREF *pTalkColour, int duration);
+	void MovieText(CORO_PARAM, int stringId, int x, int y, int fontId, COLORREF *pTalkColor, int duration);
 	int MovieCommand(char cmd, int commandOffset);
 	int FollowingPacket(int thisPacket, bool bReallyImportant);
 	void LoadSlots(int number);
@@ -151,7 +151,6 @@ private:
 	bool MaintainBuffer();
 	bool DoBMVFrame();
 	bool DoSoundFrame();
-	void LookAtBuffers();
 };
 
 
