@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/dw.h $
- * $Id: dw.h 44634 2009-10-04 21:26:33Z fingolfin $
+ * $URL$
+ * $Id$
  *
  */
 
@@ -42,8 +42,6 @@ typedef int HPOLYGON;
 #define	LF_CHAR			'\x0a'		// line feed
 
 // file names
-#define	SAMPLE_FILE		"english.smp"	// all samples
-#define	SAMPLE_INDEX		"english.idx"	// sample index filename
 #define	MIDI_FILE		"midi.dat"	// all MIDI sequences
 #define	INDEX_FILENAME		"index"		// name of index file
 #define PSX_INDEX_FILENAME	"index.dat" // name of index file in psx version
