@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/handle.cpp $
- * $Id: handle.cpp 50924 2010-07-16 03:14:03Z eriktorbjorn $
+ * $URL$
+ * $Id$
  *
  * This file contains the handle based Memory Manager code
  */
@@ -27,6 +27,7 @@
 #define BODGE
 
 #include "common/file.h"
+#include "common/textconsole.h"
 
 #include "tinsel/drives.h"
 #include "tinsel/dw.h"
@@ -65,11 +66,11 @@ enum {
 	fLoaded		= 0x20000000L	///< set when file data has been loaded
 };
 #define	FSIZE_MASK	0x00FFFFFFL	///< mask to isolate the filesize
-#define	MALLOC_MASK	0xFF000000L	///< mask to isolate the memory allocation flags
-//#define	HANDLEMASK		0xFF800000L	///< get handle of address
 
 //----------------- LOCAL GLOBAL DATA --------------------
 
+// FIXME: Avoid non-const global vars
+
 // handle table gets loaded from index file at runtime
 static MEMHANDLE *handleTable = 0;
 
@@ -78,7 +79,7 @@ static uint numHandles = 0;
 
 static uint32 cdPlayHandle = (uint32)-1;
 
-static int	cdPlayFileNum, cdPlaySceneNum;
+static int cdPlaySceneNum;
 static SCNHANDLE cdBaseHandle = 0, cdTopHandle = 0;
 static Common::File *cdGraphStream = 0;
 
@@ -100,7 +101,7 @@ void SetupHandleTable() {
 	int len;
 	uint i;
 	MEMHANDLE *pH;
-	Common::File f;
+	TinselFile f;
 
 	if (f.open(TinselV1PSX? PSX_INDEX_FILENAME : INDEX_FILENAME)) {
 		// get size of index file
@@ -124,13 +125,13 @@ void SetupHandleTable() {
 			// load data
 			for (i = 0; i < numHandles; i++) {
 				f.read(handleTable[i].szName, 12);
-				handleTable[i].filesize = f.readUint32LE();
+				handleTable[i].filesize = f.readUint32();
 				// The pointer should always be NULL. We don't
 				// need to read that from the file.
 				handleTable[i]._node = NULL;
 				f.seek(4, SEEK_CUR);
 				// For Discworld 2, read in the flags2 field
-				handleTable[i].flags2 = t2Flag ? f.readUint32LE() : 0;
+				handleTable[i].flags2 = t2Flag ? f.readUint32() : 0;
 			}
 
 			if (f.eos() || f.err()) {
@@ -233,7 +234,7 @@ void LoadCDGraphData(MEMHANDLE *pH) {
 	// clear the loading flag
 //	pH->filesize &= ~fLoading;
 
-	if (bytes != ((cdTopHandle-cdBaseHandle) & OFFSETMASK))
+	if (bytes != ((cdTopHandle - cdBaseHandle) & OFFSETMASK))
 		// file is corrupt
 		error(FILE_READ_ERROR, "CD play file");
 }
@@ -246,7 +247,9 @@ void LoadCDGraphData(MEMHANDLE *pH) {
  * @param next			Handle of end of range + 1
  */
 void LoadExtraGraphData(SCNHANDLE start, SCNHANDLE next) {
-	if (cdPlayFileNum == cdPlaySceneNum && start == cdBaseHandle)
+	// It's not clear that this can ever be true. See bug #3306020, DW2:
+	// Crash On Entering Sewers, for some background information.
+	if (cdPlaySceneNum == 0 && start == cdBaseHandle)
 		return;
 
 	OpenCDGraphFile();
